function o(e) {
  for (var c = e.length / 6 | 0, n = new Array(c), a = 0; a < c; ) n[a] = "#" + e.slice(a * 6, ++a * 6);
  return n;
}
const r = o("4e79a7f28e2ce1575976b7b259a14fedc949af7aa1ff9da79c755fbab0ab");
export {
  r as s
};
//# sourceMappingURL=Tableau10-D7jGxypv.js.map
