import { p as a, f as o } from "./flowDb-d35e309a-BaBjQEl3.js";
import { f as e, g as t } from "./styles-7383a064-BDRHALxK.js";
import { t as s } from "./main-8k4vh9Gc.js";
import "./graph-CalDMoQe.js";
import "./layout-DK4bM4A7.js";
const p = {
  parser: a,
  db: o,
  renderer: e,
  styles: t,
  init: (r) => {
    r.flowchart || (r.flowchart = {}), r.flowchart.arrowMarkerAbsolute = r.arrowMarkerAbsolute, s({ flowchart: { arrowMarkerAbsolute: r.arrowMarkerAbsolute } }), e.setConf(r.flowchart), o.clear(), o.setGen("gen-2");
  }
};
export {
  p as diagram
};
//# sourceMappingURL=flowDiagram-v2-49332944-Yvkjh7JA.js.map
