/* AGI.Green Chat component styles */
.agi-green-chat-send-button {
    position: absolute;
    right: 10px;
    bottom: 20px;
    height: 30px;
    width: 30px;
    padding: 10;
    border: none;
    background: none;
    cursor: pointer;
}

.agi-green-chat-input-container {
    position: relative;
    margin: 1rem;
    display: flex;
    align-items: flex-start;
    height: auto;
    min-height: 50px;
}

.agi-green-chat-send-button img {
    width: 100%;
    height: 100%;
}
