/**
 * ResizableLayout CSS
 * 
 * This file contains base styles for the ResizableLayout component,
 * defining the appearance of panes and splitters while providing 
 * hooks for app-specific theming.
 *
 * Applications can override these styles with higher specificity selectors
 * to change appearance without affecting resizing behavior.
 */

/* Base styles for ResizableLayout component */
.agi-green-layout-container {
  display: flex;
  width: 100%;
  height: 100%;
  overflow: hidden;
  position: relative;
}

.agi-green-pane {
  height: 100%;
  overflow: auto;
  position: relative;
  transition: none;
}

/* Splitter styling with grabbable handle */
.agi-green-splitter {
  width: 8px;
  background-color: #404040;
  cursor: col-resize;
  z-index: 10;
  position: relative;
  flex-shrink: 0;
}

/* Add handle for better visibility */
.agi-green-splitter::after {
  content: "";
  position: absolute;
  top: 50%;
  left: 50%;
  transform: translate(-50%, -50%);
  height: 60px;
  width: 2px;
  background-color: #777;
  border-radius: 1px;
}

.agi-green-splitter:hover,
.agi-green-splitter:active {
  background-color: #555;
}

.agi-green-splitter:hover::after,
.agi-green-splitter:active::after {
  background-color: #aaa;
}

/* Prevent text selection during resize */
body.agi-green-resizing {
  user-select: none;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  cursor: col-resize;
}
