import { ref as he, readonly as tW, getCurrentInstance as fi, onMounted as On, nextTick as Ut, watch as et, mergeProps as $e, openBlock as U, createElementBlock as ee, Fragment as gt, renderList as It, createBlock as Ae, resolveDynamicComponent as ze, createElementVNode as de, createCommentVNode as se, renderSlot as Me, toRefs as De, computed as N, provide as aa, onBeforeMount as Gu, onBeforeUpdate as iF, onUpdated as aF, onBeforeUnmount as pa, onUnmounted as l1, markRaw as Ll, inject as En, h as oF, reactive as u1, resolveComponent as Bt, createApp as WT, toDisplayString as zt, normalizeClass as re, createVNode as rn, unref as ks, withDirectives as Gn, withKeys as Zr, vModelText as sF, pushScopeId as lF, popScopeId as uF, resolveDirective as nW, vShow as Wi, normalizeStyle as am, withCtx as Qe, normalizeProps as bl, guardReactiveProps as cF, withModifiers as An, createSlots as nr, vModelCheckbox as M_, Teleport as rW, vModelSelect as dF, vModelRadio as P_, createTextVNode as qx } from "vue";
function i0(e, t) {
  var n = typeof Symbol < "u" && e[Symbol.iterator] || e["@@iterator"];
  if (!n) {
    if (Array.isArray(e) || (n = c1(e)) || t) {
      n && (e = n);
      var r = 0, i = function() {
      };
      return { s: i, n: function() {
        return r >= e.length ? { done: !0 } : { done: !1, value: e[r++] };
      }, e: function(u) {
        throw u;
      }, f: i };
    }
    throw new TypeError(`Invalid attempt to iterate non-iterable instance.
In order to be iterable, non-array objects must have a [Symbol.iterator]() method.`);
  }
  var a = !0, o = !1, s;
  return { s: function() {
    n = n.call(e);
  }, n: function() {
    var u = n.next();
    return a = u.done, u;
  }, e: function(u) {
    o = !0, s = u;
  }, f: function() {
    try {
      !a && n.return != null && n.return();
    } finally {
      if (o) throw s;
    }
  } };
}
function iW(e) {
  return sW(e) || oW(e) || c1(e) || aW();
}
function aW() {
  throw new TypeError(`Invalid attempt to spread non-iterable instance.
In order to be iterable, non-array objects must have a [Symbol.iterator]() method.`);
}
function oW(e) {
  if (typeof Symbol < "u" && e[Symbol.iterator] != null || e["@@iterator"] != null) return Array.from(e);
}
function sW(e) {
  if (Array.isArray(e)) return KT(e);
}
function Wf(e) {
  "@babel/helpers - typeof";
  return Wf = typeof Symbol == "function" && typeof Symbol.iterator == "symbol" ? function(t) {
    return typeof t;
  } : function(t) {
    return t && typeof Symbol == "function" && t.constructor === Symbol && t !== Symbol.prototype ? "symbol" : typeof t;
  }, Wf(e);
}
function a0(e, t) {
  return cW(e) || uW(e, t) || c1(e, t) || lW();
}
function lW() {
  throw new TypeError(`Invalid attempt to destructure non-iterable instance.
In order to be iterable, non-array objects must have a [Symbol.iterator]() method.`);
}
function c1(e, t) {
  if (e) {
    if (typeof e == "string") return KT(e, t);
    var n = Object.prototype.toString.call(e).slice(8, -1);
    if (n === "Object" && e.constructor && (n = e.constructor.name), n === "Map" || n === "Set") return Array.from(e);
    if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return KT(e, t);
  }
}
function KT(e, t) {
  (t == null || t > e.length) && (t = e.length);
  for (var n = 0, r = new Array(t); n < t; n++) r[n] = e[n];
  return r;
}
function uW(e, t) {
  var n = e == null ? null : typeof Symbol < "u" && e[Symbol.iterator] || e["@@iterator"];
  if (n != null) {
    var r, i, a, o, s = [], l = !0, u = !1;
    try {
      if (a = (n = n.call(e)).next, t !== 0) for (; !(l = (r = a.call(n)).done) && (s.push(r.value), s.length !== t); l = !0) ;
    } catch (c) {
      u = !0, i = c;
    } finally {
      try {
        if (!l && n.return != null && (o = n.return(), Object(o) !== o)) return;
      } finally {
        if (u) throw i;
      }
    }
    return s;
  }
}
function cW(e) {
  if (Array.isArray(e)) return e;
}
var on = {
  innerWidth: function(t) {
    if (t) {
      var n = t.offsetWidth, r = getComputedStyle(t);
      return n += parseFloat(r.paddingLeft) + parseFloat(r.paddingRight), n;
    }
    return 0;
  },
  width: function(t) {
    if (t) {
      var n = t.offsetWidth, r = getComputedStyle(t);
      return n -= parseFloat(r.paddingLeft) + parseFloat(r.paddingRight), n;
    }
    return 0;
  },
  getWindowScrollTop: function() {
    var t = document.documentElement;
    return (window.pageYOffset || t.scrollTop) - (t.clientTop || 0);
  },
  getWindowScrollLeft: function() {
    var t = document.documentElement;
    return (window.pageXOffset || t.scrollLeft) - (t.clientLeft || 0);
  },
  getOuterWidth: function(t, n) {
    if (t) {
      var r = t.offsetWidth;
      if (n) {
        var i = getComputedStyle(t);
        r += parseFloat(i.marginLeft) + parseFloat(i.marginRight);
      }
      return r;
    }
    return 0;
  },
  getOuterHeight: function(t, n) {
    if (t) {
      var r = t.offsetHeight;
      if (n) {
        var i = getComputedStyle(t);
        r += parseFloat(i.marginTop) + parseFloat(i.marginBottom);
      }
      return r;
    }
    return 0;
  },
  getClientHeight: function(t, n) {
    if (t) {
      var r = t.clientHeight;
      if (n) {
        var i = getComputedStyle(t);
        r += parseFloat(i.marginTop) + parseFloat(i.marginBottom);
      }
      return r;
    }
    return 0;
  },
  getViewport: function() {
    var t = window, n = document, r = n.documentElement, i = n.getElementsByTagName("body")[0], a = t.innerWidth || r.clientWidth || i.clientWidth, o = t.innerHeight || r.clientHeight || i.clientHeight;
    return {
      width: a,
      height: o
    };
  },
  getOffset: function(t) {
    if (t) {
      var n = t.getBoundingClientRect();
      return {
        top: n.top + (window.pageYOffset || document.documentElement.scrollTop || document.body.scrollTop || 0),
        left: n.left + (window.pageXOffset || document.documentElement.scrollLeft || document.body.scrollLeft || 0)
      };
    }
    return {
      top: "auto",
      left: "auto"
    };
  },
  index: function(t) {
    if (t)
      for (var n, r = (n = this.getParentNode(t)) === null || n === void 0 ? void 0 : n.childNodes, i = 0, a = 0; a < r.length; a++) {
        if (r[a] === t) return i;
        r[a].nodeType === 1 && i++;
      }
    return -1;
  },
  addMultipleClasses: function(t, n) {
    var r = this;
    t && n && [n].flat().filter(Boolean).forEach(function(i) {
      return i.split(" ").forEach(function(a) {
        return r.addClass(t, a);
      });
    });
  },
  removeMultipleClasses: function(t, n) {
    var r = this;
    t && n && [n].flat().filter(Boolean).forEach(function(i) {
      return i.split(" ").forEach(function(a) {
        return r.removeClass(t, a);
      });
    });
  },
  addClass: function(t, n) {
    t && n && !this.hasClass(t, n) && (t.classList ? t.classList.add(n) : t.className += " " + n);
  },
  removeClass: function(t, n) {
    t && n && (t.classList ? t.classList.remove(n) : t.className = t.className.replace(new RegExp("(^|\\b)" + n.split(" ").join("|") + "(\\b|$)", "gi"), " "));
  },
  hasClass: function(t, n) {
    return t ? t.classList ? t.classList.contains(n) : new RegExp("(^| )" + n + "( |$)", "gi").test(t.className) : !1;
  },
  addStyles: function(t) {
    var n = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : {};
    t && Object.entries(n).forEach(function(r) {
      var i = a0(r, 2), a = i[0], o = i[1];
      return t.style[a] = o;
    });
  },
  find: function(t, n) {
    return this.isElement(t) ? t.querySelectorAll(n) : [];
  },
  findSingle: function(t, n) {
    return this.isElement(t) ? t.querySelector(n) : null;
  },
  createElement: function(t) {
    var n = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : {};
    if (t) {
      var r = document.createElement(t);
      this.setAttributes(r, n);
      for (var i = arguments.length, a = new Array(i > 2 ? i - 2 : 0), o = 2; o < i; o++)
        a[o - 2] = arguments[o];
      return r.append.apply(r, a), r;
    }
  },
  setAttribute: function(t) {
    var n = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : "", r = arguments.length > 2 ? arguments[2] : void 0;
    this.isElement(t) && r !== null && r !== void 0 && t.setAttribute(n, r);
  },
  setAttributes: function(t) {
    var n = this, r = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : {};
    if (this.isElement(t)) {
      var i = function a(o, s) {
        var l, u, c = t != null && (l = t.$attrs) !== null && l !== void 0 && l[o] ? [t == null || (u = t.$attrs) === null || u === void 0 ? void 0 : u[o]] : [];
        return [s].flat().reduce(function(d, f) {
          if (f != null) {
            var h = Wf(f);
            if (h === "string" || h === "number")
              d.push(f);
            else if (h === "object") {
              var m = Array.isArray(f) ? a(o, f) : Object.entries(f).map(function(v) {
                var b = a0(v, 2), y = b[0], g = b[1];
                return o === "style" && (g || g === 0) ? "".concat(y.replace(/([a-z])([A-Z])/g, "$1-$2").toLowerCase(), ":").concat(g) : g ? y : void 0;
              });
              d = m.length ? d.concat(m.filter(function(v) {
                return !!v;
              })) : d;
            }
          }
          return d;
        }, c);
      };
      Object.entries(r).forEach(function(a) {
        var o = a0(a, 2), s = o[0], l = o[1];
        if (l != null) {
          var u = s.match(/^on(.+)/);
          u ? t.addEventListener(u[1].toLowerCase(), l) : s === "p-bind" ? n.setAttributes(t, l) : (l = s === "class" ? iW(new Set(i("class", l))).join(" ").trim() : s === "style" ? i("style", l).join(";").trim() : l, (t.$attrs = t.$attrs || {}) && (t.$attrs[s] = l), t.setAttribute(s, l));
        }
      });
    }
  },
  getAttribute: function(t, n) {
    if (this.isElement(t)) {
      var r = t.getAttribute(n);
      return isNaN(r) ? r === "true" || r === "false" ? r === "true" : r : +r;
    }
  },
  isAttributeEquals: function(t, n, r) {
    return this.isElement(t) ? this.getAttribute(t, n) === r : !1;
  },
  isAttributeNotEquals: function(t, n, r) {
    return !this.isAttributeEquals(t, n, r);
  },
  getHeight: function(t) {
    if (t) {
      var n = t.offsetHeight, r = getComputedStyle(t);
      return n -= parseFloat(r.paddingTop) + parseFloat(r.paddingBottom) + parseFloat(r.borderTopWidth) + parseFloat(r.borderBottomWidth), n;
    }
    return 0;
  },
  getWidth: function(t) {
    if (t) {
      var n = t.offsetWidth, r = getComputedStyle(t);
      return n -= parseFloat(r.paddingLeft) + parseFloat(r.paddingRight) + parseFloat(r.borderLeftWidth) + parseFloat(r.borderRightWidth), n;
    }
    return 0;
  },
  absolutePosition: function(t, n) {
    var r = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : !0;
    if (t) {
      var i = t.offsetParent ? {
        width: t.offsetWidth,
        height: t.offsetHeight
      } : this.getHiddenElementDimensions(t), a = i.height, o = i.width, s = n.offsetHeight, l = n.offsetWidth, u = n.getBoundingClientRect(), c = this.getWindowScrollTop(), d = this.getWindowScrollLeft(), f = this.getViewport(), h, m, v = "top";
      u.top + s + a > f.height ? (h = u.top + c - a, v = "bottom", h < 0 && (h = c)) : h = s + u.top + c, u.left + o > f.width ? m = Math.max(0, u.left + d + l - o) : m = u.left + d, t.style.top = h + "px", t.style.left = m + "px", t.style.transformOrigin = v, r && (t.style.marginTop = v === "bottom" ? "calc(var(--p-anchor-gutter) * -1)" : "calc(var(--p-anchor-gutter))");
    }
  },
  relativePosition: function(t, n) {
    var r = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : !0;
    if (t) {
      var i = t.offsetParent ? {
        width: t.offsetWidth,
        height: t.offsetHeight
      } : this.getHiddenElementDimensions(t), a = n.offsetHeight, o = n.getBoundingClientRect(), s = this.getViewport(), l, u, c = "top";
      o.top + a + i.height > s.height ? (l = -1 * i.height, c = "bottom", o.top + l < 0 && (l = -1 * o.top)) : l = a, i.width > s.width ? u = o.left * -1 : o.left + i.width > s.width ? u = (o.left + i.width - s.width) * -1 : u = 0, t.style.top = l + "px", t.style.left = u + "px", t.style.transformOrigin = c, r && (t.style.marginTop = c === "bottom" ? "calc(var(--p-anchor-gutter) * -1)" : "calc(var(--p-anchor-gutter))");
    }
  },
  nestedPosition: function(t, n) {
    if (t) {
      var r = t.parentElement, i = this.getOffset(r), a = this.getViewport(), o = t.offsetParent ? t.offsetWidth : this.getHiddenElementOuterWidth(t), s = this.getOuterWidth(r.children[0]), l;
      parseInt(i.left, 10) + s + o > a.width - this.calculateScrollbarWidth() ? parseInt(i.left, 10) < o ? n % 2 === 1 ? l = parseInt(i.left, 10) ? "-" + parseInt(i.left, 10) + "px" : "100%" : n % 2 === 0 && (l = a.width - o - this.calculateScrollbarWidth() + "px") : l = "-100%" : l = "100%", t.style.top = "0px", t.style.left = l;
    }
  },
  getParentNode: function(t) {
    var n = t == null ? void 0 : t.parentNode;
    return n && n instanceof ShadowRoot && n.host && (n = n.host), n;
  },
  getParents: function(t) {
    var n = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : [], r = this.getParentNode(t);
    return r === null ? n : this.getParents(r, n.concat([r]));
  },
  getScrollableParents: function(t) {
    var n = [];
    if (t) {
      var r = this.getParents(t), i = /(auto|scroll)/, a = function(b) {
        try {
          var y = window.getComputedStyle(b, null);
          return i.test(y.getPropertyValue("overflow")) || i.test(y.getPropertyValue("overflowX")) || i.test(y.getPropertyValue("overflowY"));
        } catch {
          return !1;
        }
      }, o = i0(r), s;
      try {
        for (o.s(); !(s = o.n()).done; ) {
          var l = s.value, u = l.nodeType === 1 && l.dataset.scrollselectors;
          if (u) {
            var c = u.split(","), d = i0(c), f;
            try {
              for (d.s(); !(f = d.n()).done; ) {
                var h = f.value, m = this.findSingle(l, h);
                m && a(m) && n.push(m);
              }
            } catch (v) {
              d.e(v);
            } finally {
              d.f();
            }
          }
          l.nodeType !== 9 && a(l) && n.push(l);
        }
      } catch (v) {
        o.e(v);
      } finally {
        o.f();
      }
    }
    return n;
  },
  getHiddenElementOuterHeight: function(t) {
    if (t) {
      t.style.visibility = "hidden", t.style.display = "block";
      var n = t.offsetHeight;
      return t.style.display = "none", t.style.visibility = "visible", n;
    }
    return 0;
  },
  getHiddenElementOuterWidth: function(t) {
    if (t) {
      t.style.visibility = "hidden", t.style.display = "block";
      var n = t.offsetWidth;
      return t.style.display = "none", t.style.visibility = "visible", n;
    }
    return 0;
  },
  getHiddenElementDimensions: function(t) {
    if (t) {
      var n = {};
      return t.style.visibility = "hidden", t.style.display = "block", n.width = t.offsetWidth, n.height = t.offsetHeight, t.style.display = "none", t.style.visibility = "visible", n;
    }
    return 0;
  },
  fadeIn: function(t, n) {
    if (t) {
      t.style.opacity = 0;
      var r = +/* @__PURE__ */ new Date(), i = 0, a = function o() {
        i = +t.style.opacity + ((/* @__PURE__ */ new Date()).getTime() - r) / n, t.style.opacity = i, r = +/* @__PURE__ */ new Date(), +i < 1 && (window.requestAnimationFrame && requestAnimationFrame(o) || setTimeout(o, 16));
      };
      a();
    }
  },
  fadeOut: function(t, n) {
    if (t)
      var r = 1, i = 50, a = n, o = i / a, s = setInterval(function() {
        r -= o, r <= 0 && (r = 0, clearInterval(s)), t.style.opacity = r;
      }, i);
  },
  getUserAgent: function() {
    return navigator.userAgent;
  },
  appendChild: function(t, n) {
    if (this.isElement(n)) n.appendChild(t);
    else if (n.el && n.elElement) n.elElement.appendChild(t);
    else throw new Error("Cannot append " + n + " to " + t);
  },
  isElement: function(t) {
    return (typeof HTMLElement > "u" ? "undefined" : Wf(HTMLElement)) === "object" ? t instanceof HTMLElement : t && Wf(t) === "object" && t !== null && t.nodeType === 1 && typeof t.nodeName == "string";
  },
  scrollInView: function(t, n) {
    var r = getComputedStyle(t).getPropertyValue("borderTopWidth"), i = r ? parseFloat(r) : 0, a = getComputedStyle(t).getPropertyValue("paddingTop"), o = a ? parseFloat(a) : 0, s = t.getBoundingClientRect(), l = n.getBoundingClientRect(), u = l.top + document.body.scrollTop - (s.top + document.body.scrollTop) - i - o, c = t.scrollTop, d = t.clientHeight, f = this.getOuterHeight(n);
    u < 0 ? t.scrollTop = c + u : u + f > d && (t.scrollTop = c + u - d + f);
  },
  clearSelection: function() {
    if (window.getSelection)
      window.getSelection().empty ? window.getSelection().empty() : window.getSelection().removeAllRanges && window.getSelection().rangeCount > 0 && window.getSelection().getRangeAt(0).getClientRects().length > 0 && window.getSelection().removeAllRanges();
    else if (document.selection && document.selection.empty)
      try {
        document.selection.empty();
      } catch {
      }
  },
  getSelection: function() {
    return window.getSelection ? window.getSelection().toString() : document.getSelection ? document.getSelection().toString() : document.selection ? document.selection.createRange().text : null;
  },
  calculateScrollbarWidth: function() {
    if (this.calculatedScrollbarWidth != null) return this.calculatedScrollbarWidth;
    var t = document.createElement("div");
    this.addStyles(t, {
      width: "100px",
      height: "100px",
      overflow: "scroll",
      position: "absolute",
      top: "-9999px"
    }), document.body.appendChild(t);
    var n = t.offsetWidth - t.clientWidth;
    return document.body.removeChild(t), this.calculatedScrollbarWidth = n, n;
  },
  calculateBodyScrollbarWidth: function() {
    return window.innerWidth - document.documentElement.offsetWidth;
  },
  getBrowser: function() {
    if (!this.browser) {
      var t = this.resolveUserAgent();
      this.browser = {}, t.browser && (this.browser[t.browser] = !0, this.browser.version = t.version), this.browser.chrome ? this.browser.webkit = !0 : this.browser.webkit && (this.browser.safari = !0);
    }
    return this.browser;
  },
  resolveUserAgent: function() {
    var t = navigator.userAgent.toLowerCase(), n = /(chrome)[ ]([\w.]+)/.exec(t) || /(webkit)[ ]([\w.]+)/.exec(t) || /(opera)(?:.*version|)[ ]([\w.]+)/.exec(t) || /(msie) ([\w.]+)/.exec(t) || t.indexOf("compatible") < 0 && /(mozilla)(?:.*? rv:([\w.]+)|)/.exec(t) || [];
    return {
      browser: n[1] || "",
      version: n[2] || "0"
    };
  },
  isVisible: function(t) {
    return t && t.offsetParent != null;
  },
  invokeElementMethod: function(t, n, r) {
    t[n].apply(t, r);
  },
  isExist: function(t) {
    return !!(t !== null && typeof t < "u" && t.nodeName && this.getParentNode(t));
  },
  isClient: function() {
    return !!(typeof window < "u" && window.document && window.document.createElement);
  },
  focus: function(t, n) {
    t && document.activeElement !== t && t.focus(n);
  },
  isFocusableElement: function(t) {
    var n = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : "";
    return this.isElement(t) ? t.matches('button:not([tabindex = "-1"]):not([disabled]):not([style*="display:none"]):not([hidden])'.concat(n, `,
                [href][clientHeight][clientWidth]:not([tabindex = "-1"]):not([disabled]):not([style*="display:none"]):not([hidden])`).concat(n, `,
                input:not([tabindex = "-1"]):not([disabled]):not([style*="display:none"]):not([hidden])`).concat(n, `,
                select:not([tabindex = "-1"]):not([disabled]):not([style*="display:none"]):not([hidden])`).concat(n, `,
                textarea:not([tabindex = "-1"]):not([disabled]):not([style*="display:none"]):not([hidden])`).concat(n, `,
                [tabIndex]:not([tabIndex = "-1"]):not([disabled]):not([style*="display:none"]):not([hidden])`).concat(n, `,
                [contenteditable]:not([tabIndex = "-1"]):not([disabled]):not([style*="display:none"]):not([hidden])`).concat(n)) : !1;
  },
  getFocusableElements: function(t) {
    var n = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : "", r = this.find(t, 'button:not([tabindex = "-1"]):not([disabled]):not([style*="display:none"]):not([hidden])'.concat(n, `,
                [href][clientHeight][clientWidth]:not([tabindex = "-1"]):not([disabled]):not([style*="display:none"]):not([hidden])`).concat(n, `,
                input:not([tabindex = "-1"]):not([disabled]):not([style*="display:none"]):not([hidden])`).concat(n, `,
                select:not([tabindex = "-1"]):not([disabled]):not([style*="display:none"]):not([hidden])`).concat(n, `,
                textarea:not([tabindex = "-1"]):not([disabled]):not([style*="display:none"]):not([hidden])`).concat(n, `,
                [tabIndex]:not([tabIndex = "-1"]):not([disabled]):not([style*="display:none"]):not([hidden])`).concat(n, `,
                [contenteditable]:not([tabIndex = "-1"]):not([disabled]):not([style*="display:none"]):not([hidden])`).concat(n)), i = [], a = i0(r), o;
    try {
      for (a.s(); !(o = a.n()).done; ) {
        var s = o.value;
        getComputedStyle(s).display != "none" && getComputedStyle(s).visibility != "hidden" && i.push(s);
      }
    } catch (l) {
      a.e(l);
    } finally {
      a.f();
    }
    return i;
  },
  getFirstFocusableElement: function(t, n) {
    var r = this.getFocusableElements(t, n);
    return r.length > 0 ? r[0] : null;
  },
  getLastFocusableElement: function(t, n) {
    var r = this.getFocusableElements(t, n);
    return r.length > 0 ? r[r.length - 1] : null;
  },
  getNextFocusableElement: function(t, n, r) {
    var i = this.getFocusableElements(t, r), a = i.length > 0 ? i.findIndex(function(s) {
      return s === n;
    }) : -1, o = a > -1 && i.length >= a + 1 ? a + 1 : -1;
    return o > -1 ? i[o] : null;
  },
  getPreviousElementSibling: function(t, n) {
    for (var r = t.previousElementSibling; r; ) {
      if (r.matches(n))
        return r;
      r = r.previousElementSibling;
    }
    return null;
  },
  getNextElementSibling: function(t, n) {
    for (var r = t.nextElementSibling; r; ) {
      if (r.matches(n))
        return r;
      r = r.nextElementSibling;
    }
    return null;
  },
  isClickable: function(t) {
    if (t) {
      var n = t.nodeName, r = t.parentElement && t.parentElement.nodeName;
      return n === "INPUT" || n === "TEXTAREA" || n === "BUTTON" || n === "A" || r === "INPUT" || r === "TEXTAREA" || r === "BUTTON" || r === "A" || !!t.closest(".p-button, .p-checkbox, .p-radiobutton");
    }
    return !1;
  },
  applyStyle: function(t, n) {
    if (typeof n == "string")
      t.style.cssText = n;
    else
      for (var r in n)
        t.style[r] = n[r];
  },
  isIOS: function() {
    return /iPad|iPhone|iPod/.test(navigator.userAgent) && !window.MSStream;
  },
  isAndroid: function() {
    return /(android)/i.test(navigator.userAgent);
  },
  isTouchDevice: function() {
    return "ontouchstart" in window || navigator.maxTouchPoints > 0 || navigator.msMaxTouchPoints > 0;
  },
  hasCSSAnimation: function(t) {
    if (t) {
      var n = getComputedStyle(t), r = parseFloat(n.getPropertyValue("animation-duration") || "0");
      return r > 0;
    }
    return !1;
  },
  hasCSSTransition: function(t) {
    if (t) {
      var n = getComputedStyle(t), r = parseFloat(n.getPropertyValue("transition-duration") || "0");
      return r > 0;
    }
    return !1;
  },
  exportCSV: function(t, n) {
    var r = new Blob([t], {
      type: "application/csv;charset=utf-8;"
    });
    if (window.navigator.msSaveOrOpenBlob)
      navigator.msSaveOrOpenBlob(r, n + ".csv");
    else {
      var i = document.createElement("a");
      i.download !== void 0 ? (i.setAttribute("href", URL.createObjectURL(r)), i.setAttribute("download", n + ".csv"), i.style.display = "none", document.body.appendChild(i), i.click(), document.body.removeChild(i)) : (t = "data:text/csv;charset=utf-8," + t, window.open(encodeURI(t)));
    }
  },
  blockBodyScroll: function() {
    var t = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : "p-overflow-hidden";
    document.body.style.setProperty("--scrollbar-width", this.calculateBodyScrollbarWidth() + "px"), this.addClass(document.body, t);
  },
  unblockBodyScroll: function() {
    var t = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : "p-overflow-hidden";
    document.body.style.removeProperty("--scrollbar-width"), this.removeClass(document.body, t);
  }
};
function Gx(e, t) {
  return pW(e) || fW(e, t) || d1(e, t) || dW();
}
function dW() {
  throw new TypeError(`Invalid attempt to destructure non-iterable instance.
In order to be iterable, non-array objects must have a [Symbol.iterator]() method.`);
}
function fW(e, t) {
  var n = e == null ? null : typeof Symbol < "u" && e[Symbol.iterator] || e["@@iterator"];
  if (n != null) {
    var r, i, a, o, s = [], l = !0, u = !1;
    try {
      if (a = (n = n.call(e)).next, t !== 0) for (; !(l = (r = a.call(n)).done) && (s.push(r.value), s.length !== t); l = !0) ;
    } catch (c) {
      u = !0, i = c;
    } finally {
      try {
        if (!l && n.return != null && (o = n.return(), Object(o) !== o)) return;
      } finally {
        if (u) throw i;
      }
    }
    return s;
  }
}
function pW(e) {
  if (Array.isArray(e)) return e;
}
function Yx(e) {
  return gW(e) || hW(e) || d1(e) || mW();
}
function mW() {
  throw new TypeError(`Invalid attempt to spread non-iterable instance.
In order to be iterable, non-array objects must have a [Symbol.iterator]() method.`);
}
function hW(e) {
  if (typeof Symbol < "u" && e[Symbol.iterator] != null || e["@@iterator"] != null) return Array.from(e);
}
function gW(e) {
  if (Array.isArray(e)) return jT(e);
}
function o0(e, t) {
  var n = typeof Symbol < "u" && e[Symbol.iterator] || e["@@iterator"];
  if (!n) {
    if (Array.isArray(e) || (n = d1(e)) || t) {
      n && (e = n);
      var r = 0, i = function() {
      };
      return { s: i, n: function() {
        return r >= e.length ? { done: !0 } : { done: !1, value: e[r++] };
      }, e: function(u) {
        throw u;
      }, f: i };
    }
    throw new TypeError(`Invalid attempt to iterate non-iterable instance.
In order to be iterable, non-array objects must have a [Symbol.iterator]() method.`);
  }
  var a = !0, o = !1, s;
  return { s: function() {
    n = n.call(e);
  }, n: function() {
    var u = n.next();
    return a = u.done, u;
  }, e: function(u) {
    o = !0, s = u;
  }, f: function() {
    try {
      !a && n.return != null && n.return();
    } finally {
      if (o) throw s;
    }
  } };
}
function d1(e, t) {
  if (e) {
    if (typeof e == "string") return jT(e, t);
    var n = Object.prototype.toString.call(e).slice(8, -1);
    if (n === "Object" && e.constructor && (n = e.constructor.name), n === "Map" || n === "Set") return Array.from(e);
    if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return jT(e, t);
  }
}
function jT(e, t) {
  (t == null || t > e.length) && (t = e.length);
  for (var n = 0, r = new Array(t); n < t; n++) r[n] = e[n];
  return r;
}
function Kf(e) {
  "@babel/helpers - typeof";
  return Kf = typeof Symbol == "function" && typeof Symbol.iterator == "symbol" ? function(t) {
    return typeof t;
  } : function(t) {
    return t && typeof Symbol == "function" && t.constructor === Symbol && t !== Symbol.prototype ? "symbol" : typeof t;
  }, Kf(e);
}
var cn = {
  equals: function(t, n, r) {
    return r ? this.resolveFieldData(t, r) === this.resolveFieldData(n, r) : this.deepEquals(t, n);
  },
  deepEquals: function(t, n) {
    if (t === n) return !0;
    if (t && n && Kf(t) == "object" && Kf(n) == "object") {
      var r = Array.isArray(t), i = Array.isArray(n), a, o, s;
      if (r && i) {
        if (o = t.length, o != n.length) return !1;
        for (a = o; a-- !== 0; ) if (!this.deepEquals(t[a], n[a])) return !1;
        return !0;
      }
      if (r != i) return !1;
      var l = t instanceof Date, u = n instanceof Date;
      if (l != u) return !1;
      if (l && u) return t.getTime() == n.getTime();
      var c = t instanceof RegExp, d = n instanceof RegExp;
      if (c != d) return !1;
      if (c && d) return t.toString() == n.toString();
      var f = Object.keys(t);
      if (o = f.length, o !== Object.keys(n).length) return !1;
      for (a = o; a-- !== 0; ) if (!Object.prototype.hasOwnProperty.call(n, f[a])) return !1;
      for (a = o; a-- !== 0; )
        if (s = f[a], !this.deepEquals(t[s], n[s])) return !1;
      return !0;
    }
    return t !== t && n !== n;
  },
  resolveFieldData: function(t, n) {
    if (!t || !n)
      return null;
    try {
      var r = t[n];
      if (this.isNotEmpty(r)) return r;
    } catch {
    }
    if (Object.keys(t).length) {
      if (this.isFunction(n))
        return n(t);
      if (n.indexOf(".") === -1)
        return t[n];
      for (var i = n.split("."), a = t, o = 0, s = i.length; o < s; ++o) {
        if (a == null)
          return null;
        a = a[i[o]];
      }
      return a;
    }
    return null;
  },
  getItemValue: function(t) {
    for (var n = arguments.length, r = new Array(n > 1 ? n - 1 : 0), i = 1; i < n; i++)
      r[i - 1] = arguments[i];
    return this.isFunction(t) ? t.apply(void 0, r) : t;
  },
  filter: function(t, n, r) {
    var i = [];
    if (t) {
      var a = o0(t), o;
      try {
        for (a.s(); !(o = a.n()).done; ) {
          var s = o.value, l = o0(n), u;
          try {
            for (l.s(); !(u = l.n()).done; ) {
              var c = u.value;
              if (String(this.resolveFieldData(s, c)).toLowerCase().indexOf(r.toLowerCase()) > -1) {
                i.push(s);
                break;
              }
            }
          } catch (d) {
            l.e(d);
          } finally {
            l.f();
          }
        }
      } catch (d) {
        a.e(d);
      } finally {
        a.f();
      }
    }
    return i;
  },
  reorderArray: function(t, n, r) {
    t && n !== r && (r >= t.length && (r %= t.length, n %= t.length), t.splice(r, 0, t.splice(n, 1)[0]));
  },
  findIndexInList: function(t, n) {
    var r = -1;
    if (n) {
      for (var i = 0; i < n.length; i++)
        if (n[i] === t) {
          r = i;
          break;
        }
    }
    return r;
  },
  contains: function(t, n) {
    if (t != null && n && n.length) {
      var r = o0(n), i;
      try {
        for (r.s(); !(i = r.n()).done; ) {
          var a = i.value;
          if (this.equals(t, a)) return !0;
        }
      } catch (o) {
        r.e(o);
      } finally {
        r.f();
      }
    }
    return !1;
  },
  insertIntoOrderedArray: function(t, n, r, i) {
    if (r.length > 0) {
      for (var a = !1, o = 0; o < r.length; o++) {
        var s = this.findIndexInList(r[o], i);
        if (s > n) {
          r.splice(o, 0, t), a = !0;
          break;
        }
      }
      a || r.push(t);
    } else
      r.push(t);
  },
  removeAccents: function(t) {
    return t && t.search(/[\xC0-\xFF]/g) > -1 && (t = t.replace(/[\xC0-\xC5]/g, "A").replace(/[\xC6]/g, "AE").replace(/[\xC7]/g, "C").replace(/[\xC8-\xCB]/g, "E").replace(/[\xCC-\xCF]/g, "I").replace(/[\xD0]/g, "D").replace(/[\xD1]/g, "N").replace(/[\xD2-\xD6\xD8]/g, "O").replace(/[\xD9-\xDC]/g, "U").replace(/[\xDD]/g, "Y").replace(/[\xDE]/g, "P").replace(/[\xE0-\xE5]/g, "a").replace(/[\xE6]/g, "ae").replace(/[\xE7]/g, "c").replace(/[\xE8-\xEB]/g, "e").replace(/[\xEC-\xEF]/g, "i").replace(/[\xF1]/g, "n").replace(/[\xF2-\xF6\xF8]/g, "o").replace(/[\xF9-\xFC]/g, "u").replace(/[\xFE]/g, "p").replace(/[\xFD\xFF]/g, "y")), t;
  },
  getVNodeProp: function(t, n) {
    if (t) {
      var r = t.props;
      if (r) {
        var i = n.replace(/([a-z])([A-Z])/g, "$1-$2").toLowerCase(), a = Object.prototype.hasOwnProperty.call(r, i) ? i : n;
        return t.type.extends.props[n].type === Boolean && r[a] === "" ? !0 : r[a];
      }
    }
    return null;
  },
  toFlatCase: function(t) {
    return this.isString(t) ? t.replace(/(-|_)/g, "").toLowerCase() : t;
  },
  toKebabCase: function(t) {
    return this.isString(t) ? t.replace(/(_)/g, "-").replace(/[A-Z]/g, function(n, r) {
      return r === 0 ? n : "-" + n.toLowerCase();
    }).toLowerCase() : t;
  },
  toCapitalCase: function(t) {
    return this.isString(t, {
      empty: !1
    }) ? t[0].toUpperCase() + t.slice(1) : t;
  },
  isEmpty: function(t) {
    return t == null || t === "" || Array.isArray(t) && t.length === 0 || !(t instanceof Date) && Kf(t) === "object" && Object.keys(t).length === 0;
  },
  isNotEmpty: function(t) {
    return !this.isEmpty(t);
  },
  isFunction: function(t) {
    return !!(t && t.constructor && t.call && t.apply);
  },
  isObject: function(t) {
    var n = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : !0;
    return t instanceof Object && t.constructor === Object && (n || Object.keys(t).length !== 0);
  },
  isDate: function(t) {
    return t instanceof Date && t.constructor === Date;
  },
  isArray: function(t) {
    var n = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : !0;
    return Array.isArray(t) && (n || t.length !== 0);
  },
  isString: function(t) {
    var n = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : !0;
    return typeof t == "string" && (n || t !== "");
  },
  isPrintableCharacter: function() {
    var t = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : "";
    return this.isNotEmpty(t) && t.length === 1 && t.match(/\S| /);
  },
  /**
   * Firefox-v103 does not currently support the "findLast" method. It is stated that this method will be supported with Firefox-v104.
   * https://caniuse.com/mdn-javascript_builtins_array_findlast
   */
  findLast: function(t, n) {
    var r;
    if (this.isNotEmpty(t))
      try {
        r = t.findLast(n);
      } catch {
        r = Yx(t).reverse().find(n);
      }
    return r;
  },
  /**
   * Firefox-v103 does not currently support the "findLastIndex" method. It is stated that this method will be supported with Firefox-v104.
   * https://caniuse.com/mdn-javascript_builtins_array_findlastindex
   */
  findLastIndex: function(t, n) {
    var r = -1;
    if (this.isNotEmpty(t))
      try {
        r = t.findLastIndex(n);
      } catch {
        r = t.lastIndexOf(Yx(t).reverse().find(n));
      }
    return r;
  },
  sort: function(t, n) {
    var r = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : 1, i = arguments.length > 3 ? arguments[3] : void 0, a = arguments.length > 4 && arguments[4] !== void 0 ? arguments[4] : 1, o = this.compare(t, n, i, r), s = r;
    return (this.isEmpty(t) || this.isEmpty(n)) && (s = a === 1 ? r : a), s * o;
  },
  compare: function(t, n, r) {
    var i = arguments.length > 3 && arguments[3] !== void 0 ? arguments[3] : 1, a = -1, o = this.isEmpty(t), s = this.isEmpty(n);
    return o && s ? a = 0 : o ? a = i : s ? a = -i : typeof t == "string" && typeof n == "string" ? a = r(t, n) : a = t < n ? -1 : t > n ? 1 : 0, a;
  },
  localeComparator: function() {
    return new Intl.Collator(void 0, {
      numeric: !0
    }).compare;
  },
  nestedKeys: function() {
    var t = this, n = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : {}, r = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : "";
    return Object.entries(n).reduce(function(i, a) {
      var o = Gx(a, 2), s = o[0], l = o[1], u = r ? "".concat(r, ".").concat(s) : s;
      return t.isObject(l) ? i = i.concat(t.nestedKeys(l, u)) : i.push(u), i;
    }, []);
  },
  stringify: function(t) {
    var n = this, r = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : 2, i = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : 0, a = " ".repeat(i), o = " ".repeat(i + r);
    return this.isArray(t) ? "[" + t.map(function(s) {
      return n.stringify(s, r, i + r);
    }).join(", ") + "]" : this.isDate(t) ? t.toISOString() : this.isFunction(t) ? t.toString() : this.isObject(t) ? `{
` + Object.entries(t).map(function(s) {
      var l = Gx(s, 2), u = l[0], c = l[1];
      return "".concat(o).concat(u, ": ").concat(n.stringify(c, r, i + r));
    }).join(`,
`) + `
`.concat(a) + "}" : JSON.stringify(t);
  }
}, Hx = 0;
function zx() {
  var e = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : "pv_id_";
  return Hx++, "".concat(e).concat(Hx);
}
function mp(e) {
  "@babel/helpers - typeof";
  return mp = typeof Symbol == "function" && typeof Symbol.iterator == "symbol" ? function(t) {
    return typeof t;
  } : function(t) {
    return t && typeof Symbol == "function" && t.constructor === Symbol && t !== Symbol.prototype ? "symbol" : typeof t;
  }, mp(e);
}
function Vx(e, t) {
  var n = Object.keys(e);
  if (Object.getOwnPropertySymbols) {
    var r = Object.getOwnPropertySymbols(e);
    t && (r = r.filter(function(i) {
      return Object.getOwnPropertyDescriptor(e, i).enumerable;
    })), n.push.apply(n, r);
  }
  return n;
}
function Wx(e) {
  for (var t = 1; t < arguments.length; t++) {
    var n = arguments[t] != null ? arguments[t] : {};
    t % 2 ? Vx(Object(n), !0).forEach(function(r) {
      _W(e, r, n[r]);
    }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(n)) : Vx(Object(n)).forEach(function(r) {
      Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(n, r));
    });
  }
  return e;
}
function _W(e, t, n) {
  return t = vW(t), t in e ? Object.defineProperty(e, t, { value: n, enumerable: !0, configurable: !0, writable: !0 }) : e[t] = n, e;
}
function vW(e) {
  var t = bW(e, "string");
  return mp(t) == "symbol" ? t : String(t);
}
function bW(e, t) {
  if (mp(e) != "object" || !e) return e;
  var n = e[Symbol.toPrimitive];
  if (n !== void 0) {
    var r = n.call(e, t || "default");
    if (mp(r) != "object") return r;
    throw new TypeError("@@toPrimitive must return a primitive value.");
  }
  return (t === "string" ? String : Number)(e);
}
function EW(e) {
  var t = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : !0;
  fi() ? On(e) : t ? e() : Ut(e);
}
var SW = 0;
function fF(e) {
  var t = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : {}, n = he(!1), r = he(e), i = he(null), a = on.isClient() ? window.document : void 0, o = t.document, s = o === void 0 ? a : o, l = t.immediate, u = l === void 0 ? !0 : l, c = t.manual, d = c === void 0 ? !1 : c, f = t.name, h = f === void 0 ? "style_".concat(++SW) : f, m = t.id, v = m === void 0 ? void 0 : m, b = t.media, y = b === void 0 ? void 0 : b, g = t.nonce, E = g === void 0 ? void 0 : g, S = t.props, C = S === void 0 ? {} : S, T = function() {
  }, O = function(q) {
    var $ = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : {};
    if (s) {
      var P = Wx(Wx({}, C), $), Y = P.name || h, L = P.id || v, x = P.nonce || E;
      i.value = s.querySelector('style[data-primevue-style-id="'.concat(Y, '"]')) || s.getElementById(L) || s.createElement("style"), i.value.isConnected || (r.value = q || e, on.setAttributes(i.value, {
        type: "text/css",
        id: L,
        media: y,
        nonce: x
      }), s.head.appendChild(i.value), on.setAttribute(i.value, "data-primevue-style-id", h), on.setAttributes(i.value, P)), !n.value && (T = et(r, function(I) {
        i.value.textContent = I;
      }, {
        immediate: !0
      }), n.value = !0);
    }
  }, R = function() {
    !s || !n.value || (T(), on.isExist(i.value) && s.head.removeChild(i.value), n.value = !1);
  };
  return u && !d && EW(O), {
    id: v,
    name: h,
    css: r,
    unload: R,
    load: O,
    isLoaded: tW(n)
  };
}
function hp(e) {
  "@babel/helpers - typeof";
  return hp = typeof Symbol == "function" && typeof Symbol.iterator == "symbol" ? function(t) {
    return typeof t;
  } : function(t) {
    return t && typeof Symbol == "function" && t.constructor === Symbol && t !== Symbol.prototype ? "symbol" : typeof t;
  }, hp(e);
}
function yW(e, t) {
  return OW(e) || AW(e, t) || CW(e, t) || TW();
}
function TW() {
  throw new TypeError(`Invalid attempt to destructure non-iterable instance.
In order to be iterable, non-array objects must have a [Symbol.iterator]() method.`);
}
function CW(e, t) {
  if (e) {
    if (typeof e == "string") return Kx(e, t);
    var n = Object.prototype.toString.call(e).slice(8, -1);
    if (n === "Object" && e.constructor && (n = e.constructor.name), n === "Map" || n === "Set") return Array.from(e);
    if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return Kx(e, t);
  }
}
function Kx(e, t) {
  (t == null || t > e.length) && (t = e.length);
  for (var n = 0, r = new Array(t); n < t; n++) r[n] = e[n];
  return r;
}
function AW(e, t) {
  var n = e == null ? null : typeof Symbol < "u" && e[Symbol.iterator] || e["@@iterator"];
  if (n != null) {
    var r, i, a, o, s = [], l = !0, u = !1;
    try {
      if (a = (n = n.call(e)).next, t !== 0) for (; !(l = (r = a.call(n)).done) && (s.push(r.value), s.length !== t); l = !0) ;
    } catch (c) {
      u = !0, i = c;
    } finally {
      try {
        if (!l && n.return != null && (o = n.return(), Object(o) !== o)) return;
      } finally {
        if (u) throw i;
      }
    }
    return s;
  }
}
function OW(e) {
  if (Array.isArray(e)) return e;
}
function jx(e, t) {
  var n = Object.keys(e);
  if (Object.getOwnPropertySymbols) {
    var r = Object.getOwnPropertySymbols(e);
    t && (r = r.filter(function(i) {
      return Object.getOwnPropertyDescriptor(e, i).enumerable;
    })), n.push.apply(n, r);
  }
  return n;
}
function s0(e) {
  for (var t = 1; t < arguments.length; t++) {
    var n = arguments[t] != null ? arguments[t] : {};
    t % 2 ? jx(Object(n), !0).forEach(function(r) {
      RW(e, r, n[r]);
    }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(n)) : jx(Object(n)).forEach(function(r) {
      Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(n, r));
    });
  }
  return e;
}
function RW(e, t, n) {
  return t = wW(t), t in e ? Object.defineProperty(e, t, { value: n, enumerable: !0, configurable: !0, writable: !0 }) : e[t] = n, e;
}
function wW(e) {
  var t = xW(e, "string");
  return hp(t) == "symbol" ? t : String(t);
}
function xW(e, t) {
  if (hp(e) != "object" || !e) return e;
  var n = e[Symbol.toPrimitive];
  if (n !== void 0) {
    var r = n.call(e, t || "default");
    if (hp(r) != "object") return r;
    throw new TypeError("@@toPrimitive must return a primitive value.");
  }
  return (t === "string" ? String : Number)(e);
}
var NW = `
.p-hidden-accessible {
    border: 0;
    clip: rect(0 0 0 0);
    height: 1px;
    margin: -1px;
    overflow: hidden;
    padding: 0;
    position: absolute;
    width: 1px;
}

.p-hidden-accessible input,
.p-hidden-accessible select {
    transform: scale(0);
}

.p-overflow-hidden {
    overflow: hidden;
    padding-right: var(--scrollbar-width);
}
`, DW = {}, IW = {}, Wo = {
  name: "base",
  css: NW,
  classes: DW,
  inlineStyles: IW,
  loadStyle: function() {
    var t = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : {};
    return this.css ? fF(this.css, s0({
      name: this.name
    }, t)) : {};
  },
  getStyleSheet: function() {
    var t = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : "", n = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : {};
    if (this.css) {
      var r = Object.entries(n).reduce(function(i, a) {
        var o = yW(a, 2), s = o[0], l = o[1];
        return i.push("".concat(s, '="').concat(l, '"')) && i;
      }, []).join(" ");
      return '<style type="text/css" data-primevue-style-id="'.concat(this.name, '" ').concat(r, ">").concat(this.css).concat(t, "</style>");
    }
    return "";
  },
  extend: function(t) {
    return s0(s0({}, this), {}, {
      css: void 0
    }, t);
  }
};
function gp(e) {
  "@babel/helpers - typeof";
  return gp = typeof Symbol == "function" && typeof Symbol.iterator == "symbol" ? function(t) {
    return typeof t;
  } : function(t) {
    return t && typeof Symbol == "function" && t.constructor === Symbol && t !== Symbol.prototype ? "symbol" : typeof t;
  }, gp(e);
}
function Qx(e, t) {
  var n = Object.keys(e);
  if (Object.getOwnPropertySymbols) {
    var r = Object.getOwnPropertySymbols(e);
    t && (r = r.filter(function(i) {
      return Object.getOwnPropertyDescriptor(e, i).enumerable;
    })), n.push.apply(n, r);
  }
  return n;
}
function LW(e) {
  for (var t = 1; t < arguments.length; t++) {
    var n = arguments[t] != null ? arguments[t] : {};
    t % 2 ? Qx(Object(n), !0).forEach(function(r) {
      kW(e, r, n[r]);
    }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(n)) : Qx(Object(n)).forEach(function(r) {
      Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(n, r));
    });
  }
  return e;
}
function kW(e, t, n) {
  return t = MW(t), t in e ? Object.defineProperty(e, t, { value: n, enumerable: !0, configurable: !0, writable: !0 }) : e[t] = n, e;
}
function MW(e) {
  var t = PW(e, "string");
  return gp(t) == "symbol" ? t : String(t);
}
function PW(e, t) {
  if (gp(e) != "object" || !e) return e;
  var n = e[Symbol.toPrimitive];
  if (n !== void 0) {
    var r = n.call(e, t || "default");
    if (gp(r) != "object") return r;
    throw new TypeError("@@toPrimitive must return a primitive value.");
  }
  return (t === "string" ? String : Number)(e);
}
var l0 = Wo.extend({
  name: "common",
  loadGlobalStyle: function(t) {
    var n = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : {};
    return fF(t, LW({
      name: "global"
    }, n));
  }
});
function _p(e) {
  "@babel/helpers - typeof";
  return _p = typeof Symbol == "function" && typeof Symbol.iterator == "symbol" ? function(t) {
    return typeof t;
  } : function(t) {
    return t && typeof Symbol == "function" && t.constructor === Symbol && t !== Symbol.prototype ? "symbol" : typeof t;
  }, _p(e);
}
function Xx(e, t) {
  var n = Object.keys(e);
  if (Object.getOwnPropertySymbols) {
    var r = Object.getOwnPropertySymbols(e);
    t && (r = r.filter(function(i) {
      return Object.getOwnPropertyDescriptor(e, i).enumerable;
    })), n.push.apply(n, r);
  }
  return n;
}
function fr(e) {
  for (var t = 1; t < arguments.length; t++) {
    var n = arguments[t] != null ? arguments[t] : {};
    t % 2 ? Xx(Object(n), !0).forEach(function(r) {
      ag(e, r, n[r]);
    }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(n)) : Xx(Object(n)).forEach(function(r) {
      Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(n, r));
    });
  }
  return e;
}
function ag(e, t, n) {
  return t = FW(t), t in e ? Object.defineProperty(e, t, { value: n, enumerable: !0, configurable: !0, writable: !0 }) : e[t] = n, e;
}
function FW(e) {
  var t = BW(e, "string");
  return _p(t) == "symbol" ? t : String(t);
}
function BW(e, t) {
  if (_p(e) != "object" || !e) return e;
  var n = e[Symbol.toPrimitive];
  if (n !== void 0) {
    var r = n.call(e, t || "default");
    if (_p(r) != "object") return r;
    throw new TypeError("@@toPrimitive must return a primitive value.");
  }
  return (t === "string" ? String : Number)(e);
}
var Cd = {
  name: "BaseComponent",
  props: {
    pt: {
      type: Object,
      default: void 0
    },
    ptOptions: {
      type: Object,
      default: void 0
    },
    unstyled: {
      type: Boolean,
      default: void 0
    }
  },
  inject: {
    $parentInstance: {
      default: void 0
    }
  },
  watch: {
    isUnstyled: {
      immediate: !0,
      handler: function(t) {
        if (!t) {
          var n, r;
          l0.loadStyle({
            nonce: (n = this.$config) === null || n === void 0 || (n = n.csp) === null || n === void 0 ? void 0 : n.nonce
          }), this.$options.style && this.$style.loadStyle({
            nonce: (r = this.$config) === null || r === void 0 || (r = r.csp) === null || r === void 0 ? void 0 : r.nonce
          });
        }
      }
    }
  },
  beforeCreate: function() {
    var t, n, r, i, a, o, s, l, u, c, d, f = (t = this.pt) === null || t === void 0 ? void 0 : t._usept, h = f ? (n = this.pt) === null || n === void 0 || (n = n.originalValue) === null || n === void 0 ? void 0 : n[this.$.type.name] : void 0, m = f ? (r = this.pt) === null || r === void 0 || (r = r.value) === null || r === void 0 ? void 0 : r[this.$.type.name] : this.pt;
    (i = m || h) === null || i === void 0 || (i = i.hooks) === null || i === void 0 || (a = i.onBeforeCreate) === null || a === void 0 || a.call(i);
    var v = (o = this.$config) === null || o === void 0 || (o = o.pt) === null || o === void 0 ? void 0 : o._usept, b = v ? (s = this.$primevue) === null || s === void 0 || (s = s.config) === null || s === void 0 || (s = s.pt) === null || s === void 0 ? void 0 : s.originalValue : void 0, y = v ? (l = this.$primevue) === null || l === void 0 || (l = l.config) === null || l === void 0 || (l = l.pt) === null || l === void 0 ? void 0 : l.value : (u = this.$primevue) === null || u === void 0 || (u = u.config) === null || u === void 0 ? void 0 : u.pt;
    (c = y || b) === null || c === void 0 || (c = c[this.$.type.name]) === null || c === void 0 || (c = c.hooks) === null || c === void 0 || (d = c.onBeforeCreate) === null || d === void 0 || d.call(c);
  },
  created: function() {
    this._hook("onCreated");
  },
  beforeMount: function() {
    var t;
    Wo.loadStyle({
      nonce: (t = this.$config) === null || t === void 0 || (t = t.csp) === null || t === void 0 ? void 0 : t.nonce
    }), this._loadGlobalStyles(), this._hook("onBeforeMount");
  },
  mounted: function() {
    this._hook("onMounted");
  },
  beforeUpdate: function() {
    this._hook("onBeforeUpdate");
  },
  updated: function() {
    this._hook("onUpdated");
  },
  beforeUnmount: function() {
    this._hook("onBeforeUnmount");
  },
  unmounted: function() {
    this._hook("onUnmounted");
  },
  methods: {
    _hook: function(t) {
      if (!this.$options.hostName) {
        var n = this._usePT(this._getPT(this.pt, this.$.type.name), this._getOptionValue, "hooks.".concat(t)), r = this._useDefaultPT(this._getOptionValue, "hooks.".concat(t));
        n == null || n(), r == null || r();
      }
    },
    _mergeProps: function(t) {
      for (var n = arguments.length, r = new Array(n > 1 ? n - 1 : 0), i = 1; i < n; i++)
        r[i - 1] = arguments[i];
      return cn.isFunction(t) ? t.apply(void 0, r) : $e.apply(void 0, r);
    },
    _loadGlobalStyles: function() {
      var t, n = this._useGlobalPT(this._getOptionValue, "global.css", this.$params);
      cn.isNotEmpty(n) && l0.loadGlobalStyle(n, {
        nonce: (t = this.$config) === null || t === void 0 || (t = t.csp) === null || t === void 0 ? void 0 : t.nonce
      });
    },
    _getHostInstance: function(t) {
      return t ? this.$options.hostName ? t.$.type.name === this.$options.hostName ? t : this._getHostInstance(t.$parentInstance) : t.$parentInstance : void 0;
    },
    _getPropValue: function(t) {
      var n;
      return this[t] || ((n = this._getHostInstance(this)) === null || n === void 0 ? void 0 : n[t]);
    },
    _getOptionValue: function(t) {
      var n = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : "", r = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : {}, i = cn.toFlatCase(n).split("."), a = i.shift();
      return a ? cn.isObject(t) ? this._getOptionValue(cn.getItemValue(t[Object.keys(t).find(function(o) {
        return cn.toFlatCase(o) === a;
      }) || ""], r), i.join("."), r) : void 0 : cn.getItemValue(t, r);
    },
    _getPTValue: function() {
      var t, n = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : {}, r = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : "", i = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : {}, a = arguments.length > 3 && arguments[3] !== void 0 ? arguments[3] : !0, o = /./g.test(r) && !!i[r.split(".")[0]], s = this._getPropValue("ptOptions") || ((t = this.$config) === null || t === void 0 ? void 0 : t.ptOptions) || {}, l = s.mergeSections, u = l === void 0 ? !0 : l, c = s.mergeProps, d = c === void 0 ? !1 : c, f = a ? o ? this._useGlobalPT(this._getPTClassValue, r, i) : this._useDefaultPT(this._getPTClassValue, r, i) : void 0, h = o ? void 0 : this._usePT(this._getPT(n, this.$name), this._getPTClassValue, r, fr(fr({}, i), {}, {
        global: f || {}
      })), m = this._getPTDatasets(r);
      return u || !u && h ? d ? this._mergeProps(d, f, h, m) : fr(fr(fr({}, f), h), m) : fr(fr({}, h), m);
    },
    _getPTDatasets: function() {
      var t, n, r = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : "", i = "data-pc-", a = r === "root" && cn.isNotEmpty((t = this.pt) === null || t === void 0 ? void 0 : t["data-pc-section"]);
      return r !== "transition" && fr(fr({}, r === "root" && fr(ag({}, "".concat(i, "name"), cn.toFlatCase(a ? (n = this.pt) === null || n === void 0 ? void 0 : n["data-pc-section"] : this.$.type.name)), a && ag({}, "".concat(i, "extend"), cn.toFlatCase(this.$.type.name)))), {}, ag({}, "".concat(i, "section"), cn.toFlatCase(r)));
    },
    _getPTClassValue: function() {
      var t = this._getOptionValue.apply(this, arguments);
      return cn.isString(t) || cn.isArray(t) ? {
        class: t
      } : t;
    },
    _getPT: function(t) {
      var n = this, r = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : "", i = arguments.length > 2 ? arguments[2] : void 0, a = function(s) {
        var l, u = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : !1, c = i ? i(s) : s, d = cn.toFlatCase(r), f = cn.toFlatCase(n.$name);
        return (l = u ? d !== f ? c == null ? void 0 : c[d] : void 0 : c == null ? void 0 : c[d]) !== null && l !== void 0 ? l : c;
      };
      return t != null && t.hasOwnProperty("_usept") ? {
        _usept: t._usept,
        originalValue: a(t.originalValue),
        value: a(t.value)
      } : a(t, !0);
    },
    _usePT: function(t, n, r, i) {
      var a = function(v) {
        return n(v, r, i);
      };
      if (t != null && t.hasOwnProperty("_usept")) {
        var o, s = t._usept || ((o = this.$config) === null || o === void 0 ? void 0 : o.ptOptions) || {}, l = s.mergeSections, u = l === void 0 ? !0 : l, c = s.mergeProps, d = c === void 0 ? !1 : c, f = a(t.originalValue), h = a(t.value);
        return f === void 0 && h === void 0 ? void 0 : cn.isString(h) ? h : cn.isString(f) ? f : u || !u && h ? d ? this._mergeProps(d, f, h) : fr(fr({}, f), h) : h;
      }
      return a(t);
    },
    _useGlobalPT: function(t, n, r) {
      return this._usePT(this.globalPT, t, n, r);
    },
    _useDefaultPT: function(t, n, r) {
      return this._usePT(this.defaultPT, t, n, r);
    },
    ptm: function() {
      var t = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : "", n = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : {};
      return this._getPTValue(this.pt, t, fr(fr({}, this.$params), n));
    },
    ptmo: function() {
      var t = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : {}, n = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : "", r = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : {};
      return this._getPTValue(t, n, fr({
        instance: this
      }, r), !1);
    },
    cx: function() {
      var t = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : "", n = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : {};
      return this.isUnstyled ? void 0 : this._getOptionValue(this.$style.classes, t, fr(fr({}, this.$params), n));
    },
    sx: function() {
      var t = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : "", n = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : !0, r = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : {};
      if (n) {
        var i = this._getOptionValue(this.$style.inlineStyles, t, fr(fr({}, this.$params), r)), a = this._getOptionValue(l0.inlineStyles, t, fr(fr({}, this.$params), r));
        return [a, i];
      }
    }
  },
  computed: {
    globalPT: function() {
      var t, n = this;
      return this._getPT((t = this.$config) === null || t === void 0 ? void 0 : t.pt, void 0, function(r) {
        return cn.getItemValue(r, {
          instance: n
        });
      });
    },
    defaultPT: function() {
      var t, n = this;
      return this._getPT((t = this.$config) === null || t === void 0 ? void 0 : t.pt, void 0, function(r) {
        return n._getOptionValue(r, n.$name, fr({}, n.$params)) || cn.getItemValue(r, fr({}, n.$params));
      });
    },
    isUnstyled: function() {
      var t;
      return this.unstyled !== void 0 ? this.unstyled : (t = this.$config) === null || t === void 0 ? void 0 : t.unstyled;
    },
    $params: function() {
      var t = this._getHostInstance(this) || this.$parent;
      return {
        instance: this,
        props: this.$props,
        state: this.$data,
        attrs: this.$attrs,
        parent: {
          instance: t,
          props: t == null ? void 0 : t.$props,
          state: t == null ? void 0 : t.$data,
          attrs: t == null ? void 0 : t.$attrs
        },
        /* @deprecated since v3.43.0. Use the `parent.instance` instead of the `parentInstance`.*/
        parentInstance: t
      };
    },
    $style: function() {
      return fr(fr({
        classes: void 0,
        inlineStyles: void 0,
        loadStyle: function() {
        },
        loadCustomStyle: function() {
        }
      }, (this._getHostInstance(this) || {}).$style), this.$options.style);
    },
    $config: function() {
      var t;
      return (t = this.$primevue) === null || t === void 0 ? void 0 : t.config;
    },
    $name: function() {
      return this.$options.hostName || this.$.type.name;
    }
  }
}, $W = {
  root: function(t) {
    var n = t.props;
    return ["p-splitter p-component", "p-splitter-" + n.layout];
  },
  gutter: "p-splitter-gutter",
  gutterHandler: "p-splitter-gutter-handle"
}, UW = {
  root: function(t) {
    var n = t.props;
    return [{
      display: "flex",
      "flex-wrap": "nowrap"
    }, n.layout === "vertical" ? {
      "flex-direction": "column"
    } : ""];
  }
}, qW = Wo.extend({
  name: "splitter",
  classes: $W,
  inlineStyles: UW
}), GW = {
  name: "BaseSplitter",
  extends: Cd,
  props: {
    layout: {
      type: String,
      default: "horizontal"
    },
    gutterSize: {
      type: Number,
      default: 4
    },
    stateKey: {
      type: String,
      default: null
    },
    stateStorage: {
      type: String,
      default: "session"
    },
    step: {
      type: Number,
      default: 5
    }
  },
  style: qW,
  provide: function() {
    return {
      $parentInstance: this
    };
  }
};
function Zx(e) {
  return VW(e) || zW(e) || HW(e) || YW();
}
function YW() {
  throw new TypeError(`Invalid attempt to spread non-iterable instance.
In order to be iterable, non-array objects must have a [Symbol.iterator]() method.`);
}
function HW(e, t) {
  if (e) {
    if (typeof e == "string") return QT(e, t);
    var n = Object.prototype.toString.call(e).slice(8, -1);
    if (n === "Object" && e.constructor && (n = e.constructor.name), n === "Map" || n === "Set") return Array.from(e);
    if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return QT(e, t);
  }
}
function zW(e) {
  if (typeof Symbol < "u" && e[Symbol.iterator] != null || e["@@iterator"] != null) return Array.from(e);
}
function VW(e) {
  if (Array.isArray(e)) return QT(e);
}
function QT(e, t) {
  (t == null || t > e.length) && (t = e.length);
  for (var n = 0, r = new Array(t); n < t; n++) r[n] = e[n];
  return r;
}
var pF = {
  name: "Splitter",
  extends: GW,
  emits: ["resizestart", "resizeend", "resize"],
  dragging: !1,
  mouseMoveListener: null,
  mouseUpListener: null,
  touchMoveListener: null,
  touchEndListener: null,
  size: null,
  gutterElement: null,
  startPos: null,
  prevPanelElement: null,
  nextPanelElement: null,
  nextPanelSize: null,
  prevPanelSize: null,
  panelSizes: null,
  prevPanelIndex: null,
  timer: null,
  data: function() {
    return {
      prevSize: null
    };
  },
  mounted: function() {
    var t = this;
    if (this.panels && this.panels.length) {
      var n = !1;
      if (this.isStateful() && (n = this.restoreState()), !n) {
        var r = Zx(this.$el.children).filter(function(a) {
          return a.getAttribute("data-pc-name") === "splitterpanel";
        }), i = [];
        this.panels.map(function(a, o) {
          var s = a.props && a.props.size ? a.props.size : null, l = s || 100 / t.panels.length;
          i[o] = l, r[o].style.flexBasis = "calc(" + l + "% - " + (t.panels.length - 1) * t.gutterSize + "px)";
        }), this.panelSizes = i, this.prevSize = parseFloat(i[0]).toFixed(4);
      }
    }
  },
  beforeUnmount: function() {
    this.clear(), this.unbindMouseListeners();
  },
  methods: {
    getPTOptions: function() {
      var t;
      return {
        context: {
          nested: on.getAttribute((t = this.$parentInstance) === null || t === void 0 ? void 0 : t.$el, "data-pc-name") === "splitterpanel"
        }
      };
    },
    isSplitterPanel: function(t) {
      return t.type.name === "SplitterPanel";
    },
    onResizeStart: function(t, n, r) {
      this.gutterElement = t.currentTarget || t.target.parentElement, this.size = this.horizontal ? on.getWidth(this.$el) : on.getHeight(this.$el), r || (this.dragging = !0, this.startPos = this.layout === "horizontal" ? t.pageX || t.changedTouches[0].pageX : t.pageY || t.changedTouches[0].pageY), this.prevPanelElement = this.gutterElement.previousElementSibling, this.nextPanelElement = this.gutterElement.nextElementSibling, r ? (this.prevPanelSize = this.horizontal ? on.getOuterWidth(this.prevPanelElement, !0) : on.getOuterHeight(this.prevPanelElement, !0), this.nextPanelSize = this.horizontal ? on.getOuterWidth(this.nextPanelElement, !0) : on.getOuterHeight(this.nextPanelElement, !0)) : (this.prevPanelSize = 100 * (this.horizontal ? on.getOuterWidth(this.prevPanelElement, !0) : on.getOuterHeight(this.prevPanelElement, !0)) / this.size, this.nextPanelSize = 100 * (this.horizontal ? on.getOuterWidth(this.nextPanelElement, !0) : on.getOuterHeight(this.nextPanelElement, !0)) / this.size), this.prevPanelIndex = n, this.$emit("resizestart", {
        originalEvent: t,
        sizes: this.panelSizes
      }), this.$refs.gutter[n].setAttribute("data-p-gutter-resizing", !0), this.$el.setAttribute("data-p-resizing", !0);
    },
    onResize: function(t, n, r) {
      var i, a, o;
      r ? this.horizontal ? (a = 100 * (this.prevPanelSize + n) / this.size, o = 100 * (this.nextPanelSize - n) / this.size) : (a = 100 * (this.prevPanelSize - n) / this.size, o = 100 * (this.nextPanelSize + n) / this.size) : (this.horizontal ? i = t.pageX * 100 / this.size - this.startPos * 100 / this.size : i = t.pageY * 100 / this.size - this.startPos * 100 / this.size, a = this.prevPanelSize + i, o = this.nextPanelSize - i), this.validateResize(a, o) && (this.prevPanelElement.style.flexBasis = "calc(" + a + "% - " + (this.panels.length - 1) * this.gutterSize + "px)", this.nextPanelElement.style.flexBasis = "calc(" + o + "% - " + (this.panels.length - 1) * this.gutterSize + "px)", this.panelSizes[this.prevPanelIndex] = a, this.panelSizes[this.prevPanelIndex + 1] = o, this.prevSize = parseFloat(a).toFixed(4)), this.$emit("resize", {
        originalEvent: t,
        sizes: this.panelSizes
      });
    },
    onResizeEnd: function(t) {
      this.isStateful() && this.saveState(), this.$emit("resizeend", {
        originalEvent: t,
        sizes: this.panelSizes
      }), this.$refs.gutter.forEach(function(n) {
        return n.setAttribute("data-p-gutter-resizing", !1);
      }), this.$el.setAttribute("data-p-resizing", !1), this.clear();
    },
    repeat: function(t, n, r) {
      this.onResizeStart(t, n, !0), this.onResize(t, r, !0);
    },
    setTimer: function(t, n, r) {
      var i = this;
      this.timer || (this.timer = setInterval(function() {
        i.repeat(t, n, r);
      }, 40));
    },
    clearTimer: function() {
      this.timer && (clearInterval(this.timer), this.timer = null);
    },
    onGutterKeyUp: function() {
      this.clearTimer(), this.onResizeEnd();
    },
    onGutterKeyDown: function(t, n) {
      switch (t.code) {
        case "ArrowLeft": {
          this.layout === "horizontal" && this.setTimer(t, n, this.step * -1), t.preventDefault();
          break;
        }
        case "ArrowRight": {
          this.layout === "horizontal" && this.setTimer(t, n, this.step), t.preventDefault();
          break;
        }
        case "ArrowDown": {
          this.layout === "vertical" && this.setTimer(t, n, this.step * -1), t.preventDefault();
          break;
        }
        case "ArrowUp": {
          this.layout === "vertical" && this.setTimer(t, n, this.step), t.preventDefault();
          break;
        }
      }
    },
    onGutterMouseDown: function(t, n) {
      this.onResizeStart(t, n), this.bindMouseListeners();
    },
    onGutterTouchStart: function(t, n) {
      this.onResizeStart(t, n), this.bindTouchListeners(), t.preventDefault();
    },
    onGutterTouchMove: function(t) {
      this.onResize(t), t.preventDefault();
    },
    onGutterTouchEnd: function(t) {
      this.onResizeEnd(t), this.unbindTouchListeners(), t.preventDefault();
    },
    bindMouseListeners: function() {
      var t = this;
      this.mouseMoveListener || (this.mouseMoveListener = function(n) {
        return t.onResize(n);
      }, document.addEventListener("mousemove", this.mouseMoveListener)), this.mouseUpListener || (this.mouseUpListener = function(n) {
        t.onResizeEnd(n), t.unbindMouseListeners();
      }, document.addEventListener("mouseup", this.mouseUpListener));
    },
    bindTouchListeners: function() {
      var t = this;
      this.touchMoveListener || (this.touchMoveListener = function(n) {
        return t.onResize(n.changedTouches[0]);
      }, document.addEventListener("touchmove", this.touchMoveListener)), this.touchEndListener || (this.touchEndListener = function(n) {
        t.resizeEnd(n), t.unbindTouchListeners();
      }, document.addEventListener("touchend", this.touchEndListener));
    },
    validateResize: function(t, n) {
      if (t > 100 || t < 0 || n > 100 || n < 0) return !1;
      var r = cn.getVNodeProp(this.panels[this.prevPanelIndex], "minSize");
      if (this.panels[this.prevPanelIndex].props && r && r > t)
        return !1;
      var i = cn.getVNodeProp(this.panels[this.prevPanelIndex + 1], "minSize");
      return !(this.panels[this.prevPanelIndex + 1].props && i && i > n);
    },
    unbindMouseListeners: function() {
      this.mouseMoveListener && (document.removeEventListener("mousemove", this.mouseMoveListener), this.mouseMoveListener = null), this.mouseUpListener && (document.removeEventListener("mouseup", this.mouseUpListener), this.mouseUpListener = null);
    },
    unbindTouchListeners: function() {
      this.touchMoveListener && (document.removeEventListener("touchmove", this.touchMoveListener), this.touchMoveListener = null), this.touchEndListener && (document.removeEventListener("touchend", this.touchEndListener), this.touchEndListener = null);
    },
    clear: function() {
      this.dragging = !1, this.size = null, this.startPos = null, this.prevPanelElement = null, this.nextPanelElement = null, this.prevPanelSize = null, this.nextPanelSize = null, this.gutterElement = null, this.prevPanelIndex = null;
    },
    isStateful: function() {
      return this.stateKey != null;
    },
    getStorage: function() {
      switch (this.stateStorage) {
        case "local":
          return window.localStorage;
        case "session":
          return window.sessionStorage;
        default:
          throw new Error(this.stateStorage + ' is not a valid value for the state storage, supported values are "local" and "session".');
      }
    },
    saveState: function() {
      cn.isArray(this.panelSizes) && this.getStorage().setItem(this.stateKey, JSON.stringify(this.panelSizes));
    },
    restoreState: function() {
      var t = this, n = this.getStorage(), r = n.getItem(this.stateKey);
      if (r) {
        this.panelSizes = JSON.parse(r);
        var i = Zx(this.$el.children).filter(function(a) {
          return a.getAttribute("data-pc-name") === "splitterpanel";
        });
        return i.forEach(function(a, o) {
          a.style.flexBasis = "calc(" + t.panelSizes[o] + "% - " + (t.panels.length - 1) * t.gutterSize + "px)";
        }), !0;
      }
      return !1;
    }
  },
  computed: {
    panels: function() {
      var t = this, n = [];
      return this.$slots.default().forEach(function(r) {
        t.isSplitterPanel(r) ? n.push(r) : r.children instanceof Array && r.children.forEach(function(i) {
          t.isSplitterPanel(i) && n.push(i);
        });
      }), n;
    },
    gutterStyle: function() {
      return this.horizontal ? {
        width: this.gutterSize + "px"
      } : {
        height: this.gutterSize + "px"
      };
    },
    horizontal: function() {
      return this.layout === "horizontal";
    }
  }
}, WW = ["onMousedown", "onTouchstart", "onTouchmove", "onTouchend"], KW = ["aria-orientation", "aria-valuenow", "onKeydown"];
function jW(e, t, n, r, i, a) {
  return U(), ee("div", $e({
    class: e.cx("root"),
    style: e.sx("root"),
    "data-p-resizing": !1
  }, e.ptm("root", a.getPTOptions())), [(U(!0), ee(gt, null, It(a.panels, function(o, s) {
    return U(), ee(gt, {
      key: s
    }, [(U(), Ae(ze(o), {
      tabindex: "-1"
    })), s !== a.panels.length - 1 ? (U(), ee("div", $e({
      key: 0,
      ref_for: !0,
      ref: "gutter",
      class: e.cx("gutter"),
      role: "separator",
      tabindex: "-1",
      onMousedown: function(u) {
        return a.onGutterMouseDown(u, s);
      },
      onTouchstart: function(u) {
        return a.onGutterTouchStart(u, s);
      },
      onTouchmove: function(u) {
        return a.onGutterTouchMove(u, s);
      },
      onTouchend: function(u) {
        return a.onGutterTouchEnd(u, s);
      },
      "data-p-gutter-resizing": !1
    }, e.ptm("gutter")), [de("div", $e({
      class: e.cx("gutterHandler"),
      tabindex: "0",
      style: [a.gutterStyle],
      "aria-orientation": e.layout,
      "aria-valuenow": i.prevSize,
      onKeyup: t[0] || (t[0] = function() {
        return a.onGutterKeyUp && a.onGutterKeyUp.apply(a, arguments);
      }),
      onKeydown: function(u) {
        return a.onGutterKeyDown(u, s);
      }
    }, e.ptm("gutterHandler")), null, 16, KW)], 16, WW)) : se("", !0)], 64);
  }), 128))], 16);
}
pF.render = jW;
var QW = {
  root: function(t) {
    var n = t.instance;
    return ["p-splitter-panel", {
      "p-splitter-panel-nested": n.isNested
    }];
  }
}, XW = Wo.extend({
  name: "splitterpanel",
  classes: QW
}), ZW = {
  name: "BaseSplitterPanel",
  extends: Cd,
  props: {
    size: {
      type: Number,
      default: null
    },
    minSize: {
      type: Number,
      default: null
    }
  },
  style: XW,
  provide: function() {
    return {
      $parentInstance: this
    };
  }
}, XT = {
  name: "SplitterPanel",
  extends: ZW,
  computed: {
    isNested: function() {
      return this.$slots.default().some(function(t) {
        return t.type.name === "Splitter";
      });
    },
    getPTOptions: function() {
      return {
        context: {
          nested: this.isNested
        }
      };
    }
  }
};
function JW(e, t, n, r, i, a) {
  return U(), ee("div", $e({
    ref: "container",
    class: e.cx("root")
  }, e.ptm("root", a.getPTOptions)), [Me(e.$slots, "default")], 16);
}
XT.render = JW;
const eK = "data:image/png;base64,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", Jx = {};
function tK(e) {
  let t = Jx[e];
  if (t)
    return t;
  t = Jx[e] = [];
  for (let n = 0; n < 128; n++) {
    const r = String.fromCharCode(n);
    t.push(r);
  }
  for (let n = 0; n < e.length; n++) {
    const r = e.charCodeAt(n);
    t[r] = "%" + ("0" + r.toString(16).toUpperCase()).slice(-2);
  }
  return t;
}
function sd(e, t) {
  typeof t != "string" && (t = sd.defaultChars);
  const n = tK(t);
  return e.replace(/(%[a-f0-9]{2})+/gi, function(r) {
    let i = "";
    for (let a = 0, o = r.length; a < o; a += 3) {
      const s = parseInt(r.slice(a + 1, a + 3), 16);
      if (s < 128) {
        i += n[s];
        continue;
      }
      if ((s & 224) === 192 && a + 3 < o) {
        const l = parseInt(r.slice(a + 4, a + 6), 16);
        if ((l & 192) === 128) {
          const u = s << 6 & 1984 | l & 63;
          u < 128 ? i += "��" : i += String.fromCharCode(u), a += 3;
          continue;
        }
      }
      if ((s & 240) === 224 && a + 6 < o) {
        const l = parseInt(r.slice(a + 4, a + 6), 16), u = parseInt(r.slice(a + 7, a + 9), 16);
        if ((l & 192) === 128 && (u & 192) === 128) {
          const c = s << 12 & 61440 | l << 6 & 4032 | u & 63;
          c < 2048 || c >= 55296 && c <= 57343 ? i += "���" : i += String.fromCharCode(c), a += 6;
          continue;
        }
      }
      if ((s & 248) === 240 && a + 9 < o) {
        const l = parseInt(r.slice(a + 4, a + 6), 16), u = parseInt(r.slice(a + 7, a + 9), 16), c = parseInt(r.slice(a + 10, a + 12), 16);
        if ((l & 192) === 128 && (u & 192) === 128 && (c & 192) === 128) {
          let d = s << 18 & 1835008 | l << 12 & 258048 | u << 6 & 4032 | c & 63;
          d < 65536 || d > 1114111 ? i += "����" : (d -= 65536, i += String.fromCharCode(55296 + (d >> 10), 56320 + (d & 1023))), a += 9;
          continue;
        }
      }
      i += "�";
    }
    return i;
  });
}
sd.defaultChars = ";/?:@&=+$,#";
sd.componentChars = "";
const eN = {};
function nK(e) {
  let t = eN[e];
  if (t)
    return t;
  t = eN[e] = [];
  for (let n = 0; n < 128; n++) {
    const r = String.fromCharCode(n);
    /^[0-9a-z]$/i.test(r) ? t.push(r) : t.push("%" + ("0" + n.toString(16).toUpperCase()).slice(-2));
  }
  for (let n = 0; n < e.length; n++)
    t[e.charCodeAt(n)] = e[n];
  return t;
}
function om(e, t, n) {
  typeof t != "string" && (n = t, t = om.defaultChars), typeof n > "u" && (n = !0);
  const r = nK(t);
  let i = "";
  for (let a = 0, o = e.length; a < o; a++) {
    const s = e.charCodeAt(a);
    if (n && s === 37 && a + 2 < o && /^[0-9a-f]{2}$/i.test(e.slice(a + 1, a + 3))) {
      i += e.slice(a, a + 3), a += 2;
      continue;
    }
    if (s < 128) {
      i += r[s];
      continue;
    }
    if (s >= 55296 && s <= 57343) {
      if (s >= 55296 && s <= 56319 && a + 1 < o) {
        const l = e.charCodeAt(a + 1);
        if (l >= 56320 && l <= 57343) {
          i += encodeURIComponent(e[a] + e[a + 1]), a++;
          continue;
        }
      }
      i += "%EF%BF%BD";
      continue;
    }
    i += encodeURIComponent(e[a]);
  }
  return i;
}
om.defaultChars = ";/?:@&=+$,-_.!~*'()#";
om.componentChars = "-_.!~*'()";
function f1(e) {
  let t = "";
  return t += e.protocol || "", t += e.slashes ? "//" : "", t += e.auth ? e.auth + "@" : "", e.hostname && e.hostname.indexOf(":") !== -1 ? t += "[" + e.hostname + "]" : t += e.hostname || "", t += e.port ? ":" + e.port : "", t += e.pathname || "", t += e.search || "", t += e.hash || "", t;
}
function Ig() {
  this.protocol = null, this.slashes = null, this.auth = null, this.port = null, this.hostname = null, this.hash = null, this.search = null, this.pathname = null;
}
const rK = /^([a-z0-9.+-]+:)/i, iK = /:[0-9]*$/, aK = /^(\/\/?(?!\/)[^\?\s]*)(\?[^\s]*)?$/, oK = ["<", ">", '"', "`", " ", "\r", `
`, "	"], sK = ["{", "}", "|", "\\", "^", "`"].concat(oK), lK = ["'"].concat(sK), tN = ["%", "/", "?", ";", "#"].concat(lK), nN = ["/", "?", "#"], uK = 255, rN = /^[+a-z0-9A-Z_-]{0,63}$/, cK = /^([+a-z0-9A-Z_-]{0,63})(.*)$/, iN = {
  javascript: !0,
  "javascript:": !0
}, aN = {
  http: !0,
  https: !0,
  ftp: !0,
  gopher: !0,
  file: !0,
  "http:": !0,
  "https:": !0,
  "ftp:": !0,
  "gopher:": !0,
  "file:": !0
};
function p1(e, t) {
  if (e && e instanceof Ig) return e;
  const n = new Ig();
  return n.parse(e, t), n;
}
Ig.prototype.parse = function(e, t) {
  let n, r, i, a = e;
  if (a = a.trim(), !t && e.split("#").length === 1) {
    const u = aK.exec(a);
    if (u)
      return this.pathname = u[1], u[2] && (this.search = u[2]), this;
  }
  let o = rK.exec(a);
  if (o && (o = o[0], n = o.toLowerCase(), this.protocol = o, a = a.substr(o.length)), (t || o || a.match(/^\/\/[^@\/]+@[^@\/]+/)) && (i = a.substr(0, 2) === "//", i && !(o && iN[o]) && (a = a.substr(2), this.slashes = !0)), !iN[o] && (i || o && !aN[o])) {
    let u = -1;
    for (let m = 0; m < nN.length; m++)
      r = a.indexOf(nN[m]), r !== -1 && (u === -1 || r < u) && (u = r);
    let c, d;
    u === -1 ? d = a.lastIndexOf("@") : d = a.lastIndexOf("@", u), d !== -1 && (c = a.slice(0, d), a = a.slice(d + 1), this.auth = c), u = -1;
    for (let m = 0; m < tN.length; m++)
      r = a.indexOf(tN[m]), r !== -1 && (u === -1 || r < u) && (u = r);
    u === -1 && (u = a.length), a[u - 1] === ":" && u--;
    const f = a.slice(0, u);
    a = a.slice(u), this.parseHost(f), this.hostname = this.hostname || "";
    const h = this.hostname[0] === "[" && this.hostname[this.hostname.length - 1] === "]";
    if (!h) {
      const m = this.hostname.split(/\./);
      for (let v = 0, b = m.length; v < b; v++) {
        const y = m[v];
        if (y && !y.match(rN)) {
          let g = "";
          for (let E = 0, S = y.length; E < S; E++)
            y.charCodeAt(E) > 127 ? g += "x" : g += y[E];
          if (!g.match(rN)) {
            const E = m.slice(0, v), S = m.slice(v + 1), C = y.match(cK);
            C && (E.push(C[1]), S.unshift(C[2])), S.length && (a = S.join(".") + a), this.hostname = E.join(".");
            break;
          }
        }
      }
    }
    this.hostname.length > uK && (this.hostname = ""), h && (this.hostname = this.hostname.substr(1, this.hostname.length - 2));
  }
  const s = a.indexOf("#");
  s !== -1 && (this.hash = a.substr(s), a = a.slice(0, s));
  const l = a.indexOf("?");
  return l !== -1 && (this.search = a.substr(l), a = a.slice(0, l)), a && (this.pathname = a), aN[n] && this.hostname && !this.pathname && (this.pathname = ""), this;
};
Ig.prototype.parseHost = function(e) {
  let t = iK.exec(e);
  t && (t = t[0], t !== ":" && (this.port = t.substr(1)), e = e.substr(0, e.length - t.length)), e && (this.hostname = e);
};
const dK = /* @__PURE__ */ Object.freeze(/* @__PURE__ */ Object.defineProperty({
  __proto__: null,
  decode: sd,
  encode: om,
  format: f1,
  parse: p1
}, Symbol.toStringTag, { value: "Module" })), mF = /[\0-\uD7FF\uE000-\uFFFF]|[\uD800-\uDBFF][\uDC00-\uDFFF]|[\uD800-\uDBFF](?![\uDC00-\uDFFF])|(?:[^\uD800-\uDBFF]|^)[\uDC00-\uDFFF]/, hF = /[\0-\x1F\x7F-\x9F]/, fK = /[\xAD\u0600-\u0605\u061C\u06DD\u070F\u0890\u0891\u08E2\u180E\u200B-\u200F\u202A-\u202E\u2060-\u2064\u2066-\u206F\uFEFF\uFFF9-\uFFFB]|\uD804[\uDCBD\uDCCD]|\uD80D[\uDC30-\uDC3F]|\uD82F[\uDCA0-\uDCA3]|\uD834[\uDD73-\uDD7A]|\uDB40[\uDC01\uDC20-\uDC7F]/, m1 = /[!-#%-\*,-\/:;\?@\[-\]_\{\}\xA1\xA7\xAB\xB6\xB7\xBB\xBF\u037E\u0387\u055A-\u055F\u0589\u058A\u05BE\u05C0\u05C3\u05C6\u05F3\u05F4\u0609\u060A\u060C\u060D\u061B\u061D-\u061F\u066A-\u066D\u06D4\u0700-\u070D\u07F7-\u07F9\u0830-\u083E\u085E\u0964\u0965\u0970\u09FD\u0A76\u0AF0\u0C77\u0C84\u0DF4\u0E4F\u0E5A\u0E5B\u0F04-\u0F12\u0F14\u0F3A-\u0F3D\u0F85\u0FD0-\u0FD4\u0FD9\u0FDA\u104A-\u104F\u10FB\u1360-\u1368\u1400\u166E\u169B\u169C\u16EB-\u16ED\u1735\u1736\u17D4-\u17D6\u17D8-\u17DA\u1800-\u180A\u1944\u1945\u1A1E\u1A1F\u1AA0-\u1AA6\u1AA8-\u1AAD\u1B5A-\u1B60\u1B7D\u1B7E\u1BFC-\u1BFF\u1C3B-\u1C3F\u1C7E\u1C7F\u1CC0-\u1CC7\u1CD3\u2010-\u2027\u2030-\u2043\u2045-\u2051\u2053-\u205E\u207D\u207E\u208D\u208E\u2308-\u230B\u2329\u232A\u2768-\u2775\u27C5\u27C6\u27E6-\u27EF\u2983-\u2998\u29D8-\u29DB\u29FC\u29FD\u2CF9-\u2CFC\u2CFE\u2CFF\u2D70\u2E00-\u2E2E\u2E30-\u2E4F\u2E52-\u2E5D\u3001-\u3003\u3008-\u3011\u3014-\u301F\u3030\u303D\u30A0\u30FB\uA4FE\uA4FF\uA60D-\uA60F\uA673\uA67E\uA6F2-\uA6F7\uA874-\uA877\uA8CE\uA8CF\uA8F8-\uA8FA\uA8FC\uA92E\uA92F\uA95F\uA9C1-\uA9CD\uA9DE\uA9DF\uAA5C-\uAA5F\uAADE\uAADF\uAAF0\uAAF1\uABEB\uFD3E\uFD3F\uFE10-\uFE19\uFE30-\uFE52\uFE54-\uFE61\uFE63\uFE68\uFE6A\uFE6B\uFF01-\uFF03\uFF05-\uFF0A\uFF0C-\uFF0F\uFF1A\uFF1B\uFF1F\uFF20\uFF3B-\uFF3D\uFF3F\uFF5B\uFF5D\uFF5F-\uFF65]|\uD800[\uDD00-\uDD02\uDF9F\uDFD0]|\uD801\uDD6F|\uD802[\uDC57\uDD1F\uDD3F\uDE50-\uDE58\uDE7F\uDEF0-\uDEF6\uDF39-\uDF3F\uDF99-\uDF9C]|\uD803[\uDEAD\uDF55-\uDF59\uDF86-\uDF89]|\uD804[\uDC47-\uDC4D\uDCBB\uDCBC\uDCBE-\uDCC1\uDD40-\uDD43\uDD74\uDD75\uDDC5-\uDDC8\uDDCD\uDDDB\uDDDD-\uDDDF\uDE38-\uDE3D\uDEA9]|\uD805[\uDC4B-\uDC4F\uDC5A\uDC5B\uDC5D\uDCC6\uDDC1-\uDDD7\uDE41-\uDE43\uDE60-\uDE6C\uDEB9\uDF3C-\uDF3E]|\uD806[\uDC3B\uDD44-\uDD46\uDDE2\uDE3F-\uDE46\uDE9A-\uDE9C\uDE9E-\uDEA2\uDF00-\uDF09]|\uD807[\uDC41-\uDC45\uDC70\uDC71\uDEF7\uDEF8\uDF43-\uDF4F\uDFFF]|\uD809[\uDC70-\uDC74]|\uD80B[\uDFF1\uDFF2]|\uD81A[\uDE6E\uDE6F\uDEF5\uDF37-\uDF3B\uDF44]|\uD81B[\uDE97-\uDE9A\uDFE2]|\uD82F\uDC9F|\uD836[\uDE87-\uDE8B]|\uD83A[\uDD5E\uDD5F]/, gF = /[ \xA0\u1680\u2000-\u200A\u2028\u2029\u202F\u205F\u3000]/, pK = /* @__PURE__ */ Object.freeze(/* @__PURE__ */ Object.defineProperty({
  __proto__: null,
  Any: mF,
  Cc: hF,
  Cf: fK,
  P: m1,
  Z: gF
}, Symbol.toStringTag, { value: "Module" })), mK = new Uint16Array(
  // prettier-ignore
  'ᵁ<Õıʊҝջאٵ۞ޢߖࠏ੊ઑඡ๭༉༦჊ረዡᐕᒝᓃᓟᔥ\0\0\0\0\0\0ᕫᛍᦍᰒᷝ὾⁠↰⊍⏀⏻⑂⠤⤒ⴈ⹈⿎〖㊺㘹㞬㣾㨨㩱㫠㬮ࠀEMabcfglmnoprstu\\bfms¦³¹ÈÏlig耻Æ䃆P耻&䀦cute耻Á䃁reve;䄂Āiyx}rc耻Â䃂;䐐r;쀀𝔄rave耻À䃀pha;䎑acr;䄀d;橓Āgp¡on;䄄f;쀀𝔸plyFunction;恡ing耻Å䃅Ācs¾Ãr;쀀𝒜ign;扔ilde耻Ã䃃ml耻Ä䃄ЀaceforsuåûþėĜĢħĪĀcrêòkslash;或Ŷöø;櫧ed;挆y;䐑ƀcrtąċĔause;戵noullis;愬a;䎒r;쀀𝔅pf;쀀𝔹eve;䋘còēmpeq;扎܀HOacdefhilorsuōőŖƀƞƢƵƷƺǜȕɳɸɾcy;䐧PY耻©䂩ƀcpyŝŢźute;䄆Ā;iŧŨ拒talDifferentialD;慅leys;愭ȀaeioƉƎƔƘron;䄌dil耻Ç䃇rc;䄈nint;戰ot;䄊ĀdnƧƭilla;䂸terDot;䂷òſi;䎧rcleȀDMPTǇǋǑǖot;抙inus;抖lus;投imes;抗oĀcsǢǸkwiseContourIntegral;戲eCurlyĀDQȃȏoubleQuote;思uote;怙ȀlnpuȞȨɇɕonĀ;eȥȦ户;橴ƀgitȯȶȺruent;扡nt;戯ourIntegral;戮ĀfrɌɎ;愂oduct;成nterClockwiseContourIntegral;戳oss;樯cr;쀀𝒞pĀ;Cʄʅ拓ap;才րDJSZacefiosʠʬʰʴʸˋ˗ˡ˦̳ҍĀ;oŹʥtrahd;椑cy;䐂cy;䐅cy;䐏ƀgrsʿ˄ˇger;怡r;憡hv;櫤Āayː˕ron;䄎;䐔lĀ;t˝˞戇a;䎔r;쀀𝔇Āaf˫̧Ācm˰̢riticalȀADGT̖̜̀̆cute;䂴oŴ̋̍;䋙bleAcute;䋝rave;䁠ilde;䋜ond;拄ferentialD;慆Ѱ̽\0\0\0͔͂\0Ѕf;쀀𝔻ƀ;DE͈͉͍䂨ot;惜qual;扐blèCDLRUVͣͲ΂ϏϢϸontourIntegraìȹoɴ͹\0\0ͻ»͉nArrow;懓Āeo·ΤftƀARTΐΖΡrrow;懐ightArrow;懔eåˊngĀLRΫτeftĀARγιrrow;柸ightArrow;柺ightArrow;柹ightĀATϘϞrrow;懒ee;抨pɁϩ\0\0ϯrrow;懑ownArrow;懕erticalBar;戥ǹABLRTaВЪаўѿͼrrowƀ;BUНОТ憓ar;椓pArrow;懵reve;䌑eft˒к\0ц\0ѐightVector;楐eeVector;楞ectorĀ;Bљњ憽ar;楖ightǔѧ\0ѱeeVector;楟ectorĀ;BѺѻ懁ar;楗eeĀ;A҆҇护rrow;憧ĀctҒҗr;쀀𝒟rok;䄐ࠀNTacdfglmopqstuxҽӀӄӋӞӢӧӮӵԡԯԶՒ՝ՠեG;䅊H耻Ð䃐cute耻É䃉ƀaiyӒӗӜron;䄚rc耻Ê䃊;䐭ot;䄖r;쀀𝔈rave耻È䃈ement;戈ĀapӺӾcr;䄒tyɓԆ\0\0ԒmallSquare;旻erySmallSquare;斫ĀgpԦԪon;䄘f;쀀𝔼silon;䎕uĀaiԼՉlĀ;TՂՃ橵ilde;扂librium;懌Āci՗՚r;愰m;橳a;䎗ml耻Ë䃋Āipժկsts;戃onentialE;慇ʀcfiosօֈ֍ֲ׌y;䐤r;쀀𝔉lledɓ֗\0\0֣mallSquare;旼erySmallSquare;斪Ͱֺ\0ֿ\0\0ׄf;쀀𝔽All;戀riertrf;愱cò׋؀JTabcdfgorstר׬ׯ׺؀ؒؖ؛؝أ٬ٲcy;䐃耻>䀾mmaĀ;d׷׸䎓;䏜reve;䄞ƀeiy؇،ؐdil;䄢rc;䄜;䐓ot;䄠r;쀀𝔊;拙pf;쀀𝔾eater̀EFGLSTصلَٖٛ٦qualĀ;Lؾؿ扥ess;招ullEqual;执reater;檢ess;扷lantEqual;橾ilde;扳cr;쀀𝒢;扫ЀAacfiosuڅڋږڛڞڪھۊRDcy;䐪Āctڐڔek;䋇;䁞irc;䄤r;愌lbertSpace;愋ǰگ\0ڲf;愍izontalLine;攀Āctۃۅòکrok;䄦mpńېۘownHumðįqual;扏܀EJOacdfgmnostuۺ۾܃܇܎ܚܞܡܨ݄ݸދޏޕcy;䐕lig;䄲cy;䐁cute耻Í䃍Āiyܓܘrc耻Î䃎;䐘ot;䄰r;愑rave耻Ì䃌ƀ;apܠܯܿĀcgܴܷr;䄪inaryI;慈lieóϝǴ݉\0ݢĀ;eݍݎ戬Āgrݓݘral;戫section;拂isibleĀCTݬݲomma;恣imes;恢ƀgptݿރވon;䄮f;쀀𝕀a;䎙cr;愐ilde;䄨ǫޚ\0ޞcy;䐆l耻Ï䃏ʀcfosuެ޷޼߂ߐĀiyޱ޵rc;䄴;䐙r;쀀𝔍pf;쀀𝕁ǣ߇\0ߌr;쀀𝒥rcy;䐈kcy;䐄΀HJacfosߤߨ߽߬߱ࠂࠈcy;䐥cy;䐌ppa;䎚Āey߶߻dil;䄶;䐚r;쀀𝔎pf;쀀𝕂cr;쀀𝒦րJTaceflmostࠥࠩࠬࡐࡣ঳সে্਷ੇcy;䐉耻<䀼ʀcmnpr࠷࠼ࡁࡄࡍute;䄹bda;䎛g;柪lacetrf;愒r;憞ƀaeyࡗ࡜ࡡron;䄽dil;䄻;䐛Āfsࡨ॰tԀACDFRTUVarࡾࢩࢱࣦ࣠ࣼयज़ΐ४Ānrࢃ࢏gleBracket;柨rowƀ;BR࢙࢚࢞憐ar;懤ightArrow;懆eiling;挈oǵࢷ\0ࣃbleBracket;柦nǔࣈ\0࣒eeVector;楡ectorĀ;Bࣛࣜ懃ar;楙loor;挊ightĀAV࣯ࣵrrow;憔ector;楎Āerँगeƀ;AVउऊऐ抣rrow;憤ector;楚iangleƀ;BEतथऩ抲ar;槏qual;抴pƀDTVषूौownVector;楑eeVector;楠ectorĀ;Bॖॗ憿ar;楘ectorĀ;B॥०憼ar;楒ightáΜs̀EFGLSTॾঋকঝঢভqualGreater;拚ullEqual;扦reater;扶ess;檡lantEqual;橽ilde;扲r;쀀𝔏Ā;eঽা拘ftarrow;懚idot;䄿ƀnpw৔ਖਛgȀLRlr৞৷ਂਐeftĀAR০৬rrow;柵ightArrow;柷ightArrow;柶eftĀarγਊightáοightáϊf;쀀𝕃erĀLRਢਬeftArrow;憙ightArrow;憘ƀchtਾੀੂòࡌ;憰rok;䅁;扪Ѐacefiosuਗ਼੝੠੷੼અઋ઎p;椅y;䐜Ādl੥੯iumSpace;恟lintrf;愳r;쀀𝔐nusPlus;戓pf;쀀𝕄cò੶;䎜ҀJacefostuણધભીଔଙඑ඗ඞcy;䐊cute;䅃ƀaey઴હાron;䅇dil;䅅;䐝ƀgswે૰଎ativeƀMTV૓૟૨ediumSpace;怋hiĀcn૦૘ë૙eryThiî૙tedĀGL૸ଆreaterGreateòٳessLesóੈLine;䀊r;쀀𝔑ȀBnptଢନଷ଺reak;恠BreakingSpace;䂠f;愕ڀ;CDEGHLNPRSTV୕ୖ୪୼஡௫ఄ౞಄ದ೘ൡඅ櫬Āou୛୤ngruent;扢pCap;扭oubleVerticalBar;戦ƀlqxஃஊ஛ement;戉ualĀ;Tஒஓ扠ilde;쀀≂̸ists;戄reater΀;EFGLSTஶஷ஽௉௓௘௥扯qual;扱ullEqual;쀀≧̸reater;쀀≫̸ess;批lantEqual;쀀⩾̸ilde;扵umpń௲௽ownHump;쀀≎̸qual;쀀≏̸eĀfsఊధtTriangleƀ;BEచఛడ拪ar;쀀⧏̸qual;括s̀;EGLSTవశ఼ౄోౘ扮qual;扰reater;扸ess;쀀≪̸lantEqual;쀀⩽̸ilde;扴estedĀGL౨౹reaterGreater;쀀⪢̸essLess;쀀⪡̸recedesƀ;ESಒಓಛ技qual;쀀⪯̸lantEqual;拠ĀeiಫಹverseElement;戌ghtTriangleƀ;BEೋೌ೒拫ar;쀀⧐̸qual;拭ĀquೝഌuareSuĀbp೨೹setĀ;E೰ೳ쀀⊏̸qual;拢ersetĀ;Eഃആ쀀⊐̸qual;拣ƀbcpഓതൎsetĀ;Eഛഞ쀀⊂⃒qual;抈ceedsȀ;ESTലള഻െ抁qual;쀀⪰̸lantEqual;拡ilde;쀀≿̸ersetĀ;E൘൛쀀⊃⃒qual;抉ildeȀ;EFT൮൯൵ൿ扁qual;扄ullEqual;扇ilde;扉erticalBar;戤cr;쀀𝒩ilde耻Ñ䃑;䎝܀Eacdfgmoprstuvලෂ෉෕ෛ෠෧෼ขภยา฿ไlig;䅒cute耻Ó䃓Āiy෎ීrc耻Ô䃔;䐞blac;䅐r;쀀𝔒rave耻Ò䃒ƀaei෮ෲ෶cr;䅌ga;䎩cron;䎟pf;쀀𝕆enCurlyĀDQฎบoubleQuote;怜uote;怘;橔Āclวฬr;쀀𝒪ash耻Ø䃘iŬื฼de耻Õ䃕es;樷ml耻Ö䃖erĀBP๋๠Āar๐๓r;怾acĀek๚๜;揞et;掴arenthesis;揜Ҁacfhilors๿ງຊຏຒດຝະ໼rtialD;戂y;䐟r;쀀𝔓i;䎦;䎠usMinus;䂱Āipຢອncareplanåڝf;愙Ȁ;eio຺ູ໠໤檻cedesȀ;EST່້໏໚扺qual;檯lantEqual;扼ilde;找me;怳Ādp໩໮uct;戏ortionĀ;aȥ໹l;戝Āci༁༆r;쀀𝒫;䎨ȀUfos༑༖༛༟OT耻"䀢r;쀀𝔔pf;愚cr;쀀𝒬؀BEacefhiorsu༾གྷཇའཱིྦྷྪྭ႖ႩႴႾarr;椐G耻®䂮ƀcnrཎནབute;䅔g;柫rĀ;tཛྷཝ憠l;椖ƀaeyཧཬཱron;䅘dil;䅖;䐠Ā;vླྀཹ愜erseĀEUྂྙĀlq྇ྎement;戋uilibrium;懋pEquilibrium;楯r»ཹo;䎡ghtЀACDFTUVa࿁࿫࿳ဢဨၛႇϘĀnr࿆࿒gleBracket;柩rowƀ;BL࿜࿝࿡憒ar;懥eftArrow;懄eiling;按oǵ࿹\0စbleBracket;柧nǔည\0နeeVector;楝ectorĀ;Bဝသ懂ar;楕loor;挋Āerိ၃eƀ;AVဵံြ抢rrow;憦ector;楛iangleƀ;BEၐၑၕ抳ar;槐qual;抵pƀDTVၣၮၸownVector;楏eeVector;楜ectorĀ;Bႂႃ憾ar;楔ectorĀ;B႑႒懀ar;楓Āpuႛ႞f;愝ndImplies;楰ightarrow;懛ĀchႹႼr;愛;憱leDelayed;槴ڀHOacfhimoqstuფჱჷჽᄙᄞᅑᅖᅡᅧᆵᆻᆿĀCcჩხHcy;䐩y;䐨FTcy;䐬cute;䅚ʀ;aeiyᄈᄉᄎᄓᄗ檼ron;䅠dil;䅞rc;䅜;䐡r;쀀𝔖ortȀDLRUᄪᄴᄾᅉownArrow»ОeftArrow»࢚ightArrow»࿝pArrow;憑gma;䎣allCircle;战pf;쀀𝕊ɲᅭ\0\0ᅰt;戚areȀ;ISUᅻᅼᆉᆯ斡ntersection;抓uĀbpᆏᆞsetĀ;Eᆗᆘ抏qual;抑ersetĀ;Eᆨᆩ抐qual;抒nion;抔cr;쀀𝒮ar;拆ȀbcmpᇈᇛሉላĀ;sᇍᇎ拐etĀ;Eᇍᇕqual;抆ĀchᇠህeedsȀ;ESTᇭᇮᇴᇿ扻qual;檰lantEqual;扽ilde;承Tháྌ;我ƀ;esሒሓሣ拑rsetĀ;Eሜም抃qual;抇et»ሓրHRSacfhiorsሾቄ቉ቕ቞ቱቶኟዂወዑORN耻Þ䃞ADE;愢ĀHc቎ቒcy;䐋y;䐦Ābuቚቜ;䀉;䎤ƀaeyብቪቯron;䅤dil;䅢;䐢r;쀀𝔗Āeiቻ኉ǲኀ\0ኇefore;戴a;䎘Ācn኎ኘkSpace;쀀  Space;怉ldeȀ;EFTካኬኲኼ戼qual;扃ullEqual;扅ilde;扈pf;쀀𝕋ipleDot;惛Āctዖዛr;쀀𝒯rok;䅦ૡዷጎጚጦ\0ጬጱ\0\0\0\0\0ጸጽ፷ᎅ\0᏿ᐄᐊᐐĀcrዻጁute耻Ú䃚rĀ;oጇገ憟cir;楉rǣጓ\0጖y;䐎ve;䅬Āiyጞጣrc耻Û䃛;䐣blac;䅰r;쀀𝔘rave耻Ù䃙acr;䅪Ādiፁ፩erĀBPፈ፝Āarፍፐr;䁟acĀekፗፙ;揟et;掵arenthesis;揝onĀ;P፰፱拃lus;抎Āgp፻፿on;䅲f;쀀𝕌ЀADETadps᎕ᎮᎸᏄϨᏒᏗᏳrrowƀ;BDᅐᎠᎤar;椒ownArrow;懅ownArrow;憕quilibrium;楮eeĀ;AᏋᏌ报rrow;憥ownáϳerĀLRᏞᏨeftArrow;憖ightArrow;憗iĀ;lᏹᏺ䏒on;䎥ing;䅮cr;쀀𝒰ilde;䅨ml耻Ü䃜ҀDbcdefosvᐧᐬᐰᐳᐾᒅᒊᒐᒖash;披ar;櫫y;䐒ashĀ;lᐻᐼ抩;櫦Āerᑃᑅ;拁ƀbtyᑌᑐᑺar;怖Ā;iᑏᑕcalȀBLSTᑡᑥᑪᑴar;戣ine;䁼eparator;杘ilde;所ThinSpace;怊r;쀀𝔙pf;쀀𝕍cr;쀀𝒱dash;抪ʀcefosᒧᒬᒱᒶᒼirc;䅴dge;拀r;쀀𝔚pf;쀀𝕎cr;쀀𝒲Ȁfiosᓋᓐᓒᓘr;쀀𝔛;䎞pf;쀀𝕏cr;쀀𝒳ҀAIUacfosuᓱᓵᓹᓽᔄᔏᔔᔚᔠcy;䐯cy;䐇cy;䐮cute耻Ý䃝Āiyᔉᔍrc;䅶;䐫r;쀀𝔜pf;쀀𝕐cr;쀀𝒴ml;䅸ЀHacdefosᔵᔹᔿᕋᕏᕝᕠᕤcy;䐖cute;䅹Āayᕄᕉron;䅽;䐗ot;䅻ǲᕔ\0ᕛoWidtè૙a;䎖r;愨pf;愤cr;쀀𝒵௡ᖃᖊᖐ\0ᖰᖶᖿ\0\0\0\0ᗆᗛᗫᙟ᙭\0ᚕ᚛ᚲᚹ\0ᚾcute耻á䃡reve;䄃̀;Ediuyᖜᖝᖡᖣᖨᖭ戾;쀀∾̳;房rc耻â䃢te肻´̆;䐰lig耻æ䃦Ā;r²ᖺ;쀀𝔞rave耻à䃠ĀepᗊᗖĀfpᗏᗔsym;愵èᗓha;䎱ĀapᗟcĀclᗤᗧr;䄁g;樿ɤᗰ\0\0ᘊʀ;adsvᗺᗻᗿᘁᘇ戧nd;橕;橜lope;橘;橚΀;elmrszᘘᘙᘛᘞᘿᙏᙙ戠;榤e»ᘙsdĀ;aᘥᘦ戡ѡᘰᘲᘴᘶᘸᘺᘼᘾ;榨;榩;榪;榫;榬;榭;榮;榯tĀ;vᙅᙆ戟bĀ;dᙌᙍ抾;榝Āptᙔᙗh;戢»¹arr;捼Āgpᙣᙧon;䄅f;쀀𝕒΀;Eaeiop዁ᙻᙽᚂᚄᚇᚊ;橰cir;橯;扊d;手s;䀧roxĀ;e዁ᚒñᚃing耻å䃥ƀctyᚡᚦᚨr;쀀𝒶;䀪mpĀ;e዁ᚯñʈilde耻ã䃣ml耻ä䃤Āciᛂᛈoninôɲnt;樑ࠀNabcdefiklnoprsu᛭ᛱᜰ᜼ᝃᝈ᝸᝽០៦ᠹᡐᜍ᤽᥈ᥰot;櫭Ācrᛶ᜞kȀcepsᜀᜅᜍᜓong;扌psilon;䏶rime;怵imĀ;e᜚᜛戽q;拍Ŷᜢᜦee;抽edĀ;gᜬᜭ挅e»ᜭrkĀ;t፜᜷brk;掶Āoyᜁᝁ;䐱quo;怞ʀcmprtᝓ᝛ᝡᝤᝨausĀ;eĊĉptyv;榰séᜌnoõēƀahwᝯ᝱ᝳ;䎲;愶een;扬r;쀀𝔟g΀costuvwឍឝឳេ៕៛៞ƀaiuបពរðݠrc;旯p»፱ƀdptឤឨឭot;樀lus;樁imes;樂ɱឹ\0\0ើcup;樆ar;昅riangleĀdu៍្own;施p;斳plus;樄eåᑄåᒭarow;植ƀako៭ᠦᠵĀcn៲ᠣkƀlst៺֫᠂ozenge;槫riangleȀ;dlr᠒᠓᠘᠝斴own;斾eft;旂ight;斸k;搣Ʊᠫ\0ᠳƲᠯ\0ᠱ;斒;斑4;斓ck;斈ĀeoᠾᡍĀ;qᡃᡆ쀀=⃥uiv;쀀≡⃥t;挐Ȁptwxᡙᡞᡧᡬf;쀀𝕓Ā;tᏋᡣom»Ꮜtie;拈؀DHUVbdhmptuvᢅᢖᢪᢻᣗᣛᣬ᣿ᤅᤊᤐᤡȀLRlrᢎᢐᢒᢔ;敗;敔;敖;敓ʀ;DUduᢡᢢᢤᢦᢨ敐;敦;敩;敤;敧ȀLRlrᢳᢵᢷᢹ;敝;敚;敜;教΀;HLRhlrᣊᣋᣍᣏᣑᣓᣕ救;敬;散;敠;敫;敢;敟ox;槉ȀLRlrᣤᣦᣨᣪ;敕;敒;攐;攌ʀ;DUduڽ᣷᣹᣻᣽;敥;敨;攬;攴inus;抟lus;択imes;抠ȀLRlrᤙᤛᤝ᤟;敛;敘;攘;攔΀;HLRhlrᤰᤱᤳᤵᤷ᤻᤹攂;敪;敡;敞;攼;攤;攜Āevģ᥂bar耻¦䂦Ȁceioᥑᥖᥚᥠr;쀀𝒷mi;恏mĀ;e᜚᜜lƀ;bhᥨᥩᥫ䁜;槅sub;柈Ŭᥴ᥾lĀ;e᥹᥺怢t»᥺pƀ;Eeįᦅᦇ;檮Ā;qۜۛೡᦧ\0᧨ᨑᨕᨲ\0ᨷᩐ\0\0᪴\0\0᫁\0\0ᬡᬮ᭍᭒\0᯽\0ᰌƀcpr᦭ᦲ᧝ute;䄇̀;abcdsᦿᧀᧄ᧊᧕᧙戩nd;橄rcup;橉Āau᧏᧒p;橋p;橇ot;橀;쀀∩︀Āeo᧢᧥t;恁îړȀaeiu᧰᧻ᨁᨅǰ᧵\0᧸s;橍on;䄍dil耻ç䃧rc;䄉psĀ;sᨌᨍ橌m;橐ot;䄋ƀdmnᨛᨠᨦil肻¸ƭptyv;榲t脀¢;eᨭᨮ䂢räƲr;쀀𝔠ƀceiᨽᩀᩍy;䑇ckĀ;mᩇᩈ朓ark»ᩈ;䏇r΀;Ecefms᩟᩠ᩢᩫ᪤᪪᪮旋;槃ƀ;elᩩᩪᩭ䋆q;扗eɡᩴ\0\0᪈rrowĀlr᩼᪁eft;憺ight;憻ʀRSacd᪒᪔᪖᪚᪟»ཇ;擈st;抛irc;抚ash;抝nint;樐id;櫯cir;槂ubsĀ;u᪻᪼晣it»᪼ˬ᫇᫔᫺\0ᬊonĀ;eᫍᫎ䀺Ā;qÇÆɭ᫙\0\0᫢aĀ;t᫞᫟䀬;䁀ƀ;fl᫨᫩᫫戁îᅠeĀmx᫱᫶ent»᫩eóɍǧ᫾\0ᬇĀ;dኻᬂot;橭nôɆƀfryᬐᬔᬗ;쀀𝕔oäɔ脀©;sŕᬝr;愗Āaoᬥᬩrr;憵ss;朗Ācuᬲᬷr;쀀𝒸Ābpᬼ᭄Ā;eᭁᭂ櫏;櫑Ā;eᭉᭊ櫐;櫒dot;拯΀delprvw᭠᭬᭷ᮂᮬᯔ᯹arrĀlr᭨᭪;椸;椵ɰ᭲\0\0᭵r;拞c;拟arrĀ;p᭿ᮀ憶;椽̀;bcdosᮏᮐᮖᮡᮥᮨ截rcap;橈Āauᮛᮞp;橆p;橊ot;抍r;橅;쀀∪︀Ȁalrv᮵ᮿᯞᯣrrĀ;mᮼᮽ憷;椼yƀevwᯇᯔᯘqɰᯎ\0\0ᯒreã᭳uã᭵ee;拎edge;拏en耻¤䂤earrowĀlrᯮ᯳eft»ᮀight»ᮽeäᯝĀciᰁᰇoninôǷnt;戱lcty;挭ঀAHabcdefhijlorstuwz᰸᰻᰿ᱝᱩᱵᲊᲞᲬᲷ᳻᳿ᴍᵻᶑᶫᶻ᷆᷍rò΁ar;楥Ȁglrs᱈ᱍ᱒᱔ger;怠eth;愸òᄳhĀ;vᱚᱛ怐»ऊūᱡᱧarow;椏aã̕Āayᱮᱳron;䄏;䐴ƀ;ao̲ᱼᲄĀgrʿᲁr;懊tseq;橷ƀglmᲑᲔᲘ耻°䂰ta;䎴ptyv;榱ĀirᲣᲨsht;楿;쀀𝔡arĀlrᲳᲵ»ࣜ»သʀaegsv᳂͸᳖᳜᳠mƀ;oș᳊᳔ndĀ;ș᳑uit;晦amma;䏝in;拲ƀ;io᳧᳨᳸䃷de脀÷;o᳧ᳰntimes;拇nø᳷cy;䑒cɯᴆ\0\0ᴊrn;挞op;挍ʀlptuwᴘᴝᴢᵉᵕlar;䀤f;쀀𝕕ʀ;emps̋ᴭᴷᴽᵂqĀ;d͒ᴳot;扑inus;戸lus;戔quare;抡blebarwedgåúnƀadhᄮᵝᵧownarrowóᲃarpoonĀlrᵲᵶefôᲴighôᲶŢᵿᶅkaro÷གɯᶊ\0\0ᶎrn;挟op;挌ƀcotᶘᶣᶦĀryᶝᶡ;쀀𝒹;䑕l;槶rok;䄑Ādrᶰᶴot;拱iĀ;fᶺ᠖斿Āah᷀᷃ròЩaòྦangle;榦Āci᷒ᷕy;䑟grarr;柿ऀDacdefglmnopqrstuxḁḉḙḸոḼṉṡṾấắẽỡἪἷὄ὎὚ĀDoḆᴴoôᲉĀcsḎḔute耻é䃩ter;橮ȀaioyḢḧḱḶron;䄛rĀ;cḭḮ扖耻ê䃪lon;払;䑍ot;䄗ĀDrṁṅot;扒;쀀𝔢ƀ;rsṐṑṗ檚ave耻è䃨Ā;dṜṝ檖ot;檘Ȁ;ilsṪṫṲṴ檙nters;揧;愓Ā;dṹṺ檕ot;檗ƀapsẅẉẗcr;䄓tyƀ;svẒẓẕ戅et»ẓpĀ1;ẝẤĳạả;怄;怅怃ĀgsẪẬ;䅋p;怂ĀgpẴẸon;䄙f;쀀𝕖ƀalsỄỎỒrĀ;sỊị拕l;槣us;橱iƀ;lvỚớở䎵on»ớ;䏵ȀcsuvỪỳἋἣĀioữḱrc»Ḯɩỹ\0\0ỻíՈantĀglἂἆtr»ṝess»Ṻƀaeiἒ἖Ἒls;䀽st;扟vĀ;DȵἠD;橸parsl;槥ĀDaἯἳot;打rr;楱ƀcdiἾὁỸr;愯oô͒ĀahὉὋ;䎷耻ð䃰Āmrὓὗl耻ë䃫o;悬ƀcipὡὤὧl;䀡sôծĀeoὬὴctatioîՙnentialåչৡᾒ\0ᾞ\0ᾡᾧ\0\0ῆῌ\0ΐ\0ῦῪ \0 ⁚llingdotseñṄy;䑄male;晀ƀilrᾭᾳ῁lig;耀ﬃɩᾹ\0\0᾽g;耀ﬀig;耀ﬄ;쀀𝔣lig;耀ﬁlig;쀀fjƀaltῙ῜ῡt;晭ig;耀ﬂns;斱of;䆒ǰ΅\0ῳf;쀀𝕗ĀakֿῷĀ;vῼ´拔;櫙artint;樍Āao‌⁕Ācs‑⁒α‚‰‸⁅⁈\0⁐β•‥‧‪‬\0‮耻½䂽;慓耻¼䂼;慕;慙;慛Ƴ‴\0‶;慔;慖ʴ‾⁁\0\0⁃耻¾䂾;慗;慜5;慘ƶ⁌\0⁎;慚;慝8;慞l;恄wn;挢cr;쀀𝒻ࢀEabcdefgijlnorstv₂₉₟₥₰₴⃰⃵⃺⃿℃ℒℸ̗ℾ⅒↞Ā;lٍ₇;檌ƀcmpₐₕ₝ute;䇵maĀ;dₜ᳚䎳;檆reve;䄟Āiy₪₮rc;䄝;䐳ot;䄡Ȁ;lqsؾق₽⃉ƀ;qsؾٌ⃄lanô٥Ȁ;cdl٥⃒⃥⃕c;檩otĀ;o⃜⃝檀Ā;l⃢⃣檂;檄Ā;e⃪⃭쀀⋛︀s;檔r;쀀𝔤Ā;gٳ؛mel;愷cy;䑓Ȁ;Eajٚℌℎℐ;檒;檥;檤ȀEaesℛℝ℩ℴ;扩pĀ;p℣ℤ檊rox»ℤĀ;q℮ℯ檈Ā;q℮ℛim;拧pf;쀀𝕘Āci⅃ⅆr;愊mƀ;el٫ⅎ⅐;檎;檐茀>;cdlqr׮ⅠⅪⅮⅳⅹĀciⅥⅧ;檧r;橺ot;拗Par;榕uest;橼ʀadelsↄⅪ←ٖ↛ǰ↉\0↎proø₞r;楸qĀlqؿ↖lesó₈ií٫Āen↣↭rtneqq;쀀≩︀Å↪ԀAabcefkosy⇄⇇⇱⇵⇺∘∝∯≨≽ròΠȀilmr⇐⇔⇗⇛rsðᒄf»․ilôکĀdr⇠⇤cy;䑊ƀ;cwࣴ⇫⇯ir;楈;憭ar;意irc;䄥ƀalr∁∎∓rtsĀ;u∉∊晥it»∊lip;怦con;抹r;쀀𝔥sĀew∣∩arow;椥arow;椦ʀamopr∺∾≃≞≣rr;懿tht;戻kĀlr≉≓eftarrow;憩ightarrow;憪f;쀀𝕙bar;怕ƀclt≯≴≸r;쀀𝒽asè⇴rok;䄧Ābp⊂⊇ull;恃hen»ᱛૡ⊣\0⊪\0⊸⋅⋎\0⋕⋳\0\0⋸⌢⍧⍢⍿\0⎆⎪⎴cute耻í䃭ƀ;iyݱ⊰⊵rc耻î䃮;䐸Ācx⊼⊿y;䐵cl耻¡䂡ĀfrΟ⋉;쀀𝔦rave耻ì䃬Ȁ;inoܾ⋝⋩⋮Āin⋢⋦nt;樌t;戭fin;槜ta;愩lig;䄳ƀaop⋾⌚⌝ƀcgt⌅⌈⌗r;䄫ƀelpܟ⌏⌓inåގarôܠh;䄱f;抷ed;䆵ʀ;cfotӴ⌬⌱⌽⍁are;愅inĀ;t⌸⌹戞ie;槝doô⌙ʀ;celpݗ⍌⍐⍛⍡al;抺Āgr⍕⍙eróᕣã⍍arhk;樗rod;樼Ȁcgpt⍯⍲⍶⍻y;䑑on;䄯f;쀀𝕚a;䎹uest耻¿䂿Āci⎊⎏r;쀀𝒾nʀ;EdsvӴ⎛⎝⎡ӳ;拹ot;拵Ā;v⎦⎧拴;拳Ā;iݷ⎮lde;䄩ǫ⎸\0⎼cy;䑖l耻ï䃯̀cfmosu⏌⏗⏜⏡⏧⏵Āiy⏑⏕rc;䄵;䐹r;쀀𝔧ath;䈷pf;쀀𝕛ǣ⏬\0⏱r;쀀𝒿rcy;䑘kcy;䑔Ѐacfghjos␋␖␢␧␭␱␵␻ppaĀ;v␓␔䎺;䏰Āey␛␠dil;䄷;䐺r;쀀𝔨reen;䄸cy;䑅cy;䑜pf;쀀𝕜cr;쀀𝓀஀ABEHabcdefghjlmnoprstuv⑰⒁⒆⒍⒑┎┽╚▀♎♞♥♹♽⚚⚲⛘❝❨➋⟀⠁⠒ƀart⑷⑺⑼rò৆òΕail;椛arr;椎Ā;gঔ⒋;檋ar;楢ॣ⒥\0⒪\0⒱\0\0\0\0\0⒵Ⓔ\0ⓆⓈⓍ\0⓹ute;䄺mptyv;榴raîࡌbda;䎻gƀ;dlࢎⓁⓃ;榑åࢎ;檅uo耻«䂫rЀ;bfhlpst࢙ⓞⓦⓩ⓫⓮⓱⓵Ā;f࢝ⓣs;椟s;椝ë≒p;憫l;椹im;楳l;憢ƀ;ae⓿─┄檫il;椙Ā;s┉┊檭;쀀⪭︀ƀabr┕┙┝rr;椌rk;杲Āak┢┬cĀek┨┪;䁻;䁛Āes┱┳;榋lĀdu┹┻;榏;榍Ȁaeuy╆╋╖╘ron;䄾Ādi═╔il;䄼ìࢰâ┩;䐻Ȁcqrs╣╦╭╽a;椶uoĀ;rนᝆĀdu╲╷har;楧shar;楋h;憲ʀ;fgqs▋▌উ◳◿扤tʀahlrt▘▤▷◂◨rrowĀ;t࢙□aé⓶arpoonĀdu▯▴own»њp»०eftarrows;懇ightƀahs◍◖◞rrowĀ;sࣴࢧarpoonó྘quigarro÷⇰hreetimes;拋ƀ;qs▋ও◺lanôবʀ;cdgsব☊☍☝☨c;檨otĀ;o☔☕橿Ā;r☚☛檁;檃Ā;e☢☥쀀⋚︀s;檓ʀadegs☳☹☽♉♋pproøⓆot;拖qĀgq♃♅ôউgtò⒌ôছiíলƀilr♕࣡♚sht;楼;쀀𝔩Ā;Eজ♣;檑š♩♶rĀdu▲♮Ā;l॥♳;楪lk;斄cy;䑙ʀ;achtੈ⚈⚋⚑⚖rò◁orneòᴈard;楫ri;旺Āio⚟⚤dot;䅀ustĀ;a⚬⚭掰che»⚭ȀEaes⚻⚽⛉⛔;扨pĀ;p⛃⛄檉rox»⛄Ā;q⛎⛏檇Ā;q⛎⚻im;拦Ѐabnoptwz⛩⛴⛷✚✯❁❇❐Ānr⛮⛱g;柬r;懽rëࣁgƀlmr⛿✍✔eftĀar০✇ightá৲apsto;柼ightá৽parrowĀlr✥✩efô⓭ight;憬ƀafl✶✹✽r;榅;쀀𝕝us;樭imes;樴š❋❏st;戗áፎƀ;ef❗❘᠀旊nge»❘arĀ;l❤❥䀨t;榓ʀachmt❳❶❼➅➇ròࢨorneòᶌarĀ;d྘➃;業;怎ri;抿̀achiqt➘➝ੀ➢➮➻quo;怹r;쀀𝓁mƀ;egল➪➬;檍;檏Ābu┪➳oĀ;rฟ➹;怚rok;䅂萀<;cdhilqrࠫ⟒☹⟜⟠⟥⟪⟰Āci⟗⟙;檦r;橹reå◲mes;拉arr;楶uest;橻ĀPi⟵⟹ar;榖ƀ;ef⠀भ᠛旃rĀdu⠇⠍shar;楊har;楦Āen⠗⠡rtneqq;쀀≨︀Å⠞܀Dacdefhilnopsu⡀⡅⢂⢎⢓⢠⢥⢨⣚⣢⣤ઃ⣳⤂Dot;戺Ȁclpr⡎⡒⡣⡽r耻¯䂯Āet⡗⡙;時Ā;e⡞⡟朠se»⡟Ā;sျ⡨toȀ;dluျ⡳⡷⡻owîҌefôएðᏑker;斮Āoy⢇⢌mma;権;䐼ash;怔asuredangle»ᘦr;쀀𝔪o;愧ƀcdn⢯⢴⣉ro耻µ䂵Ȁ;acdᑤ⢽⣀⣄sôᚧir;櫰ot肻·Ƶusƀ;bd⣒ᤃ⣓戒Ā;uᴼ⣘;横ţ⣞⣡p;櫛ò−ðઁĀdp⣩⣮els;抧f;쀀𝕞Āct⣸⣽r;쀀𝓂pos»ᖝƀ;lm⤉⤊⤍䎼timap;抸ఀGLRVabcdefghijlmoprstuvw⥂⥓⥾⦉⦘⧚⧩⨕⨚⩘⩝⪃⪕⪤⪨⬄⬇⭄⭿⮮ⰴⱧⱼ⳩Āgt⥇⥋;쀀⋙̸Ā;v⥐௏쀀≫⃒ƀelt⥚⥲⥶ftĀar⥡⥧rrow;懍ightarrow;懎;쀀⋘̸Ā;v⥻ే쀀≪⃒ightarrow;懏ĀDd⦎⦓ash;抯ash;抮ʀbcnpt⦣⦧⦬⦱⧌la»˞ute;䅄g;쀀∠⃒ʀ;Eiop඄⦼⧀⧅⧈;쀀⩰̸d;쀀≋̸s;䅉roø඄urĀ;a⧓⧔普lĀ;s⧓ସǳ⧟\0⧣p肻 ଷmpĀ;e௹ఀʀaeouy⧴⧾⨃⨐⨓ǰ⧹\0⧻;橃on;䅈dil;䅆ngĀ;dൾ⨊ot;쀀⩭̸p;橂;䐽ash;怓΀;Aadqsxஒ⨩⨭⨻⩁⩅⩐rr;懗rĀhr⨳⨶k;椤Ā;oᏲᏰot;쀀≐̸uiöୣĀei⩊⩎ar;椨í஘istĀ;s஠டr;쀀𝔫ȀEest௅⩦⩹⩼ƀ;qs஼⩭௡ƀ;qs஼௅⩴lanô௢ií௪Ā;rஶ⪁»ஷƀAap⪊⪍⪑rò⥱rr;憮ar;櫲ƀ;svྍ⪜ྌĀ;d⪡⪢拼;拺cy;䑚΀AEadest⪷⪺⪾⫂⫅⫶⫹rò⥦;쀀≦̸rr;憚r;急Ȁ;fqs఻⫎⫣⫯tĀar⫔⫙rro÷⫁ightarro÷⪐ƀ;qs఻⪺⫪lanôౕĀ;sౕ⫴»శiíౝĀ;rవ⫾iĀ;eచథiäඐĀpt⬌⬑f;쀀𝕟膀¬;in⬙⬚⬶䂬nȀ;Edvஉ⬤⬨⬮;쀀⋹̸ot;쀀⋵̸ǡஉ⬳⬵;拷;拶iĀ;vಸ⬼ǡಸ⭁⭃;拾;拽ƀaor⭋⭣⭩rȀ;ast୻⭕⭚⭟lleì୻l;쀀⫽⃥;쀀∂̸lint;樔ƀ;ceಒ⭰⭳uåಥĀ;cಘ⭸Ā;eಒ⭽ñಘȀAait⮈⮋⮝⮧rò⦈rrƀ;cw⮔⮕⮙憛;쀀⤳̸;쀀↝̸ghtarrow»⮕riĀ;eೋೖ΀chimpqu⮽⯍⯙⬄୸⯤⯯Ȁ;cerല⯆ഷ⯉uå൅;쀀𝓃ortɭ⬅\0\0⯖ará⭖mĀ;e൮⯟Ā;q൴൳suĀbp⯫⯭å೸åഋƀbcp⯶ⰑⰙȀ;Ees⯿ⰀഢⰄ抄;쀀⫅̸etĀ;eഛⰋqĀ;qണⰀcĀ;eലⰗñസȀ;EesⰢⰣൟⰧ抅;쀀⫆̸etĀ;e൘ⰮqĀ;qൠⰣȀgilrⰽⰿⱅⱇìௗlde耻ñ䃱çృiangleĀlrⱒⱜeftĀ;eచⱚñదightĀ;eೋⱥñ೗Ā;mⱬⱭ䎽ƀ;esⱴⱵⱹ䀣ro;愖p;怇ҀDHadgilrsⲏⲔⲙⲞⲣⲰⲶⳓⳣash;抭arr;椄p;쀀≍⃒ash;抬ĀetⲨⲬ;쀀≥⃒;쀀>⃒nfin;槞ƀAetⲽⳁⳅrr;椂;쀀≤⃒Ā;rⳊⳍ쀀<⃒ie;쀀⊴⃒ĀAtⳘⳜrr;椃rie;쀀⊵⃒im;쀀∼⃒ƀAan⳰⳴ⴂrr;懖rĀhr⳺⳽k;椣Ā;oᏧᏥear;椧ቓ᪕\0\0\0\0\0\0\0\0\0\0\0\0\0ⴭ\0ⴸⵈⵠⵥ⵲ⶄᬇ\0\0ⶍⶫ\0ⷈⷎ\0ⷜ⸙⸫⸾⹃Ācsⴱ᪗ute耻ó䃳ĀiyⴼⵅrĀ;c᪞ⵂ耻ô䃴;䐾ʀabios᪠ⵒⵗǈⵚlac;䅑v;樸old;榼lig;䅓Ācr⵩⵭ir;榿;쀀𝔬ͯ⵹\0\0⵼\0ⶂn;䋛ave耻ò䃲;槁Ābmⶈ෴ar;榵Ȁacitⶕ⶘ⶥⶨrò᪀Āir⶝ⶠr;榾oss;榻nå๒;槀ƀaeiⶱⶵⶹcr;䅍ga;䏉ƀcdnⷀⷅǍron;䎿;榶pf;쀀𝕠ƀaelⷔ⷗ǒr;榷rp;榹΀;adiosvⷪⷫⷮ⸈⸍⸐⸖戨rò᪆Ȁ;efmⷷⷸ⸂⸅橝rĀ;oⷾⷿ愴f»ⷿ耻ª䂪耻º䂺gof;抶r;橖lope;橗;橛ƀclo⸟⸡⸧ò⸁ash耻ø䃸l;折iŬⸯ⸴de耻õ䃵esĀ;aǛ⸺s;樶ml耻ö䃶bar;挽ૡ⹞\0⹽\0⺀⺝\0⺢⺹\0\0⻋ຜ\0⼓\0\0⼫⾼\0⿈rȀ;astЃ⹧⹲຅脀¶;l⹭⹮䂶leìЃɩ⹸\0\0⹻m;櫳;櫽y;䐿rʀcimpt⺋⺏⺓ᡥ⺗nt;䀥od;䀮il;怰enk;怱r;쀀𝔭ƀimo⺨⺰⺴Ā;v⺭⺮䏆;䏕maô੶ne;明ƀ;tv⺿⻀⻈䏀chfork»´;䏖Āau⻏⻟nĀck⻕⻝kĀ;h⇴⻛;愎ö⇴sҀ;abcdemst⻳⻴ᤈ⻹⻽⼄⼆⼊⼎䀫cir;樣ir;樢Āouᵀ⼂;樥;橲n肻±ຝim;樦wo;樧ƀipu⼙⼠⼥ntint;樕f;쀀𝕡nd耻£䂣Ԁ;Eaceinosu່⼿⽁⽄⽇⾁⾉⾒⽾⾶;檳p;檷uå໙Ā;c໎⽌̀;acens່⽙⽟⽦⽨⽾pproø⽃urlyeñ໙ñ໎ƀaes⽯⽶⽺pprox;檹qq;檵im;拨iíໟmeĀ;s⾈ຮ怲ƀEas⽸⾐⽺ð⽵ƀdfp໬⾙⾯ƀals⾠⾥⾪lar;挮ine;挒urf;挓Ā;t໻⾴ï໻rel;抰Āci⿀⿅r;쀀𝓅;䏈ncsp;怈̀fiopsu⿚⋢⿟⿥⿫⿱r;쀀𝔮pf;쀀𝕢rime;恗cr;쀀𝓆ƀaeo⿸〉〓tĀei⿾々rnionóڰnt;樖stĀ;e【】䀿ñἙô༔઀ABHabcdefhilmnoprstux぀けさすムㄎㄫㅇㅢㅲㆎ㈆㈕㈤㈩㉘㉮㉲㊐㊰㊷ƀartぇおがròႳòϝail;検aròᱥar;楤΀cdenqrtとふへみわゔヌĀeuねぱ;쀀∽̱te;䅕iãᅮmptyv;榳gȀ;del࿑らるろ;榒;榥å࿑uo耻»䂻rր;abcfhlpstw࿜ガクシスゼゾダッデナp;極Ā;f࿠ゴs;椠;椳s;椞ë≝ð✮l;楅im;楴l;憣;憝Āaiパフil;椚oĀ;nホボ戶aló༞ƀabrョリヮrò៥rk;杳ĀakンヽcĀekヹ・;䁽;䁝Āes㄂㄄;榌lĀduㄊㄌ;榎;榐Ȁaeuyㄗㄜㄧㄩron;䅙Ādiㄡㄥil;䅗ì࿲âヺ;䑀Ȁclqsㄴㄷㄽㅄa;椷dhar;楩uoĀ;rȎȍh;憳ƀacgㅎㅟངlȀ;ipsླྀㅘㅛႜnåႻarôྩt;断ƀilrㅩဣㅮsht;楽;쀀𝔯ĀaoㅷㆆrĀduㅽㅿ»ѻĀ;l႑ㆄ;楬Ā;vㆋㆌ䏁;䏱ƀgns㆕ㇹㇼht̀ahlrstㆤㆰ㇂㇘㇤㇮rrowĀ;t࿜ㆭaéトarpoonĀduㆻㆿowîㅾp»႒eftĀah㇊㇐rrowó࿪arpoonóՑightarrows;應quigarro÷ニhreetimes;拌g;䋚ingdotseñἲƀahm㈍㈐㈓rò࿪aòՑ;怏oustĀ;a㈞㈟掱che»㈟mid;櫮Ȁabpt㈲㈽㉀㉒Ānr㈷㈺g;柭r;懾rëဃƀafl㉇㉊㉎r;榆;쀀𝕣us;樮imes;樵Āap㉝㉧rĀ;g㉣㉤䀩t;榔olint;樒arò㇣Ȁachq㉻㊀Ⴜ㊅quo;怺r;쀀𝓇Ābu・㊊oĀ;rȔȓƀhir㊗㊛㊠reåㇸmes;拊iȀ;efl㊪ၙᠡ㊫方tri;槎luhar;楨;愞ൡ㋕㋛㋟㌬㌸㍱\0㍺㎤\0\0㏬㏰\0㐨㑈㑚㒭㒱㓊㓱\0㘖\0\0㘳cute;䅛quï➺Ԁ;Eaceinpsyᇭ㋳㋵㋿㌂㌋㌏㌟㌦㌩;檴ǰ㋺\0㋼;檸on;䅡uåᇾĀ;dᇳ㌇il;䅟rc;䅝ƀEas㌖㌘㌛;檶p;檺im;择olint;樓iíሄ;䑁otƀ;be㌴ᵇ㌵担;橦΀Aacmstx㍆㍊㍗㍛㍞㍣㍭rr;懘rĀhr㍐㍒ë∨Ā;oਸ਼਴t耻§䂧i;䀻war;椩mĀin㍩ðnuóñt;朶rĀ;o㍶⁕쀀𝔰Ȁacoy㎂㎆㎑㎠rp;景Āhy㎋㎏cy;䑉;䑈rtɭ㎙\0\0㎜iäᑤaraì⹯耻­䂭Āgm㎨㎴maƀ;fv㎱㎲㎲䏃;䏂Ѐ;deglnprካ㏅㏉㏎㏖㏞㏡㏦ot;橪Ā;q኱ኰĀ;E㏓㏔檞;檠Ā;E㏛㏜檝;檟e;扆lus;樤arr;楲aròᄽȀaeit㏸㐈㐏㐗Āls㏽㐄lsetmé㍪hp;樳parsl;槤Ādlᑣ㐔e;挣Ā;e㐜㐝檪Ā;s㐢㐣檬;쀀⪬︀ƀflp㐮㐳㑂tcy;䑌Ā;b㐸㐹䀯Ā;a㐾㐿槄r;挿f;쀀𝕤aĀdr㑍ЂesĀ;u㑔㑕晠it»㑕ƀcsu㑠㑹㒟Āau㑥㑯pĀ;sᆈ㑫;쀀⊓︀pĀ;sᆴ㑵;쀀⊔︀uĀbp㑿㒏ƀ;esᆗᆜ㒆etĀ;eᆗ㒍ñᆝƀ;esᆨᆭ㒖etĀ;eᆨ㒝ñᆮƀ;afᅻ㒦ְrť㒫ֱ»ᅼaròᅈȀcemt㒹㒾㓂㓅r;쀀𝓈tmîñiì㐕aræᆾĀar㓎㓕rĀ;f㓔ឿ昆Āan㓚㓭ightĀep㓣㓪psiloîỠhé⺯s»⡒ʀbcmnp㓻㕞ሉ㖋㖎Ҁ;Edemnprs㔎㔏㔑㔕㔞㔣㔬㔱㔶抂;櫅ot;檽Ā;dᇚ㔚ot;櫃ult;櫁ĀEe㔨㔪;櫋;把lus;檿arr;楹ƀeiu㔽㕒㕕tƀ;en㔎㕅㕋qĀ;qᇚ㔏eqĀ;q㔫㔨m;櫇Ābp㕚㕜;櫕;櫓c̀;acensᇭ㕬㕲㕹㕻㌦pproø㋺urlyeñᇾñᇳƀaes㖂㖈㌛pproø㌚qñ㌗g;晪ڀ123;Edehlmnps㖩㖬㖯ሜ㖲㖴㗀㗉㗕㗚㗟㗨㗭耻¹䂹耻²䂲耻³䂳;櫆Āos㖹㖼t;檾ub;櫘Ā;dሢ㗅ot;櫄sĀou㗏㗒l;柉b;櫗arr;楻ult;櫂ĀEe㗤㗦;櫌;抋lus;櫀ƀeiu㗴㘉㘌tƀ;enሜ㗼㘂qĀ;qሢ㖲eqĀ;q㗧㗤m;櫈Ābp㘑㘓;櫔;櫖ƀAan㘜㘠㘭rr;懙rĀhr㘦㘨ë∮Ā;oਫ਩war;椪lig耻ß䃟௡㙑㙝㙠ዎ㙳㙹\0㙾㛂\0\0\0\0\0㛛㜃\0㜉㝬\0\0\0㞇ɲ㙖\0\0㙛get;挖;䏄rë๟ƀaey㙦㙫㙰ron;䅥dil;䅣;䑂lrec;挕r;쀀𝔱Ȁeiko㚆㚝㚵㚼ǲ㚋\0㚑eĀ4fኄኁaƀ;sv㚘㚙㚛䎸ym;䏑Ācn㚢㚲kĀas㚨㚮pproø዁im»ኬsðኞĀas㚺㚮ð዁rn耻þ䃾Ǭ̟㛆⋧es膀×;bd㛏㛐㛘䃗Ā;aᤏ㛕r;樱;樰ƀeps㛡㛣㜀á⩍Ȁ;bcf҆㛬㛰㛴ot;挶ir;櫱Ā;o㛹㛼쀀𝕥rk;櫚á㍢rime;怴ƀaip㜏㜒㝤dåቈ΀adempst㜡㝍㝀㝑㝗㝜㝟ngleʀ;dlqr㜰㜱㜶㝀㝂斵own»ᶻeftĀ;e⠀㜾ñम;扜ightĀ;e㊪㝋ñၚot;旬inus;樺lus;樹b;槍ime;樻ezium;揢ƀcht㝲㝽㞁Āry㝷㝻;쀀𝓉;䑆cy;䑛rok;䅧Āio㞋㞎xô᝷headĀlr㞗㞠eftarro÷ࡏightarrow»ཝऀAHabcdfghlmoprstuw㟐㟓㟗㟤㟰㟼㠎㠜㠣㠴㡑㡝㡫㢩㣌㣒㣪㣶ròϭar;楣Ācr㟜㟢ute耻ú䃺òᅐrǣ㟪\0㟭y;䑞ve;䅭Āiy㟵㟺rc耻û䃻;䑃ƀabh㠃㠆㠋ròᎭlac;䅱aòᏃĀir㠓㠘sht;楾;쀀𝔲rave耻ù䃹š㠧㠱rĀlr㠬㠮»ॗ»ႃlk;斀Āct㠹㡍ɯ㠿\0\0㡊rnĀ;e㡅㡆挜r»㡆op;挏ri;旸Āal㡖㡚cr;䅫肻¨͉Āgp㡢㡦on;䅳f;쀀𝕦̀adhlsuᅋ㡸㡽፲㢑㢠ownáᎳarpoonĀlr㢈㢌efô㠭ighô㠯iƀ;hl㢙㢚㢜䏅»ᏺon»㢚parrows;懈ƀcit㢰㣄㣈ɯ㢶\0\0㣁rnĀ;e㢼㢽挝r»㢽op;挎ng;䅯ri;旹cr;쀀𝓊ƀdir㣙㣝㣢ot;拰lde;䅩iĀ;f㜰㣨»᠓Āam㣯㣲rò㢨l耻ü䃼angle;榧ހABDacdeflnoprsz㤜㤟㤩㤭㦵㦸㦽㧟㧤㧨㧳㧹㧽㨁㨠ròϷarĀ;v㤦㤧櫨;櫩asèϡĀnr㤲㤷grt;榜΀eknprst㓣㥆㥋㥒㥝㥤㦖appá␕othinçẖƀhir㓫⻈㥙opô⾵Ā;hᎷ㥢ïㆍĀiu㥩㥭gmá㎳Ābp㥲㦄setneqĀ;q㥽㦀쀀⊊︀;쀀⫋︀setneqĀ;q㦏㦒쀀⊋︀;쀀⫌︀Āhr㦛㦟etá㚜iangleĀlr㦪㦯eft»थight»ၑy;䐲ash»ံƀelr㧄㧒㧗ƀ;beⷪ㧋㧏ar;抻q;扚lip;拮Ābt㧜ᑨaòᑩr;쀀𝔳tré㦮suĀbp㧯㧱»ജ»൙pf;쀀𝕧roð໻tré㦴Ācu㨆㨋r;쀀𝓋Ābp㨐㨘nĀEe㦀㨖»㥾nĀEe㦒㨞»㦐igzag;榚΀cefoprs㨶㨻㩖㩛㩔㩡㩪irc;䅵Ādi㩀㩑Ābg㩅㩉ar;機eĀ;qᗺ㩏;扙erp;愘r;쀀𝔴pf;쀀𝕨Ā;eᑹ㩦atèᑹcr;쀀𝓌ૣណ㪇\0㪋\0㪐㪛\0\0㪝㪨㪫㪯\0\0㫃㫎\0㫘ៜ៟tré៑r;쀀𝔵ĀAa㪔㪗ròσrò৶;䎾ĀAa㪡㪤ròθrò৫að✓is;拻ƀdptឤ㪵㪾Āfl㪺ឩ;쀀𝕩imåឲĀAa㫇㫊ròώròਁĀcq㫒ីr;쀀𝓍Āpt៖㫜ré។Ѐacefiosu㫰㫽㬈㬌㬑㬕㬛㬡cĀuy㫶㫻te耻ý䃽;䑏Āiy㬂㬆rc;䅷;䑋n耻¥䂥r;쀀𝔶cy;䑗pf;쀀𝕪cr;쀀𝓎Ācm㬦㬩y;䑎l耻ÿ䃿Ԁacdefhiosw㭂㭈㭔㭘㭤㭩㭭㭴㭺㮀cute;䅺Āay㭍㭒ron;䅾;䐷ot;䅼Āet㭝㭡træᕟa;䎶r;쀀𝔷cy;䐶grarr;懝pf;쀀𝕫cr;쀀𝓏Ājn㮅㮇;怍j;怌'.split("").map((e) => e.charCodeAt(0))
), hK = new Uint16Array(
  // prettier-ignore
  "Ȁaglq	\x1Bɭ\0\0p;䀦os;䀧t;䀾t;䀼uot;䀢".split("").map((e) => e.charCodeAt(0))
);
var u0;
const gK = /* @__PURE__ */ new Map([
  [0, 65533],
  // C1 Unicode control character reference replacements
  [128, 8364],
  [130, 8218],
  [131, 402],
  [132, 8222],
  [133, 8230],
  [134, 8224],
  [135, 8225],
  [136, 710],
  [137, 8240],
  [138, 352],
  [139, 8249],
  [140, 338],
  [142, 381],
  [145, 8216],
  [146, 8217],
  [147, 8220],
  [148, 8221],
  [149, 8226],
  [150, 8211],
  [151, 8212],
  [152, 732],
  [153, 8482],
  [154, 353],
  [155, 8250],
  [156, 339],
  [158, 382],
  [159, 376]
]), _K = (
  // eslint-disable-next-line @typescript-eslint/no-unnecessary-condition, node/no-unsupported-features/es-builtins
  (u0 = String.fromCodePoint) !== null && u0 !== void 0 ? u0 : function(e) {
    let t = "";
    return e > 65535 && (e -= 65536, t += String.fromCharCode(e >>> 10 & 1023 | 55296), e = 56320 | e & 1023), t += String.fromCharCode(e), t;
  }
);
function vK(e) {
  var t;
  return e >= 55296 && e <= 57343 || e > 1114111 ? 65533 : (t = gK.get(e)) !== null && t !== void 0 ? t : e;
}
var di;
(function(e) {
  e[e.NUM = 35] = "NUM", e[e.SEMI = 59] = "SEMI", e[e.EQUALS = 61] = "EQUALS", e[e.ZERO = 48] = "ZERO", e[e.NINE = 57] = "NINE", e[e.LOWER_A = 97] = "LOWER_A", e[e.LOWER_F = 102] = "LOWER_F", e[e.LOWER_X = 120] = "LOWER_X", e[e.LOWER_Z = 122] = "LOWER_Z", e[e.UPPER_A = 65] = "UPPER_A", e[e.UPPER_F = 70] = "UPPER_F", e[e.UPPER_Z = 90] = "UPPER_Z";
})(di || (di = {}));
const bK = 32;
var Rl;
(function(e) {
  e[e.VALUE_LENGTH = 49152] = "VALUE_LENGTH", e[e.BRANCH_LENGTH = 16256] = "BRANCH_LENGTH", e[e.JUMP_TABLE = 127] = "JUMP_TABLE";
})(Rl || (Rl = {}));
function ZT(e) {
  return e >= di.ZERO && e <= di.NINE;
}
function EK(e) {
  return e >= di.UPPER_A && e <= di.UPPER_F || e >= di.LOWER_A && e <= di.LOWER_F;
}
function SK(e) {
  return e >= di.UPPER_A && e <= di.UPPER_Z || e >= di.LOWER_A && e <= di.LOWER_Z || ZT(e);
}
function yK(e) {
  return e === di.EQUALS || SK(e);
}
var ci;
(function(e) {
  e[e.EntityStart = 0] = "EntityStart", e[e.NumericStart = 1] = "NumericStart", e[e.NumericDecimal = 2] = "NumericDecimal", e[e.NumericHex = 3] = "NumericHex", e[e.NamedEntity = 4] = "NamedEntity";
})(ci || (ci = {}));
var Al;
(function(e) {
  e[e.Legacy = 0] = "Legacy", e[e.Strict = 1] = "Strict", e[e.Attribute = 2] = "Attribute";
})(Al || (Al = {}));
class TK {
  constructor(t, n, r) {
    this.decodeTree = t, this.emitCodePoint = n, this.errors = r, this.state = ci.EntityStart, this.consumed = 1, this.result = 0, this.treeIndex = 0, this.excess = 1, this.decodeMode = Al.Strict;
  }
  /** Resets the instance to make it reusable. */
  startEntity(t) {
    this.decodeMode = t, this.state = ci.EntityStart, this.result = 0, this.treeIndex = 0, this.excess = 1, this.consumed = 1;
  }
  /**
   * Write an entity to the decoder. This can be called multiple times with partial entities.
   * If the entity is incomplete, the decoder will return -1.
   *
   * Mirrors the implementation of `getDecoder`, but with the ability to stop decoding if the
   * entity is incomplete, and resume when the next string is written.
   *
   * @param string The string containing the entity (or a continuation of the entity).
   * @param offset The offset at which the entity begins. Should be 0 if this is not the first call.
   * @returns The number of characters that were consumed, or -1 if the entity is incomplete.
   */
  write(t, n) {
    switch (this.state) {
      case ci.EntityStart:
        return t.charCodeAt(n) === di.NUM ? (this.state = ci.NumericStart, this.consumed += 1, this.stateNumericStart(t, n + 1)) : (this.state = ci.NamedEntity, this.stateNamedEntity(t, n));
      case ci.NumericStart:
        return this.stateNumericStart(t, n);
      case ci.NumericDecimal:
        return this.stateNumericDecimal(t, n);
      case ci.NumericHex:
        return this.stateNumericHex(t, n);
      case ci.NamedEntity:
        return this.stateNamedEntity(t, n);
    }
  }
  /**
   * Switches between the numeric decimal and hexadecimal states.
   *
   * Equivalent to the `Numeric character reference state` in the HTML spec.
   *
   * @param str The string containing the entity (or a continuation of the entity).
   * @param offset The current offset.
   * @returns The number of characters that were consumed, or -1 if the entity is incomplete.
   */
  stateNumericStart(t, n) {
    return n >= t.length ? -1 : (t.charCodeAt(n) | bK) === di.LOWER_X ? (this.state = ci.NumericHex, this.consumed += 1, this.stateNumericHex(t, n + 1)) : (this.state = ci.NumericDecimal, this.stateNumericDecimal(t, n));
  }
  addToNumericResult(t, n, r, i) {
    if (n !== r) {
      const a = r - n;
      this.result = this.result * Math.pow(i, a) + parseInt(t.substr(n, a), i), this.consumed += a;
    }
  }
  /**
   * Parses a hexadecimal numeric entity.
   *
   * Equivalent to the `Hexademical character reference state` in the HTML spec.
   *
   * @param str The string containing the entity (or a continuation of the entity).
   * @param offset The current offset.
   * @returns The number of characters that were consumed, or -1 if the entity is incomplete.
   */
  stateNumericHex(t, n) {
    const r = n;
    for (; n < t.length; ) {
      const i = t.charCodeAt(n);
      if (ZT(i) || EK(i))
        n += 1;
      else
        return this.addToNumericResult(t, r, n, 16), this.emitNumericEntity(i, 3);
    }
    return this.addToNumericResult(t, r, n, 16), -1;
  }
  /**
   * Parses a decimal numeric entity.
   *
   * Equivalent to the `Decimal character reference state` in the HTML spec.
   *
   * @param str The string containing the entity (or a continuation of the entity).
   * @param offset The current offset.
   * @returns The number of characters that were consumed, or -1 if the entity is incomplete.
   */
  stateNumericDecimal(t, n) {
    const r = n;
    for (; n < t.length; ) {
      const i = t.charCodeAt(n);
      if (ZT(i))
        n += 1;
      else
        return this.addToNumericResult(t, r, n, 10), this.emitNumericEntity(i, 2);
    }
    return this.addToNumericResult(t, r, n, 10), -1;
  }
  /**
   * Validate and emit a numeric entity.
   *
   * Implements the logic from the `Hexademical character reference start
   * state` and `Numeric character reference end state` in the HTML spec.
   *
   * @param lastCp The last code point of the entity. Used to see if the
   *               entity was terminated with a semicolon.
   * @param expectedLength The minimum number of characters that should be
   *                       consumed. Used to validate that at least one digit
   *                       was consumed.
   * @returns The number of characters that were consumed.
   */
  emitNumericEntity(t, n) {
    var r;
    if (this.consumed <= n)
      return (r = this.errors) === null || r === void 0 || r.absenceOfDigitsInNumericCharacterReference(this.consumed), 0;
    if (t === di.SEMI)
      this.consumed += 1;
    else if (this.decodeMode === Al.Strict)
      return 0;
    return this.emitCodePoint(vK(this.result), this.consumed), this.errors && (t !== di.SEMI && this.errors.missingSemicolonAfterCharacterReference(), this.errors.validateNumericCharacterReference(this.result)), this.consumed;
  }
  /**
   * Parses a named entity.
   *
   * Equivalent to the `Named character reference state` in the HTML spec.
   *
   * @param str The string containing the entity (or a continuation of the entity).
   * @param offset The current offset.
   * @returns The number of characters that were consumed, or -1 if the entity is incomplete.
   */
  stateNamedEntity(t, n) {
    const { decodeTree: r } = this;
    let i = r[this.treeIndex], a = (i & Rl.VALUE_LENGTH) >> 14;
    for (; n < t.length; n++, this.excess++) {
      const o = t.charCodeAt(n);
      if (this.treeIndex = CK(r, i, this.treeIndex + Math.max(1, a), o), this.treeIndex < 0)
        return this.result === 0 || // If we are parsing an attribute
        this.decodeMode === Al.Attribute && // We shouldn't have consumed any characters after the entity,
        (a === 0 || // And there should be no invalid characters.
        yK(o)) ? 0 : this.emitNotTerminatedNamedEntity();
      if (i = r[this.treeIndex], a = (i & Rl.VALUE_LENGTH) >> 14, a !== 0) {
        if (o === di.SEMI)
          return this.emitNamedEntityData(this.treeIndex, a, this.consumed + this.excess);
        this.decodeMode !== Al.Strict && (this.result = this.treeIndex, this.consumed += this.excess, this.excess = 0);
      }
    }
    return -1;
  }
  /**
   * Emit a named entity that was not terminated with a semicolon.
   *
   * @returns The number of characters consumed.
   */
  emitNotTerminatedNamedEntity() {
    var t;
    const { result: n, decodeTree: r } = this, i = (r[n] & Rl.VALUE_LENGTH) >> 14;
    return this.emitNamedEntityData(n, i, this.consumed), (t = this.errors) === null || t === void 0 || t.missingSemicolonAfterCharacterReference(), this.consumed;
  }
  /**
   * Emit a named entity.
   *
   * @param result The index of the entity in the decode tree.
   * @param valueLength The number of bytes in the entity.
   * @param consumed The number of characters consumed.
   *
   * @returns The number of characters consumed.
   */
  emitNamedEntityData(t, n, r) {
    const { decodeTree: i } = this;
    return this.emitCodePoint(n === 1 ? i[t] & ~Rl.VALUE_LENGTH : i[t + 1], r), n === 3 && this.emitCodePoint(i[t + 2], r), r;
  }
  /**
   * Signal to the parser that the end of the input was reached.
   *
   * Remaining data will be emitted and relevant errors will be produced.
   *
   * @returns The number of characters consumed.
   */
  end() {
    var t;
    switch (this.state) {
      case ci.NamedEntity:
        return this.result !== 0 && (this.decodeMode !== Al.Attribute || this.result === this.treeIndex) ? this.emitNotTerminatedNamedEntity() : 0;
      case ci.NumericDecimal:
        return this.emitNumericEntity(0, 2);
      case ci.NumericHex:
        return this.emitNumericEntity(0, 3);
      case ci.NumericStart:
        return (t = this.errors) === null || t === void 0 || t.absenceOfDigitsInNumericCharacterReference(this.consumed), 0;
      case ci.EntityStart:
        return 0;
    }
  }
}
function _F(e) {
  let t = "";
  const n = new TK(e, (r) => t += _K(r));
  return function(i, a) {
    let o = 0, s = 0;
    for (; (s = i.indexOf("&", s)) >= 0; ) {
      t += i.slice(o, s), n.startEntity(a);
      const u = n.write(
        i,
        // Skip the "&"
        s + 1
      );
      if (u < 0) {
        o = s + n.end();
        break;
      }
      o = s + u, s = u === 0 ? o + 1 : o;
    }
    const l = t + i.slice(o);
    return t = "", l;
  };
}
function CK(e, t, n, r) {
  const i = (t & Rl.BRANCH_LENGTH) >> 7, a = t & Rl.JUMP_TABLE;
  if (i === 0)
    return a !== 0 && r === a ? n : -1;
  if (a) {
    const l = r - a;
    return l < 0 || l >= i ? -1 : e[n + l] - 1;
  }
  let o = n, s = o + i - 1;
  for (; o <= s; ) {
    const l = o + s >>> 1, u = e[l];
    if (u < r)
      o = l + 1;
    else if (u > r)
      s = l - 1;
    else
      return e[l + i];
  }
  return -1;
}
const AK = _F(mK);
_F(hK);
function vF(e, t = Al.Legacy) {
  return AK(e, t);
}
function OK(e) {
  return Object.prototype.toString.call(e);
}
function h1(e) {
  return OK(e) === "[object String]";
}
const RK = Object.prototype.hasOwnProperty;
function wK(e, t) {
  return RK.call(e, t);
}
function F_(e) {
  return Array.prototype.slice.call(arguments, 1).forEach(function(n) {
    if (n) {
      if (typeof n != "object")
        throw new TypeError(n + "must be object");
      Object.keys(n).forEach(function(r) {
        e[r] = n[r];
      });
    }
  }), e;
}
function bF(e, t, n) {
  return [].concat(e.slice(0, t), n, e.slice(t + 1));
}
function g1(e) {
  return !(e >= 55296 && e <= 57343 || e >= 64976 && e <= 65007 || (e & 65535) === 65535 || (e & 65535) === 65534 || e >= 0 && e <= 8 || e === 11 || e >= 14 && e <= 31 || e >= 127 && e <= 159 || e > 1114111);
}
function Lg(e) {
  if (e > 65535) {
    e -= 65536;
    const t = 55296 + (e >> 10), n = 56320 + (e & 1023);
    return String.fromCharCode(t, n);
  }
  return String.fromCharCode(e);
}
const EF = /\\([!"#$%&'()*+,\-./:;<=>?@[\\\]^_`{|}~])/g, xK = /&([a-z#][a-z0-9]{1,31});/gi, NK = new RegExp(EF.source + "|" + xK.source, "gi"), DK = /^#((?:x[a-f0-9]{1,8}|[0-9]{1,8}))$/i;
function IK(e, t) {
  if (t.charCodeAt(0) === 35 && DK.test(t)) {
    const r = t[1].toLowerCase() === "x" ? parseInt(t.slice(2), 16) : parseInt(t.slice(1), 10);
    return g1(r) ? Lg(r) : e;
  }
  const n = vF(e);
  return n !== e ? n : e;
}
function LK(e) {
  return e.indexOf("\\") < 0 ? e : e.replace(EF, "$1");
}
function vp(e) {
  return e.indexOf("\\") < 0 && e.indexOf("&") < 0 ? e : e.replace(NK, function(t, n, r) {
    return n || IK(t, r);
  });
}
const kK = /[&<>"]/, MK = /[&<>"]/g, PK = {
  "&": "&amp;",
  "<": "&lt;",
  ">": "&gt;",
  '"': "&quot;"
};
function FK(e) {
  return PK[e];
}
function Bl(e) {
  return kK.test(e) ? e.replace(MK, FK) : e;
}
const BK = /[.?*+^$[\]\\(){}|-]/g;
function $K(e) {
  return e.replace(BK, "\\$&");
}
function tr(e) {
  switch (e) {
    case 9:
    case 32:
      return !0;
  }
  return !1;
}
function bp(e) {
  if (e >= 8192 && e <= 8202)
    return !0;
  switch (e) {
    case 9:
    case 10:
    case 11:
    case 12:
    case 13:
    case 32:
    case 160:
    case 5760:
    case 8239:
    case 8287:
    case 12288:
      return !0;
  }
  return !1;
}
function Ep(e) {
  return m1.test(e);
}
function Sp(e) {
  switch (e) {
    case 33:
    case 34:
    case 35:
    case 36:
    case 37:
    case 38:
    case 39:
    case 40:
    case 41:
    case 42:
    case 43:
    case 44:
    case 45:
    case 46:
    case 47:
    case 58:
    case 59:
    case 60:
    case 61:
    case 62:
    case 63:
    case 64:
    case 91:
    case 92:
    case 93:
    case 94:
    case 95:
    case 96:
    case 123:
    case 124:
    case 125:
    case 126:
      return !0;
    default:
      return !1;
  }
}
function B_(e) {
  return e = e.trim().replace(/\s+/g, " "), "ẞ".toLowerCase() === "Ṿ" && (e = e.replace(/ẞ/g, "ß")), e.toLowerCase().toUpperCase();
}
const UK = { mdurl: dK, ucmicro: pK }, qK = /* @__PURE__ */ Object.freeze(/* @__PURE__ */ Object.defineProperty({
  __proto__: null,
  arrayReplaceAt: bF,
  assign: F_,
  escapeHtml: Bl,
  escapeRE: $K,
  fromCodePoint: Lg,
  has: wK,
  isMdAsciiPunct: Sp,
  isPunctChar: Ep,
  isSpace: tr,
  isString: h1,
  isValidEntityCode: g1,
  isWhiteSpace: bp,
  lib: UK,
  normalizeReference: B_,
  unescapeAll: vp,
  unescapeMd: LK
}, Symbol.toStringTag, { value: "Module" }));
function GK(e, t, n) {
  let r, i, a, o;
  const s = e.posMax, l = e.pos;
  for (e.pos = t + 1, r = 1; e.pos < s; ) {
    if (a = e.src.charCodeAt(e.pos), a === 93 && (r--, r === 0)) {
      i = !0;
      break;
    }
    if (o = e.pos, e.md.inline.skipToken(e), a === 91) {
      if (o === e.pos - 1)
        r++;
      else if (n)
        return e.pos = l, -1;
    }
  }
  let u = -1;
  return i && (u = e.pos), e.pos = l, u;
}
function YK(e, t, n) {
  let r, i = t;
  const a = {
    ok: !1,
    pos: 0,
    lines: 0,
    str: ""
  };
  if (e.charCodeAt(i) === 60) {
    for (i++; i < n; ) {
      if (r = e.charCodeAt(i), r === 10 || r === 60)
        return a;
      if (r === 62)
        return a.pos = i + 1, a.str = vp(e.slice(t + 1, i)), a.ok = !0, a;
      if (r === 92 && i + 1 < n) {
        i += 2;
        continue;
      }
      i++;
    }
    return a;
  }
  let o = 0;
  for (; i < n && (r = e.charCodeAt(i), !(r === 32 || r < 32 || r === 127)); ) {
    if (r === 92 && i + 1 < n) {
      if (e.charCodeAt(i + 1) === 32)
        break;
      i += 2;
      continue;
    }
    if (r === 40 && (o++, o > 32))
      return a;
    if (r === 41) {
      if (o === 0)
        break;
      o--;
    }
    i++;
  }
  return t === i || o !== 0 || (a.str = vp(e.slice(t, i)), a.pos = i, a.ok = !0), a;
}
function HK(e, t, n) {
  let r, i, a = 0, o = t;
  const s = {
    ok: !1,
    pos: 0,
    lines: 0,
    str: ""
  };
  if (o >= n || (i = e.charCodeAt(o), i !== 34 && i !== 39 && i !== 40))
    return s;
  for (o++, i === 40 && (i = 41); o < n; ) {
    if (r = e.charCodeAt(o), r === i)
      return s.pos = o + 1, s.lines = a, s.str = vp(e.slice(t + 1, o)), s.ok = !0, s;
    if (r === 40 && i === 41)
      return s;
    r === 10 ? a++ : r === 92 && o + 1 < n && (o++, e.charCodeAt(o) === 10 && a++), o++;
  }
  return s;
}
const zK = /* @__PURE__ */ Object.freeze(/* @__PURE__ */ Object.defineProperty({
  __proto__: null,
  parseLinkDestination: YK,
  parseLinkLabel: GK,
  parseLinkTitle: HK
}, Symbol.toStringTag, { value: "Module" })), es = {};
es.code_inline = function(e, t, n, r, i) {
  const a = e[t];
  return "<code" + i.renderAttrs(a) + ">" + Bl(a.content) + "</code>";
};
es.code_block = function(e, t, n, r, i) {
  const a = e[t];
  return "<pre" + i.renderAttrs(a) + "><code>" + Bl(e[t].content) + `</code></pre>
`;
};
es.fence = function(e, t, n, r, i) {
  const a = e[t], o = a.info ? vp(a.info).trim() : "";
  let s = "", l = "";
  if (o) {
    const c = o.split(/(\s+)/g);
    s = c[0], l = c.slice(2).join("");
  }
  let u;
  if (n.highlight ? u = n.highlight(a.content, s, l) || Bl(a.content) : u = Bl(a.content), u.indexOf("<pre") === 0)
    return u + `
`;
  if (o) {
    const c = a.attrIndex("class"), d = a.attrs ? a.attrs.slice() : [];
    c < 0 ? d.push(["class", n.langPrefix + s]) : (d[c] = d[c].slice(), d[c][1] += " " + n.langPrefix + s);
    const f = {
      attrs: d
    };
    return `<pre><code${i.renderAttrs(f)}>${u}</code></pre>
`;
  }
  return `<pre><code${i.renderAttrs(a)}>${u}</code></pre>
`;
};
es.image = function(e, t, n, r, i) {
  const a = e[t];
  return a.attrs[a.attrIndex("alt")][1] = i.renderInlineAsText(a.children, n, r), i.renderToken(e, t, n);
};
es.hardbreak = function(e, t, n) {
  return n.xhtmlOut ? `<br />
` : `<br>
`;
};
es.softbreak = function(e, t, n) {
  return n.breaks ? n.xhtmlOut ? `<br />
` : `<br>
` : `
`;
};
es.text = function(e, t) {
  return Bl(e[t].content);
};
es.html_block = function(e, t) {
  return e[t].content;
};
es.html_inline = function(e, t) {
  return e[t].content;
};
function Ad() {
  this.rules = F_({}, es);
}
Ad.prototype.renderAttrs = function(t) {
  let n, r, i;
  if (!t.attrs)
    return "";
  for (i = "", n = 0, r = t.attrs.length; n < r; n++)
    i += " " + Bl(t.attrs[n][0]) + '="' + Bl(t.attrs[n][1]) + '"';
  return i;
};
Ad.prototype.renderToken = function(t, n, r) {
  const i = t[n];
  let a = "";
  if (i.hidden)
    return "";
  i.block && i.nesting !== -1 && n && t[n - 1].hidden && (a += `
`), a += (i.nesting === -1 ? "</" : "<") + i.tag, a += this.renderAttrs(i), i.nesting === 0 && r.xhtmlOut && (a += " /");
  let o = !1;
  if (i.block && (o = !0, i.nesting === 1 && n + 1 < t.length)) {
    const s = t[n + 1];
    (s.type === "inline" || s.hidden || s.nesting === -1 && s.tag === i.tag) && (o = !1);
  }
  return a += o ? `>
` : ">", a;
};
Ad.prototype.renderInline = function(e, t, n) {
  let r = "";
  const i = this.rules;
  for (let a = 0, o = e.length; a < o; a++) {
    const s = e[a].type;
    typeof i[s] < "u" ? r += i[s](e, a, t, n, this) : r += this.renderToken(e, a, t);
  }
  return r;
};
Ad.prototype.renderInlineAsText = function(e, t, n) {
  let r = "";
  for (let i = 0, a = e.length; i < a; i++)
    switch (e[i].type) {
      case "text":
        r += e[i].content;
        break;
      case "image":
        r += this.renderInlineAsText(e[i].children, t, n);
        break;
      case "html_inline":
      case "html_block":
        r += e[i].content;
        break;
      case "softbreak":
      case "hardbreak":
        r += `
`;
        break;
    }
  return r;
};
Ad.prototype.render = function(e, t, n) {
  let r = "";
  const i = this.rules;
  for (let a = 0, o = e.length; a < o; a++) {
    const s = e[a].type;
    s === "inline" ? r += this.renderInline(e[a].children, t, n) : typeof i[s] < "u" ? r += i[s](e, a, t, n, this) : r += this.renderToken(e, a, t, n);
  }
  return r;
};
function ma() {
  this.__rules__ = [], this.__cache__ = null;
}
ma.prototype.__find__ = function(e) {
  for (let t = 0; t < this.__rules__.length; t++)
    if (this.__rules__[t].name === e)
      return t;
  return -1;
};
ma.prototype.__compile__ = function() {
  const e = this, t = [""];
  e.__rules__.forEach(function(n) {
    n.enabled && n.alt.forEach(function(r) {
      t.indexOf(r) < 0 && t.push(r);
    });
  }), e.__cache__ = {}, t.forEach(function(n) {
    e.__cache__[n] = [], e.__rules__.forEach(function(r) {
      r.enabled && (n && r.alt.indexOf(n) < 0 || e.__cache__[n].push(r.fn));
    });
  });
};
ma.prototype.at = function(e, t, n) {
  const r = this.__find__(e), i = n || {};
  if (r === -1)
    throw new Error("Parser rule not found: " + e);
  this.__rules__[r].fn = t, this.__rules__[r].alt = i.alt || [], this.__cache__ = null;
};
ma.prototype.before = function(e, t, n, r) {
  const i = this.__find__(e), a = r || {};
  if (i === -1)
    throw new Error("Parser rule not found: " + e);
  this.__rules__.splice(i, 0, {
    name: t,
    enabled: !0,
    fn: n,
    alt: a.alt || []
  }), this.__cache__ = null;
};
ma.prototype.after = function(e, t, n, r) {
  const i = this.__find__(e), a = r || {};
  if (i === -1)
    throw new Error("Parser rule not found: " + e);
  this.__rules__.splice(i + 1, 0, {
    name: t,
    enabled: !0,
    fn: n,
    alt: a.alt || []
  }), this.__cache__ = null;
};
ma.prototype.push = function(e, t, n) {
  const r = n || {};
  this.__rules__.push({
    name: e,
    enabled: !0,
    fn: t,
    alt: r.alt || []
  }), this.__cache__ = null;
};
ma.prototype.enable = function(e, t) {
  Array.isArray(e) || (e = [e]);
  const n = [];
  return e.forEach(function(r) {
    const i = this.__find__(r);
    if (i < 0) {
      if (t)
        return;
      throw new Error("Rules manager: invalid rule name " + r);
    }
    this.__rules__[i].enabled = !0, n.push(r);
  }, this), this.__cache__ = null, n;
};
ma.prototype.enableOnly = function(e, t) {
  Array.isArray(e) || (e = [e]), this.__rules__.forEach(function(n) {
    n.enabled = !1;
  }), this.enable(e, t);
};
ma.prototype.disable = function(e, t) {
  Array.isArray(e) || (e = [e]);
  const n = [];
  return e.forEach(function(r) {
    const i = this.__find__(r);
    if (i < 0) {
      if (t)
        return;
      throw new Error("Rules manager: invalid rule name " + r);
    }
    this.__rules__[i].enabled = !1, n.push(r);
  }, this), this.__cache__ = null, n;
};
ma.prototype.getRules = function(e) {
  return this.__cache__ === null && this.__compile__(), this.__cache__[e] || [];
};
function Ao(e, t, n) {
  this.type = e, this.tag = t, this.attrs = null, this.map = null, this.nesting = n, this.level = 0, this.children = null, this.content = "", this.markup = "", this.info = "", this.meta = null, this.block = !1, this.hidden = !1;
}
Ao.prototype.attrIndex = function(t) {
  if (!this.attrs)
    return -1;
  const n = this.attrs;
  for (let r = 0, i = n.length; r < i; r++)
    if (n[r][0] === t)
      return r;
  return -1;
};
Ao.prototype.attrPush = function(t) {
  this.attrs ? this.attrs.push(t) : this.attrs = [t];
};
Ao.prototype.attrSet = function(t, n) {
  const r = this.attrIndex(t), i = [t, n];
  r < 0 ? this.attrPush(i) : this.attrs[r] = i;
};
Ao.prototype.attrGet = function(t) {
  const n = this.attrIndex(t);
  let r = null;
  return n >= 0 && (r = this.attrs[n][1]), r;
};
Ao.prototype.attrJoin = function(t, n) {
  const r = this.attrIndex(t);
  r < 0 ? this.attrPush([t, n]) : this.attrs[r][1] = this.attrs[r][1] + " " + n;
};
function SF(e, t, n) {
  this.src = e, this.env = n, this.tokens = [], this.inlineMode = !1, this.md = t;
}
SF.prototype.Token = Ao;
const VK = /\r\n?|\n/g, WK = /\0/g;
function KK(e) {
  let t;
  t = e.src.replace(VK, `
`), t = t.replace(WK, "�"), e.src = t;
}
function jK(e) {
  let t;
  e.inlineMode ? (t = new e.Token("inline", "", 0), t.content = e.src, t.map = [0, 1], t.children = [], e.tokens.push(t)) : e.md.block.parse(e.src, e.md, e.env, e.tokens);
}
function QK(e) {
  const t = e.tokens;
  for (let n = 0, r = t.length; n < r; n++) {
    const i = t[n];
    i.type === "inline" && e.md.inline.parse(i.content, e.md, e.env, i.children);
  }
}
function XK(e) {
  return /^<a[>\s]/i.test(e);
}
function ZK(e) {
  return /^<\/a\s*>/i.test(e);
}
function JK(e) {
  const t = e.tokens;
  if (e.md.options.linkify)
    for (let n = 0, r = t.length; n < r; n++) {
      if (t[n].type !== "inline" || !e.md.linkify.pretest(t[n].content))
        continue;
      let i = t[n].children, a = 0;
      for (let o = i.length - 1; o >= 0; o--) {
        const s = i[o];
        if (s.type === "link_close") {
          for (o--; i[o].level !== s.level && i[o].type !== "link_open"; )
            o--;
          continue;
        }
        if (s.type === "html_inline" && (XK(s.content) && a > 0 && a--, ZK(s.content) && a++), !(a > 0) && s.type === "text" && e.md.linkify.test(s.content)) {
          const l = s.content;
          let u = e.md.linkify.match(l);
          const c = [];
          let d = s.level, f = 0;
          u.length > 0 && u[0].index === 0 && o > 0 && i[o - 1].type === "text_special" && (u = u.slice(1));
          for (let h = 0; h < u.length; h++) {
            const m = u[h].url, v = e.md.normalizeLink(m);
            if (!e.md.validateLink(v))
              continue;
            let b = u[h].text;
            u[h].schema ? u[h].schema === "mailto:" && !/^mailto:/i.test(b) ? b = e.md.normalizeLinkText("mailto:" + b).replace(/^mailto:/, "") : b = e.md.normalizeLinkText(b) : b = e.md.normalizeLinkText("http://" + b).replace(/^http:\/\//, "");
            const y = u[h].index;
            if (y > f) {
              const C = new e.Token("text", "", 0);
              C.content = l.slice(f, y), C.level = d, c.push(C);
            }
            const g = new e.Token("link_open", "a", 1);
            g.attrs = [["href", v]], g.level = d++, g.markup = "linkify", g.info = "auto", c.push(g);
            const E = new e.Token("text", "", 0);
            E.content = b, E.level = d, c.push(E);
            const S = new e.Token("link_close", "a", -1);
            S.level = --d, S.markup = "linkify", S.info = "auto", c.push(S), f = u[h].lastIndex;
          }
          if (f < l.length) {
            const h = new e.Token("text", "", 0);
            h.content = l.slice(f), h.level = d, c.push(h);
          }
          t[n].children = i = bF(i, o, c);
        }
      }
    }
}
const yF = /\+-|\.\.|\?\?\?\?|!!!!|,,|--/, ej = /\((c|tm|r)\)/i, tj = /\((c|tm|r)\)/ig, nj = {
  c: "©",
  r: "®",
  tm: "™"
};
function rj(e, t) {
  return nj[t.toLowerCase()];
}
function ij(e) {
  let t = 0;
  for (let n = e.length - 1; n >= 0; n--) {
    const r = e[n];
    r.type === "text" && !t && (r.content = r.content.replace(tj, rj)), r.type === "link_open" && r.info === "auto" && t--, r.type === "link_close" && r.info === "auto" && t++;
  }
}
function aj(e) {
  let t = 0;
  for (let n = e.length - 1; n >= 0; n--) {
    const r = e[n];
    r.type === "text" && !t && yF.test(r.content) && (r.content = r.content.replace(/\+-/g, "±").replace(/\.{2,}/g, "…").replace(/([?!])…/g, "$1..").replace(/([?!]){4,}/g, "$1$1$1").replace(/,{2,}/g, ",").replace(/(^|[^-])---(?=[^-]|$)/mg, "$1—").replace(/(^|\s)--(?=\s|$)/mg, "$1–").replace(/(^|[^-\s])--(?=[^-\s]|$)/mg, "$1–")), r.type === "link_open" && r.info === "auto" && t--, r.type === "link_close" && r.info === "auto" && t++;
  }
}
function oj(e) {
  let t;
  if (e.md.options.typographer)
    for (t = e.tokens.length - 1; t >= 0; t--)
      e.tokens[t].type === "inline" && (ej.test(e.tokens[t].content) && ij(e.tokens[t].children), yF.test(e.tokens[t].content) && aj(e.tokens[t].children));
}
const sj = /['"]/, oN = /['"]/g, sN = "’";
function kh(e, t, n) {
  return e.slice(0, t) + n + e.slice(t + 1);
}
function lj(e, t) {
  let n;
  const r = [];
  for (let i = 0; i < e.length; i++) {
    const a = e[i], o = e[i].level;
    for (n = r.length - 1; n >= 0 && !(r[n].level <= o); n--)
      ;
    if (r.length = n + 1, a.type !== "text")
      continue;
    let s = a.content, l = 0, u = s.length;
    e:
      for (; l < u; ) {
        oN.lastIndex = l;
        const c = oN.exec(s);
        if (!c)
          break;
        let d = !0, f = !0;
        l = c.index + 1;
        const h = c[0] === "'";
        let m = 32;
        if (c.index - 1 >= 0)
          m = s.charCodeAt(c.index - 1);
        else
          for (n = i - 1; n >= 0 && !(e[n].type === "softbreak" || e[n].type === "hardbreak"); n--)
            if (e[n].content) {
              m = e[n].content.charCodeAt(e[n].content.length - 1);
              break;
            }
        let v = 32;
        if (l < u)
          v = s.charCodeAt(l);
        else
          for (n = i + 1; n < e.length && !(e[n].type === "softbreak" || e[n].type === "hardbreak"); n++)
            if (e[n].content) {
              v = e[n].content.charCodeAt(0);
              break;
            }
        const b = Sp(m) || Ep(String.fromCharCode(m)), y = Sp(v) || Ep(String.fromCharCode(v)), g = bp(m), E = bp(v);
        if (E ? d = !1 : y && (g || b || (d = !1)), g ? f = !1 : b && (E || y || (f = !1)), v === 34 && c[0] === '"' && m >= 48 && m <= 57 && (f = d = !1), d && f && (d = b, f = y), !d && !f) {
          h && (a.content = kh(a.content, c.index, sN));
          continue;
        }
        if (f)
          for (n = r.length - 1; n >= 0; n--) {
            let S = r[n];
            if (r[n].level < o)
              break;
            if (S.single === h && r[n].level === o) {
              S = r[n];
              let C, T;
              h ? (C = t.md.options.quotes[2], T = t.md.options.quotes[3]) : (C = t.md.options.quotes[0], T = t.md.options.quotes[1]), a.content = kh(a.content, c.index, T), e[S.token].content = kh(
                e[S.token].content,
                S.pos,
                C
              ), l += T.length - 1, S.token === i && (l += C.length - 1), s = a.content, u = s.length, r.length = n;
              continue e;
            }
          }
        d ? r.push({
          token: i,
          pos: c.index,
          single: h,
          level: o
        }) : f && h && (a.content = kh(a.content, c.index, sN));
      }
  }
}
function uj(e) {
  if (e.md.options.typographer)
    for (let t = e.tokens.length - 1; t >= 0; t--)
      e.tokens[t].type !== "inline" || !sj.test(e.tokens[t].content) || lj(e.tokens[t].children, e);
}
function cj(e) {
  let t, n;
  const r = e.tokens, i = r.length;
  for (let a = 0; a < i; a++) {
    if (r[a].type !== "inline") continue;
    const o = r[a].children, s = o.length;
    for (t = 0; t < s; t++)
      o[t].type === "text_special" && (o[t].type = "text");
    for (t = n = 0; t < s; t++)
      o[t].type === "text" && t + 1 < s && o[t + 1].type === "text" ? o[t + 1].content = o[t].content + o[t + 1].content : (t !== n && (o[n] = o[t]), n++);
    t !== n && (o.length = n);
  }
}
const c0 = [
  ["normalize", KK],
  ["block", jK],
  ["inline", QK],
  ["linkify", JK],
  ["replacements", oj],
  ["smartquotes", uj],
  // `text_join` finds `text_special` tokens (for escape sequences)
  // and joins them with the rest of the text
  ["text_join", cj]
];
function _1() {
  this.ruler = new ma();
  for (let e = 0; e < c0.length; e++)
    this.ruler.push(c0[e][0], c0[e][1]);
}
_1.prototype.process = function(e) {
  const t = this.ruler.getRules("");
  for (let n = 0, r = t.length; n < r; n++)
    t[n](e);
};
_1.prototype.State = SF;
function ts(e, t, n, r) {
  this.src = e, this.md = t, this.env = n, this.tokens = r, this.bMarks = [], this.eMarks = [], this.tShift = [], this.sCount = [], this.bsCount = [], this.blkIndent = 0, this.line = 0, this.lineMax = 0, this.tight = !1, this.ddIndent = -1, this.listIndent = -1, this.parentType = "root", this.level = 0;
  const i = this.src;
  for (let a = 0, o = 0, s = 0, l = 0, u = i.length, c = !1; o < u; o++) {
    const d = i.charCodeAt(o);
    if (!c)
      if (tr(d)) {
        s++, d === 9 ? l += 4 - l % 4 : l++;
        continue;
      } else
        c = !0;
    (d === 10 || o === u - 1) && (d !== 10 && o++, this.bMarks.push(a), this.eMarks.push(o), this.tShift.push(s), this.sCount.push(l), this.bsCount.push(0), c = !1, s = 0, l = 0, a = o + 1);
  }
  this.bMarks.push(i.length), this.eMarks.push(i.length), this.tShift.push(0), this.sCount.push(0), this.bsCount.push(0), this.lineMax = this.bMarks.length - 1;
}
ts.prototype.push = function(e, t, n) {
  const r = new Ao(e, t, n);
  return r.block = !0, n < 0 && this.level--, r.level = this.level, n > 0 && this.level++, this.tokens.push(r), r;
};
ts.prototype.isEmpty = function(t) {
  return this.bMarks[t] + this.tShift[t] >= this.eMarks[t];
};
ts.prototype.skipEmptyLines = function(t) {
  for (let n = this.lineMax; t < n && !(this.bMarks[t] + this.tShift[t] < this.eMarks[t]); t++)
    ;
  return t;
};
ts.prototype.skipSpaces = function(t) {
  for (let n = this.src.length; t < n; t++) {
    const r = this.src.charCodeAt(t);
    if (!tr(r))
      break;
  }
  return t;
};
ts.prototype.skipSpacesBack = function(t, n) {
  if (t <= n)
    return t;
  for (; t > n; )
    if (!tr(this.src.charCodeAt(--t)))
      return t + 1;
  return t;
};
ts.prototype.skipChars = function(t, n) {
  for (let r = this.src.length; t < r && this.src.charCodeAt(t) === n; t++)
    ;
  return t;
};
ts.prototype.skipCharsBack = function(t, n, r) {
  if (t <= r)
    return t;
  for (; t > r; )
    if (n !== this.src.charCodeAt(--t))
      return t + 1;
  return t;
};
ts.prototype.getLines = function(t, n, r, i) {
  if (t >= n)
    return "";
  const a = new Array(n - t);
  for (let o = 0, s = t; s < n; s++, o++) {
    let l = 0;
    const u = this.bMarks[s];
    let c = u, d;
    for (s + 1 < n || i ? d = this.eMarks[s] + 1 : d = this.eMarks[s]; c < d && l < r; ) {
      const f = this.src.charCodeAt(c);
      if (tr(f))
        f === 9 ? l += 4 - (l + this.bsCount[s]) % 4 : l++;
      else if (c - u < this.tShift[s])
        l++;
      else
        break;
      c++;
    }
    l > r ? a[o] = new Array(l - r + 1).join(" ") + this.src.slice(c, d) : a[o] = this.src.slice(c, d);
  }
  return a.join("");
};
ts.prototype.Token = Ao;
function d0(e, t) {
  const n = e.bMarks[t] + e.tShift[t], r = e.eMarks[t];
  return e.src.slice(n, r);
}
function lN(e) {
  const t = [], n = e.length;
  let r = 0, i = e.charCodeAt(r), a = !1, o = 0, s = "";
  for (; r < n; )
    i === 124 && (a ? (s += e.substring(o, r - 1), o = r) : (t.push(s + e.substring(o, r)), s = "", o = r + 1)), a = i === 92, r++, i = e.charCodeAt(r);
  return t.push(s + e.substring(o)), t;
}
function dj(e, t, n, r) {
  if (t + 2 > n)
    return !1;
  let i = t + 1;
  if (e.sCount[i] < e.blkIndent || e.sCount[i] - e.blkIndent >= 4)
    return !1;
  let a = e.bMarks[i] + e.tShift[i];
  if (a >= e.eMarks[i])
    return !1;
  const o = e.src.charCodeAt(a++);
  if (o !== 124 && o !== 45 && o !== 58 || a >= e.eMarks[i])
    return !1;
  const s = e.src.charCodeAt(a++);
  if (s !== 124 && s !== 45 && s !== 58 && !tr(s) || o === 45 && tr(s))
    return !1;
  for (; a < e.eMarks[i]; ) {
    const E = e.src.charCodeAt(a);
    if (E !== 124 && E !== 45 && E !== 58 && !tr(E))
      return !1;
    a++;
  }
  let l = d0(e, t + 1), u = l.split("|");
  const c = [];
  for (let E = 0; E < u.length; E++) {
    const S = u[E].trim();
    if (!S) {
      if (E === 0 || E === u.length - 1)
        continue;
      return !1;
    }
    if (!/^:?-+:?$/.test(S))
      return !1;
    S.charCodeAt(S.length - 1) === 58 ? c.push(S.charCodeAt(0) === 58 ? "center" : "right") : S.charCodeAt(0) === 58 ? c.push("left") : c.push("");
  }
  if (l = d0(e, t).trim(), l.indexOf("|") === -1 || e.sCount[t] - e.blkIndent >= 4)
    return !1;
  u = lN(l), u.length && u[0] === "" && u.shift(), u.length && u[u.length - 1] === "" && u.pop();
  const d = u.length;
  if (d === 0 || d !== c.length)
    return !1;
  if (r)
    return !0;
  const f = e.parentType;
  e.parentType = "table";
  const h = e.md.block.ruler.getRules("blockquote"), m = e.push("table_open", "table", 1), v = [t, 0];
  m.map = v;
  const b = e.push("thead_open", "thead", 1);
  b.map = [t, t + 1];
  const y = e.push("tr_open", "tr", 1);
  y.map = [t, t + 1];
  for (let E = 0; E < u.length; E++) {
    const S = e.push("th_open", "th", 1);
    c[E] && (S.attrs = [["style", "text-align:" + c[E]]]);
    const C = e.push("inline", "", 0);
    C.content = u[E].trim(), C.children = [], e.push("th_close", "th", -1);
  }
  e.push("tr_close", "tr", -1), e.push("thead_close", "thead", -1);
  let g;
  for (i = t + 2; i < n && !(e.sCount[i] < e.blkIndent); i++) {
    let E = !1;
    for (let C = 0, T = h.length; C < T; C++)
      if (h[C](e, i, n, !0)) {
        E = !0;
        break;
      }
    if (E || (l = d0(e, i).trim(), !l) || e.sCount[i] - e.blkIndent >= 4)
      break;
    if (u = lN(l), u.length && u[0] === "" && u.shift(), u.length && u[u.length - 1] === "" && u.pop(), i === t + 2) {
      const C = e.push("tbody_open", "tbody", 1);
      C.map = g = [t + 2, 0];
    }
    const S = e.push("tr_open", "tr", 1);
    S.map = [i, i + 1];
    for (let C = 0; C < d; C++) {
      const T = e.push("td_open", "td", 1);
      c[C] && (T.attrs = [["style", "text-align:" + c[C]]]);
      const O = e.push("inline", "", 0);
      O.content = u[C] ? u[C].trim() : "", O.children = [], e.push("td_close", "td", -1);
    }
    e.push("tr_close", "tr", -1);
  }
  return g && (e.push("tbody_close", "tbody", -1), g[1] = i), e.push("table_close", "table", -1), v[1] = i, e.parentType = f, e.line = i, !0;
}
function fj(e, t, n) {
  if (e.sCount[t] - e.blkIndent < 4)
    return !1;
  let r = t + 1, i = r;
  for (; r < n; ) {
    if (e.isEmpty(r)) {
      r++;
      continue;
    }
    if (e.sCount[r] - e.blkIndent >= 4) {
      r++, i = r;
      continue;
    }
    break;
  }
  e.line = i;
  const a = e.push("code_block", "code", 0);
  return a.content = e.getLines(t, i, 4 + e.blkIndent, !1) + `
`, a.map = [t, e.line], !0;
}
function pj(e, t, n, r) {
  let i = e.bMarks[t] + e.tShift[t], a = e.eMarks[t];
  if (e.sCount[t] - e.blkIndent >= 4 || i + 3 > a)
    return !1;
  const o = e.src.charCodeAt(i);
  if (o !== 126 && o !== 96)
    return !1;
  let s = i;
  i = e.skipChars(i, o);
  let l = i - s;
  if (l < 3)
    return !1;
  const u = e.src.slice(s, i), c = e.src.slice(i, a);
  if (o === 96 && c.indexOf(String.fromCharCode(o)) >= 0)
    return !1;
  if (r)
    return !0;
  let d = t, f = !1;
  for (; d++, !(d >= n || (i = s = e.bMarks[d] + e.tShift[d], a = e.eMarks[d], i < a && e.sCount[d] < e.blkIndent)); )
    if (e.src.charCodeAt(i) === o && !(e.sCount[d] - e.blkIndent >= 4) && (i = e.skipChars(i, o), !(i - s < l) && (i = e.skipSpaces(i), !(i < a)))) {
      f = !0;
      break;
    }
  l = e.sCount[t], e.line = d + (f ? 1 : 0);
  const h = e.push("fence", "code", 0);
  return h.info = c, h.content = e.getLines(t + 1, d, l, !0), h.markup = u, h.map = [t, e.line], !0;
}
function mj(e, t, n, r) {
  let i = e.bMarks[t] + e.tShift[t], a = e.eMarks[t];
  const o = e.lineMax;
  if (e.sCount[t] - e.blkIndent >= 4 || e.src.charCodeAt(i) !== 62)
    return !1;
  if (r)
    return !0;
  const s = [], l = [], u = [], c = [], d = e.md.block.ruler.getRules("blockquote"), f = e.parentType;
  e.parentType = "blockquote";
  let h = !1, m;
  for (m = t; m < n; m++) {
    const E = e.sCount[m] < e.blkIndent;
    if (i = e.bMarks[m] + e.tShift[m], a = e.eMarks[m], i >= a)
      break;
    if (e.src.charCodeAt(i++) === 62 && !E) {
      let C = e.sCount[m] + 1, T, O;
      e.src.charCodeAt(i) === 32 ? (i++, C++, O = !1, T = !0) : e.src.charCodeAt(i) === 9 ? (T = !0, (e.bsCount[m] + C) % 4 === 3 ? (i++, C++, O = !1) : O = !0) : T = !1;
      let R = C;
      for (s.push(e.bMarks[m]), e.bMarks[m] = i; i < a; ) {
        const D = e.src.charCodeAt(i);
        if (tr(D))
          D === 9 ? R += 4 - (R + e.bsCount[m] + (O ? 1 : 0)) % 4 : R++;
        else
          break;
        i++;
      }
      h = i >= a, l.push(e.bsCount[m]), e.bsCount[m] = e.sCount[m] + 1 + (T ? 1 : 0), u.push(e.sCount[m]), e.sCount[m] = R - C, c.push(e.tShift[m]), e.tShift[m] = i - e.bMarks[m];
      continue;
    }
    if (h)
      break;
    let S = !1;
    for (let C = 0, T = d.length; C < T; C++)
      if (d[C](e, m, n, !0)) {
        S = !0;
        break;
      }
    if (S) {
      e.lineMax = m, e.blkIndent !== 0 && (s.push(e.bMarks[m]), l.push(e.bsCount[m]), c.push(e.tShift[m]), u.push(e.sCount[m]), e.sCount[m] -= e.blkIndent);
      break;
    }
    s.push(e.bMarks[m]), l.push(e.bsCount[m]), c.push(e.tShift[m]), u.push(e.sCount[m]), e.sCount[m] = -1;
  }
  const v = e.blkIndent;
  e.blkIndent = 0;
  const b = e.push("blockquote_open", "blockquote", 1);
  b.markup = ">";
  const y = [t, 0];
  b.map = y, e.md.block.tokenize(e, t, m);
  const g = e.push("blockquote_close", "blockquote", -1);
  g.markup = ">", e.lineMax = o, e.parentType = f, y[1] = e.line;
  for (let E = 0; E < c.length; E++)
    e.bMarks[E + t] = s[E], e.tShift[E + t] = c[E], e.sCount[E + t] = u[E], e.bsCount[E + t] = l[E];
  return e.blkIndent = v, !0;
}
function hj(e, t, n, r) {
  const i = e.eMarks[t];
  if (e.sCount[t] - e.blkIndent >= 4)
    return !1;
  let a = e.bMarks[t] + e.tShift[t];
  const o = e.src.charCodeAt(a++);
  if (o !== 42 && o !== 45 && o !== 95)
    return !1;
  let s = 1;
  for (; a < i; ) {
    const u = e.src.charCodeAt(a++);
    if (u !== o && !tr(u))
      return !1;
    u === o && s++;
  }
  if (s < 3)
    return !1;
  if (r)
    return !0;
  e.line = t + 1;
  const l = e.push("hr", "hr", 0);
  return l.map = [t, e.line], l.markup = Array(s + 1).join(String.fromCharCode(o)), !0;
}
function uN(e, t) {
  const n = e.eMarks[t];
  let r = e.bMarks[t] + e.tShift[t];
  const i = e.src.charCodeAt(r++);
  if (i !== 42 && i !== 45 && i !== 43)
    return -1;
  if (r < n) {
    const a = e.src.charCodeAt(r);
    if (!tr(a))
      return -1;
  }
  return r;
}
function cN(e, t) {
  const n = e.bMarks[t] + e.tShift[t], r = e.eMarks[t];
  let i = n;
  if (i + 1 >= r)
    return -1;
  let a = e.src.charCodeAt(i++);
  if (a < 48 || a > 57)
    return -1;
  for (; ; ) {
    if (i >= r)
      return -1;
    if (a = e.src.charCodeAt(i++), a >= 48 && a <= 57) {
      if (i - n >= 10)
        return -1;
      continue;
    }
    if (a === 41 || a === 46)
      break;
    return -1;
  }
  return i < r && (a = e.src.charCodeAt(i), !tr(a)) ? -1 : i;
}
function gj(e, t) {
  const n = e.level + 2;
  for (let r = t + 2, i = e.tokens.length - 2; r < i; r++)
    e.tokens[r].level === n && e.tokens[r].type === "paragraph_open" && (e.tokens[r + 2].hidden = !0, e.tokens[r].hidden = !0, r += 2);
}
function _j(e, t, n, r) {
  let i, a, o, s, l = t, u = !0;
  if (e.sCount[l] - e.blkIndent >= 4 || e.listIndent >= 0 && e.sCount[l] - e.listIndent >= 4 && e.sCount[l] < e.blkIndent)
    return !1;
  let c = !1;
  r && e.parentType === "paragraph" && e.sCount[l] >= e.blkIndent && (c = !0);
  let d, f, h;
  if ((h = cN(e, l)) >= 0) {
    if (d = !0, o = e.bMarks[l] + e.tShift[l], f = Number(e.src.slice(o, h - 1)), c && f !== 1) return !1;
  } else if ((h = uN(e, l)) >= 0)
    d = !1;
  else
    return !1;
  if (c && e.skipSpaces(h) >= e.eMarks[l])
    return !1;
  if (r)
    return !0;
  const m = e.src.charCodeAt(h - 1), v = e.tokens.length;
  d ? (s = e.push("ordered_list_open", "ol", 1), f !== 1 && (s.attrs = [["start", f]])) : s = e.push("bullet_list_open", "ul", 1);
  const b = [l, 0];
  s.map = b, s.markup = String.fromCharCode(m);
  let y = !1;
  const g = e.md.block.ruler.getRules("list"), E = e.parentType;
  for (e.parentType = "list"; l < n; ) {
    a = h, i = e.eMarks[l];
    const S = e.sCount[l] + h - (e.bMarks[l] + e.tShift[l]);
    let C = S;
    for (; a < i; ) {
      const x = e.src.charCodeAt(a);
      if (x === 9)
        C += 4 - (C + e.bsCount[l]) % 4;
      else if (x === 32)
        C++;
      else
        break;
      a++;
    }
    const T = a;
    let O;
    T >= i ? O = 1 : O = C - S, O > 4 && (O = 1);
    const R = S + O;
    s = e.push("list_item_open", "li", 1), s.markup = String.fromCharCode(m);
    const D = [l, 0];
    s.map = D, d && (s.info = e.src.slice(o, h - 1));
    const q = e.tight, $ = e.tShift[l], P = e.sCount[l], Y = e.listIndent;
    if (e.listIndent = e.blkIndent, e.blkIndent = R, e.tight = !0, e.tShift[l] = T - e.bMarks[l], e.sCount[l] = C, T >= i && e.isEmpty(l + 1) ? e.line = Math.min(e.line + 2, n) : e.md.block.tokenize(e, l, n, !0), (!e.tight || y) && (u = !1), y = e.line - l > 1 && e.isEmpty(e.line - 1), e.blkIndent = e.listIndent, e.listIndent = Y, e.tShift[l] = $, e.sCount[l] = P, e.tight = q, s = e.push("list_item_close", "li", -1), s.markup = String.fromCharCode(m), l = e.line, D[1] = l, l >= n || e.sCount[l] < e.blkIndent || e.sCount[l] - e.blkIndent >= 4)
      break;
    let L = !1;
    for (let x = 0, I = g.length; x < I; x++)
      if (g[x](e, l, n, !0)) {
        L = !0;
        break;
      }
    if (L)
      break;
    if (d) {
      if (h = cN(e, l), h < 0)
        break;
      o = e.bMarks[l] + e.tShift[l];
    } else if (h = uN(e, l), h < 0)
      break;
    if (m !== e.src.charCodeAt(h - 1))
      break;
  }
  return d ? s = e.push("ordered_list_close", "ol", -1) : s = e.push("bullet_list_close", "ul", -1), s.markup = String.fromCharCode(m), b[1] = l, e.line = l, e.parentType = E, u && gj(e, v), !0;
}
function vj(e, t, n, r) {
  let i = 0, a = e.bMarks[t] + e.tShift[t], o = e.eMarks[t], s = t + 1;
  if (e.sCount[t] - e.blkIndent >= 4 || e.src.charCodeAt(a) !== 91)
    return !1;
  for (; ++a < o; )
    if (e.src.charCodeAt(a) === 93 && e.src.charCodeAt(a - 1) !== 92) {
      if (a + 1 === o || e.src.charCodeAt(a + 1) !== 58)
        return !1;
      break;
    }
  const l = e.lineMax, u = e.md.block.ruler.getRules("reference"), c = e.parentType;
  for (e.parentType = "reference"; s < l && !e.isEmpty(s); s++) {
    if (e.sCount[s] - e.blkIndent > 3 || e.sCount[s] < 0)
      continue;
    let C = !1;
    for (let T = 0, O = u.length; T < O; T++)
      if (u[T](e, s, l, !0)) {
        C = !0;
        break;
      }
    if (C)
      break;
  }
  const d = e.getLines(t, s, e.blkIndent, !1).trim();
  o = d.length;
  let f = -1;
  for (a = 1; a < o; a++) {
    const C = d.charCodeAt(a);
    if (C === 91)
      return !1;
    if (C === 93) {
      f = a;
      break;
    } else C === 10 ? i++ : C === 92 && (a++, a < o && d.charCodeAt(a) === 10 && i++);
  }
  if (f < 0 || d.charCodeAt(f + 1) !== 58)
    return !1;
  for (a = f + 2; a < o; a++) {
    const C = d.charCodeAt(a);
    if (C === 10)
      i++;
    else if (!tr(C)) break;
  }
  const h = e.md.helpers.parseLinkDestination(d, a, o);
  if (!h.ok)
    return !1;
  const m = e.md.normalizeLink(h.str);
  if (!e.md.validateLink(m))
    return !1;
  a = h.pos, i += h.lines;
  const v = a, b = i, y = a;
  for (; a < o; a++) {
    const C = d.charCodeAt(a);
    if (C === 10)
      i++;
    else if (!tr(C)) break;
  }
  const g = e.md.helpers.parseLinkTitle(d, a, o);
  let E;
  for (a < o && y !== a && g.ok ? (E = g.str, a = g.pos, i += g.lines) : (E = "", a = v, i = b); a < o; ) {
    const C = d.charCodeAt(a);
    if (!tr(C))
      break;
    a++;
  }
  if (a < o && d.charCodeAt(a) !== 10 && E)
    for (E = "", a = v, i = b; a < o; ) {
      const C = d.charCodeAt(a);
      if (!tr(C))
        break;
      a++;
    }
  if (a < o && d.charCodeAt(a) !== 10)
    return !1;
  const S = B_(d.slice(1, f));
  return S ? (r || (typeof e.env.references > "u" && (e.env.references = {}), typeof e.env.references[S] > "u" && (e.env.references[S] = { title: E, href: m }), e.parentType = c, e.line = t + i + 1), !0) : !1;
}
const bj = [
  "address",
  "article",
  "aside",
  "base",
  "basefont",
  "blockquote",
  "body",
  "caption",
  "center",
  "col",
  "colgroup",
  "dd",
  "details",
  "dialog",
  "dir",
  "div",
  "dl",
  "dt",
  "fieldset",
  "figcaption",
  "figure",
  "footer",
  "form",
  "frame",
  "frameset",
  "h1",
  "h2",
  "h3",
  "h4",
  "h5",
  "h6",
  "head",
  "header",
  "hr",
  "html",
  "iframe",
  "legend",
  "li",
  "link",
  "main",
  "menu",
  "menuitem",
  "nav",
  "noframes",
  "ol",
  "optgroup",
  "option",
  "p",
  "param",
  "section",
  "source",
  "summary",
  "table",
  "tbody",
  "td",
  "tfoot",
  "th",
  "thead",
  "title",
  "tr",
  "track",
  "ul"
], Ej = "[a-zA-Z_:][a-zA-Z0-9:._-]*", Sj = "[^\"'=<>`\\x00-\\x20]+", yj = "'[^']*'", Tj = '"[^"]*"', Cj = "(?:" + Sj + "|" + yj + "|" + Tj + ")", Aj = "(?:\\s+" + Ej + "(?:\\s*=\\s*" + Cj + ")?)", TF = "<[A-Za-z][A-Za-z0-9\\-]*" + Aj + "*\\s*\\/?>", CF = "<\\/[A-Za-z][A-Za-z0-9\\-]*\\s*>", Oj = "<!---->|<!--(?:-?[^>-])(?:-?[^-])*-->", Rj = "<[?][\\s\\S]*?[?]>", wj = "<![A-Z]+\\s+[^>]*>", xj = "<!\\[CDATA\\[[\\s\\S]*?\\]\\]>", Nj = new RegExp("^(?:" + TF + "|" + CF + "|" + Oj + "|" + Rj + "|" + wj + "|" + xj + ")"), Dj = new RegExp("^(?:" + TF + "|" + CF + ")"), Oc = [
  [/^<(script|pre|style|textarea)(?=(\s|>|$))/i, /<\/(script|pre|style|textarea)>/i, !0],
  [/^<!--/, /-->/, !0],
  [/^<\?/, /\?>/, !0],
  [/^<![A-Z]/, />/, !0],
  [/^<!\[CDATA\[/, /\]\]>/, !0],
  [new RegExp("^</?(" + bj.join("|") + ")(?=(\\s|/?>|$))", "i"), /^$/, !0],
  [new RegExp(Dj.source + "\\s*$"), /^$/, !1]
];
function Ij(e, t, n, r) {
  let i = e.bMarks[t] + e.tShift[t], a = e.eMarks[t];
  if (e.sCount[t] - e.blkIndent >= 4 || !e.md.options.html || e.src.charCodeAt(i) !== 60)
    return !1;
  let o = e.src.slice(i, a), s = 0;
  for (; s < Oc.length && !Oc[s][0].test(o); s++)
    ;
  if (s === Oc.length)
    return !1;
  if (r)
    return Oc[s][2];
  let l = t + 1;
  if (!Oc[s][1].test(o)) {
    for (; l < n && !(e.sCount[l] < e.blkIndent); l++)
      if (i = e.bMarks[l] + e.tShift[l], a = e.eMarks[l], o = e.src.slice(i, a), Oc[s][1].test(o)) {
        o.length !== 0 && l++;
        break;
      }
  }
  e.line = l;
  const u = e.push("html_block", "", 0);
  return u.map = [t, l], u.content = e.getLines(t, l, e.blkIndent, !0), !0;
}
function Lj(e, t, n, r) {
  let i = e.bMarks[t] + e.tShift[t], a = e.eMarks[t];
  if (e.sCount[t] - e.blkIndent >= 4)
    return !1;
  let o = e.src.charCodeAt(i);
  if (o !== 35 || i >= a)
    return !1;
  let s = 1;
  for (o = e.src.charCodeAt(++i); o === 35 && i < a && s <= 6; )
    s++, o = e.src.charCodeAt(++i);
  if (s > 6 || i < a && !tr(o))
    return !1;
  if (r)
    return !0;
  a = e.skipSpacesBack(a, i);
  const l = e.skipCharsBack(a, 35, i);
  l > i && tr(e.src.charCodeAt(l - 1)) && (a = l), e.line = t + 1;
  const u = e.push("heading_open", "h" + String(s), 1);
  u.markup = "########".slice(0, s), u.map = [t, e.line];
  const c = e.push("inline", "", 0);
  c.content = e.src.slice(i, a).trim(), c.map = [t, e.line], c.children = [];
  const d = e.push("heading_close", "h" + String(s), -1);
  return d.markup = "########".slice(0, s), !0;
}
function kj(e, t, n) {
  const r = e.md.block.ruler.getRules("paragraph");
  if (e.sCount[t] - e.blkIndent >= 4)
    return !1;
  const i = e.parentType;
  e.parentType = "paragraph";
  let a = 0, o, s = t + 1;
  for (; s < n && !e.isEmpty(s); s++) {
    if (e.sCount[s] - e.blkIndent > 3)
      continue;
    if (e.sCount[s] >= e.blkIndent) {
      let h = e.bMarks[s] + e.tShift[s];
      const m = e.eMarks[s];
      if (h < m && (o = e.src.charCodeAt(h), (o === 45 || o === 61) && (h = e.skipChars(h, o), h = e.skipSpaces(h), h >= m))) {
        a = o === 61 ? 1 : 2;
        break;
      }
    }
    if (e.sCount[s] < 0)
      continue;
    let f = !1;
    for (let h = 0, m = r.length; h < m; h++)
      if (r[h](e, s, n, !0)) {
        f = !0;
        break;
      }
    if (f)
      break;
  }
  if (!a)
    return !1;
  const l = e.getLines(t, s, e.blkIndent, !1).trim();
  e.line = s + 1;
  const u = e.push("heading_open", "h" + String(a), 1);
  u.markup = String.fromCharCode(o), u.map = [t, e.line];
  const c = e.push("inline", "", 0);
  c.content = l, c.map = [t, e.line - 1], c.children = [];
  const d = e.push("heading_close", "h" + String(a), -1);
  return d.markup = String.fromCharCode(o), e.parentType = i, !0;
}
function Mj(e, t, n) {
  const r = e.md.block.ruler.getRules("paragraph"), i = e.parentType;
  let a = t + 1;
  for (e.parentType = "paragraph"; a < n && !e.isEmpty(a); a++) {
    if (e.sCount[a] - e.blkIndent > 3 || e.sCount[a] < 0)
      continue;
    let u = !1;
    for (let c = 0, d = r.length; c < d; c++)
      if (r[c](e, a, n, !0)) {
        u = !0;
        break;
      }
    if (u)
      break;
  }
  const o = e.getLines(t, a, e.blkIndent, !1).trim();
  e.line = a;
  const s = e.push("paragraph_open", "p", 1);
  s.map = [t, e.line];
  const l = e.push("inline", "", 0);
  return l.content = o, l.map = [t, e.line], l.children = [], e.push("paragraph_close", "p", -1), e.parentType = i, !0;
}
const Mh = [
  // First 2 params - rule name & source. Secondary array - list of rules,
  // which can be terminated by this one.
  ["table", dj, ["paragraph", "reference"]],
  ["code", fj],
  ["fence", pj, ["paragraph", "reference", "blockquote", "list"]],
  ["blockquote", mj, ["paragraph", "reference", "blockquote", "list"]],
  ["hr", hj, ["paragraph", "reference", "blockquote", "list"]],
  ["list", _j, ["paragraph", "reference", "blockquote"]],
  ["reference", vj],
  ["html_block", Ij, ["paragraph", "reference", "blockquote"]],
  ["heading", Lj, ["paragraph", "reference", "blockquote"]],
  ["lheading", kj],
  ["paragraph", Mj]
];
function $_() {
  this.ruler = new ma();
  for (let e = 0; e < Mh.length; e++)
    this.ruler.push(Mh[e][0], Mh[e][1], { alt: (Mh[e][2] || []).slice() });
}
$_.prototype.tokenize = function(e, t, n) {
  const r = this.ruler.getRules(""), i = r.length, a = e.md.options.maxNesting;
  let o = t, s = !1;
  for (; o < n && (e.line = o = e.skipEmptyLines(o), !(o >= n || e.sCount[o] < e.blkIndent)); ) {
    if (e.level >= a) {
      e.line = n;
      break;
    }
    const l = e.line;
    let u = !1;
    for (let c = 0; c < i; c++)
      if (u = r[c](e, o, n, !1), u) {
        if (l >= e.line)
          throw new Error("block rule didn't increment state.line");
        break;
      }
    if (!u) throw new Error("none of the block rules matched");
    e.tight = !s, e.isEmpty(e.line - 1) && (s = !0), o = e.line, o < n && e.isEmpty(o) && (s = !0, o++, e.line = o);
  }
};
$_.prototype.parse = function(e, t, n, r) {
  if (!e)
    return;
  const i = new this.State(e, t, n, r);
  this.tokenize(i, i.line, i.lineMax);
};
$_.prototype.State = ts;
function sm(e, t, n, r) {
  this.src = e, this.env = n, this.md = t, this.tokens = r, this.tokens_meta = Array(r.length), this.pos = 0, this.posMax = this.src.length, this.level = 0, this.pending = "", this.pendingLevel = 0, this.cache = {}, this.delimiters = [], this._prev_delimiters = [], this.backticks = {}, this.backticksScanned = !1, this.linkLevel = 0;
}
sm.prototype.pushPending = function() {
  const e = new Ao("text", "", 0);
  return e.content = this.pending, e.level = this.pendingLevel, this.tokens.push(e), this.pending = "", e;
};
sm.prototype.push = function(e, t, n) {
  this.pending && this.pushPending();
  const r = new Ao(e, t, n);
  let i = null;
  return n < 0 && (this.level--, this.delimiters = this._prev_delimiters.pop()), r.level = this.level, n > 0 && (this.level++, this._prev_delimiters.push(this.delimiters), this.delimiters = [], i = { delimiters: this.delimiters }), this.pendingLevel = this.level, this.tokens.push(r), this.tokens_meta.push(i), r;
};
sm.prototype.scanDelims = function(e, t) {
  let n, r, i = !0, a = !0;
  const o = this.posMax, s = this.src.charCodeAt(e), l = e > 0 ? this.src.charCodeAt(e - 1) : 32;
  let u = e;
  for (; u < o && this.src.charCodeAt(u) === s; )
    u++;
  const c = u - e, d = u < o ? this.src.charCodeAt(u) : 32, f = Sp(l) || Ep(String.fromCharCode(l)), h = Sp(d) || Ep(String.fromCharCode(d)), m = bp(l), v = bp(d);
  return v ? i = !1 : h && (m || f || (i = !1)), m ? a = !1 : f && (v || h || (a = !1)), t ? (n = i, r = a) : (n = i && (!a || f), r = a && (!i || h)), { can_open: n, can_close: r, length: c };
};
sm.prototype.Token = Ao;
function Pj(e) {
  switch (e) {
    case 10:
    case 33:
    case 35:
    case 36:
    case 37:
    case 38:
    case 42:
    case 43:
    case 45:
    case 58:
    case 60:
    case 61:
    case 62:
    case 64:
    case 91:
    case 92:
    case 93:
    case 94:
    case 95:
    case 96:
    case 123:
    case 125:
    case 126:
      return !0;
    default:
      return !1;
  }
}
function Fj(e, t) {
  let n = e.pos;
  for (; n < e.posMax && !Pj(e.src.charCodeAt(n)); )
    n++;
  return n === e.pos ? !1 : (t || (e.pending += e.src.slice(e.pos, n)), e.pos = n, !0);
}
const Bj = /(?:^|[^a-z0-9.+-])([a-z][a-z0-9.+-]*)$/i;
function $j(e, t) {
  if (!e.md.options.linkify || e.linkLevel > 0) return !1;
  const n = e.pos, r = e.posMax;
  if (n + 3 > r || e.src.charCodeAt(n) !== 58 || e.src.charCodeAt(n + 1) !== 47 || e.src.charCodeAt(n + 2) !== 47) return !1;
  const i = e.pending.match(Bj);
  if (!i) return !1;
  const a = i[1], o = e.md.linkify.matchAtStart(e.src.slice(n - a.length));
  if (!o) return !1;
  let s = o.url;
  if (s.length <= a.length) return !1;
  s = s.replace(/\*+$/, "");
  const l = e.md.normalizeLink(s);
  if (!e.md.validateLink(l)) return !1;
  if (!t) {
    e.pending = e.pending.slice(0, -a.length);
    const u = e.push("link_open", "a", 1);
    u.attrs = [["href", l]], u.markup = "linkify", u.info = "auto";
    const c = e.push("text", "", 0);
    c.content = e.md.normalizeLinkText(s);
    const d = e.push("link_close", "a", -1);
    d.markup = "linkify", d.info = "auto";
  }
  return e.pos += s.length - a.length, !0;
}
function Uj(e, t) {
  let n = e.pos;
  if (e.src.charCodeAt(n) !== 10)
    return !1;
  const r = e.pending.length - 1, i = e.posMax;
  if (!t)
    if (r >= 0 && e.pending.charCodeAt(r) === 32)
      if (r >= 1 && e.pending.charCodeAt(r - 1) === 32) {
        let a = r - 1;
        for (; a >= 1 && e.pending.charCodeAt(a - 1) === 32; ) a--;
        e.pending = e.pending.slice(0, a), e.push("hardbreak", "br", 0);
      } else
        e.pending = e.pending.slice(0, -1), e.push("softbreak", "br", 0);
    else
      e.push("softbreak", "br", 0);
  for (n++; n < i && tr(e.src.charCodeAt(n)); )
    n++;
  return e.pos = n, !0;
}
const v1 = [];
for (let e = 0; e < 256; e++)
  v1.push(0);
"\\!\"#$%&'()*+,./:;<=>?@[]^_`{|}~-".split("").forEach(function(e) {
  v1[e.charCodeAt(0)] = 1;
});
function qj(e, t) {
  let n = e.pos;
  const r = e.posMax;
  if (e.src.charCodeAt(n) !== 92 || (n++, n >= r)) return !1;
  let i = e.src.charCodeAt(n);
  if (i === 10) {
    for (t || e.push("hardbreak", "br", 0), n++; n < r && (i = e.src.charCodeAt(n), !!tr(i)); )
      n++;
    return e.pos = n, !0;
  }
  let a = e.src[n];
  if (i >= 55296 && i <= 56319 && n + 1 < r) {
    const s = e.src.charCodeAt(n + 1);
    s >= 56320 && s <= 57343 && (a += e.src[n + 1], n++);
  }
  const o = "\\" + a;
  if (!t) {
    const s = e.push("text_special", "", 0);
    i < 256 && v1[i] !== 0 ? s.content = a : s.content = o, s.markup = o, s.info = "escape";
  }
  return e.pos = n + 1, !0;
}
function Gj(e, t) {
  let n = e.pos;
  if (e.src.charCodeAt(n) !== 96)
    return !1;
  const i = n;
  n++;
  const a = e.posMax;
  for (; n < a && e.src.charCodeAt(n) === 96; )
    n++;
  const o = e.src.slice(i, n), s = o.length;
  if (e.backticksScanned && (e.backticks[s] || 0) <= i)
    return t || (e.pending += o), e.pos += s, !0;
  let l = n, u;
  for (; (u = e.src.indexOf("`", l)) !== -1; ) {
    for (l = u + 1; l < a && e.src.charCodeAt(l) === 96; )
      l++;
    const c = l - u;
    if (c === s) {
      if (!t) {
        const d = e.push("code_inline", "code", 0);
        d.markup = o, d.content = e.src.slice(n, u).replace(/\n/g, " ").replace(/^ (.+) $/, "$1");
      }
      return e.pos = l, !0;
    }
    e.backticks[c] = u;
  }
  return e.backticksScanned = !0, t || (e.pending += o), e.pos += s, !0;
}
function Yj(e, t) {
  const n = e.pos, r = e.src.charCodeAt(n);
  if (t || r !== 126)
    return !1;
  const i = e.scanDelims(e.pos, !0);
  let a = i.length;
  const o = String.fromCharCode(r);
  if (a < 2)
    return !1;
  let s;
  a % 2 && (s = e.push("text", "", 0), s.content = o, a--);
  for (let l = 0; l < a; l += 2)
    s = e.push("text", "", 0), s.content = o + o, e.delimiters.push({
      marker: r,
      length: 0,
      // disable "rule of 3" length checks meant for emphasis
      token: e.tokens.length - 1,
      end: -1,
      open: i.can_open,
      close: i.can_close
    });
  return e.pos += i.length, !0;
}
function dN(e, t) {
  let n;
  const r = [], i = t.length;
  for (let a = 0; a < i; a++) {
    const o = t[a];
    if (o.marker !== 126 || o.end === -1)
      continue;
    const s = t[o.end];
    n = e.tokens[o.token], n.type = "s_open", n.tag = "s", n.nesting = 1, n.markup = "~~", n.content = "", n = e.tokens[s.token], n.type = "s_close", n.tag = "s", n.nesting = -1, n.markup = "~~", n.content = "", e.tokens[s.token - 1].type === "text" && e.tokens[s.token - 1].content === "~" && r.push(s.token - 1);
  }
  for (; r.length; ) {
    const a = r.pop();
    let o = a + 1;
    for (; o < e.tokens.length && e.tokens[o].type === "s_close"; )
      o++;
    o--, a !== o && (n = e.tokens[o], e.tokens[o] = e.tokens[a], e.tokens[a] = n);
  }
}
function Hj(e) {
  const t = e.tokens_meta, n = e.tokens_meta.length;
  dN(e, e.delimiters);
  for (let r = 0; r < n; r++)
    t[r] && t[r].delimiters && dN(e, t[r].delimiters);
}
const AF = {
  tokenize: Yj,
  postProcess: Hj
};
function zj(e, t) {
  const n = e.pos, r = e.src.charCodeAt(n);
  if (t || r !== 95 && r !== 42)
    return !1;
  const i = e.scanDelims(e.pos, r === 42);
  for (let a = 0; a < i.length; a++) {
    const o = e.push("text", "", 0);
    o.content = String.fromCharCode(r), e.delimiters.push({
      // Char code of the starting marker (number).
      //
      marker: r,
      // Total length of these series of delimiters.
      //
      length: i.length,
      // A position of the token this delimiter corresponds to.
      //
      token: e.tokens.length - 1,
      // If this delimiter is matched as a valid opener, `end` will be
      // equal to its position, otherwise it's `-1`.
      //
      end: -1,
      // Boolean flags that determine if this delimiter could open or close
      // an emphasis.
      //
      open: i.can_open,
      close: i.can_close
    });
  }
  return e.pos += i.length, !0;
}
function fN(e, t) {
  const n = t.length;
  for (let r = n - 1; r >= 0; r--) {
    const i = t[r];
    if (i.marker !== 95 && i.marker !== 42 || i.end === -1)
      continue;
    const a = t[i.end], o = r > 0 && t[r - 1].end === i.end + 1 && // check that first two markers match and adjacent
    t[r - 1].marker === i.marker && t[r - 1].token === i.token - 1 && // check that last two markers are adjacent (we can safely assume they match)
    t[i.end + 1].token === a.token + 1, s = String.fromCharCode(i.marker), l = e.tokens[i.token];
    l.type = o ? "strong_open" : "em_open", l.tag = o ? "strong" : "em", l.nesting = 1, l.markup = o ? s + s : s, l.content = "";
    const u = e.tokens[a.token];
    u.type = o ? "strong_close" : "em_close", u.tag = o ? "strong" : "em", u.nesting = -1, u.markup = o ? s + s : s, u.content = "", o && (e.tokens[t[r - 1].token].content = "", e.tokens[t[i.end + 1].token].content = "", r--);
  }
}
function Vj(e) {
  const t = e.tokens_meta, n = e.tokens_meta.length;
  fN(e, e.delimiters);
  for (let r = 0; r < n; r++)
    t[r] && t[r].delimiters && fN(e, t[r].delimiters);
}
const OF = {
  tokenize: zj,
  postProcess: Vj
};
function Wj(e, t) {
  let n, r, i, a, o = "", s = "", l = e.pos, u = !0;
  if (e.src.charCodeAt(e.pos) !== 91)
    return !1;
  const c = e.pos, d = e.posMax, f = e.pos + 1, h = e.md.helpers.parseLinkLabel(e, e.pos, !0);
  if (h < 0)
    return !1;
  let m = h + 1;
  if (m < d && e.src.charCodeAt(m) === 40) {
    for (u = !1, m++; m < d && (n = e.src.charCodeAt(m), !(!tr(n) && n !== 10)); m++)
      ;
    if (m >= d)
      return !1;
    if (l = m, i = e.md.helpers.parseLinkDestination(e.src, m, e.posMax), i.ok) {
      for (o = e.md.normalizeLink(i.str), e.md.validateLink(o) ? m = i.pos : o = "", l = m; m < d && (n = e.src.charCodeAt(m), !(!tr(n) && n !== 10)); m++)
        ;
      if (i = e.md.helpers.parseLinkTitle(e.src, m, e.posMax), m < d && l !== m && i.ok)
        for (s = i.str, m = i.pos; m < d && (n = e.src.charCodeAt(m), !(!tr(n) && n !== 10)); m++)
          ;
    }
    (m >= d || e.src.charCodeAt(m) !== 41) && (u = !0), m++;
  }
  if (u) {
    if (typeof e.env.references > "u")
      return !1;
    if (m < d && e.src.charCodeAt(m) === 91 ? (l = m + 1, m = e.md.helpers.parseLinkLabel(e, m), m >= 0 ? r = e.src.slice(l, m++) : m = h + 1) : m = h + 1, r || (r = e.src.slice(f, h)), a = e.env.references[B_(r)], !a)
      return e.pos = c, !1;
    o = a.href, s = a.title;
  }
  if (!t) {
    e.pos = f, e.posMax = h;
    const v = e.push("link_open", "a", 1), b = [["href", o]];
    v.attrs = b, s && b.push(["title", s]), e.linkLevel++, e.md.inline.tokenize(e), e.linkLevel--, e.push("link_close", "a", -1);
  }
  return e.pos = m, e.posMax = d, !0;
}
function Kj(e, t) {
  let n, r, i, a, o, s, l, u, c = "";
  const d = e.pos, f = e.posMax;
  if (e.src.charCodeAt(e.pos) !== 33 || e.src.charCodeAt(e.pos + 1) !== 91)
    return !1;
  const h = e.pos + 2, m = e.md.helpers.parseLinkLabel(e, e.pos + 1, !1);
  if (m < 0)
    return !1;
  if (a = m + 1, a < f && e.src.charCodeAt(a) === 40) {
    for (a++; a < f && (n = e.src.charCodeAt(a), !(!tr(n) && n !== 10)); a++)
      ;
    if (a >= f)
      return !1;
    for (u = a, s = e.md.helpers.parseLinkDestination(e.src, a, e.posMax), s.ok && (c = e.md.normalizeLink(s.str), e.md.validateLink(c) ? a = s.pos : c = ""), u = a; a < f && (n = e.src.charCodeAt(a), !(!tr(n) && n !== 10)); a++)
      ;
    if (s = e.md.helpers.parseLinkTitle(e.src, a, e.posMax), a < f && u !== a && s.ok)
      for (l = s.str, a = s.pos; a < f && (n = e.src.charCodeAt(a), !(!tr(n) && n !== 10)); a++)
        ;
    else
      l = "";
    if (a >= f || e.src.charCodeAt(a) !== 41)
      return e.pos = d, !1;
    a++;
  } else {
    if (typeof e.env.references > "u")
      return !1;
    if (a < f && e.src.charCodeAt(a) === 91 ? (u = a + 1, a = e.md.helpers.parseLinkLabel(e, a), a >= 0 ? i = e.src.slice(u, a++) : a = m + 1) : a = m + 1, i || (i = e.src.slice(h, m)), o = e.env.references[B_(i)], !o)
      return e.pos = d, !1;
    c = o.href, l = o.title;
  }
  if (!t) {
    r = e.src.slice(h, m);
    const v = [];
    e.md.inline.parse(
      r,
      e.md,
      e.env,
      v
    );
    const b = e.push("image", "img", 0), y = [["src", c], ["alt", ""]];
    b.attrs = y, b.children = v, b.content = r, l && y.push(["title", l]);
  }
  return e.pos = a, e.posMax = f, !0;
}
const jj = /^([a-zA-Z0-9.!#$%&'*+/=?^_`{|}~-]+@[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?(?:\.[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?)*)$/, Qj = /^([a-zA-Z][a-zA-Z0-9+.-]{1,31}):([^<>\x00-\x20]*)$/;
function Xj(e, t) {
  let n = e.pos;
  if (e.src.charCodeAt(n) !== 60)
    return !1;
  const r = e.pos, i = e.posMax;
  for (; ; ) {
    if (++n >= i) return !1;
    const o = e.src.charCodeAt(n);
    if (o === 60) return !1;
    if (o === 62) break;
  }
  const a = e.src.slice(r + 1, n);
  if (Qj.test(a)) {
    const o = e.md.normalizeLink(a);
    if (!e.md.validateLink(o))
      return !1;
    if (!t) {
      const s = e.push("link_open", "a", 1);
      s.attrs = [["href", o]], s.markup = "autolink", s.info = "auto";
      const l = e.push("text", "", 0);
      l.content = e.md.normalizeLinkText(a);
      const u = e.push("link_close", "a", -1);
      u.markup = "autolink", u.info = "auto";
    }
    return e.pos += a.length + 2, !0;
  }
  if (jj.test(a)) {
    const o = e.md.normalizeLink("mailto:" + a);
    if (!e.md.validateLink(o))
      return !1;
    if (!t) {
      const s = e.push("link_open", "a", 1);
      s.attrs = [["href", o]], s.markup = "autolink", s.info = "auto";
      const l = e.push("text", "", 0);
      l.content = e.md.normalizeLinkText(a);
      const u = e.push("link_close", "a", -1);
      u.markup = "autolink", u.info = "auto";
    }
    return e.pos += a.length + 2, !0;
  }
  return !1;
}
function Zj(e) {
  return /^<a[>\s]/i.test(e);
}
function Jj(e) {
  return /^<\/a\s*>/i.test(e);
}
function eQ(e) {
  const t = e | 32;
  return t >= 97 && t <= 122;
}
function tQ(e, t) {
  if (!e.md.options.html)
    return !1;
  const n = e.posMax, r = e.pos;
  if (e.src.charCodeAt(r) !== 60 || r + 2 >= n)
    return !1;
  const i = e.src.charCodeAt(r + 1);
  if (i !== 33 && i !== 63 && i !== 47 && !eQ(i))
    return !1;
  const a = e.src.slice(r).match(Nj);
  if (!a)
    return !1;
  if (!t) {
    const o = e.push("html_inline", "", 0);
    o.content = a[0], Zj(o.content) && e.linkLevel++, Jj(o.content) && e.linkLevel--;
  }
  return e.pos += a[0].length, !0;
}
const nQ = /^&#((?:x[a-f0-9]{1,6}|[0-9]{1,7}));/i, rQ = /^&([a-z][a-z0-9]{1,31});/i;
function iQ(e, t) {
  const n = e.pos, r = e.posMax;
  if (e.src.charCodeAt(n) !== 38 || n + 1 >= r) return !1;
  if (e.src.charCodeAt(n + 1) === 35) {
    const a = e.src.slice(n).match(nQ);
    if (a) {
      if (!t) {
        const o = a[1][0].toLowerCase() === "x" ? parseInt(a[1].slice(1), 16) : parseInt(a[1], 10), s = e.push("text_special", "", 0);
        s.content = g1(o) ? Lg(o) : Lg(65533), s.markup = a[0], s.info = "entity";
      }
      return e.pos += a[0].length, !0;
    }
  } else {
    const a = e.src.slice(n).match(rQ);
    if (a) {
      const o = vF(a[0]);
      if (o !== a[0]) {
        if (!t) {
          const s = e.push("text_special", "", 0);
          s.content = o, s.markup = a[0], s.info = "entity";
        }
        return e.pos += a[0].length, !0;
      }
    }
  }
  return !1;
}
function pN(e) {
  const t = {}, n = e.length;
  if (!n) return;
  let r = 0, i = -2;
  const a = [];
  for (let o = 0; o < n; o++) {
    const s = e[o];
    if (a.push(0), (e[r].marker !== s.marker || i !== s.token - 1) && (r = o), i = s.token, s.length = s.length || 0, !s.close) continue;
    t.hasOwnProperty(s.marker) || (t[s.marker] = [-1, -1, -1, -1, -1, -1]);
    const l = t[s.marker][(s.open ? 3 : 0) + s.length % 3];
    let u = r - a[r] - 1, c = u;
    for (; u > l; u -= a[u] + 1) {
      const d = e[u];
      if (d.marker === s.marker && d.open && d.end < 0) {
        let f = !1;
        if ((d.close || s.open) && (d.length + s.length) % 3 === 0 && (d.length % 3 !== 0 || s.length % 3 !== 0) && (f = !0), !f) {
          const h = u > 0 && !e[u - 1].open ? a[u - 1] + 1 : 0;
          a[o] = o - u + h, a[u] = h, s.open = !1, d.end = o, d.close = !1, c = -1, i = -2;
          break;
        }
      }
    }
    c !== -1 && (t[s.marker][(s.open ? 3 : 0) + (s.length || 0) % 3] = c);
  }
}
function aQ(e) {
  const t = e.tokens_meta, n = e.tokens_meta.length;
  pN(e.delimiters);
  for (let r = 0; r < n; r++)
    t[r] && t[r].delimiters && pN(t[r].delimiters);
}
function oQ(e) {
  let t, n, r = 0;
  const i = e.tokens, a = e.tokens.length;
  for (t = n = 0; t < a; t++)
    i[t].nesting < 0 && r--, i[t].level = r, i[t].nesting > 0 && r++, i[t].type === "text" && t + 1 < a && i[t + 1].type === "text" ? i[t + 1].content = i[t].content + i[t + 1].content : (t !== n && (i[n] = i[t]), n++);
  t !== n && (i.length = n);
}
const f0 = [
  ["text", Fj],
  ["linkify", $j],
  ["newline", Uj],
  ["escape", qj],
  ["backticks", Gj],
  ["strikethrough", AF.tokenize],
  ["emphasis", OF.tokenize],
  ["link", Wj],
  ["image", Kj],
  ["autolink", Xj],
  ["html_inline", tQ],
  ["entity", iQ]
], p0 = [
  ["balance_pairs", aQ],
  ["strikethrough", AF.postProcess],
  ["emphasis", OF.postProcess],
  // rules for pairs separate '**' into its own text tokens, which may be left unused,
  // rule below merges unused segments back with the rest of the text
  ["fragments_join", oQ]
];
function lm() {
  this.ruler = new ma();
  for (let e = 0; e < f0.length; e++)
    this.ruler.push(f0[e][0], f0[e][1]);
  this.ruler2 = new ma();
  for (let e = 0; e < p0.length; e++)
    this.ruler2.push(p0[e][0], p0[e][1]);
}
lm.prototype.skipToken = function(e) {
  const t = e.pos, n = this.ruler.getRules(""), r = n.length, i = e.md.options.maxNesting, a = e.cache;
  if (typeof a[t] < "u") {
    e.pos = a[t];
    return;
  }
  let o = !1;
  if (e.level < i) {
    for (let s = 0; s < r; s++)
      if (e.level++, o = n[s](e, !0), e.level--, o) {
        if (t >= e.pos)
          throw new Error("inline rule didn't increment state.pos");
        break;
      }
  } else
    e.pos = e.posMax;
  o || e.pos++, a[t] = e.pos;
};
lm.prototype.tokenize = function(e) {
  const t = this.ruler.getRules(""), n = t.length, r = e.posMax, i = e.md.options.maxNesting;
  for (; e.pos < r; ) {
    const a = e.pos;
    let o = !1;
    if (e.level < i) {
      for (let s = 0; s < n; s++)
        if (o = t[s](e, !1), o) {
          if (a >= e.pos)
            throw new Error("inline rule didn't increment state.pos");
          break;
        }
    }
    if (o) {
      if (e.pos >= r)
        break;
      continue;
    }
    e.pending += e.src[e.pos++];
  }
  e.pending && e.pushPending();
};
lm.prototype.parse = function(e, t, n, r) {
  const i = new this.State(e, t, n, r);
  this.tokenize(i);
  const a = this.ruler2.getRules(""), o = a.length;
  for (let s = 0; s < o; s++)
    a[s](i);
};
lm.prototype.State = sm;
function sQ(e) {
  const t = {};
  e = e || {}, t.src_Any = mF.source, t.src_Cc = hF.source, t.src_Z = gF.source, t.src_P = m1.source, t.src_ZPCc = [t.src_Z, t.src_P, t.src_Cc].join("|"), t.src_ZCc = [t.src_Z, t.src_Cc].join("|");
  const n = "[><｜]";
  return t.src_pseudo_letter = "(?:(?!" + n + "|" + t.src_ZPCc + ")" + t.src_Any + ")", t.src_ip4 = "(?:(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\\.){3}(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)", t.src_auth = "(?:(?:(?!" + t.src_ZCc + "|[@/\\[\\]()]).)+@)?", t.src_port = "(?::(?:6(?:[0-4]\\d{3}|5(?:[0-4]\\d{2}|5(?:[0-2]\\d|3[0-5])))|[1-5]?\\d{1,4}))?", t.src_host_terminator = "(?=$|" + n + "|" + t.src_ZPCc + ")(?!" + (e["---"] ? "-(?!--)|" : "-|") + "_|:\\d|\\.-|\\.(?!$|" + t.src_ZPCc + "))", t.src_path = "(?:[/?#](?:(?!" + t.src_ZCc + "|" + n + `|[()[\\]{}.,"'?!\\-;]).|\\[(?:(?!` + t.src_ZCc + "|\\]).)*\\]|\\((?:(?!" + t.src_ZCc + "|[)]).)*\\)|\\{(?:(?!" + t.src_ZCc + '|[}]).)*\\}|\\"(?:(?!' + t.src_ZCc + `|["]).)+\\"|\\'(?:(?!` + t.src_ZCc + "|[']).)+\\'|\\'(?=" + t.src_pseudo_letter + "|[-])|\\.{2,}[a-zA-Z0-9%/&]|\\.(?!" + t.src_ZCc + "|[.]|$)|" + (e["---"] ? "\\-(?!--(?:[^-]|$))(?:-*)|" : "\\-+|") + // allow `,,,` in paths
  ",(?!" + t.src_ZCc + "|$)|;(?!" + t.src_ZCc + "|$)|\\!+(?!" + t.src_ZCc + "|[!]|$)|\\?(?!" + t.src_ZCc + "|[?]|$))+|\\/)?", t.src_email_name = '[\\-;:&=\\+\\$,\\.a-zA-Z0-9_][\\-;:&=\\+\\$,\\"\\.a-zA-Z0-9_]*', t.src_xn = "xn--[a-z0-9\\-]{1,59}", t.src_domain_root = // Allow letters & digits (http://test1)
  "(?:" + t.src_xn + "|" + t.src_pseudo_letter + "{1,63})", t.src_domain = "(?:" + t.src_xn + "|(?:" + t.src_pseudo_letter + ")|(?:" + t.src_pseudo_letter + "(?:-|" + t.src_pseudo_letter + "){0,61}" + t.src_pseudo_letter + "))", t.src_host = "(?:(?:(?:(?:" + t.src_domain + ")\\.)*" + t.src_domain + "))", t.tpl_host_fuzzy = "(?:" + t.src_ip4 + "|(?:(?:(?:" + t.src_domain + ")\\.)+(?:%TLDS%)))", t.tpl_host_no_ip_fuzzy = "(?:(?:(?:" + t.src_domain + ")\\.)+(?:%TLDS%))", t.src_host_strict = t.src_host + t.src_host_terminator, t.tpl_host_fuzzy_strict = t.tpl_host_fuzzy + t.src_host_terminator, t.src_host_port_strict = t.src_host + t.src_port + t.src_host_terminator, t.tpl_host_port_fuzzy_strict = t.tpl_host_fuzzy + t.src_port + t.src_host_terminator, t.tpl_host_port_no_ip_fuzzy_strict = t.tpl_host_no_ip_fuzzy + t.src_port + t.src_host_terminator, t.tpl_host_fuzzy_test = "localhost|www\\.|\\.\\d{1,3}\\.|(?:\\.(?:%TLDS%)(?:" + t.src_ZPCc + "|>|$))", t.tpl_email_fuzzy = "(^|" + n + '|"|\\(|' + t.src_ZCc + ")(" + t.src_email_name + "@" + t.tpl_host_fuzzy_strict + ")", t.tpl_link_fuzzy = // Fuzzy link can't be prepended with .:/\- and non punctuation.
  // but can start with > (markdown blockquote)
  "(^|(?![.:/\\-_@])(?:[$+<=>^`|｜]|" + t.src_ZPCc + "))((?![$+<=>^`|｜])" + t.tpl_host_port_fuzzy_strict + t.src_path + ")", t.tpl_link_no_ip_fuzzy = // Fuzzy link can't be prepended with .:/\- and non punctuation.
  // but can start with > (markdown blockquote)
  "(^|(?![.:/\\-_@])(?:[$+<=>^`|｜]|" + t.src_ZPCc + "))((?![$+<=>^`|｜])" + t.tpl_host_port_no_ip_fuzzy_strict + t.src_path + ")", t;
}
function JT(e) {
  return Array.prototype.slice.call(arguments, 1).forEach(function(n) {
    n && Object.keys(n).forEach(function(r) {
      e[r] = n[r];
    });
  }), e;
}
function U_(e) {
  return Object.prototype.toString.call(e);
}
function lQ(e) {
  return U_(e) === "[object String]";
}
function uQ(e) {
  return U_(e) === "[object Object]";
}
function cQ(e) {
  return U_(e) === "[object RegExp]";
}
function mN(e) {
  return U_(e) === "[object Function]";
}
function dQ(e) {
  return e.replace(/[.?*+^$[\]\\(){}|-]/g, "\\$&");
}
const RF = {
  fuzzyLink: !0,
  fuzzyEmail: !0,
  fuzzyIP: !1
};
function fQ(e) {
  return Object.keys(e || {}).reduce(function(t, n) {
    return t || RF.hasOwnProperty(n);
  }, !1);
}
const pQ = {
  "http:": {
    validate: function(e, t, n) {
      const r = e.slice(t);
      return n.re.http || (n.re.http = new RegExp(
        "^\\/\\/" + n.re.src_auth + n.re.src_host_port_strict + n.re.src_path,
        "i"
      )), n.re.http.test(r) ? r.match(n.re.http)[0].length : 0;
    }
  },
  "https:": "http:",
  "ftp:": "http:",
  "//": {
    validate: function(e, t, n) {
      const r = e.slice(t);
      return n.re.no_http || (n.re.no_http = new RegExp(
        "^" + n.re.src_auth + // Don't allow single-level domains, because of false positives like '//test'
        // with code comments
        "(?:localhost|(?:(?:" + n.re.src_domain + ")\\.)+" + n.re.src_domain_root + ")" + n.re.src_port + n.re.src_host_terminator + n.re.src_path,
        "i"
      )), n.re.no_http.test(r) ? t >= 3 && e[t - 3] === ":" || t >= 3 && e[t - 3] === "/" ? 0 : r.match(n.re.no_http)[0].length : 0;
    }
  },
  "mailto:": {
    validate: function(e, t, n) {
      const r = e.slice(t);
      return n.re.mailto || (n.re.mailto = new RegExp(
        "^" + n.re.src_email_name + "@" + n.re.src_host_strict,
        "i"
      )), n.re.mailto.test(r) ? r.match(n.re.mailto)[0].length : 0;
    }
  }
}, mQ = "a[cdefgilmnoqrstuwxz]|b[abdefghijmnorstvwyz]|c[acdfghiklmnoruvwxyz]|d[ejkmoz]|e[cegrstu]|f[ijkmor]|g[abdefghilmnpqrstuwy]|h[kmnrtu]|i[delmnoqrst]|j[emop]|k[eghimnprwyz]|l[abcikrstuvy]|m[acdeghklmnopqrstuvwxyz]|n[acefgilopruz]|om|p[aefghklmnrstwy]|qa|r[eosuw]|s[abcdeghijklmnortuvxyz]|t[cdfghjklmnortvwz]|u[agksyz]|v[aceginu]|w[fs]|y[et]|z[amw]", hQ = "biz|com|edu|gov|net|org|pro|web|xxx|aero|asia|coop|info|museum|name|shop|рф".split("|");
function gQ(e) {
  e.__index__ = -1, e.__text_cache__ = "";
}
function _Q(e) {
  return function(t, n) {
    const r = t.slice(n);
    return e.test(r) ? r.match(e)[0].length : 0;
  };
}
function hN() {
  return function(e, t) {
    t.normalize(e);
  };
}
function kg(e) {
  const t = e.re = sQ(e.__opts__), n = e.__tlds__.slice();
  e.onCompile(), e.__tlds_replaced__ || n.push(mQ), n.push(t.src_xn), t.src_tlds = n.join("|");
  function r(s) {
    return s.replace("%TLDS%", t.src_tlds);
  }
  t.email_fuzzy = RegExp(r(t.tpl_email_fuzzy), "i"), t.link_fuzzy = RegExp(r(t.tpl_link_fuzzy), "i"), t.link_no_ip_fuzzy = RegExp(r(t.tpl_link_no_ip_fuzzy), "i"), t.host_fuzzy_test = RegExp(r(t.tpl_host_fuzzy_test), "i");
  const i = [];
  e.__compiled__ = {};
  function a(s, l) {
    throw new Error('(LinkifyIt) Invalid schema "' + s + '": ' + l);
  }
  Object.keys(e.__schemas__).forEach(function(s) {
    const l = e.__schemas__[s];
    if (l === null)
      return;
    const u = { validate: null, link: null };
    if (e.__compiled__[s] = u, uQ(l)) {
      cQ(l.validate) ? u.validate = _Q(l.validate) : mN(l.validate) ? u.validate = l.validate : a(s, l), mN(l.normalize) ? u.normalize = l.normalize : l.normalize ? a(s, l) : u.normalize = hN();
      return;
    }
    if (lQ(l)) {
      i.push(s);
      return;
    }
    a(s, l);
  }), i.forEach(function(s) {
    e.__compiled__[e.__schemas__[s]] && (e.__compiled__[s].validate = e.__compiled__[e.__schemas__[s]].validate, e.__compiled__[s].normalize = e.__compiled__[e.__schemas__[s]].normalize);
  }), e.__compiled__[""] = { validate: null, normalize: hN() };
  const o = Object.keys(e.__compiled__).filter(function(s) {
    return s.length > 0 && e.__compiled__[s];
  }).map(dQ).join("|");
  e.re.schema_test = RegExp("(^|(?!_)(?:[><｜]|" + t.src_ZPCc + "))(" + o + ")", "i"), e.re.schema_search = RegExp("(^|(?!_)(?:[><｜]|" + t.src_ZPCc + "))(" + o + ")", "ig"), e.re.schema_at_start = RegExp("^" + e.re.schema_search.source, "i"), e.re.pretest = RegExp(
    "(" + e.re.schema_test.source + ")|(" + e.re.host_fuzzy_test.source + ")|@",
    "i"
  ), gQ(e);
}
function vQ(e, t) {
  const n = e.__index__, r = e.__last_index__, i = e.__text_cache__.slice(n, r);
  this.schema = e.__schema__.toLowerCase(), this.index = n + t, this.lastIndex = r + t, this.raw = i, this.text = i, this.url = i;
}
function eC(e, t) {
  const n = new vQ(e, t);
  return e.__compiled__[n.schema].normalize(n, e), n;
}
function xa(e, t) {
  if (!(this instanceof xa))
    return new xa(e, t);
  t || fQ(e) && (t = e, e = {}), this.__opts__ = JT({}, RF, t), this.__index__ = -1, this.__last_index__ = -1, this.__schema__ = "", this.__text_cache__ = "", this.__schemas__ = JT({}, pQ, e), this.__compiled__ = {}, this.__tlds__ = hQ, this.__tlds_replaced__ = !1, this.re = {}, kg(this);
}
xa.prototype.add = function(t, n) {
  return this.__schemas__[t] = n, kg(this), this;
};
xa.prototype.set = function(t) {
  return this.__opts__ = JT(this.__opts__, t), this;
};
xa.prototype.test = function(t) {
  if (this.__text_cache__ = t, this.__index__ = -1, !t.length)
    return !1;
  let n, r, i, a, o, s, l, u, c;
  if (this.re.schema_test.test(t)) {
    for (l = this.re.schema_search, l.lastIndex = 0; (n = l.exec(t)) !== null; )
      if (a = this.testSchemaAt(t, n[2], l.lastIndex), a) {
        this.__schema__ = n[2], this.__index__ = n.index + n[1].length, this.__last_index__ = n.index + n[0].length + a;
        break;
      }
  }
  return this.__opts__.fuzzyLink && this.__compiled__["http:"] && (u = t.search(this.re.host_fuzzy_test), u >= 0 && (this.__index__ < 0 || u < this.__index__) && (r = t.match(this.__opts__.fuzzyIP ? this.re.link_fuzzy : this.re.link_no_ip_fuzzy)) !== null && (o = r.index + r[1].length, (this.__index__ < 0 || o < this.__index__) && (this.__schema__ = "", this.__index__ = o, this.__last_index__ = r.index + r[0].length))), this.__opts__.fuzzyEmail && this.__compiled__["mailto:"] && (c = t.indexOf("@"), c >= 0 && (i = t.match(this.re.email_fuzzy)) !== null && (o = i.index + i[1].length, s = i.index + i[0].length, (this.__index__ < 0 || o < this.__index__ || o === this.__index__ && s > this.__last_index__) && (this.__schema__ = "mailto:", this.__index__ = o, this.__last_index__ = s))), this.__index__ >= 0;
};
xa.prototype.pretest = function(t) {
  return this.re.pretest.test(t);
};
xa.prototype.testSchemaAt = function(t, n, r) {
  return this.__compiled__[n.toLowerCase()] ? this.__compiled__[n.toLowerCase()].validate(t, r, this) : 0;
};
xa.prototype.match = function(t) {
  const n = [];
  let r = 0;
  this.__index__ >= 0 && this.__text_cache__ === t && (n.push(eC(this, r)), r = this.__last_index__);
  let i = r ? t.slice(r) : t;
  for (; this.test(i); )
    n.push(eC(this, r)), i = i.slice(this.__last_index__), r += this.__last_index__;
  return n.length ? n : null;
};
xa.prototype.matchAtStart = function(t) {
  if (this.__text_cache__ = t, this.__index__ = -1, !t.length) return null;
  const n = this.re.schema_at_start.exec(t);
  if (!n) return null;
  const r = this.testSchemaAt(t, n[2], n[0].length);
  return r ? (this.__schema__ = n[2], this.__index__ = n.index + n[1].length, this.__last_index__ = n.index + n[0].length + r, eC(this, 0)) : null;
};
xa.prototype.tlds = function(t, n) {
  return t = Array.isArray(t) ? t : [t], n ? (this.__tlds__ = this.__tlds__.concat(t).sort().filter(function(r, i, a) {
    return r !== a[i - 1];
  }).reverse(), kg(this), this) : (this.__tlds__ = t.slice(), this.__tlds_replaced__ = !0, kg(this), this);
};
xa.prototype.normalize = function(t) {
  t.schema || (t.url = "http://" + t.url), t.schema === "mailto:" && !/^mailto:/i.test(t.url) && (t.url = "mailto:" + t.url);
};
xa.prototype.onCompile = function() {
};
const Zc = 2147483647, $o = 36, b1 = 1, yp = 26, bQ = 38, EQ = 700, wF = 72, xF = 128, NF = "-", SQ = /^xn--/, yQ = /[^\0-\x7F]/, TQ = /[\x2E\u3002\uFF0E\uFF61]/g, CQ = {
  overflow: "Overflow: input needs wider integers to process",
  "not-basic": "Illegal input >= 0x80 (not a basic code point)",
  "invalid-input": "Invalid input"
}, m0 = $o - b1, Uo = Math.floor, h0 = String.fromCharCode;
function Sl(e) {
  throw new RangeError(CQ[e]);
}
function AQ(e, t) {
  const n = [];
  let r = e.length;
  for (; r--; )
    n[r] = t(e[r]);
  return n;
}
function DF(e, t) {
  const n = e.split("@");
  let r = "";
  n.length > 1 && (r = n[0] + "@", e = n[1]), e = e.replace(TQ, ".");
  const i = e.split("."), a = AQ(i, t).join(".");
  return r + a;
}
function IF(e) {
  const t = [];
  let n = 0;
  const r = e.length;
  for (; n < r; ) {
    const i = e.charCodeAt(n++);
    if (i >= 55296 && i <= 56319 && n < r) {
      const a = e.charCodeAt(n++);
      (a & 64512) == 56320 ? t.push(((i & 1023) << 10) + (a & 1023) + 65536) : (t.push(i), n--);
    } else
      t.push(i);
  }
  return t;
}
const OQ = (e) => String.fromCodePoint(...e), RQ = function(e) {
  return e >= 48 && e < 58 ? 26 + (e - 48) : e >= 65 && e < 91 ? e - 65 : e >= 97 && e < 123 ? e - 97 : $o;
}, gN = function(e, t) {
  return e + 22 + 75 * (e < 26) - ((t != 0) << 5);
}, LF = function(e, t, n) {
  let r = 0;
  for (e = n ? Uo(e / EQ) : e >> 1, e += Uo(e / t); e > m0 * yp >> 1; r += $o)
    e = Uo(e / m0);
  return Uo(r + (m0 + 1) * e / (e + bQ));
}, kF = function(e) {
  const t = [], n = e.length;
  let r = 0, i = xF, a = wF, o = e.lastIndexOf(NF);
  o < 0 && (o = 0);
  for (let s = 0; s < o; ++s)
    e.charCodeAt(s) >= 128 && Sl("not-basic"), t.push(e.charCodeAt(s));
  for (let s = o > 0 ? o + 1 : 0; s < n; ) {
    const l = r;
    for (let c = 1, d = $o; ; d += $o) {
      s >= n && Sl("invalid-input");
      const f = RQ(e.charCodeAt(s++));
      f >= $o && Sl("invalid-input"), f > Uo((Zc - r) / c) && Sl("overflow"), r += f * c;
      const h = d <= a ? b1 : d >= a + yp ? yp : d - a;
      if (f < h)
        break;
      const m = $o - h;
      c > Uo(Zc / m) && Sl("overflow"), c *= m;
    }
    const u = t.length + 1;
    a = LF(r - l, u, l == 0), Uo(r / u) > Zc - i && Sl("overflow"), i += Uo(r / u), r %= u, t.splice(r++, 0, i);
  }
  return String.fromCodePoint(...t);
}, MF = function(e) {
  const t = [];
  e = IF(e);
  const n = e.length;
  let r = xF, i = 0, a = wF;
  for (const l of e)
    l < 128 && t.push(h0(l));
  const o = t.length;
  let s = o;
  for (o && t.push(NF); s < n; ) {
    let l = Zc;
    for (const c of e)
      c >= r && c < l && (l = c);
    const u = s + 1;
    l - r > Uo((Zc - i) / u) && Sl("overflow"), i += (l - r) * u, r = l;
    for (const c of e)
      if (c < r && ++i > Zc && Sl("overflow"), c === r) {
        let d = i;
        for (let f = $o; ; f += $o) {
          const h = f <= a ? b1 : f >= a + yp ? yp : f - a;
          if (d < h)
            break;
          const m = d - h, v = $o - h;
          t.push(
            h0(gN(h + m % v, 0))
          ), d = Uo(m / v);
        }
        t.push(h0(gN(d, 0))), a = LF(i, u, s === o), i = 0, ++s;
      }
    ++i, ++r;
  }
  return t.join("");
}, wQ = function(e) {
  return DF(e, function(t) {
    return SQ.test(t) ? kF(t.slice(4).toLowerCase()) : t;
  });
}, xQ = function(e) {
  return DF(e, function(t) {
    return yQ.test(t) ? "xn--" + MF(t) : t;
  });
}, PF = {
  /**
   * A string representing the current Punycode.js version number.
   * @memberOf punycode
   * @type String
   */
  version: "2.3.1",
  /**
   * An object of methods to convert from JavaScript's internal character
   * representation (UCS-2) to Unicode code points, and back.
   * @see <https://mathiasbynens.be/notes/javascript-encoding>
   * @memberOf punycode
   * @type Object
   */
  ucs2: {
    decode: IF,
    encode: OQ
  },
  decode: kF,
  encode: MF,
  toASCII: xQ,
  toUnicode: wQ
}, NQ = {
  options: {
    // Enable HTML tags in source
    html: !1,
    // Use '/' to close single tags (<br />)
    xhtmlOut: !1,
    // Convert '\n' in paragraphs into <br>
    breaks: !1,
    // CSS language prefix for fenced blocks
    langPrefix: "language-",
    // autoconvert URL-like texts to links
    linkify: !1,
    // Enable some language-neutral replacements + quotes beautification
    typographer: !1,
    // Double + single quotes replacement pairs, when typographer enabled,
    // and smartquotes on. Could be either a String or an Array.
    //
    // For example, you can use '«»„“' for Russian, '„“‚‘' for German,
    // and ['«\xA0', '\xA0»', '‹\xA0', '\xA0›'] for French (including nbsp).
    quotes: "“”‘’",
    /* “”‘’ */
    // Highlighter function. Should return escaped HTML,
    // or '' if the source string is not changed and should be escaped externaly.
    // If result starts with <pre... internal wrapper is skipped.
    //
    // function (/*str, lang*/) { return ''; }
    //
    highlight: null,
    // Internal protection, recursion limit
    maxNesting: 100
  },
  components: {
    core: {},
    block: {},
    inline: {}
  }
}, DQ = {
  options: {
    // Enable HTML tags in source
    html: !1,
    // Use '/' to close single tags (<br />)
    xhtmlOut: !1,
    // Convert '\n' in paragraphs into <br>
    breaks: !1,
    // CSS language prefix for fenced blocks
    langPrefix: "language-",
    // autoconvert URL-like texts to links
    linkify: !1,
    // Enable some language-neutral replacements + quotes beautification
    typographer: !1,
    // Double + single quotes replacement pairs, when typographer enabled,
    // and smartquotes on. Could be either a String or an Array.
    //
    // For example, you can use '«»„“' for Russian, '„“‚‘' for German,
    // and ['«\xA0', '\xA0»', '‹\xA0', '\xA0›'] for French (including nbsp).
    quotes: "“”‘’",
    /* “”‘’ */
    // Highlighter function. Should return escaped HTML,
    // or '' if the source string is not changed and should be escaped externaly.
    // If result starts with <pre... internal wrapper is skipped.
    //
    // function (/*str, lang*/) { return ''; }
    //
    highlight: null,
    // Internal protection, recursion limit
    maxNesting: 20
  },
  components: {
    core: {
      rules: [
        "normalize",
        "block",
        "inline",
        "text_join"
      ]
    },
    block: {
      rules: [
        "paragraph"
      ]
    },
    inline: {
      rules: [
        "text"
      ],
      rules2: [
        "balance_pairs",
        "fragments_join"
      ]
    }
  }
}, IQ = {
  options: {
    // Enable HTML tags in source
    html: !0,
    // Use '/' to close single tags (<br />)
    xhtmlOut: !0,
    // Convert '\n' in paragraphs into <br>
    breaks: !1,
    // CSS language prefix for fenced blocks
    langPrefix: "language-",
    // autoconvert URL-like texts to links
    linkify: !1,
    // Enable some language-neutral replacements + quotes beautification
    typographer: !1,
    // Double + single quotes replacement pairs, when typographer enabled,
    // and smartquotes on. Could be either a String or an Array.
    //
    // For example, you can use '«»„“' for Russian, '„“‚‘' for German,
    // and ['«\xA0', '\xA0»', '‹\xA0', '\xA0›'] for French (including nbsp).
    quotes: "“”‘’",
    /* “”‘’ */
    // Highlighter function. Should return escaped HTML,
    // or '' if the source string is not changed and should be escaped externaly.
    // If result starts with <pre... internal wrapper is skipped.
    //
    // function (/*str, lang*/) { return ''; }
    //
    highlight: null,
    // Internal protection, recursion limit
    maxNesting: 20
  },
  components: {
    core: {
      rules: [
        "normalize",
        "block",
        "inline",
        "text_join"
      ]
    },
    block: {
      rules: [
        "blockquote",
        "code",
        "fence",
        "heading",
        "hr",
        "html_block",
        "lheading",
        "list",
        "reference",
        "paragraph"
      ]
    },
    inline: {
      rules: [
        "autolink",
        "backticks",
        "emphasis",
        "entity",
        "escape",
        "html_inline",
        "image",
        "link",
        "newline",
        "text"
      ],
      rules2: [
        "balance_pairs",
        "emphasis",
        "fragments_join"
      ]
    }
  }
}, LQ = {
  default: NQ,
  zero: DQ,
  commonmark: IQ
}, kQ = /^(vbscript|javascript|file|data):/, MQ = /^data:image\/(gif|png|jpeg|webp);/;
function PQ(e) {
  const t = e.trim().toLowerCase();
  return kQ.test(t) ? MQ.test(t) : !0;
}
const FF = ["http:", "https:", "mailto:"];
function FQ(e) {
  const t = p1(e, !0);
  if (t.hostname && (!t.protocol || FF.indexOf(t.protocol) >= 0))
    try {
      t.hostname = PF.toASCII(t.hostname);
    } catch {
    }
  return om(f1(t));
}
function BQ(e) {
  const t = p1(e, !0);
  if (t.hostname && (!t.protocol || FF.indexOf(t.protocol) >= 0))
    try {
      t.hostname = PF.toUnicode(t.hostname);
    } catch {
    }
  return sd(f1(t), sd.defaultChars + "%");
}
function Za(e, t) {
  if (!(this instanceof Za))
    return new Za(e, t);
  t || h1(e) || (t = e || {}, e = "default"), this.inline = new lm(), this.block = new $_(), this.core = new _1(), this.renderer = new Ad(), this.linkify = new xa(), this.validateLink = PQ, this.normalizeLink = FQ, this.normalizeLinkText = BQ, this.utils = qK, this.helpers = F_({}, zK), this.options = {}, this.configure(e), t && this.set(t);
}
Za.prototype.set = function(e) {
  return F_(this.options, e), this;
};
Za.prototype.configure = function(e) {
  const t = this;
  if (h1(e)) {
    const n = e;
    if (e = LQ[n], !e)
      throw new Error('Wrong `markdown-it` preset "' + n + '", check name');
  }
  if (!e)
    throw new Error("Wrong `markdown-it` preset, can't be empty");
  return e.options && t.set(e.options), e.components && Object.keys(e.components).forEach(function(n) {
    e.components[n].rules && t[n].ruler.enableOnly(e.components[n].rules), e.components[n].rules2 && t[n].ruler2.enableOnly(e.components[n].rules2);
  }), this;
};
Za.prototype.enable = function(e, t) {
  let n = [];
  Array.isArray(e) || (e = [e]), ["core", "block", "inline"].forEach(function(i) {
    n = n.concat(this[i].ruler.enable(e, !0));
  }, this), n = n.concat(this.inline.ruler2.enable(e, !0));
  const r = e.filter(function(i) {
    return n.indexOf(i) < 0;
  });
  if (r.length && !t)
    throw new Error("MarkdownIt. Failed to enable unknown rule(s): " + r);
  return this;
};
Za.prototype.disable = function(e, t) {
  let n = [];
  Array.isArray(e) || (e = [e]), ["core", "block", "inline"].forEach(function(i) {
    n = n.concat(this[i].ruler.disable(e, !0));
  }, this), n = n.concat(this.inline.ruler2.disable(e, !0));
  const r = e.filter(function(i) {
    return n.indexOf(i) < 0;
  });
  if (r.length && !t)
    throw new Error("MarkdownIt. Failed to disable unknown rule(s): " + r);
  return this;
};
Za.prototype.use = function(e) {
  const t = [this].concat(Array.prototype.slice.call(arguments, 1));
  return e.apply(e, t), this;
};
Za.prototype.parse = function(e, t) {
  if (typeof e != "string")
    throw new Error("Input data should be a String");
  const n = new this.core.State(e, this, t);
  return this.core.process(n), n.tokens;
};
Za.prototype.render = function(e, t) {
  return t = t || {}, this.renderer.render(this.parse(e, t), this.options, t);
};
Za.prototype.parseInline = function(e, t) {
  const n = new this.core.State(e, this, t);
  return n.inlineMode = !0, this.core.process(n), n.tokens;
};
Za.prototype.renderInline = function(e, t) {
  return t = t || {}, this.renderer.render(this.parseInline(e, t), this.options, t);
};
var Pc = typeof globalThis < "u" ? globalThis : typeof window < "u" ? window : typeof global < "u" ? global : typeof self < "u" ? self : {};
function E1(e) {
  return e && e.__esModule && Object.prototype.hasOwnProperty.call(e, "default") ? e.default : e;
}
function BF(e) {
  return e instanceof Map ? e.clear = e.delete = e.set = function() {
    throw new Error("map is read-only");
  } : e instanceof Set && (e.add = e.clear = e.delete = function() {
    throw new Error("set is read-only");
  }), Object.freeze(e), Object.getOwnPropertyNames(e).forEach((t) => {
    const n = e[t], r = typeof n;
    (r === "object" || r === "function") && !Object.isFrozen(n) && BF(n);
  }), e;
}
let _N = class {
  /**
   * @param {CompiledMode} mode
   */
  constructor(t) {
    t.data === void 0 && (t.data = {}), this.data = t.data, this.isMatchIgnored = !1;
  }
  ignoreMatch() {
    this.isMatchIgnored = !0;
  }
};
function $F(e) {
  return e.replace(/&/g, "&amp;").replace(/</g, "&lt;").replace(/>/g, "&gt;").replace(/"/g, "&quot;").replace(/'/g, "&#x27;");
}
function wl(e, ...t) {
  const n = /* @__PURE__ */ Object.create(null);
  for (const r in e)
    n[r] = e[r];
  return t.forEach(function(r) {
    for (const i in r)
      n[i] = r[i];
  }), /** @type {T} */
  n;
}
const $Q = "</span>", vN = (e) => !!e.scope, UQ = (e, { prefix: t }) => {
  if (e.startsWith("language:"))
    return e.replace("language:", "language-");
  if (e.includes(".")) {
    const n = e.split(".");
    return [
      `${t}${n.shift()}`,
      ...n.map((r, i) => `${r}${"_".repeat(i + 1)}`)
    ].join(" ");
  }
  return `${t}${e}`;
};
class qQ {
  /**
   * Creates a new HTMLRenderer
   *
   * @param {Tree} parseTree - the parse tree (must support `walk` API)
   * @param {{classPrefix: string}} options
   */
  constructor(t, n) {
    this.buffer = "", this.classPrefix = n.classPrefix, t.walk(this);
  }
  /**
   * Adds texts to the output stream
   *
   * @param {string} text */
  addText(t) {
    this.buffer += $F(t);
  }
  /**
   * Adds a node open to the output stream (if needed)
   *
   * @param {Node} node */
  openNode(t) {
    if (!vN(t)) return;
    const n = UQ(
      t.scope,
      { prefix: this.classPrefix }
    );
    this.span(n);
  }
  /**
   * Adds a node close to the output stream (if needed)
   *
   * @param {Node} node */
  closeNode(t) {
    vN(t) && (this.buffer += $Q);
  }
  /**
   * returns the accumulated buffer
  */
  value() {
    return this.buffer;
  }
  // helpers
  /**
   * Builds a span element
   *
   * @param {string} className */
  span(t) {
    this.buffer += `<span class="${t}">`;
  }
}
const bN = (e = {}) => {
  const t = { children: [] };
  return Object.assign(t, e), t;
};
class S1 {
  constructor() {
    this.rootNode = bN(), this.stack = [this.rootNode];
  }
  get top() {
    return this.stack[this.stack.length - 1];
  }
  get root() {
    return this.rootNode;
  }
  /** @param {Node} node */
  add(t) {
    this.top.children.push(t);
  }
  /** @param {string} scope */
  openNode(t) {
    const n = bN({ scope: t });
    this.add(n), this.stack.push(n);
  }
  closeNode() {
    if (this.stack.length > 1)
      return this.stack.pop();
  }
  closeAllNodes() {
    for (; this.closeNode(); ) ;
  }
  toJSON() {
    return JSON.stringify(this.rootNode, null, 4);
  }
  /**
   * @typedef { import("./html_renderer").Renderer } Renderer
   * @param {Renderer} builder
   */
  walk(t) {
    return this.constructor._walk(t, this.rootNode);
  }
  /**
   * @param {Renderer} builder
   * @param {Node} node
   */
  static _walk(t, n) {
    return typeof n == "string" ? t.addText(n) : n.children && (t.openNode(n), n.children.forEach((r) => this._walk(t, r)), t.closeNode(n)), t;
  }
  /**
   * @param {Node} node
   */
  static _collapse(t) {
    typeof t != "string" && t.children && (t.children.every((n) => typeof n == "string") ? t.children = [t.children.join("")] : t.children.forEach((n) => {
      S1._collapse(n);
    }));
  }
}
class GQ extends S1 {
  /**
   * @param {*} options
   */
  constructor(t) {
    super(), this.options = t;
  }
  /**
   * @param {string} text
   */
  addText(t) {
    t !== "" && this.add(t);
  }
  /** @param {string} scope */
  startScope(t) {
    this.openNode(t);
  }
  endScope() {
    this.closeNode();
  }
  /**
   * @param {Emitter & {root: DataNode}} emitter
   * @param {string} name
   */
  __addSublanguage(t, n) {
    const r = t.root;
    n && (r.scope = `language:${n}`), this.add(r);
  }
  toHTML() {
    return new qQ(this, this.options).value();
  }
  finalize() {
    return this.closeAllNodes(), !0;
  }
}
function Tp(e) {
  return e ? typeof e == "string" ? e : e.source : null;
}
function UF(e) {
  return Qu("(?=", e, ")");
}
function YQ(e) {
  return Qu("(?:", e, ")*");
}
function HQ(e) {
  return Qu("(?:", e, ")?");
}
function Qu(...e) {
  return e.map((n) => Tp(n)).join("");
}
function zQ(e) {
  const t = e[e.length - 1];
  return typeof t == "object" && t.constructor === Object ? (e.splice(e.length - 1, 1), t) : {};
}
function y1(...e) {
  return "(" + (zQ(e).capture ? "" : "?:") + e.map((r) => Tp(r)).join("|") + ")";
}
function qF(e) {
  return new RegExp(e.toString() + "|").exec("").length - 1;
}
function VQ(e, t) {
  const n = e && e.exec(t);
  return n && n.index === 0;
}
const WQ = /\[(?:[^\\\]]|\\.)*\]|\(\??|\\([1-9][0-9]*)|\\./;
function T1(e, { joinWith: t }) {
  let n = 0;
  return e.map((r) => {
    n += 1;
    const i = n;
    let a = Tp(r), o = "";
    for (; a.length > 0; ) {
      const s = WQ.exec(a);
      if (!s) {
        o += a;
        break;
      }
      o += a.substring(0, s.index), a = a.substring(s.index + s[0].length), s[0][0] === "\\" && s[1] ? o += "\\" + String(Number(s[1]) + i) : (o += s[0], s[0] === "(" && n++);
    }
    return o;
  }).map((r) => `(${r})`).join(t);
}
const KQ = /\b\B/, GF = "[a-zA-Z]\\w*", C1 = "[a-zA-Z_]\\w*", YF = "\\b\\d+(\\.\\d+)?", HF = "(-?)(\\b0[xX][a-fA-F0-9]+|(\\b\\d+(\\.\\d*)?|\\.\\d+)([eE][-+]?\\d+)?)", zF = "\\b(0b[01]+)", jQ = "!|!=|!==|%|%=|&|&&|&=|\\*|\\*=|\\+|\\+=|,|-|-=|/=|/|:|;|<<|<<=|<=|<|===|==|=|>>>=|>>=|>=|>>>|>>|>|\\?|\\[|\\{|\\(|\\^|\\^=|\\||\\|=|\\|\\||~", QQ = (e = {}) => {
  const t = /^#![ ]*\//;
  return e.binary && (e.begin = Qu(
    t,
    /.*\b/,
    e.binary,
    /\b.*/
  )), wl({
    scope: "meta",
    begin: t,
    end: /$/,
    relevance: 0,
    /** @type {ModeCallback} */
    "on:begin": (n, r) => {
      n.index !== 0 && r.ignoreMatch();
    }
  }, e);
}, Cp = {
  begin: "\\\\[\\s\\S]",
  relevance: 0
}, XQ = {
  scope: "string",
  begin: "'",
  end: "'",
  illegal: "\\n",
  contains: [Cp]
}, ZQ = {
  scope: "string",
  begin: '"',
  end: '"',
  illegal: "\\n",
  contains: [Cp]
}, JQ = {
  begin: /\b(a|an|the|are|I'm|isn't|don't|doesn't|won't|but|just|should|pretty|simply|enough|gonna|going|wtf|so|such|will|you|your|they|like|more)\b/
}, q_ = function(e, t, n = {}) {
  const r = wl(
    {
      scope: "comment",
      begin: e,
      end: t,
      contains: []
    },
    n
  );
  r.contains.push({
    scope: "doctag",
    // hack to avoid the space from being included. the space is necessary to
    // match here to prevent the plain text rule below from gobbling up doctags
    begin: "[ ]*(?=(TODO|FIXME|NOTE|BUG|OPTIMIZE|HACK|XXX):)",
    end: /(TODO|FIXME|NOTE|BUG|OPTIMIZE|HACK|XXX):/,
    excludeBegin: !0,
    relevance: 0
  });
  const i = y1(
    // list of common 1 and 2 letter words in English
    "I",
    "a",
    "is",
    "so",
    "us",
    "to",
    "at",
    "if",
    "in",
    "it",
    "on",
    // note: this is not an exhaustive list of contractions, just popular ones
    /[A-Za-z]+['](d|ve|re|ll|t|s|n)/,
    // contractions - can't we'd they're let's, etc
    /[A-Za-z]+[-][a-z]+/,
    // `no-way`, etc.
    /[A-Za-z][a-z]{2,}/
    // allow capitalized words at beginning of sentences
  );
  return r.contains.push(
    {
      // TODO: how to include ", (, ) without breaking grammars that use these for
      // comment delimiters?
      // begin: /[ ]+([()"]?([A-Za-z'-]{3,}|is|a|I|so|us|[tT][oO]|at|if|in|it|on)[.]?[()":]?([.][ ]|[ ]|\))){3}/
      // ---
      // this tries to find sequences of 3 english words in a row (without any
      // "programming" type syntax) this gives us a strong signal that we've
      // TRULY found a comment - vs perhaps scanning with the wrong language.
      // It's possible to find something that LOOKS like the start of the
      // comment - but then if there is no readable text - good chance it is a
      // false match and not a comment.
      //
      // for a visual example please see:
      // https://github.com/highlightjs/highlight.js/issues/2827
      begin: Qu(
        /[ ]+/,
        // necessary to prevent us gobbling up doctags like /* @author Bob Mcgill */
        "(",
        i,
        /[.]?[:]?([.][ ]|[ ])/,
        "){3}"
      )
      // look for 3 words in a row
    }
  ), r;
}, eX = q_("//", "$"), tX = q_("/\\*", "\\*/"), nX = q_("#", "$"), rX = {
  scope: "number",
  begin: YF,
  relevance: 0
}, iX = {
  scope: "number",
  begin: HF,
  relevance: 0
}, aX = {
  scope: "number",
  begin: zF,
  relevance: 0
}, oX = {
  scope: "regexp",
  begin: /\/(?=[^/\n]*\/)/,
  end: /\/[gimuy]*/,
  contains: [
    Cp,
    {
      begin: /\[/,
      end: /\]/,
      relevance: 0,
      contains: [Cp]
    }
  ]
}, sX = {
  scope: "title",
  begin: GF,
  relevance: 0
}, lX = {
  scope: "title",
  begin: C1,
  relevance: 0
}, uX = {
  // excludes method names from keyword processing
  begin: "\\.\\s*" + C1,
  relevance: 0
}, cX = function(e) {
  return Object.assign(
    e,
    {
      /** @type {ModeCallback} */
      "on:begin": (t, n) => {
        n.data._beginMatch = t[1];
      },
      /** @type {ModeCallback} */
      "on:end": (t, n) => {
        n.data._beginMatch !== t[1] && n.ignoreMatch();
      }
    }
  );
};
var Ph = /* @__PURE__ */ Object.freeze({
  __proto__: null,
  APOS_STRING_MODE: XQ,
  BACKSLASH_ESCAPE: Cp,
  BINARY_NUMBER_MODE: aX,
  BINARY_NUMBER_RE: zF,
  COMMENT: q_,
  C_BLOCK_COMMENT_MODE: tX,
  C_LINE_COMMENT_MODE: eX,
  C_NUMBER_MODE: iX,
  C_NUMBER_RE: HF,
  END_SAME_AS_BEGIN: cX,
  HASH_COMMENT_MODE: nX,
  IDENT_RE: GF,
  MATCH_NOTHING_RE: KQ,
  METHOD_GUARD: uX,
  NUMBER_MODE: rX,
  NUMBER_RE: YF,
  PHRASAL_WORDS_MODE: JQ,
  QUOTE_STRING_MODE: ZQ,
  REGEXP_MODE: oX,
  RE_STARTERS_RE: jQ,
  SHEBANG: QQ,
  TITLE_MODE: sX,
  UNDERSCORE_IDENT_RE: C1,
  UNDERSCORE_TITLE_MODE: lX
});
function dX(e, t) {
  e.input[e.index - 1] === "." && t.ignoreMatch();
}
function fX(e, t) {
  e.className !== void 0 && (e.scope = e.className, delete e.className);
}
function pX(e, t) {
  t && e.beginKeywords && (e.begin = "\\b(" + e.beginKeywords.split(" ").join("|") + ")(?!\\.)(?=\\b|\\s)", e.__beforeBegin = dX, e.keywords = e.keywords || e.beginKeywords, delete e.beginKeywords, e.relevance === void 0 && (e.relevance = 0));
}
function mX(e, t) {
  Array.isArray(e.illegal) && (e.illegal = y1(...e.illegal));
}
function hX(e, t) {
  if (e.match) {
    if (e.begin || e.end) throw new Error("begin & end are not supported with match");
    e.begin = e.match, delete e.match;
  }
}
function gX(e, t) {
  e.relevance === void 0 && (e.relevance = 1);
}
const _X = (e, t) => {
  if (!e.beforeMatch) return;
  if (e.starts) throw new Error("beforeMatch cannot be used with starts");
  const n = Object.assign({}, e);
  Object.keys(e).forEach((r) => {
    delete e[r];
  }), e.keywords = n.keywords, e.begin = Qu(n.beforeMatch, UF(n.begin)), e.starts = {
    relevance: 0,
    contains: [
      Object.assign(n, { endsParent: !0 })
    ]
  }, e.relevance = 0, delete n.beforeMatch;
}, vX = [
  "of",
  "and",
  "for",
  "in",
  "not",
  "or",
  "if",
  "then",
  "parent",
  // common variable name
  "list",
  // common variable name
  "value"
  // common variable name
], bX = "keyword";
function VF(e, t, n = bX) {
  const r = /* @__PURE__ */ Object.create(null);
  return typeof e == "string" ? i(n, e.split(" ")) : Array.isArray(e) ? i(n, e) : Object.keys(e).forEach(function(a) {
    Object.assign(
      r,
      VF(e[a], t, a)
    );
  }), r;
  function i(a, o) {
    t && (o = o.map((s) => s.toLowerCase())), o.forEach(function(s) {
      const l = s.split("|");
      r[l[0]] = [a, EX(l[0], l[1])];
    });
  }
}
function EX(e, t) {
  return t ? Number(t) : SX(e) ? 0 : 1;
}
function SX(e) {
  return vX.includes(e.toLowerCase());
}
const EN = {}, Lu = (e) => {
  console.error(e);
}, SN = (e, ...t) => {
  console.log(`WARN: ${e}`, ...t);
}, Rc = (e, t) => {
  EN[`${e}/${t}`] || (console.log(`Deprecated as of ${e}. ${t}`), EN[`${e}/${t}`] = !0);
}, Mg = new Error();
function WF(e, t, { key: n }) {
  let r = 0;
  const i = e[n], a = {}, o = {};
  for (let s = 1; s <= t.length; s++)
    o[s + r] = i[s], a[s + r] = !0, r += qF(t[s - 1]);
  e[n] = o, e[n]._emit = a, e[n]._multi = !0;
}
function yX(e) {
  if (Array.isArray(e.begin)) {
    if (e.skip || e.excludeBegin || e.returnBegin)
      throw Lu("skip, excludeBegin, returnBegin not compatible with beginScope: {}"), Mg;
    if (typeof e.beginScope != "object" || e.beginScope === null)
      throw Lu("beginScope must be object"), Mg;
    WF(e, e.begin, { key: "beginScope" }), e.begin = T1(e.begin, { joinWith: "" });
  }
}
function TX(e) {
  if (Array.isArray(e.end)) {
    if (e.skip || e.excludeEnd || e.returnEnd)
      throw Lu("skip, excludeEnd, returnEnd not compatible with endScope: {}"), Mg;
    if (typeof e.endScope != "object" || e.endScope === null)
      throw Lu("endScope must be object"), Mg;
    WF(e, e.end, { key: "endScope" }), e.end = T1(e.end, { joinWith: "" });
  }
}
function CX(e) {
  e.scope && typeof e.scope == "object" && e.scope !== null && (e.beginScope = e.scope, delete e.scope);
}
function AX(e) {
  CX(e), typeof e.beginScope == "string" && (e.beginScope = { _wrap: e.beginScope }), typeof e.endScope == "string" && (e.endScope = { _wrap: e.endScope }), yX(e), TX(e);
}
function OX(e) {
  function t(o, s) {
    return new RegExp(
      Tp(o),
      "m" + (e.case_insensitive ? "i" : "") + (e.unicodeRegex ? "u" : "") + (s ? "g" : "")
    );
  }
  class n {
    constructor() {
      this.matchIndexes = {}, this.regexes = [], this.matchAt = 1, this.position = 0;
    }
    // @ts-ignore
    addRule(s, l) {
      l.position = this.position++, this.matchIndexes[this.matchAt] = l, this.regexes.push([l, s]), this.matchAt += qF(s) + 1;
    }
    compile() {
      this.regexes.length === 0 && (this.exec = () => null);
      const s = this.regexes.map((l) => l[1]);
      this.matcherRe = t(T1(s, { joinWith: "|" }), !0), this.lastIndex = 0;
    }
    /** @param {string} s */
    exec(s) {
      this.matcherRe.lastIndex = this.lastIndex;
      const l = this.matcherRe.exec(s);
      if (!l)
        return null;
      const u = l.findIndex((d, f) => f > 0 && d !== void 0), c = this.matchIndexes[u];
      return l.splice(0, u), Object.assign(l, c);
    }
  }
  class r {
    constructor() {
      this.rules = [], this.multiRegexes = [], this.count = 0, this.lastIndex = 0, this.regexIndex = 0;
    }
    // @ts-ignore
    getMatcher(s) {
      if (this.multiRegexes[s]) return this.multiRegexes[s];
      const l = new n();
      return this.rules.slice(s).forEach(([u, c]) => l.addRule(u, c)), l.compile(), this.multiRegexes[s] = l, l;
    }
    resumingScanAtSamePosition() {
      return this.regexIndex !== 0;
    }
    considerAll() {
      this.regexIndex = 0;
    }
    // @ts-ignore
    addRule(s, l) {
      this.rules.push([s, l]), l.type === "begin" && this.count++;
    }
    /** @param {string} s */
    exec(s) {
      const l = this.getMatcher(this.regexIndex);
      l.lastIndex = this.lastIndex;
      let u = l.exec(s);
      if (this.resumingScanAtSamePosition() && !(u && u.index === this.lastIndex)) {
        const c = this.getMatcher(0);
        c.lastIndex = this.lastIndex + 1, u = c.exec(s);
      }
      return u && (this.regexIndex += u.position + 1, this.regexIndex === this.count && this.considerAll()), u;
    }
  }
  function i(o) {
    const s = new r();
    return o.contains.forEach((l) => s.addRule(l.begin, { rule: l, type: "begin" })), o.terminatorEnd && s.addRule(o.terminatorEnd, { type: "end" }), o.illegal && s.addRule(o.illegal, { type: "illegal" }), s;
  }
  function a(o, s) {
    const l = (
      /** @type CompiledMode */
      o
    );
    if (o.isCompiled) return l;
    [
      fX,
      // do this early so compiler extensions generally don't have to worry about
      // the distinction between match/begin
      hX,
      AX,
      _X
    ].forEach((c) => c(o, s)), e.compilerExtensions.forEach((c) => c(o, s)), o.__beforeBegin = null, [
      pX,
      // do this later so compiler extensions that come earlier have access to the
      // raw array if they wanted to perhaps manipulate it, etc.
      mX,
      // default to 1 relevance if not specified
      gX
    ].forEach((c) => c(o, s)), o.isCompiled = !0;
    let u = null;
    return typeof o.keywords == "object" && o.keywords.$pattern && (o.keywords = Object.assign({}, o.keywords), u = o.keywords.$pattern, delete o.keywords.$pattern), u = u || /\w+/, o.keywords && (o.keywords = VF(o.keywords, e.case_insensitive)), l.keywordPatternRe = t(u, !0), s && (o.begin || (o.begin = /\B|\b/), l.beginRe = t(l.begin), !o.end && !o.endsWithParent && (o.end = /\B|\b/), o.end && (l.endRe = t(l.end)), l.terminatorEnd = Tp(l.end) || "", o.endsWithParent && s.terminatorEnd && (l.terminatorEnd += (o.end ? "|" : "") + s.terminatorEnd)), o.illegal && (l.illegalRe = t(
      /** @type {RegExp | string} */
      o.illegal
    )), o.contains || (o.contains = []), o.contains = [].concat(...o.contains.map(function(c) {
      return RX(c === "self" ? o : c);
    })), o.contains.forEach(function(c) {
      a(
        /** @type Mode */
        c,
        l
      );
    }), o.starts && a(o.starts, s), l.matcher = i(l), l;
  }
  if (e.compilerExtensions || (e.compilerExtensions = []), e.contains && e.contains.includes("self"))
    throw new Error("ERR: contains `self` is not supported at the top-level of a language.  See documentation.");
  return e.classNameAliases = wl(e.classNameAliases || {}), a(
    /** @type Mode */
    e
  );
}
function KF(e) {
  return e ? e.endsWithParent || KF(e.starts) : !1;
}
function RX(e) {
  return e.variants && !e.cachedVariants && (e.cachedVariants = e.variants.map(function(t) {
    return wl(e, { variants: null }, t);
  })), e.cachedVariants ? e.cachedVariants : KF(e) ? wl(e, { starts: e.starts ? wl(e.starts) : null }) : Object.isFrozen(e) ? wl(e) : e;
}
var wX = "11.9.0";
class xX extends Error {
  constructor(t, n) {
    super(t), this.name = "HTMLInjectionError", this.html = n;
  }
}
const g0 = $F, yN = wl, TN = Symbol("nomatch"), NX = 7, jF = function(e) {
  const t = /* @__PURE__ */ Object.create(null), n = /* @__PURE__ */ Object.create(null), r = [];
  let i = !0;
  const a = "Could not find the language '{}', did you forget to load/include a language module?", o = { disableAutodetect: !0, name: "Plain text", contains: [] };
  let s = {
    ignoreUnescapedHTML: !1,
    throwUnescapedHTML: !1,
    noHighlightRe: /^(no-?highlight)$/i,
    languageDetectRe: /\blang(?:uage)?-([\w-]+)\b/i,
    classPrefix: "hljs-",
    cssSelector: "pre code",
    languages: null,
    // beta configuration options, subject to change, welcome to discuss
    // https://github.com/highlightjs/highlight.js/issues/1086
    __emitter: GQ
  };
  function l(k) {
    return s.noHighlightRe.test(k);
  }
  function u(k) {
    let B = k.className + " ";
    B += k.parentNode ? k.parentNode.className : "";
    const W = s.languageDetectRe.exec(B);
    if (W) {
      const Z = D(W[1]);
      return Z || (SN(a.replace("{}", W[1])), SN("Falling back to no-highlight mode for this block.", k)), Z ? W[1] : "no-highlight";
    }
    return B.split(/\s+/).find((Z) => l(Z) || D(Z));
  }
  function c(k, B, W) {
    let Z = "", V = "";
    typeof B == "object" ? (Z = k, W = B.ignoreIllegals, V = B.language) : (Rc("10.7.0", "highlight(lang, code, ...args) has been deprecated."), Rc("10.7.0", `Please use highlight(code, options) instead.
https://github.com/highlightjs/highlight.js/issues/2277`), V = k, Z = B), W === void 0 && (W = !0);
    const K = {
      code: Z,
      language: V
    };
    x("before:highlight", K);
    const ne = K.result ? K.result : d(K.language, K.code, W);
    return ne.code = K.code, x("after:highlight", ne), ne;
  }
  function d(k, B, W, Z) {
    const V = /* @__PURE__ */ Object.create(null);
    function K(we, je) {
      return we.keywords[je];
    }
    function ne() {
      if (!Ke.keywords) {
        Be.addText(pt);
        return;
      }
      let we = 0;
      Ke.keywordPatternRe.lastIndex = 0;
      let je = Ke.keywordPatternRe.exec(pt), yt = "";
      for (; je; ) {
        yt += pt.substring(we, je.index);
        const Rt = We.case_insensitive ? je[0].toLowerCase() : je[0], sn = K(Ke, Rt);
        if (sn) {
          const [me, He] = sn;
          if (Be.addText(yt), yt = "", V[Rt] = (V[Rt] || 0) + 1, V[Rt] <= NX && (ft += He), me.startsWith("_"))
            yt += je[0];
          else {
            const tt = We.classNameAliases[me] || me;
            ae(je[0], tt);
          }
        } else
          yt += je[0];
        we = Ke.keywordPatternRe.lastIndex, je = Ke.keywordPatternRe.exec(pt);
      }
      yt += pt.substring(we), Be.addText(yt);
    }
    function Ee() {
      if (pt === "") return;
      let we = null;
      if (typeof Ke.subLanguage == "string") {
        if (!t[Ke.subLanguage]) {
          Be.addText(pt);
          return;
        }
        we = d(Ke.subLanguage, pt, !0, Je[Ke.subLanguage]), Je[Ke.subLanguage] = /** @type {CompiledMode} */
        we._top;
      } else
        we = h(pt, Ke.subLanguage.length ? Ke.subLanguage : null);
      Ke.relevance > 0 && (ft += we.relevance), Be.__addSublanguage(we._emitter, we.language);
    }
    function oe() {
      Ke.subLanguage != null ? Ee() : ne(), pt = "";
    }
    function ae(we, je) {
      we !== "" && (Be.startScope(je), Be.addText(we), Be.endScope());
    }
    function pe(we, je) {
      let yt = 1;
      const Rt = je.length - 1;
      for (; yt <= Rt; ) {
        if (!we._emit[yt]) {
          yt++;
          continue;
        }
        const sn = We.classNameAliases[we[yt]] || we[yt], me = je[yt];
        sn ? ae(me, sn) : (pt = me, ne(), pt = ""), yt++;
      }
    }
    function Se(we, je) {
      return we.scope && typeof we.scope == "string" && Be.openNode(We.classNameAliases[we.scope] || we.scope), we.beginScope && (we.beginScope._wrap ? (ae(pt, We.classNameAliases[we.beginScope._wrap] || we.beginScope._wrap), pt = "") : we.beginScope._multi && (pe(we.beginScope, je), pt = "")), Ke = Object.create(we, { parent: { value: Ke } }), Ke;
    }
    function Re(we, je, yt) {
      let Rt = VQ(we.endRe, yt);
      if (Rt) {
        if (we["on:end"]) {
          const sn = new _N(we);
          we["on:end"](je, sn), sn.isMatchIgnored && (Rt = !1);
        }
        if (Rt) {
          for (; we.endsParent && we.parent; )
            we = we.parent;
          return we;
        }
      }
      if (we.endsWithParent)
        return Re(we.parent, je, yt);
    }
    function Ye(we) {
      return Ke.matcher.regexIndex === 0 ? (pt += we[0], 1) : (St = !0, 0);
    }
    function nt(we) {
      const je = we[0], yt = we.rule, Rt = new _N(yt), sn = [yt.__beforeBegin, yt["on:begin"]];
      for (const me of sn)
        if (me && (me(we, Rt), Rt.isMatchIgnored))
          return Ye(je);
      return yt.skip ? pt += je : (yt.excludeBegin && (pt += je), oe(), !yt.returnBegin && !yt.excludeBegin && (pt = je)), Se(yt, we), yt.returnBegin ? 0 : je.length;
    }
    function ut(we) {
      const je = we[0], yt = B.substring(we.index), Rt = Re(Ke, we, yt);
      if (!Rt)
        return TN;
      const sn = Ke;
      Ke.endScope && Ke.endScope._wrap ? (oe(), ae(je, Ke.endScope._wrap)) : Ke.endScope && Ke.endScope._multi ? (oe(), pe(Ke.endScope, we)) : sn.skip ? pt += je : (sn.returnEnd || sn.excludeEnd || (pt += je), oe(), sn.excludeEnd && (pt = je));
      do
        Ke.scope && Be.closeNode(), !Ke.skip && !Ke.subLanguage && (ft += Ke.relevance), Ke = Ke.parent;
      while (Ke !== Rt.parent);
      return Rt.starts && Se(Rt.starts, we), sn.returnEnd ? 0 : je.length;
    }
    function Tt() {
      const we = [];
      for (let je = Ke; je !== We; je = je.parent)
        je.scope && we.unshift(je.scope);
      we.forEach((je) => Be.openNode(je));
    }
    let Ot = {};
    function Xt(we, je) {
      const yt = je && je[0];
      if (pt += we, yt == null)
        return oe(), 0;
      if (Ot.type === "begin" && je.type === "end" && Ot.index === je.index && yt === "") {
        if (pt += B.slice(je.index, je.index + 1), !i) {
          const Rt = new Error(`0 width match regex (${k})`);
          throw Rt.languageName = k, Rt.badRule = Ot.rule, Rt;
        }
        return 1;
      }
      if (Ot = je, je.type === "begin")
        return nt(je);
      if (je.type === "illegal" && !W) {
        const Rt = new Error('Illegal lexeme "' + yt + '" for mode "' + (Ke.scope || "<unnamed>") + '"');
        throw Rt.mode = Ke, Rt;
      } else if (je.type === "end") {
        const Rt = ut(je);
        if (Rt !== TN)
          return Rt;
      }
      if (je.type === "illegal" && yt === "")
        return 1;
      if (_t > 1e5 && _t > je.index * 3)
        throw new Error("potential infinite loop, way more iterations than matches");
      return pt += yt, yt.length;
    }
    const We = D(k);
    if (!We)
      throw Lu(a.replace("{}", k)), new Error('Unknown language: "' + k + '"');
    const st = OX(We);
    let Pt = "", Ke = Z || st;
    const Je = {}, Be = new s.__emitter(s);
    Tt();
    let pt = "", ft = 0, Ze = 0, _t = 0, St = !1;
    try {
      if (We.__emitTokens)
        We.__emitTokens(B, Be);
      else {
        for (Ke.matcher.considerAll(); ; ) {
          _t++, St ? St = !1 : Ke.matcher.considerAll(), Ke.matcher.lastIndex = Ze;
          const we = Ke.matcher.exec(B);
          if (!we) break;
          const je = B.substring(Ze, we.index), yt = Xt(je, we);
          Ze = we.index + yt;
        }
        Xt(B.substring(Ze));
      }
      return Be.finalize(), Pt = Be.toHTML(), {
        language: k,
        value: Pt,
        relevance: ft,
        illegal: !1,
        _emitter: Be,
        _top: Ke
      };
    } catch (we) {
      if (we.message && we.message.includes("Illegal"))
        return {
          language: k,
          value: g0(B),
          illegal: !0,
          relevance: 0,
          _illegalBy: {
            message: we.message,
            index: Ze,
            context: B.slice(Ze - 100, Ze + 100),
            mode: we.mode,
            resultSoFar: Pt
          },
          _emitter: Be
        };
      if (i)
        return {
          language: k,
          value: g0(B),
          illegal: !1,
          relevance: 0,
          errorRaised: we,
          _emitter: Be,
          _top: Ke
        };
      throw we;
    }
  }
  function f(k) {
    const B = {
      value: g0(k),
      illegal: !1,
      relevance: 0,
      _top: o,
      _emitter: new s.__emitter(s)
    };
    return B._emitter.addText(k), B;
  }
  function h(k, B) {
    B = B || s.languages || Object.keys(t);
    const W = f(k), Z = B.filter(D).filter($).map(
      (oe) => d(oe, k, !1)
    );
    Z.unshift(W);
    const V = Z.sort((oe, ae) => {
      if (oe.relevance !== ae.relevance) return ae.relevance - oe.relevance;
      if (oe.language && ae.language) {
        if (D(oe.language).supersetOf === ae.language)
          return 1;
        if (D(ae.language).supersetOf === oe.language)
          return -1;
      }
      return 0;
    }), [K, ne] = V, Ee = K;
    return Ee.secondBest = ne, Ee;
  }
  function m(k, B, W) {
    const Z = B && n[B] || W;
    k.classList.add("hljs"), k.classList.add(`language-${Z}`);
  }
  function v(k) {
    let B = null;
    const W = u(k);
    if (l(W)) return;
    if (x(
      "before:highlightElement",
      { el: k, language: W }
    ), k.dataset.highlighted) {
      console.log("Element previously highlighted. To highlight again, first unset `dataset.highlighted`.", k);
      return;
    }
    if (k.children.length > 0 && (s.ignoreUnescapedHTML || (console.warn("One of your code blocks includes unescaped HTML. This is a potentially serious security risk."), console.warn("https://github.com/highlightjs/highlight.js/wiki/security"), console.warn("The element with unescaped HTML:"), console.warn(k)), s.throwUnescapedHTML))
      throw new xX(
        "One of your code blocks includes unescaped HTML.",
        k.innerHTML
      );
    B = k;
    const Z = B.textContent, V = W ? c(Z, { language: W, ignoreIllegals: !0 }) : h(Z);
    k.innerHTML = V.value, k.dataset.highlighted = "yes", m(k, W, V.language), k.result = {
      language: V.language,
      // TODO: remove with version 11.0
      re: V.relevance,
      relevance: V.relevance
    }, V.secondBest && (k.secondBest = {
      language: V.secondBest.language,
      relevance: V.secondBest.relevance
    }), x("after:highlightElement", { el: k, result: V, text: Z });
  }
  function b(k) {
    s = yN(s, k);
  }
  const y = () => {
    S(), Rc("10.6.0", "initHighlighting() deprecated.  Use highlightAll() now.");
  };
  function g() {
    S(), Rc("10.6.0", "initHighlightingOnLoad() deprecated.  Use highlightAll() now.");
  }
  let E = !1;
  function S() {
    if (document.readyState === "loading") {
      E = !0;
      return;
    }
    document.querySelectorAll(s.cssSelector).forEach(v);
  }
  function C() {
    E && S();
  }
  typeof window < "u" && window.addEventListener && window.addEventListener("DOMContentLoaded", C, !1);
  function T(k, B) {
    let W = null;
    try {
      W = B(e);
    } catch (Z) {
      if (Lu("Language definition for '{}' could not be registered.".replace("{}", k)), i)
        Lu(Z);
      else
        throw Z;
      W = o;
    }
    W.name || (W.name = k), t[k] = W, W.rawDefinition = B.bind(null, e), W.aliases && q(W.aliases, { languageName: k });
  }
  function O(k) {
    delete t[k];
    for (const B of Object.keys(n))
      n[B] === k && delete n[B];
  }
  function R() {
    return Object.keys(t);
  }
  function D(k) {
    return k = (k || "").toLowerCase(), t[k] || t[n[k]];
  }
  function q(k, { languageName: B }) {
    typeof k == "string" && (k = [k]), k.forEach((W) => {
      n[W.toLowerCase()] = B;
    });
  }
  function $(k) {
    const B = D(k);
    return B && !B.disableAutodetect;
  }
  function P(k) {
    k["before:highlightBlock"] && !k["before:highlightElement"] && (k["before:highlightElement"] = (B) => {
      k["before:highlightBlock"](
        Object.assign({ block: B.el }, B)
      );
    }), k["after:highlightBlock"] && !k["after:highlightElement"] && (k["after:highlightElement"] = (B) => {
      k["after:highlightBlock"](
        Object.assign({ block: B.el }, B)
      );
    });
  }
  function Y(k) {
    P(k), r.push(k);
  }
  function L(k) {
    const B = r.indexOf(k);
    B !== -1 && r.splice(B, 1);
  }
  function x(k, B) {
    const W = k;
    r.forEach(function(Z) {
      Z[W] && Z[W](B);
    });
  }
  function I(k) {
    return Rc("10.7.0", "highlightBlock will be removed entirely in v12.0"), Rc("10.7.0", "Please use highlightElement now."), v(k);
  }
  Object.assign(e, {
    highlight: c,
    highlightAuto: h,
    highlightAll: S,
    highlightElement: v,
    // TODO: Remove with v12 API
    highlightBlock: I,
    configure: b,
    initHighlighting: y,
    initHighlightingOnLoad: g,
    registerLanguage: T,
    unregisterLanguage: O,
    listLanguages: R,
    getLanguage: D,
    registerAliases: q,
    autoDetection: $,
    inherit: yN,
    addPlugin: Y,
    removePlugin: L
  }), e.debugMode = function() {
    i = !1;
  }, e.safeMode = function() {
    i = !0;
  }, e.versionString = wX, e.regex = {
    concat: Qu,
    lookahead: UF,
    either: y1,
    optional: HQ,
    anyNumberOfTimes: YQ
  };
  for (const k in Ph)
    typeof Ph[k] == "object" && BF(Ph[k]);
  return Object.assign(e, Ph), e;
}, ld = jF({});
ld.newInstance = () => jF({});
var DX = ld;
ld.HighlightJS = ld;
ld.default = ld;
var _0, CN;
function IX() {
  if (CN) return _0;
  CN = 1;
  function e(t) {
    const n = "[A-Za-zА-Яа-яёЁ_][A-Za-zА-Яа-яёЁ_0-9]+", a = "далее " + "возврат вызватьисключение выполнить для если и из или иначе иначеесли исключение каждого конецесли конецпопытки конеццикла не новый перейти перем по пока попытка прервать продолжить тогда цикл экспорт ", l = "загрузитьизфайла " + "вебклиент вместо внешнеесоединение клиент конецобласти мобильноеприложениеклиент мобильноеприложениесервер наклиенте наклиентенасервере наклиентенасерверебезконтекста насервере насерверебезконтекста область перед после сервер толстыйклиентобычноеприложение толстыйклиентуправляемоеприложение тонкийклиент ", h = "разделительстраниц разделительстрок символтабуляции " + "ansitooem oemtoansi ввестивидсубконто ввестиперечисление ввестипериод ввестиплансчетов выбранныйплансчетов датагод датамесяц датачисло заголовоксистемы значениевстроку значениеизстроки каталогиб каталогпользователя кодсимв конгода конецпериодаби конецрассчитанногопериодаби конецстандартногоинтервала конквартала конмесяца коннедели лог лог10 максимальноеколичествосубконто названиеинтерфейса названиенабораправ назначитьвид назначитьсчет найтиссылки началопериодаби началостандартногоинтервала начгода начквартала начмесяца начнедели номерднягода номерднянедели номернеделигода обработкаожидания основнойжурналрасчетов основнойплансчетов основнойязык очиститьокносообщений периодстр получитьвремята получитьдатута получитьдокументта получитьзначенияотбора получитьпозициюта получитьпустоезначение получитьта префиксавтонумерации пропись пустоезначение разм разобратьпозициюдокумента рассчитатьрегистрына рассчитатьрегистрыпо симв создатьобъект статусвозврата стрколичествострок сформироватьпозициюдокумента счетпокоду текущеевремя типзначения типзначениястр установитьтана установитьтапо фиксшаблон шаблон " + "acos asin atan base64значение base64строка cos exp log log10 pow sin sqrt tan xmlзначение xmlстрока xmlтип xmlтипзнч активноеокно безопасныйрежим безопасныйрежимразделенияданных булево ввестидату ввестизначение ввестистроку ввестичисло возможностьчтенияxml вопрос восстановитьзначение врег выгрузитьжурналрегистрации выполнитьобработкуоповещения выполнитьпроверкуправдоступа вычислить год данныеформывзначение дата день деньгода деньнедели добавитьмесяц заблокироватьданныедляредактирования заблокироватьработупользователя завершитьработусистемы загрузитьвнешнююкомпоненту закрытьсправку записатьjson записатьxml записатьдатуjson записьжурналарегистрации заполнитьзначениясвойств запроситьразрешениепользователя запуститьприложение запуститьсистему зафиксироватьтранзакцию значениевданныеформы значениевстрокувнутр значениевфайл значениезаполнено значениеизстрокивнутр значениеизфайла изxmlтипа импортмоделиxdto имякомпьютера имяпользователя инициализироватьпредопределенныеданные информацияобошибке каталогбиблиотекимобильногоустройства каталогвременныхфайлов каталогдокументов каталогпрограммы кодироватьстроку кодлокализацииинформационнойбазы кодсимвола командасистемы конецгода конецдня конецквартала конецмесяца конецминуты конецнедели конецчаса конфигурациябазыданныхизмененадинамически конфигурацияизменена копироватьданныеформы копироватьфайл краткоепредставлениеошибки лев макс местноевремя месяц мин минута монопольныйрежим найти найтинедопустимыесимволыxml найтиокнопонавигационнойссылке найтипомеченныенаудаление найтипоссылкам найтифайлы началогода началодня началоквартала началомесяца началоминуты началонедели началочаса начатьзапросразрешенияпользователя начатьзапускприложения начатькопированиефайла начатьперемещениефайла начатьподключениевнешнейкомпоненты начатьподключениерасширенияработыскриптографией начатьподключениерасширенияработысфайлами начатьпоискфайлов начатьполучениекаталогавременныхфайлов начатьполучениекаталогадокументов начатьполучениерабочегокаталогаданныхпользователя начатьполучениефайлов начатьпомещениефайла начатьпомещениефайлов начатьсозданиедвоичныхданныхизфайла начатьсозданиекаталога начатьтранзакцию начатьудалениефайлов начатьустановкувнешнейкомпоненты начатьустановкурасширенияработыскриптографией начатьустановкурасширенияработысфайлами неделягода необходимостьзавершениясоединения номерсеансаинформационнойбазы номерсоединенияинформационнойбазы нрег нстр обновитьинтерфейс обновитьнумерациюобъектов обновитьповторноиспользуемыезначения обработкапрерыванияпользователя объединитьфайлы окр описаниеошибки оповестить оповеститьобизменении отключитьобработчикзапросанастроекклиенталицензирования отключитьобработчикожидания отключитьобработчикоповещения открытьзначение открытьиндекссправки открытьсодержаниесправки открытьсправку открытьформу открытьформумодально отменитьтранзакцию очиститьжурналрегистрации очиститьнастройкипользователя очиститьсообщения параметрыдоступа перейтипонавигационнойссылке переместитьфайл подключитьвнешнююкомпоненту подключитьобработчикзапросанастроекклиенталицензирования подключитьобработчикожидания подключитьобработчикоповещения подключитьрасширениеработыскриптографией подключитьрасширениеработысфайлами подробноепредставлениеошибки показатьвводдаты показатьвводзначения показатьвводстроки показатьвводчисла показатьвопрос показатьзначение показатьинформациюобошибке показатьнакарте показатьоповещениепользователя показатьпредупреждение полноеимяпользователя получитьcomобъект получитьxmlтип получитьадреспоместоположению получитьблокировкусеансов получитьвремязавершенияспящегосеанса получитьвремязасыпанияпассивногосеанса получитьвремяожиданияблокировкиданных получитьданныевыбора получитьдополнительныйпараметрклиенталицензирования получитьдопустимыекодылокализации получитьдопустимыечасовыепояса получитьзаголовокклиентскогоприложения получитьзаголовоксистемы получитьзначенияотборажурналарегистрации получитьидентификаторконфигурации получитьизвременногохранилища получитьимявременногофайла получитьимяклиенталицензирования получитьинформациюэкрановклиента получитьиспользованиежурналарегистрации получитьиспользованиесобытияжурналарегистрации получитькраткийзаголовокприложения получитьмакетоформления получитьмаскувсефайлы получитьмаскувсефайлыклиента получитьмаскувсефайлысервера получитьместоположениепоадресу получитьминимальнуюдлинупаролейпользователей получитьнавигационнуюссылку получитьнавигационнуюссылкуинформационнойбазы получитьобновлениеконфигурациибазыданных получитьобновлениепредопределенныхданныхинформационнойбазы получитьобщиймакет получитьобщуюформу получитьокна получитьоперативнуюотметкувремени получитьотключениебезопасногорежима получитьпараметрыфункциональныхопцийинтерфейса получитьполноеимяпредопределенногозначения получитьпредставлениянавигационныхссылок получитьпроверкусложностипаролейпользователей получитьразделительпути получитьразделительпутиклиента получитьразделительпутисервера получитьсеансыинформационнойбазы получитьскоростьклиентскогосоединения получитьсоединенияинформационнойбазы получитьсообщенияпользователю получитьсоответствиеобъектаиформы получитьсоставстандартногоинтерфейсаodata получитьструктурухранениябазыданных получитьтекущийсеансинформационнойбазы получитьфайл получитьфайлы получитьформу получитьфункциональнуюопцию получитьфункциональнуюопциюинтерфейса получитьчасовойпоясинформационнойбазы пользователиос поместитьвовременноехранилище поместитьфайл поместитьфайлы прав праводоступа предопределенноезначение представлениекодалокализации представлениепериода представлениеправа представлениеприложения представлениесобытияжурналарегистрации представлениечасовогопояса предупреждение прекратитьработусистемы привилегированныйрежим продолжитьвызов прочитатьjson прочитатьxml прочитатьдатуjson пустаястрока рабочийкаталогданныхпользователя разблокироватьданныедляредактирования разделитьфайл разорватьсоединениесвнешнимисточникомданных раскодироватьстроку рольдоступна секунда сигнал символ скопироватьжурналрегистрации смещениелетнеговремени смещениестандартноговремени соединитьбуферыдвоичныхданных создатькаталог создатьфабрикуxdto сокрл сокрлп сокрп сообщить состояние сохранитьзначение сохранитьнастройкипользователя сред стрдлина стрзаканчиваетсяна стрзаменить стрнайти стрначинаетсяс строка строкасоединенияинформационнойбазы стрполучитьстроку стрразделить стрсоединить стрсравнить стрчисловхождений стрчислострок стршаблон текущаядата текущаядатасеанса текущаяуниверсальнаядата текущаяуниверсальнаядатавмиллисекундах текущийвариантинтерфейсаклиентскогоприложения текущийвариантосновногошрифтаклиентскогоприложения текущийкодлокализации текущийрежимзапуска текущийязык текущийязыксистемы тип типзнч транзакцияактивна трег удалитьданныеинформационнойбазы удалитьизвременногохранилища удалитьобъекты удалитьфайлы универсальноевремя установитьбезопасныйрежим установитьбезопасныйрежимразделенияданных установитьблокировкусеансов установитьвнешнююкомпоненту установитьвремязавершенияспящегосеанса установитьвремязасыпанияпассивногосеанса установитьвремяожиданияблокировкиданных установитьзаголовокклиентскогоприложения установитьзаголовоксистемы установитьиспользованиежурналарегистрации установитьиспользованиесобытияжурналарегистрации установитькраткийзаголовокприложения установитьминимальнуюдлинупаролейпользователей установитьмонопольныйрежим установитьнастройкиклиенталицензирования установитьобновлениепредопределенныхданныхинформационнойбазы установитьотключениебезопасногорежима установитьпараметрыфункциональныхопцийинтерфейса установитьпривилегированныйрежим установитьпроверкусложностипаролейпользователей установитьрасширениеработыскриптографией установитьрасширениеработысфайлами установитьсоединениесвнешнимисточникомданных установитьсоответствиеобъектаиформы установитьсоставстандартногоинтерфейсаodata установитьчасовойпоясинформационнойбазы установитьчасовойпояссеанса формат цел час часовойпояс часовойпояссеанса число числопрописью этоадресвременногохранилища " + "wsссылки библиотекакартинок библиотекамакетовоформлениякомпоновкиданных библиотекастилей бизнеспроцессы внешниеисточникиданных внешниеобработки внешниеотчеты встроенныепокупки главныйинтерфейс главныйстиль документы доставляемыеуведомления журналыдокументов задачи информацияобинтернетсоединении использованиерабочейдаты историяработыпользователя константы критерииотбора метаданные обработки отображениерекламы отправкадоставляемыхуведомлений отчеты панельзадачос параметрзапуска параметрысеанса перечисления планывидоврасчета планывидовхарактеристик планыобмена планысчетов полнотекстовыйпоиск пользователиинформационнойбазы последовательности проверкавстроенныхпокупок рабочаядата расширенияконфигурации регистрыбухгалтерии регистрынакопления регистрырасчета регистрысведений регламентныезадания сериализаторxdto справочники средствагеопозиционирования средствакриптографии средствамультимедиа средстваотображениярекламы средствапочты средствателефонии фабрикаxdto файловыепотоки фоновыезадания хранилищанастроек хранилищевариантовотчетов хранилищенастроекданныхформ хранилищеобщихнастроек хранилищепользовательскихнастроекдинамическихсписков хранилищепользовательскихнастроекотчетов хранилищесистемныхнастроек ", Z = "webцвета windowsцвета windowsшрифты библиотекакартинок рамкистиля символы цветастиля шрифтыстиля " + "автоматическоесохранениеданныхформывнастройках автонумерациявформе автораздвижениесерий анимациядиаграммы вариантвыравниванияэлементовизаголовков вариантуправлениявысотойтаблицы вертикальнаяпрокруткаформы вертикальноеположение вертикальноеположениеэлемента видгруппыформы виддекорацииформы виддополненияэлементаформы видизмененияданных видкнопкиформы видпереключателя видподписейкдиаграмме видполяформы видфлажка влияниеразмеранапузырекдиаграммы горизонтальноеположение горизонтальноеположениеэлемента группировкаколонок группировкаподчиненныхэлементовформы группыиэлементы действиеперетаскивания дополнительныйрежимотображения допустимыедействияперетаскивания интервалмеждуэлементамиформы использованиевывода использованиеполосыпрокрутки используемоезначениеточкибиржевойдиаграммы историявыборапривводе источникзначенийоситочекдиаграммы источникзначенияразмерапузырькадиаграммы категориягруппыкоманд максимумсерий начальноеотображениедерева начальноеотображениесписка обновлениетекстаредактирования ориентациядендрограммы ориентациядиаграммы ориентацияметокдиаграммы ориентацияметоксводнойдиаграммы ориентацияэлементаформы отображениевдиаграмме отображениевлегендедиаграммы отображениегруппыкнопок отображениезаголовкашкалыдиаграммы отображениезначенийсводнойдиаграммы отображениезначенияизмерительнойдиаграммы отображениеинтерваладиаграммыганта отображениекнопки отображениекнопкивыбора отображениеобсужденийформы отображениеобычнойгруппы отображениеотрицательныхзначенийпузырьковойдиаграммы отображениепанелипоиска отображениеподсказки отображениепредупрежденияприредактировании отображениеразметкиполосырегулирования отображениестраницформы отображениетаблицы отображениетекстазначениядиаграммыганта отображениеуправленияобычнойгруппы отображениефигурыкнопки палитрацветовдиаграммы поведениеобычнойгруппы поддержкамасштабадендрограммы поддержкамасштабадиаграммыганта поддержкамасштабасводнойдиаграммы поисквтаблицепривводе положениезаголовкаэлементаформы положениекартинкикнопкиформы положениекартинкиэлементаграфическойсхемы положениекоманднойпанелиформы положениекоманднойпанелиэлементаформы положениеопорнойточкиотрисовки положениеподписейкдиаграмме положениеподписейшкалызначенийизмерительнойдиаграммы положениесостоянияпросмотра положениестрокипоиска положениетекстасоединительнойлинии положениеуправленияпоиском положениешкалывремени порядокотображенияточекгоризонтальнойгистограммы порядоксерийвлегендедиаграммы размеркартинки расположениезаголовкашкалыдиаграммы растягиваниеповертикалидиаграммыганта режимавтоотображениясостояния режимвводастроктаблицы режимвыборанезаполненного режимвыделениядаты режимвыделениястрокитаблицы режимвыделениятаблицы режимизмененияразмера режимизменениясвязанногозначения режимиспользованиядиалогапечати режимиспользованияпараметракоманды режиммасштабированияпросмотра режимосновногоокнаклиентскогоприложения режимоткрытияокнаформы режимотображениявыделения режимотображениягеографическойсхемы режимотображениязначенийсерии режимотрисовкисеткиграфическойсхемы режимполупрозрачностидиаграммы режимпробеловдиаграммы режимразмещениянастранице режимредактированияколонки режимсглаживаниядиаграммы режимсглаживанияиндикатора режимсписказадач сквозноевыравнивание сохранениеданныхформывнастройках способзаполнениятекстазаголовкашкалыдиаграммы способопределенияограничивающегозначениядиаграммы стандартнаягруппакоманд стандартноеоформление статусоповещенияпользователя стильстрелки типаппроксимациилиниитрендадиаграммы типдиаграммы типединицышкалывремени типимпортасерийслоягеографическойсхемы типлиниигеографическойсхемы типлиниидиаграммы типмаркерагеографическойсхемы типмаркерадиаграммы типобластиоформления типорганизацииисточникаданныхгеографическойсхемы типотображениясериислоягеографическойсхемы типотображенияточечногообъектагеографическойсхемы типотображенияшкалыэлементалегендыгеографическойсхемы типпоискаобъектовгеографическойсхемы типпроекциигеографическойсхемы типразмещенияизмерений типразмещенияреквизитовизмерений типрамкиэлементауправления типсводнойдиаграммы типсвязидиаграммыганта типсоединениязначенийпосериямдиаграммы типсоединенияточекдиаграммы типсоединительнойлинии типстороныэлементаграфическойсхемы типформыотчета типшкалырадарнойдиаграммы факторлиниитрендадиаграммы фигуракнопки фигурыграфическойсхемы фиксациявтаблице форматдняшкалывремени форматкартинки ширинаподчиненныхэлементовформы " + "виддвижениябухгалтерии виддвижениянакопления видпериодарегистрарасчета видсчета видточкимаршрутабизнеспроцесса использованиеагрегатарегистранакопления использованиегруппиэлементов использованиережимапроведения использованиесреза периодичностьагрегатарегистранакопления режимавтовремя режимзаписидокумента режимпроведениядокумента " + "авторегистрацияизменений допустимыйномерсообщения отправкаэлементаданных получениеэлементаданных " + "использованиерасшифровкитабличногодокумента ориентациястраницы положениеитоговколоноксводнойтаблицы положениеитоговстроксводнойтаблицы положениетекстаотносительнокартинки расположениезаголовкагруппировкитабличногодокумента способчтениязначенийтабличногодокумента типдвустороннейпечати типзаполненияобластитабличногодокумента типкурсоровтабличногодокумента типлиниирисункатабличногодокумента типлинииячейкитабличногодокумента типнаправленияпереходатабличногодокумента типотображениявыделениятабличногодокумента типотображениялинийсводнойтаблицы типразмещениятекстатабличногодокумента типрисункатабличногодокумента типсмещениятабличногодокумента типузоратабличногодокумента типфайлатабличногодокумента точностьпечати чередованиерасположениястраниц " + "отображениевремениэлементовпланировщика " + "типфайлаформатированногодокумента " + "обходрезультатазапроса типзаписизапроса " + "видзаполнениярасшифровкипостроителяотчета типдобавленияпредставлений типизмеренияпостроителяотчета типразмещенияитогов " + "доступкфайлу режимдиалогавыборафайла режимоткрытияфайла " + "типизмеренияпостроителязапроса " + "видданныханализа методкластеризации типединицыинтервалавременианализаданных типзаполнениятаблицырезультатаанализаданных типиспользованиячисловыхзначенийанализаданных типисточникаданныхпоискаассоциаций типколонкианализаданныхдереворешений типколонкианализаданныхкластеризация типколонкианализаданныхобщаястатистика типколонкианализаданныхпоискассоциаций типколонкианализаданныхпоискпоследовательностей типколонкимоделипрогноза типмерырасстоянияанализаданных типотсеченияправилассоциации типполяанализаданных типстандартизациианализаданных типупорядочиванияправилассоциациианализаданных типупорядочиванияшаблоновпоследовательностейанализаданных типупрощениядереварешений " + "wsнаправлениепараметра вариантxpathxs вариантзаписидатыjson вариантпростоготипаxs видгруппымоделиxs видфасетаxdto действиепостроителяdom завершенностьпростоготипаxs завершенностьсоставноготипаxs завершенностьсхемыxs запрещенныеподстановкиxs исключениягруппподстановкиxs категорияиспользованияатрибутаxs категорияограниченияидентичностиxs категорияограниченияпространствименxs методнаследованияxs модельсодержимогоxs назначениетипаxml недопустимыеподстановкиxs обработкапробельныхсимволовxs обработкасодержимогоxs ограничениезначенияxs параметрыотбораузловdom переносстрокjson позициявдокументеdom пробельныесимволыxml типатрибутаxml типзначенияjson типканоническогоxml типкомпонентыxs типпроверкиxml типрезультатаdomxpath типузлаdom типузлаxml формаxml формапредставленияxs форматдатыjson экранированиесимволовjson " + "видсравнениякомпоновкиданных действиеобработкирасшифровкикомпоновкиданных направлениесортировкикомпоновкиданных расположениевложенныхэлементоврезультатакомпоновкиданных расположениеитоговкомпоновкиданных расположениегруппировкикомпоновкиданных расположениеполейгруппировкикомпоновкиданных расположениеполякомпоновкиданных расположениереквизитовкомпоновкиданных расположениересурсовкомпоновкиданных типбухгалтерскогоостаткакомпоновкиданных типвыводатекстакомпоновкиданных типгруппировкикомпоновкиданных типгруппыэлементовотборакомпоновкиданных типдополненияпериодакомпоновкиданных типзаголовкаполейкомпоновкиданных типмакетагруппировкикомпоновкиданных типмакетаобластикомпоновкиданных типостаткакомпоновкиданных типпериодакомпоновкиданных типразмещениятекстакомпоновкиданных типсвязинаборовданныхкомпоновкиданных типэлементарезультатакомпоновкиданных расположениелегендыдиаграммыкомпоновкиданных типпримененияотборакомпоновкиданных режимотображенияэлементанастройкикомпоновкиданных режимотображениянастроеккомпоновкиданных состояниеэлементанастройкикомпоновкиданных способвосстановлениянастроеккомпоновкиданных режимкомпоновкирезультата использованиепараметракомпоновкиданных автопозицияресурсовкомпоновкиданных вариантиспользованиягруппировкикомпоновкиданных расположениересурсоввдиаграммекомпоновкиданных фиксациякомпоновкиданных использованиеусловногооформлениякомпоновкиданных " + "важностьинтернетпочтовогосообщения обработкатекстаинтернетпочтовогосообщения способкодированияинтернетпочтовоговложения способкодированиянеasciiсимволовинтернетпочтовогосообщения типтекстапочтовогосообщения протоколинтернетпочты статусразборапочтовогосообщения " + "режимтранзакциизаписижурналарегистрации статустранзакциизаписижурналарегистрации уровеньжурналарегистрации " + "расположениехранилищасертификатовкриптографии режимвключениясертификатовкриптографии режимпроверкисертификатакриптографии типхранилищасертификатовкриптографии " + "кодировкаименфайловвzipфайле методсжатияzip методшифрованияzip режимвосстановленияпутейфайловzip режимобработкиподкаталоговzip режимсохраненияпутейzip уровеньсжатияzip " + "звуковоеоповещение направлениепереходакстроке позициявпотоке порядокбайтов режимблокировкиданных режимуправленияблокировкойданных сервисвстроенныхпокупок состояниефоновогозадания типподписчикадоставляемыхуведомлений уровеньиспользованиязащищенногосоединенияftp " + "направлениепорядкасхемызапроса типдополненияпериодамисхемызапроса типконтрольнойточкисхемызапроса типобъединениясхемызапроса типпараметрадоступнойтаблицысхемызапроса типсоединениясхемызапроса " + "httpметод автоиспользованиеобщегореквизита автопрефиксномеразадачи вариантвстроенногоязыка видиерархии видрегистранакопления видтаблицывнешнегоисточникаданных записьдвиженийприпроведении заполнениепоследовательностей индексирование использованиебазыпланавидоврасчета использованиебыстроговыбора использованиеобщегореквизита использованиеподчинения использованиеполнотекстовогопоиска использованиеразделяемыхданныхобщегореквизита использованиереквизита назначениеиспользованияприложения назначениерасширенияконфигурации направлениепередачи обновлениепредопределенныхданных оперативноепроведение основноепредставлениевидарасчета основноепредставлениевидахарактеристики основноепредставлениезадачи основноепредставлениепланаобмена основноепредставлениесправочника основноепредставлениесчета перемещениеграницыприпроведении периодичностьномерабизнеспроцесса периодичностьномерадокумента периодичностьрегистрарасчета периодичностьрегистрасведений повторноеиспользованиевозвращаемыхзначений полнотекстовыйпоискпривводепостроке принадлежностьобъекта проведение разделениеаутентификацииобщегореквизита разделениеданныхобщегореквизита разделениерасширенийконфигурацииобщегореквизита режимавтонумерацииобъектов режимзаписирегистра режимиспользованиямодальности режимиспользованиясинхронныхвызововрасширенийплатформыивнешнихкомпонент режимповторногоиспользованиясеансов режимполученияданныхвыборапривводепостроке режимсовместимости режимсовместимостиинтерфейса режимуправленияблокировкойданныхпоумолчанию сериикодовпланавидовхарактеристик сериикодовпланасчетов сериикодовсправочника созданиепривводе способвыбора способпоискастрокипривводепостроке способредактирования типданныхтаблицывнешнегоисточникаданных типкодапланавидоврасчета типкодасправочника типмакета типномерабизнеспроцесса типномерадокумента типномеразадачи типформы удалениедвижений " + "важностьпроблемыприменениярасширенияконфигурации вариантинтерфейсаклиентскогоприложения вариантмасштабаформклиентскогоприложения вариантосновногошрифтаклиентскогоприложения вариантстандартногопериода вариантстандартнойдатыначала видграницы видкартинки видотображенияполнотекстовогопоиска видрамки видсравнения видцвета видчисловогозначения видшрифта допустимаядлина допустимыйзнак использованиеbyteordermark использованиеметаданныхполнотекстовогопоиска источникрасширенийконфигурации клавиша кодвозвратадиалога кодировкаxbase кодировкатекста направлениепоиска направлениесортировки обновлениепредопределенныхданных обновлениеприизмененииданных отображениепанелиразделов проверказаполнения режимдиалогавопрос режимзапускаклиентскогоприложения режимокругления режимоткрытияформприложения режимполнотекстовогопоиска скоростьклиентскогосоединения состояниевнешнегоисточникаданных состояниеобновленияконфигурациибазыданных способвыборасертификатаwindows способкодированиястроки статуссообщения типвнешнейкомпоненты типплатформы типповеденияклавишиenter типэлементаинформацииовыполненииобновленияконфигурациибазыданных уровеньизоляциитранзакций хешфункция частидаты", ne = "comобъект ftpсоединение httpзапрос httpсервисответ httpсоединение wsопределения wsпрокси xbase анализданных аннотацияxs блокировкаданных буфердвоичныхданных включениеxs выражениекомпоновкиданных генераторслучайныхчисел географическаясхема географическиекоординаты графическаясхема группамоделиxs данныерасшифровкикомпоновкиданных двоичныеданные дендрограмма диаграмма диаграммаганта диалогвыборафайла диалогвыборацвета диалогвыборашрифта диалограсписаниярегламентногозадания диалогредактированиястандартногопериода диапазон документdom документhtml документацияxs доставляемоеуведомление записьdom записьfastinfoset записьhtml записьjson записьxml записьzipфайла записьданных записьтекста записьузловdom запрос защищенноесоединениеopenssl значенияполейрасшифровкикомпоновкиданных извлечениетекста импортxs интернетпочта интернетпочтовоесообщение интернетпочтовыйпрофиль интернетпрокси интернетсоединение информациядляприложенияxs использованиеатрибутаxs использованиесобытияжурналарегистрации источникдоступныхнастроеккомпоновкиданных итераторузловdom картинка квалификаторыдаты квалификаторыдвоичныхданных квалификаторыстроки квалификаторычисла компоновщикмакетакомпоновкиданных компоновщикнастроеккомпоновкиданных конструктормакетаоформлениякомпоновкиданных конструкторнастроеккомпоновкиданных конструкторформатнойстроки линия макеткомпоновкиданных макетобластикомпоновкиданных макетоформлениякомпоновкиданных маскаxs менеджеркриптографии наборсхемxml настройкикомпоновкиданных настройкисериализацииjson обработкакартинок обработкарасшифровкикомпоновкиданных обходдереваdom объявлениеатрибутаxs объявлениенотацииxs объявлениеэлементаxs описаниеиспользованиясобытиядоступжурналарегистрации описаниеиспользованиясобытияотказвдоступежурналарегистрации описаниеобработкирасшифровкикомпоновкиданных описаниепередаваемогофайла описаниетипов определениегруппыатрибутовxs определениегруппымоделиxs определениеограниченияидентичностиxs определениепростоготипаxs определениесоставноготипаxs определениетипадокументаdom определенияxpathxs отборкомпоновкиданных пакетотображаемыхдокументов параметрвыбора параметркомпоновкиданных параметрызаписиjson параметрызаписиxml параметрычтенияxml переопределениеxs планировщик полеанализаданных полекомпоновкиданных построительdom построительзапроса построительотчета построительотчетаанализаданных построительсхемxml поток потоквпамяти почта почтовоесообщение преобразованиеxsl преобразованиекканоническомуxml процессорвыводарезультатакомпоновкиданныхвколлекциюзначений процессорвыводарезультатакомпоновкиданныхвтабличныйдокумент процессоркомпоновкиданных разыменовательпространствименdom рамка расписаниерегламентногозадания расширенноеимяxml результатчтенияданных своднаядиаграмма связьпараметравыбора связьпотипу связьпотипукомпоновкиданных сериализаторxdto сертификатклиентаwindows сертификатклиентафайл сертификаткриптографии сертификатыудостоверяющихцентровwindows сертификатыудостоверяющихцентровфайл сжатиеданных системнаяинформация сообщениепользователю сочетаниеклавиш сравнениезначений стандартнаядатаначала стандартныйпериод схемаxml схемакомпоновкиданных табличныйдокумент текстовыйдокумент тестируемоеприложение типданныхxml уникальныйидентификатор фабрикаxdto файл файловыйпоток фасетдлиныxs фасетколичестваразрядовдробнойчастиxs фасетмаксимальноговключающегозначенияxs фасетмаксимальногоисключающегозначенияxs фасетмаксимальнойдлиныxs фасетминимальноговключающегозначенияxs фасетминимальногоисключающегозначенияxs фасетминимальнойдлиныxs фасетобразцаxs фасетобщегоколичестваразрядовxs фасетперечисленияxs фасетпробельныхсимволовxs фильтрузловdom форматированнаястрока форматированныйдокумент фрагментxs хешированиеданных хранилищезначения цвет чтениеfastinfoset чтениеhtml чтениеjson чтениеxml чтениеzipфайла чтениеданных чтениетекста чтениеузловdom шрифт элементрезультатакомпоновкиданных " + "comsafearray деревозначений массив соответствие списокзначений структура таблицазначений фиксированнаяструктура фиксированноесоответствие фиксированныймассив ", Ee = "null истина ложь неопределено", oe = t.inherit(t.NUMBER_MODE), ae = {
      className: "string",
      begin: '"|\\|',
      end: '"|$',
      contains: [{ begin: '""' }]
    }, pe = {
      begin: "'",
      end: "'",
      excludeBegin: !0,
      excludeEnd: !0,
      contains: [
        {
          className: "number",
          begin: "\\d{4}([\\.\\\\/:-]?\\d{2}){0,5}"
        }
      ]
    }, Se = t.inherit(t.C_LINE_COMMENT_MODE), Re = {
      className: "meta",
      begin: "#|&",
      end: "$",
      keywords: {
        $pattern: n,
        keyword: a + l
      },
      contains: [Se]
    }, Ye = {
      className: "symbol",
      begin: "~",
      end: ";|:",
      excludeEnd: !0
    }, nt = {
      className: "function",
      variants: [
        {
          begin: "процедура|функция",
          end: "\\)",
          keywords: "процедура функция"
        },
        {
          begin: "конецпроцедуры|конецфункции",
          keywords: "конецпроцедуры конецфункции"
        }
      ],
      contains: [
        {
          begin: "\\(",
          end: "\\)",
          endsParent: !0,
          contains: [
            {
              className: "params",
              begin: n,
              end: ",",
              excludeEnd: !0,
              endsWithParent: !0,
              keywords: {
                $pattern: n,
                keyword: "знач",
                literal: Ee
              },
              contains: [
                oe,
                ae,
                pe
              ]
            },
            Se
          ]
        },
        t.inherit(t.TITLE_MODE, { begin: n })
      ]
    };
    return {
      name: "1C:Enterprise",
      case_insensitive: !0,
      keywords: {
        $pattern: n,
        keyword: a,
        built_in: h,
        class: Z,
        type: ne,
        literal: Ee
      },
      contains: [
        Re,
        nt,
        Se,
        Ye,
        oe,
        ae,
        pe
      ]
    };
  }
  return _0 = e, _0;
}
var v0, AN;
function LX() {
  if (AN) return v0;
  AN = 1;
  function e(t) {
    const n = t.regex, r = /^[a-zA-Z][a-zA-Z0-9-]*/, i = [
      "ALPHA",
      "BIT",
      "CHAR",
      "CR",
      "CRLF",
      "CTL",
      "DIGIT",
      "DQUOTE",
      "HEXDIG",
      "HTAB",
      "LF",
      "LWSP",
      "OCTET",
      "SP",
      "VCHAR",
      "WSP"
    ], a = t.COMMENT(/;/, /$/), o = {
      scope: "symbol",
      match: /%b[0-1]+(-[0-1]+|(\.[0-1]+)+)?/
    }, s = {
      scope: "symbol",
      match: /%d[0-9]+(-[0-9]+|(\.[0-9]+)+)?/
    }, l = {
      scope: "symbol",
      match: /%x[0-9A-F]+(-[0-9A-F]+|(\.[0-9A-F]+)+)?/
    }, u = {
      scope: "symbol",
      match: /%[si](?=".*")/
    }, c = {
      scope: "attribute",
      match: n.concat(r, /(?=\s*=)/)
    };
    return {
      name: "Augmented Backus-Naur Form",
      illegal: /[!@#$^&',?+~`|:]/,
      keywords: i,
      contains: [
        {
          scope: "operator",
          match: /=\/?/
        },
        c,
        a,
        o,
        s,
        l,
        u,
        t.QUOTE_STRING_MODE,
        t.NUMBER_MODE
      ]
    };
  }
  return v0 = e, v0;
}
var b0, ON;
function kX() {
  if (ON) return b0;
  ON = 1;
  function e(t) {
    const n = t.regex, r = [
      "GET",
      "POST",
      "HEAD",
      "PUT",
      "DELETE",
      "CONNECT",
      "OPTIONS",
      "PATCH",
      "TRACE"
    ];
    return {
      name: "Apache Access Log",
      contains: [
        // IP
        {
          className: "number",
          begin: /^\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}(:\d{1,5})?\b/,
          relevance: 5
        },
        // Other numbers
        {
          className: "number",
          begin: /\b\d+\b/,
          relevance: 0
        },
        // Requests
        {
          className: "string",
          begin: n.concat(/"/, n.either(...r)),
          end: /"/,
          keywords: r,
          illegal: /\n/,
          relevance: 5,
          contains: [
            {
              begin: /HTTP\/[12]\.\d'/,
              relevance: 5
            }
          ]
        },
        // Dates
        {
          className: "string",
          // dates must have a certain length, this prevents matching
          // simple array accesses a[123] and [] and other common patterns
          // found in other languages
          begin: /\[\d[^\]\n]{8,}\]/,
          illegal: /\n/,
          relevance: 1
        },
        {
          className: "string",
          begin: /\[/,
          end: /\]/,
          illegal: /\n/,
          relevance: 0
        },
        // User agent / relevance boost
        {
          className: "string",
          begin: /"Mozilla\/\d\.\d \(/,
          end: /"/,
          illegal: /\n/,
          relevance: 3
        },
        // Strings
        {
          className: "string",
          begin: /"/,
          end: /"/,
          illegal: /\n/,
          relevance: 0
        }
      ]
    };
  }
  return b0 = e, b0;
}
var E0, RN;
function MX() {
  if (RN) return E0;
  RN = 1;
  function e(t) {
    const n = t.regex, r = /[a-zA-Z_$][a-zA-Z0-9_$]*/, i = n.concat(
      r,
      n.concat("(\\.", r, ")*")
    ), a = /([*]|[a-zA-Z_$][a-zA-Z0-9_$]*)/, o = {
      className: "rest_arg",
      begin: /[.]{3}/,
      end: r,
      relevance: 10
    };
    return {
      name: "ActionScript",
      aliases: ["as"],
      keywords: {
        keyword: [
          "as",
          "break",
          "case",
          "catch",
          "class",
          "const",
          "continue",
          "default",
          "delete",
          "do",
          "dynamic",
          "each",
          "else",
          "extends",
          "final",
          "finally",
          "for",
          "function",
          "get",
          "if",
          "implements",
          "import",
          "in",
          "include",
          "instanceof",
          "interface",
          "internal",
          "is",
          "namespace",
          "native",
          "new",
          "override",
          "package",
          "private",
          "protected",
          "public",
          "return",
          "set",
          "static",
          "super",
          "switch",
          "this",
          "throw",
          "try",
          "typeof",
          "use",
          "var",
          "void",
          "while",
          "with"
        ],
        literal: [
          "true",
          "false",
          "null",
          "undefined"
        ]
      },
      contains: [
        t.APOS_STRING_MODE,
        t.QUOTE_STRING_MODE,
        t.C_LINE_COMMENT_MODE,
        t.C_BLOCK_COMMENT_MODE,
        t.C_NUMBER_MODE,
        {
          match: [
            /\bpackage/,
            /\s+/,
            i
          ],
          className: {
            1: "keyword",
            3: "title.class"
          }
        },
        {
          match: [
            /\b(?:class|interface|extends|implements)/,
            /\s+/,
            r
          ],
          className: {
            1: "keyword",
            3: "title.class"
          }
        },
        {
          className: "meta",
          beginKeywords: "import include",
          end: /;/,
          keywords: { keyword: "import include" }
        },
        {
          beginKeywords: "function",
          end: /[{;]/,
          excludeEnd: !0,
          illegal: /\S/,
          contains: [
            t.inherit(t.TITLE_MODE, { className: "title.function" }),
            {
              className: "params",
              begin: /\(/,
              end: /\)/,
              contains: [
                t.APOS_STRING_MODE,
                t.QUOTE_STRING_MODE,
                t.C_LINE_COMMENT_MODE,
                t.C_BLOCK_COMMENT_MODE,
                o
              ]
            },
            { begin: n.concat(/:\s*/, a) }
          ]
        },
        t.METHOD_GUARD
      ],
      illegal: /#/
    };
  }
  return E0 = e, E0;
}
var S0, wN;
function PX() {
  if (wN) return S0;
  wN = 1;
  function e(t) {
    const n = "\\d(_|\\d)*", r = "[eE][-+]?" + n, i = n + "(\\." + n + ")?(" + r + ")?", a = "\\w+", s = "\\b(" + (n + "#" + a + "(\\." + a + ")?#(" + r + ")?") + "|" + i + ")", l = "[A-Za-z](_?[A-Za-z0-9.])*", u = `[]\\{\\}%#'"`, c = t.COMMENT("--", "$"), d = {
      // TODO: These spaces are not required by the Ada syntax
      // however, I have yet to see handwritten Ada code where
      // someone does not put spaces around :
      begin: "\\s+:\\s+",
      end: "\\s*(:=|;|\\)|=>|$)",
      // endsWithParent: true,
      // returnBegin: true,
      illegal: u,
      contains: [
        {
          // workaround to avoid highlighting
          // named loops and declare blocks
          beginKeywords: "loop for declare others",
          endsParent: !0
        },
        {
          // properly highlight all modifiers
          className: "keyword",
          beginKeywords: "not null constant access function procedure in out aliased exception"
        },
        {
          className: "type",
          begin: l,
          endsParent: !0,
          relevance: 0
        }
      ]
    };
    return {
      name: "Ada",
      case_insensitive: !0,
      keywords: {
        keyword: [
          "abort",
          "else",
          "new",
          "return",
          "abs",
          "elsif",
          "not",
          "reverse",
          "abstract",
          "end",
          "accept",
          "entry",
          "select",
          "access",
          "exception",
          "of",
          "separate",
          "aliased",
          "exit",
          "or",
          "some",
          "all",
          "others",
          "subtype",
          "and",
          "for",
          "out",
          "synchronized",
          "array",
          "function",
          "overriding",
          "at",
          "tagged",
          "generic",
          "package",
          "task",
          "begin",
          "goto",
          "pragma",
          "terminate",
          "body",
          "private",
          "then",
          "if",
          "procedure",
          "type",
          "case",
          "in",
          "protected",
          "constant",
          "interface",
          "is",
          "raise",
          "use",
          "declare",
          "range",
          "delay",
          "limited",
          "record",
          "when",
          "delta",
          "loop",
          "rem",
          "while",
          "digits",
          "renames",
          "with",
          "do",
          "mod",
          "requeue",
          "xor"
        ],
        literal: [
          "True",
          "False"
        ]
      },
      contains: [
        c,
        // strings "foobar"
        {
          className: "string",
          begin: /"/,
          end: /"/,
          contains: [
            {
              begin: /""/,
              relevance: 0
            }
          ]
        },
        // characters ''
        {
          // character literals always contain one char
          className: "string",
          begin: /'.'/
        },
        {
          // number literals
          className: "number",
          begin: s,
          relevance: 0
        },
        {
          // Attributes
          className: "symbol",
          begin: "'" + l
        },
        {
          // package definition, maybe inside generic
          className: "title",
          begin: "(\\bwith\\s+)?(\\bprivate\\s+)?\\bpackage\\s+(\\bbody\\s+)?",
          end: "(is|$)",
          keywords: "package body",
          excludeBegin: !0,
          excludeEnd: !0,
          illegal: u
        },
        {
          // function/procedure declaration/definition
          // maybe inside generic
          begin: "(\\b(with|overriding)\\s+)?\\b(function|procedure)\\s+",
          end: "(\\bis|\\bwith|\\brenames|\\)\\s*;)",
          keywords: "overriding function procedure with is renames return",
          // we need to re-match the 'function' keyword, so that
          // the title mode below matches only exactly once
          returnBegin: !0,
          contains: [
            c,
            {
              // name of the function/procedure
              className: "title",
              begin: "(\\bwith\\s+)?\\b(function|procedure)\\s+",
              end: "(\\(|\\s+|$)",
              excludeBegin: !0,
              excludeEnd: !0,
              illegal: u
            },
            // 'self'
            // // parameter types
            d,
            {
              // return type
              className: "type",
              begin: "\\breturn\\s+",
              end: "(\\s+|;|$)",
              keywords: "return",
              excludeBegin: !0,
              excludeEnd: !0,
              // we are done with functions
              endsParent: !0,
              illegal: u
            }
          ]
        },
        {
          // new type declarations
          // maybe inside generic
          className: "type",
          begin: "\\b(sub)?type\\s+",
          end: "\\s+",
          keywords: "type",
          excludeBegin: !0,
          illegal: u
        },
        // see comment above the definition
        d
        // no markup
        // relevance boosters for small snippets
        // {begin: '\\s*=>\\s*'},
        // {begin: '\\s*:=\\s*'},
        // {begin: '\\s+:=\\s+'},
      ]
    };
  }
  return S0 = e, S0;
}
var y0, xN;
function FX() {
  if (xN) return y0;
  xN = 1;
  function e(t) {
    const n = {
      className: "built_in",
      begin: "\\b(void|bool|int8|int16|int32|int64|int|uint8|uint16|uint32|uint64|uint|string|ref|array|double|float|auto|dictionary)"
    }, r = {
      className: "symbol",
      begin: "[a-zA-Z0-9_]+@"
    }, i = {
      className: "keyword",
      begin: "<",
      end: ">",
      contains: [
        n,
        r
      ]
    };
    return n.contains = [i], r.contains = [i], {
      name: "AngelScript",
      aliases: ["asc"],
      keywords: [
        "for",
        "in|0",
        "break",
        "continue",
        "while",
        "do|0",
        "return",
        "if",
        "else",
        "case",
        "switch",
        "namespace",
        "is",
        "cast",
        "or",
        "and",
        "xor",
        "not",
        "get|0",
        "in",
        "inout|10",
        "out",
        "override",
        "set|0",
        "private",
        "public",
        "const",
        "default|0",
        "final",
        "shared",
        "external",
        "mixin|10",
        "enum",
        "typedef",
        "funcdef",
        "this",
        "super",
        "import",
        "from",
        "interface",
        "abstract|0",
        "try",
        "catch",
        "protected",
        "explicit",
        "property"
      ],
      // avoid close detection with C# and JS
      illegal: "(^using\\s+[A-Za-z0-9_\\.]+;$|\\bfunction\\s*[^\\(])",
      contains: [
        {
          // 'strings'
          className: "string",
          begin: "'",
          end: "'",
          illegal: "\\n",
          contains: [t.BACKSLASH_ESCAPE],
          relevance: 0
        },
        // """heredoc strings"""
        {
          className: "string",
          begin: '"""',
          end: '"""'
        },
        {
          // "strings"
          className: "string",
          begin: '"',
          end: '"',
          illegal: "\\n",
          contains: [t.BACKSLASH_ESCAPE],
          relevance: 0
        },
        t.C_LINE_COMMENT_MODE,
        // single-line comments
        t.C_BLOCK_COMMENT_MODE,
        // comment blocks
        {
          // metadata
          className: "string",
          begin: "^\\s*\\[",
          end: "\\]"
        },
        {
          // interface or namespace declaration
          beginKeywords: "interface namespace",
          end: /\{/,
          illegal: "[;.\\-]",
          contains: [
            {
              // interface or namespace name
              className: "symbol",
              begin: "[a-zA-Z0-9_]+"
            }
          ]
        },
        {
          // class declaration
          beginKeywords: "class",
          end: /\{/,
          illegal: "[;.\\-]",
          contains: [
            {
              // class name
              className: "symbol",
              begin: "[a-zA-Z0-9_]+",
              contains: [
                {
                  begin: "[:,]\\s*",
                  contains: [
                    {
                      className: "symbol",
                      begin: "[a-zA-Z0-9_]+"
                    }
                  ]
                }
              ]
            }
          ]
        },
        n,
        // built-in types
        r,
        // object handles
        {
          // literals
          className: "literal",
          begin: "\\b(null|true|false)"
        },
        {
          // numbers
          className: "number",
          relevance: 0,
          begin: "(-?)(\\b0[xXbBoOdD][a-fA-F0-9]+|(\\b\\d+(\\.\\d*)?f?|\\.\\d+f?)([eE][-+]?\\d+f?)?)"
        }
      ]
    };
  }
  return y0 = e, y0;
}
var T0, NN;
function BX() {
  if (NN) return T0;
  NN = 1;
  function e(t) {
    const n = {
      className: "number",
      begin: /[$%]\d+/
    }, r = {
      className: "number",
      begin: /\b\d+/
    }, i = {
      className: "number",
      begin: /\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}(:\d{1,5})?/
    }, a = {
      className: "number",
      begin: /:\d{1,5}/
    };
    return {
      name: "Apache config",
      aliases: ["apacheconf"],
      case_insensitive: !0,
      contains: [
        t.HASH_COMMENT_MODE,
        {
          className: "section",
          begin: /<\/?/,
          end: />/,
          contains: [
            i,
            a,
            // low relevance prevents us from claming XML/HTML where this rule would
            // match strings inside of XML tags
            t.inherit(t.QUOTE_STRING_MODE, { relevance: 0 })
          ]
        },
        {
          className: "attribute",
          begin: /\w+/,
          relevance: 0,
          // keywords aren’t needed for highlighting per se, they only boost relevance
          // for a very generally defined mode (starts with a word, ends with line-end
          keywords: { _: [
            "order",
            "deny",
            "allow",
            "setenv",
            "rewriterule",
            "rewriteengine",
            "rewritecond",
            "documentroot",
            "sethandler",
            "errordocument",
            "loadmodule",
            "options",
            "header",
            "listen",
            "serverroot",
            "servername"
          ] },
          starts: {
            end: /$/,
            relevance: 0,
            keywords: { literal: "on off all deny allow" },
            contains: [
              {
                className: "meta",
                begin: /\s\[/,
                end: /\]$/
              },
              {
                className: "variable",
                begin: /[\$%]\{/,
                end: /\}/,
                contains: [
                  "self",
                  n
                ]
              },
              i,
              r,
              t.QUOTE_STRING_MODE
            ]
          }
        }
      ],
      illegal: /\S/
    };
  }
  return T0 = e, T0;
}
var C0, DN;
function $X() {
  if (DN) return C0;
  DN = 1;
  function e(t) {
    const n = t.regex, r = t.inherit(
      t.QUOTE_STRING_MODE,
      { illegal: null }
    ), i = {
      className: "params",
      begin: /\(/,
      end: /\)/,
      contains: [
        "self",
        t.C_NUMBER_MODE,
        r
      ]
    }, a = t.COMMENT(/--/, /$/), o = t.COMMENT(
      /\(\*/,
      /\*\)/,
      { contains: [
        "self",
        // allow nesting
        a
      ] }
    ), s = [
      a,
      o,
      t.HASH_COMMENT_MODE
    ], l = [
      /apart from/,
      /aside from/,
      /instead of/,
      /out of/,
      /greater than/,
      /isn't|(doesn't|does not) (equal|come before|come after|contain)/,
      /(greater|less) than( or equal)?/,
      /(starts?|ends|begins?) with/,
      /contained by/,
      /comes (before|after)/,
      /a (ref|reference)/,
      /POSIX (file|path)/,
      /(date|time) string/,
      /quoted form/
    ], u = [
      /clipboard info/,
      /the clipboard/,
      /info for/,
      /list (disks|folder)/,
      /mount volume/,
      /path to/,
      /(close|open for) access/,
      /(get|set) eof/,
      /current date/,
      /do shell script/,
      /get volume settings/,
      /random number/,
      /set volume/,
      /system attribute/,
      /system info/,
      /time to GMT/,
      /(load|run|store) script/,
      /scripting components/,
      /ASCII (character|number)/,
      /localized string/,
      /choose (application|color|file|file name|folder|from list|remote application|URL)/,
      /display (alert|dialog)/
    ];
    return {
      name: "AppleScript",
      aliases: ["osascript"],
      keywords: {
        keyword: "about above after against and around as at back before beginning behind below beneath beside between but by considering contain contains continue copy div does eighth else end equal equals error every exit fifth first for fourth from front get given global if ignoring in into is it its last local me middle mod my ninth not of on onto or over prop property put ref reference repeat returning script second set seventh since sixth some tell tenth that the|0 then third through thru timeout times to transaction try until where while whose with without",
        literal: "AppleScript false linefeed return pi quote result space tab true",
        built_in: "alias application boolean class constant date file integer list number real record string text activate beep count delay launch log offset read round run say summarize write character characters contents day frontmost id item length month name|0 paragraph paragraphs rest reverse running time version weekday word words year"
      },
      contains: [
        r,
        t.C_NUMBER_MODE,
        {
          className: "built_in",
          begin: n.concat(
            /\b/,
            n.either(...u),
            /\b/
          )
        },
        {
          className: "built_in",
          begin: /^\s*return\b/
        },
        {
          className: "literal",
          begin: /\b(text item delimiters|current application|missing value)\b/
        },
        {
          className: "keyword",
          begin: n.concat(
            /\b/,
            n.either(...l),
            /\b/
          )
        },
        {
          beginKeywords: "on",
          illegal: /[${=;\n]/,
          contains: [
            t.UNDERSCORE_TITLE_MODE,
            i
          ]
        },
        ...s
      ],
      illegal: /\/\/|->|=>|\[\[/
    };
  }
  return C0 = e, C0;
}
var A0, IN;
function UX() {
  if (IN) return A0;
  IN = 1;
  function e(t) {
    const n = "[A-Za-z_][0-9A-Za-z_]*", r = {
      keyword: [
        "if",
        "for",
        "while",
        "var",
        "new",
        "function",
        "do",
        "return",
        "void",
        "else",
        "break"
      ],
      literal: [
        "BackSlash",
        "DoubleQuote",
        "false",
        "ForwardSlash",
        "Infinity",
        "NaN",
        "NewLine",
        "null",
        "PI",
        "SingleQuote",
        "Tab",
        "TextFormatting",
        "true",
        "undefined"
      ],
      built_in: [
        "Abs",
        "Acos",
        "All",
        "Angle",
        "Any",
        "Area",
        "AreaGeodetic",
        "Array",
        "Asin",
        "Atan",
        "Atan2",
        "Attachments",
        "Average",
        "Back",
        "Bearing",
        "Boolean",
        "Buffer",
        "BufferGeodetic",
        "Ceil",
        "Centroid",
        "Clip",
        "Concatenate",
        "Console",
        "Constrain",
        "Contains",
        "ConvertDirection",
        "Cos",
        "Count",
        "Crosses",
        "Cut",
        "Date",
        "DateAdd",
        "DateDiff",
        "Day",
        "Decode",
        "DefaultValue",
        "Densify",
        "DensifyGeodetic",
        "Dictionary",
        "Difference",
        "Disjoint",
        "Distance",
        "DistanceGeodetic",
        "Distinct",
        "Domain",
        "DomainCode",
        "DomainName",
        "EnvelopeIntersects",
        "Equals",
        "Erase",
        "Exp",
        "Expects",
        "Extent",
        "Feature",
        "FeatureSet",
        "FeatureSetByAssociation",
        "FeatureSetById",
        "FeatureSetByName",
        "FeatureSetByPortalItem",
        "FeatureSetByRelationshipName",
        "Filter",
        "Find",
        "First",
        "Floor",
        "FromCharCode",
        "FromCodePoint",
        "FromJSON",
        "GdbVersion",
        "Generalize",
        "Geometry",
        "GetFeatureSet",
        "GetUser",
        "GroupBy",
        "Guid",
        "Hash",
        "HasKey",
        "Hour",
        "IIf",
        "Includes",
        "IndexOf",
        "Insert",
        "Intersection",
        "Intersects",
        "IsEmpty",
        "IsNan",
        "ISOMonth",
        "ISOWeek",
        "ISOWeekday",
        "ISOYear",
        "IsSelfIntersecting",
        "IsSimple",
        "Left|0",
        "Length",
        "Length3D",
        "LengthGeodetic",
        "Log",
        "Lower",
        "Map",
        "Max",
        "Mean",
        "Mid",
        "Millisecond",
        "Min",
        "Minute",
        "Month",
        "MultiPartToSinglePart",
        "Multipoint",
        "NextSequenceValue",
        "None",
        "Now",
        "Number",
        "Offset|0",
        "OrderBy",
        "Overlaps",
        "Point",
        "Polygon",
        "Polyline",
        "Pop",
        "Portal",
        "Pow",
        "Proper",
        "Push",
        "Random",
        "Reduce",
        "Relate",
        "Replace",
        "Resize",
        "Reverse",
        "Right|0",
        "RingIsClockwise",
        "Rotate",
        "Round",
        "Schema",
        "Second",
        "SetGeometry",
        "Simplify",
        "Sin",
        "Slice",
        "Sort",
        "Splice",
        "Split",
        "Sqrt",
        "Stdev",
        "SubtypeCode",
        "SubtypeName",
        "Subtypes",
        "Sum",
        "SymmetricDifference",
        "Tan",
        "Text",
        "Timestamp",
        "ToCharCode",
        "ToCodePoint",
        "Today",
        "ToHex",
        "ToLocal",
        "Top|0",
        "Touches",
        "ToUTC",
        "TrackAccelerationAt",
        "TrackAccelerationWindow",
        "TrackCurrentAcceleration",
        "TrackCurrentDistance",
        "TrackCurrentSpeed",
        "TrackCurrentTime",
        "TrackDistanceAt",
        "TrackDistanceWindow",
        "TrackDuration",
        "TrackFieldWindow",
        "TrackGeometryWindow",
        "TrackIndex",
        "TrackSpeedAt",
        "TrackSpeedWindow",
        "TrackStartTime",
        "TrackWindow",
        "Trim",
        "TypeOf",
        "Union",
        "Upper",
        "UrlEncode",
        "Variance",
        "Week",
        "Weekday",
        "When",
        "Within",
        "Year"
      ]
    }, i = {
      className: "symbol",
      begin: "\\$[datastore|feature|layer|map|measure|sourcefeature|sourcelayer|targetfeature|targetlayer|value|view]+"
    }, a = {
      className: "number",
      variants: [
        { begin: "\\b(0[bB][01]+)" },
        { begin: "\\b(0[oO][0-7]+)" },
        { begin: t.C_NUMBER_RE }
      ],
      relevance: 0
    }, o = {
      className: "subst",
      begin: "\\$\\{",
      end: "\\}",
      keywords: r,
      contains: []
      // defined later
    }, s = {
      className: "string",
      begin: "`",
      end: "`",
      contains: [
        t.BACKSLASH_ESCAPE,
        o
      ]
    };
    o.contains = [
      t.APOS_STRING_MODE,
      t.QUOTE_STRING_MODE,
      s,
      a,
      t.REGEXP_MODE
    ];
    const l = o.contains.concat([
      t.C_BLOCK_COMMENT_MODE,
      t.C_LINE_COMMENT_MODE
    ]);
    return {
      name: "ArcGIS Arcade",
      case_insensitive: !0,
      keywords: r,
      contains: [
        t.APOS_STRING_MODE,
        t.QUOTE_STRING_MODE,
        s,
        t.C_LINE_COMMENT_MODE,
        t.C_BLOCK_COMMENT_MODE,
        i,
        a,
        {
          // object attr container
          begin: /[{,]\s*/,
          relevance: 0,
          contains: [
            {
              begin: n + "\\s*:",
              returnBegin: !0,
              relevance: 0,
              contains: [
                {
                  className: "attr",
                  begin: n,
                  relevance: 0
                }
              ]
            }
          ]
        },
        {
          // "value" container
          begin: "(" + t.RE_STARTERS_RE + "|\\b(return)\\b)\\s*",
          keywords: "return",
          contains: [
            t.C_LINE_COMMENT_MODE,
            t.C_BLOCK_COMMENT_MODE,
            t.REGEXP_MODE,
            {
              className: "function",
              begin: "(\\(.*?\\)|" + n + ")\\s*=>",
              returnBegin: !0,
              end: "\\s*=>",
              contains: [
                {
                  className: "params",
                  variants: [
                    { begin: n },
                    { begin: /\(\s*\)/ },
                    {
                      begin: /\(/,
                      end: /\)/,
                      excludeBegin: !0,
                      excludeEnd: !0,
                      keywords: r,
                      contains: l
                    }
                  ]
                }
              ]
            }
          ],
          relevance: 0
        },
        {
          beginKeywords: "function",
          end: /\{/,
          excludeEnd: !0,
          contains: [
            t.inherit(t.TITLE_MODE, {
              className: "title.function",
              begin: n
            }),
            {
              className: "params",
              begin: /\(/,
              end: /\)/,
              excludeBegin: !0,
              excludeEnd: !0,
              contains: l
            }
          ],
          illegal: /\[|%/
        },
        { begin: /\$[(.]/ }
      ],
      illegal: /#(?!!)/
    };
  }
  return A0 = e, A0;
}
var O0, LN;
function qX() {
  if (LN) return O0;
  LN = 1;
  function e(n) {
    const r = n.regex, i = n.COMMENT("//", "$", { contains: [{ begin: /\\\n/ }] }), a = "decltype\\(auto\\)", o = "[a-zA-Z_]\\w*::", l = "(?!struct)(" + a + "|" + r.optional(o) + "[a-zA-Z_]\\w*" + r.optional("<[^<>]+>") + ")", u = {
      className: "type",
      begin: "\\b[a-z\\d_]*_t\\b"
    }, d = {
      className: "string",
      variants: [
        {
          begin: '(u8?|U|L)?"',
          end: '"',
          illegal: "\\n",
          contains: [n.BACKSLASH_ESCAPE]
        },
        {
          begin: "(u8?|U|L)?'(" + "\\\\(x[0-9A-Fa-f]{2}|u[0-9A-Fa-f]{4,8}|[0-7]{3}|\\S)" + "|.)",
          end: "'",
          illegal: "."
        },
        n.END_SAME_AS_BEGIN({
          begin: /(?:u8?|U|L)?R"([^()\\ ]{0,16})\(/,
          end: /\)([^()\\ ]{0,16})"/
        })
      ]
    }, f = {
      className: "number",
      variants: [
        { begin: "\\b(0b[01']+)" },
        { begin: "(-?)\\b([\\d']+(\\.[\\d']*)?|\\.[\\d']+)((ll|LL|l|L)(u|U)?|(u|U)(ll|LL|l|L)?|f|F|b|B)" },
        { begin: "(-?)(\\b0[xX][a-fA-F0-9']+|(\\b[\\d']+(\\.[\\d']*)?|\\.[\\d']+)([eE][-+]?[\\d']+)?)" }
      ],
      relevance: 0
    }, h = {
      className: "meta",
      begin: /#\s*[a-z]+\b/,
      end: /$/,
      keywords: { keyword: "if else elif endif define undef warning error line pragma _Pragma ifdef ifndef include" },
      contains: [
        {
          begin: /\\\n/,
          relevance: 0
        },
        n.inherit(d, { className: "string" }),
        {
          className: "string",
          begin: /<.*?>/
        },
        i,
        n.C_BLOCK_COMMENT_MODE
      ]
    }, m = {
      className: "title",
      begin: r.optional(o) + n.IDENT_RE,
      relevance: 0
    }, v = r.optional(o) + n.IDENT_RE + "\\s*\\(", b = [
      "alignas",
      "alignof",
      "and",
      "and_eq",
      "asm",
      "atomic_cancel",
      "atomic_commit",
      "atomic_noexcept",
      "auto",
      "bitand",
      "bitor",
      "break",
      "case",
      "catch",
      "class",
      "co_await",
      "co_return",
      "co_yield",
      "compl",
      "concept",
      "const_cast|10",
      "consteval",
      "constexpr",
      "constinit",
      "continue",
      "decltype",
      "default",
      "delete",
      "do",
      "dynamic_cast|10",
      "else",
      "enum",
      "explicit",
      "export",
      "extern",
      "false",
      "final",
      "for",
      "friend",
      "goto",
      "if",
      "import",
      "inline",
      "module",
      "mutable",
      "namespace",
      "new",
      "noexcept",
      "not",
      "not_eq",
      "nullptr",
      "operator",
      "or",
      "or_eq",
      "override",
      "private",
      "protected",
      "public",
      "reflexpr",
      "register",
      "reinterpret_cast|10",
      "requires",
      "return",
      "sizeof",
      "static_assert",
      "static_cast|10",
      "struct",
      "switch",
      "synchronized",
      "template",
      "this",
      "thread_local",
      "throw",
      "transaction_safe",
      "transaction_safe_dynamic",
      "true",
      "try",
      "typedef",
      "typeid",
      "typename",
      "union",
      "using",
      "virtual",
      "volatile",
      "while",
      "xor",
      "xor_eq"
    ], y = [
      "bool",
      "char",
      "char16_t",
      "char32_t",
      "char8_t",
      "double",
      "float",
      "int",
      "long",
      "short",
      "void",
      "wchar_t",
      "unsigned",
      "signed",
      "const",
      "static"
    ], g = [
      "any",
      "auto_ptr",
      "barrier",
      "binary_semaphore",
      "bitset",
      "complex",
      "condition_variable",
      "condition_variable_any",
      "counting_semaphore",
      "deque",
      "false_type",
      "future",
      "imaginary",
      "initializer_list",
      "istringstream",
      "jthread",
      "latch",
      "lock_guard",
      "multimap",
      "multiset",
      "mutex",
      "optional",
      "ostringstream",
      "packaged_task",
      "pair",
      "promise",
      "priority_queue",
      "queue",
      "recursive_mutex",
      "recursive_timed_mutex",
      "scoped_lock",
      "set",
      "shared_future",
      "shared_lock",
      "shared_mutex",
      "shared_timed_mutex",
      "shared_ptr",
      "stack",
      "string_view",
      "stringstream",
      "timed_mutex",
      "thread",
      "true_type",
      "tuple",
      "unique_lock",
      "unique_ptr",
      "unordered_map",
      "unordered_multimap",
      "unordered_multiset",
      "unordered_set",
      "variant",
      "vector",
      "weak_ptr",
      "wstring",
      "wstring_view"
    ], E = [
      "abort",
      "abs",
      "acos",
      "apply",
      "as_const",
      "asin",
      "atan",
      "atan2",
      "calloc",
      "ceil",
      "cerr",
      "cin",
      "clog",
      "cos",
      "cosh",
      "cout",
      "declval",
      "endl",
      "exchange",
      "exit",
      "exp",
      "fabs",
      "floor",
      "fmod",
      "forward",
      "fprintf",
      "fputs",
      "free",
      "frexp",
      "fscanf",
      "future",
      "invoke",
      "isalnum",
      "isalpha",
      "iscntrl",
      "isdigit",
      "isgraph",
      "islower",
      "isprint",
      "ispunct",
      "isspace",
      "isupper",
      "isxdigit",
      "labs",
      "launder",
      "ldexp",
      "log",
      "log10",
      "make_pair",
      "make_shared",
      "make_shared_for_overwrite",
      "make_tuple",
      "make_unique",
      "malloc",
      "memchr",
      "memcmp",
      "memcpy",
      "memset",
      "modf",
      "move",
      "pow",
      "printf",
      "putchar",
      "puts",
      "realloc",
      "scanf",
      "sin",
      "sinh",
      "snprintf",
      "sprintf",
      "sqrt",
      "sscanf",
      "std",
      "stderr",
      "stdin",
      "stdout",
      "strcat",
      "strchr",
      "strcmp",
      "strcpy",
      "strcspn",
      "strlen",
      "strncat",
      "strncmp",
      "strncpy",
      "strpbrk",
      "strrchr",
      "strspn",
      "strstr",
      "swap",
      "tan",
      "tanh",
      "terminate",
      "to_underlying",
      "tolower",
      "toupper",
      "vfprintf",
      "visit",
      "vprintf",
      "vsprintf"
    ], T = {
      type: y,
      keyword: b,
      literal: [
        "NULL",
        "false",
        "nullopt",
        "nullptr",
        "true"
      ],
      built_in: ["_Pragma"],
      _type_hints: g
    }, O = {
      className: "function.dispatch",
      relevance: 0,
      keywords: {
        // Only for relevance, not highlighting.
        _hint: E
      },
      begin: r.concat(
        /\b/,
        /(?!decltype)/,
        /(?!if)/,
        /(?!for)/,
        /(?!switch)/,
        /(?!while)/,
        n.IDENT_RE,
        r.lookahead(/(<[^<>]+>|)\s*\(/)
      )
    }, R = [
      O,
      h,
      u,
      i,
      n.C_BLOCK_COMMENT_MODE,
      f,
      d
    ], D = {
      // This mode covers expression context where we can't expect a function
      // definition and shouldn't highlight anything that looks like one:
      // `return some()`, `else if()`, `(x*sum(1, 2))`
      variants: [
        {
          begin: /=/,
          end: /;/
        },
        {
          begin: /\(/,
          end: /\)/
        },
        {
          beginKeywords: "new throw return else",
          end: /;/
        }
      ],
      keywords: T,
      contains: R.concat([
        {
          begin: /\(/,
          end: /\)/,
          keywords: T,
          contains: R.concat(["self"]),
          relevance: 0
        }
      ]),
      relevance: 0
    }, q = {
      className: "function",
      begin: "(" + l + "[\\*&\\s]+)+" + v,
      returnBegin: !0,
      end: /[{;=]/,
      excludeEnd: !0,
      keywords: T,
      illegal: /[^\w\s\*&:<>.]/,
      contains: [
        {
          // to prevent it from being confused as the function title
          begin: a,
          keywords: T,
          relevance: 0
        },
        {
          begin: v,
          returnBegin: !0,
          contains: [m],
          relevance: 0
        },
        // needed because we do not have look-behind on the below rule
        // to prevent it from grabbing the final : in a :: pair
        {
          begin: /::/,
          relevance: 0
        },
        // initializers
        {
          begin: /:/,
          endsWithParent: !0,
          contains: [
            d,
            f
          ]
        },
        // allow for multiple declarations, e.g.:
        // extern void f(int), g(char);
        {
          relevance: 0,
          match: /,/
        },
        {
          className: "params",
          begin: /\(/,
          end: /\)/,
          keywords: T,
          relevance: 0,
          contains: [
            i,
            n.C_BLOCK_COMMENT_MODE,
            d,
            f,
            u,
            // Count matching parentheses.
            {
              begin: /\(/,
              end: /\)/,
              keywords: T,
              relevance: 0,
              contains: [
                "self",
                i,
                n.C_BLOCK_COMMENT_MODE,
                d,
                f,
                u
              ]
            }
          ]
        },
        u,
        i,
        n.C_BLOCK_COMMENT_MODE,
        h
      ]
    };
    return {
      name: "C++",
      aliases: [
        "cc",
        "c++",
        "h++",
        "hpp",
        "hh",
        "hxx",
        "cxx"
      ],
      keywords: T,
      illegal: "</",
      classNameAliases: { "function.dispatch": "built_in" },
      contains: [].concat(
        D,
        q,
        O,
        R,
        [
          h,
          {
            // containers: ie, `vector <int> rooms (9);`
            begin: "\\b(deque|list|queue|priority_queue|pair|stack|vector|map|set|bitset|multiset|multimap|unordered_map|unordered_set|unordered_multiset|unordered_multimap|array|tuple|optional|variant|function)\\s*<(?!<)",
            end: ">",
            keywords: T,
            contains: [
              "self",
              u
            ]
          },
          {
            begin: n.IDENT_RE + "::",
            keywords: T
          },
          {
            match: [
              // extra complexity to deal with `enum class` and `enum struct`
              /\b(?:enum(?:\s+(?:class|struct))?|class|struct|union)/,
              /\s+/,
              /\w+/
            ],
            className: {
              1: "keyword",
              3: "title.class"
            }
          }
        ]
      )
    };
  }
  function t(n) {
    const r = {
      type: [
        "boolean",
        "byte",
        "word",
        "String"
      ],
      built_in: [
        "KeyboardController",
        "MouseController",
        "SoftwareSerial",
        "EthernetServer",
        "EthernetClient",
        "LiquidCrystal",
        "RobotControl",
        "GSMVoiceCall",
        "EthernetUDP",
        "EsploraTFT",
        "HttpClient",
        "RobotMotor",
        "WiFiClient",
        "GSMScanner",
        "FileSystem",
        "Scheduler",
        "GSMServer",
        "YunClient",
        "YunServer",
        "IPAddress",
        "GSMClient",
        "GSMModem",
        "Keyboard",
        "Ethernet",
        "Console",
        "GSMBand",
        "Esplora",
        "Stepper",
        "Process",
        "WiFiUDP",
        "GSM_SMS",
        "Mailbox",
        "USBHost",
        "Firmata",
        "PImage",
        "Client",
        "Server",
        "GSMPIN",
        "FileIO",
        "Bridge",
        "Serial",
        "EEPROM",
        "Stream",
        "Mouse",
        "Audio",
        "Servo",
        "File",
        "Task",
        "GPRS",
        "WiFi",
        "Wire",
        "TFT",
        "GSM",
        "SPI",
        "SD"
      ],
      _hints: [
        "setup",
        "loop",
        "runShellCommandAsynchronously",
        "analogWriteResolution",
        "retrieveCallingNumber",
        "printFirmwareVersion",
        "analogReadResolution",
        "sendDigitalPortPair",
        "noListenOnLocalhost",
        "readJoystickButton",
        "setFirmwareVersion",
        "readJoystickSwitch",
        "scrollDisplayRight",
        "getVoiceCallStatus",
        "scrollDisplayLeft",
        "writeMicroseconds",
        "delayMicroseconds",
        "beginTransmission",
        "getSignalStrength",
        "runAsynchronously",
        "getAsynchronously",
        "listenOnLocalhost",
        "getCurrentCarrier",
        "readAccelerometer",
        "messageAvailable",
        "sendDigitalPorts",
        "lineFollowConfig",
        "countryNameWrite",
        "runShellCommand",
        "readStringUntil",
        "rewindDirectory",
        "readTemperature",
        "setClockDivider",
        "readLightSensor",
        "endTransmission",
        "analogReference",
        "detachInterrupt",
        "countryNameRead",
        "attachInterrupt",
        "encryptionType",
        "readBytesUntil",
        "robotNameWrite",
        "readMicrophone",
        "robotNameRead",
        "cityNameWrite",
        "userNameWrite",
        "readJoystickY",
        "readJoystickX",
        "mouseReleased",
        "openNextFile",
        "scanNetworks",
        "noInterrupts",
        "digitalWrite",
        "beginSpeaker",
        "mousePressed",
        "isActionDone",
        "mouseDragged",
        "displayLogos",
        "noAutoscroll",
        "addParameter",
        "remoteNumber",
        "getModifiers",
        "keyboardRead",
        "userNameRead",
        "waitContinue",
        "processInput",
        "parseCommand",
        "printVersion",
        "readNetworks",
        "writeMessage",
        "blinkVersion",
        "cityNameRead",
        "readMessage",
        "setDataMode",
        "parsePacket",
        "isListening",
        "setBitOrder",
        "beginPacket",
        "isDirectory",
        "motorsWrite",
        "drawCompass",
        "digitalRead",
        "clearScreen",
        "serialEvent",
        "rightToLeft",
        "setTextSize",
        "leftToRight",
        "requestFrom",
        "keyReleased",
        "compassRead",
        "analogWrite",
        "interrupts",
        "WiFiServer",
        "disconnect",
        "playMelody",
        "parseFloat",
        "autoscroll",
        "getPINUsed",
        "setPINUsed",
        "setTimeout",
        "sendAnalog",
        "readSlider",
        "analogRead",
        "beginWrite",
        "createChar",
        "motorsStop",
        "keyPressed",
        "tempoWrite",
        "readButton",
        "subnetMask",
        "debugPrint",
        "macAddress",
        "writeGreen",
        "randomSeed",
        "attachGPRS",
        "readString",
        "sendString",
        "remotePort",
        "releaseAll",
        "mouseMoved",
        "background",
        "getXChange",
        "getYChange",
        "answerCall",
        "getResult",
        "voiceCall",
        "endPacket",
        "constrain",
        "getSocket",
        "writeJSON",
        "getButton",
        "available",
        "connected",
        "findUntil",
        "readBytes",
        "exitValue",
        "readGreen",
        "writeBlue",
        "startLoop",
        "IPAddress",
        "isPressed",
        "sendSysex",
        "pauseMode",
        "gatewayIP",
        "setCursor",
        "getOemKey",
        "tuneWrite",
        "noDisplay",
        "loadImage",
        "switchPIN",
        "onRequest",
        "onReceive",
        "changePIN",
        "playFile",
        "noBuffer",
        "parseInt",
        "overflow",
        "checkPIN",
        "knobRead",
        "beginTFT",
        "bitClear",
        "updateIR",
        "bitWrite",
        "position",
        "writeRGB",
        "highByte",
        "writeRed",
        "setSpeed",
        "readBlue",
        "noStroke",
        "remoteIP",
        "transfer",
        "shutdown",
        "hangCall",
        "beginSMS",
        "endWrite",
        "attached",
        "maintain",
        "noCursor",
        "checkReg",
        "checkPUK",
        "shiftOut",
        "isValid",
        "shiftIn",
        "pulseIn",
        "connect",
        "println",
        "localIP",
        "pinMode",
        "getIMEI",
        "display",
        "noBlink",
        "process",
        "getBand",
        "running",
        "beginSD",
        "drawBMP",
        "lowByte",
        "setBand",
        "release",
        "bitRead",
        "prepare",
        "pointTo",
        "readRed",
        "setMode",
        "noFill",
        "remove",
        "listen",
        "stroke",
        "detach",
        "attach",
        "noTone",
        "exists",
        "buffer",
        "height",
        "bitSet",
        "circle",
        "config",
        "cursor",
        "random",
        "IRread",
        "setDNS",
        "endSMS",
        "getKey",
        "micros",
        "millis",
        "begin",
        "print",
        "write",
        "ready",
        "flush",
        "width",
        "isPIN",
        "blink",
        "clear",
        "press",
        "mkdir",
        "rmdir",
        "close",
        "point",
        "yield",
        "image",
        "BSSID",
        "click",
        "delay",
        "read",
        "text",
        "move",
        "peek",
        "beep",
        "rect",
        "line",
        "open",
        "seek",
        "fill",
        "size",
        "turn",
        "stop",
        "home",
        "find",
        "step",
        "tone",
        "sqrt",
        "RSSI",
        "SSID",
        "end",
        "bit",
        "tan",
        "cos",
        "sin",
        "pow",
        "map",
        "abs",
        "max",
        "min",
        "get",
        "run",
        "put"
      ],
      literal: [
        "DIGITAL_MESSAGE",
        "FIRMATA_STRING",
        "ANALOG_MESSAGE",
        "REPORT_DIGITAL",
        "REPORT_ANALOG",
        "INPUT_PULLUP",
        "SET_PIN_MODE",
        "INTERNAL2V56",
        "SYSTEM_RESET",
        "LED_BUILTIN",
        "INTERNAL1V1",
        "SYSEX_START",
        "INTERNAL",
        "EXTERNAL",
        "DEFAULT",
        "OUTPUT",
        "INPUT",
        "HIGH",
        "LOW"
      ]
    }, i = e(n), a = (
      /** @type {Record<string,any>} */
      i.keywords
    );
    return a.type = [
      ...a.type,
      ...r.type
    ], a.literal = [
      ...a.literal,
      ...r.literal
    ], a.built_in = [
      ...a.built_in,
      ...r.built_in
    ], a._hints = r._hints, i.name = "Arduino", i.aliases = ["ino"], i.supersetOf = "cpp", i;
  }
  return O0 = t, O0;
}
var R0, kN;
function GX() {
  if (kN) return R0;
  kN = 1;
  function e(t) {
    const n = { variants: [
      t.COMMENT("^[ \\t]*(?=#)", "$", {
        relevance: 0,
        excludeBegin: !0
      }),
      t.COMMENT("[;@]", "$", { relevance: 0 }),
      t.C_LINE_COMMENT_MODE,
      t.C_BLOCK_COMMENT_MODE
    ] };
    return {
      name: "ARM Assembly",
      case_insensitive: !0,
      aliases: ["arm"],
      keywords: {
        $pattern: "\\.?" + t.IDENT_RE,
        meta: (
          // GNU preprocs
          ".2byte .4byte .align .ascii .asciz .balign .byte .code .data .else .end .endif .endm .endr .equ .err .exitm .extern .global .hword .if .ifdef .ifndef .include .irp .long .macro .rept .req .section .set .skip .space .text .word .arm .thumb .code16 .code32 .force_thumb .thumb_func .ltorg ALIAS ALIGN ARM AREA ASSERT ATTR CN CODE CODE16 CODE32 COMMON CP DATA DCB DCD DCDU DCDO DCFD DCFDU DCI DCQ DCQU DCW DCWU DN ELIF ELSE END ENDFUNC ENDIF ENDP ENTRY EQU EXPORT EXPORTAS EXTERN FIELD FILL FUNCTION GBLA GBLL GBLS GET GLOBAL IF IMPORT INCBIN INCLUDE INFO KEEP LCLA LCLL LCLS LTORG MACRO MAP MEND MEXIT NOFP OPT PRESERVE8 PROC QN READONLY RELOC REQUIRE REQUIRE8 RLIST FN ROUT SETA SETL SETS SN SPACE SUBT THUMB THUMBX TTL WHILE WEND "
        ),
        built_in: "r0 r1 r2 r3 r4 r5 r6 r7 r8 r9 r10 r11 r12 r13 r14 r15 w0 w1 w2 w3 w4 w5 w6 w7 w8 w9 w10 w11 w12 w13 w14 w15 w16 w17 w18 w19 w20 w21 w22 w23 w24 w25 w26 w27 w28 w29 w30 x0 x1 x2 x3 x4 x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17 x18 x19 x20 x21 x22 x23 x24 x25 x26 x27 x28 x29 x30 pc lr sp ip sl sb fp a1 a2 a3 a4 v1 v2 v3 v4 v5 v6 v7 v8 f0 f1 f2 f3 f4 f5 f6 f7 p0 p1 p2 p3 p4 p5 p6 p7 p8 p9 p10 p11 p12 p13 p14 p15 c0 c1 c2 c3 c4 c5 c6 c7 c8 c9 c10 c11 c12 c13 c14 c15 q0 q1 q2 q3 q4 q5 q6 q7 q8 q9 q10 q11 q12 q13 q14 q15 cpsr_c cpsr_x cpsr_s cpsr_f cpsr_cx cpsr_cxs cpsr_xs cpsr_xsf cpsr_sf cpsr_cxsf spsr_c spsr_x spsr_s spsr_f spsr_cx spsr_cxs spsr_xs spsr_xsf spsr_sf spsr_cxsf s0 s1 s2 s3 s4 s5 s6 s7 s8 s9 s10 s11 s12 s13 s14 s15 s16 s17 s18 s19 s20 s21 s22 s23 s24 s25 s26 s27 s28 s29 s30 s31 d0 d1 d2 d3 d4 d5 d6 d7 d8 d9 d10 d11 d12 d13 d14 d15 d16 d17 d18 d19 d20 d21 d22 d23 d24 d25 d26 d27 d28 d29 d30 d31 {PC} {VAR} {TRUE} {FALSE} {OPT} {CONFIG} {ENDIAN} {CODESIZE} {CPU} {FPU} {ARCHITECTURE} {PCSTOREOFFSET} {ARMASM_VERSION} {INTER} {ROPI} {RWPI} {SWST} {NOSWST} . @"
      },
      contains: [
        {
          className: "keyword",
          begin: "\\b(adc|(qd?|sh?|u[qh]?)?add(8|16)?|usada?8|(q|sh?|u[qh]?)?(as|sa)x|and|adrl?|sbc|rs[bc]|asr|b[lx]?|blx|bxj|cbn?z|tb[bh]|bic|bfc|bfi|[su]bfx|bkpt|cdp2?|clz|clrex|cmp|cmn|cpsi[ed]|cps|setend|dbg|dmb|dsb|eor|isb|it[te]{0,3}|lsl|lsr|ror|rrx|ldm(([id][ab])|f[ds])?|ldr((s|ex)?[bhd])?|movt?|mvn|mra|mar|mul|[us]mull|smul[bwt][bt]|smu[as]d|smmul|smmla|mla|umlaal|smlal?([wbt][bt]|d)|mls|smlsl?[ds]|smc|svc|sev|mia([bt]{2}|ph)?|mrr?c2?|mcrr2?|mrs|msr|orr|orn|pkh(tb|bt)|rbit|rev(16|sh)?|sel|[su]sat(16)?|nop|pop|push|rfe([id][ab])?|stm([id][ab])?|str(ex)?[bhd]?|(qd?)?sub|(sh?|q|u[qh]?)?sub(8|16)|[su]xt(a?h|a?b(16)?)|srs([id][ab])?|swpb?|swi|smi|tst|teq|wfe|wfi|yield)(eq|ne|cs|cc|mi|pl|vs|vc|hi|ls|ge|lt|gt|le|al|hs|lo)?[sptrx]?(?=\\s)"
          // followed by space
        },
        n,
        t.QUOTE_STRING_MODE,
        {
          className: "string",
          begin: "'",
          end: "[^\\\\]'",
          relevance: 0
        },
        {
          className: "title",
          begin: "\\|",
          end: "\\|",
          illegal: "\\n",
          relevance: 0
        },
        {
          className: "number",
          variants: [
            {
              // hex
              begin: "[#$=]?0x[0-9a-f]+"
            },
            {
              // bin
              begin: "[#$=]?0b[01]+"
            },
            {
              // literal
              begin: "[#$=]\\d+"
            },
            {
              // bare number
              begin: "\\b\\d+"
            }
          ],
          relevance: 0
        },
        {
          className: "symbol",
          variants: [
            {
              // GNU ARM syntax
              begin: "^[ \\t]*[a-z_\\.\\$][a-z0-9_\\.\\$]+:"
            },
            {
              // ARM syntax
              begin: "^[a-z_\\.\\$][a-z0-9_\\.\\$]+"
            },
            {
              // label reference
              begin: "[=#]\\w+"
            }
          ],
          relevance: 0
        }
      ]
    };
  }
  return R0 = e, R0;
}
var w0, MN;
function YX() {
  if (MN) return w0;
  MN = 1;
  function e(t) {
    const n = t.regex, r = n.concat(/[\p{L}_]/u, n.optional(/[\p{L}0-9_.-]*:/u), /[\p{L}0-9_.-]*/u), i = /[\p{L}0-9._:-]+/u, a = {
      className: "symbol",
      begin: /&[a-z]+;|&#[0-9]+;|&#x[a-f0-9]+;/
    }, o = {
      begin: /\s/,
      contains: [
        {
          className: "keyword",
          begin: /#?[a-z_][a-z1-9_-]+/,
          illegal: /\n/
        }
      ]
    }, s = t.inherit(o, {
      begin: /\(/,
      end: /\)/
    }), l = t.inherit(t.APOS_STRING_MODE, { className: "string" }), u = t.inherit(t.QUOTE_STRING_MODE, { className: "string" }), c = {
      endsWithParent: !0,
      illegal: /</,
      relevance: 0,
      contains: [
        {
          className: "attr",
          begin: i,
          relevance: 0
        },
        {
          begin: /=\s*/,
          relevance: 0,
          contains: [
            {
              className: "string",
              endsParent: !0,
              variants: [
                {
                  begin: /"/,
                  end: /"/,
                  contains: [a]
                },
                {
                  begin: /'/,
                  end: /'/,
                  contains: [a]
                },
                { begin: /[^\s"'=<>`]+/ }
              ]
            }
          ]
        }
      ]
    };
    return {
      name: "HTML, XML",
      aliases: [
        "html",
        "xhtml",
        "rss",
        "atom",
        "xjb",
        "xsd",
        "xsl",
        "plist",
        "wsf",
        "svg"
      ],
      case_insensitive: !0,
      unicodeRegex: !0,
      contains: [
        {
          className: "meta",
          begin: /<![a-z]/,
          end: />/,
          relevance: 10,
          contains: [
            o,
            u,
            l,
            s,
            {
              begin: /\[/,
              end: /\]/,
              contains: [
                {
                  className: "meta",
                  begin: /<![a-z]/,
                  end: />/,
                  contains: [
                    o,
                    s,
                    u,
                    l
                  ]
                }
              ]
            }
          ]
        },
        t.COMMENT(
          /<!--/,
          /-->/,
          { relevance: 10 }
        ),
        {
          begin: /<!\[CDATA\[/,
          end: /\]\]>/,
          relevance: 10
        },
        a,
        // xml processing instructions
        {
          className: "meta",
          end: /\?>/,
          variants: [
            {
              begin: /<\?xml/,
              relevance: 10,
              contains: [
                u
              ]
            },
            {
              begin: /<\?[a-z][a-z0-9]+/
            }
          ]
        },
        {
          className: "tag",
          /*
          The lookahead pattern (?=...) ensures that 'begin' only matches
          '<style' as a single word, followed by a whitespace or an
          ending bracket.
          */
          begin: /<style(?=\s|>)/,
          end: />/,
          keywords: { name: "style" },
          contains: [c],
          starts: {
            end: /<\/style>/,
            returnEnd: !0,
            subLanguage: [
              "css",
              "xml"
            ]
          }
        },
        {
          className: "tag",
          // See the comment in the <style tag about the lookahead pattern
          begin: /<script(?=\s|>)/,
          end: />/,
          keywords: { name: "script" },
          contains: [c],
          starts: {
            end: /<\/script>/,
            returnEnd: !0,
            subLanguage: [
              "javascript",
              "handlebars",
              "xml"
            ]
          }
        },
        // we need this for now for jSX
        {
          className: "tag",
          begin: /<>|<\/>/
        },
        // open tag
        {
          className: "tag",
          begin: n.concat(
            /</,
            n.lookahead(n.concat(
              r,
              // <tag/>
              // <tag>
              // <tag ...
              n.either(/\/>/, />/, /\s/)
            ))
          ),
          end: /\/?>/,
          contains: [
            {
              className: "name",
              begin: r,
              relevance: 0,
              starts: c
            }
          ]
        },
        // close tag
        {
          className: "tag",
          begin: n.concat(
            /<\//,
            n.lookahead(n.concat(
              r,
              />/
            ))
          ),
          contains: [
            {
              className: "name",
              begin: r,
              relevance: 0
            },
            {
              begin: />/,
              relevance: 0,
              endsParent: !0
            }
          ]
        }
      ]
    };
  }
  return w0 = e, w0;
}
var x0, PN;
function HX() {
  if (PN) return x0;
  PN = 1;
  function e(t) {
    const n = t.regex, r = {
      begin: "^'{3,}[ \\t]*$",
      relevance: 10
    }, i = [
      // escaped constrained formatting marks (i.e., \* \_ or \`)
      { begin: /\\[*_`]/ },
      // escaped unconstrained formatting marks (i.e., \\** \\__ or \\``)
      // must ignore until the next formatting marks
      // this rule might not be 100% compliant with Asciidoctor 2.0 but we are entering undefined behavior territory...
      { begin: /\\\\\*{2}[^\n]*?\*{2}/ },
      { begin: /\\\\_{2}[^\n]*_{2}/ },
      { begin: /\\\\`{2}[^\n]*`{2}/ },
      // guard: constrained formatting mark may not be preceded by ":", ";" or
      // "}". match these so the constrained rule doesn't see them
      { begin: /[:;}][*_`](?![*_`])/ }
    ], a = [
      // inline unconstrained strong (single line)
      {
        className: "strong",
        begin: /\*{2}([^\n]+?)\*{2}/
      },
      // inline unconstrained strong (multi-line)
      {
        className: "strong",
        begin: n.concat(
          /\*\*/,
          /((\*(?!\*)|\\[^\n]|[^*\n\\])+\n)+/,
          /(\*(?!\*)|\\[^\n]|[^*\n\\])*/,
          /\*\*/
        ),
        relevance: 0
      },
      // inline constrained strong (single line)
      {
        className: "strong",
        // must not precede or follow a word character
        begin: /\B\*(\S|\S[^\n]*?\S)\*(?!\w)/
      },
      // inline constrained strong (multi-line)
      {
        className: "strong",
        // must not precede or follow a word character
        begin: /\*[^\s]([^\n]+\n)+([^\n]+)\*/
      }
    ], o = [
      // inline unconstrained emphasis (single line)
      {
        className: "emphasis",
        begin: /_{2}([^\n]+?)_{2}/
      },
      // inline unconstrained emphasis (multi-line)
      {
        className: "emphasis",
        begin: n.concat(
          /__/,
          /((_(?!_)|\\[^\n]|[^_\n\\])+\n)+/,
          /(_(?!_)|\\[^\n]|[^_\n\\])*/,
          /__/
        ),
        relevance: 0
      },
      // inline constrained emphasis (single line)
      {
        className: "emphasis",
        // must not precede or follow a word character
        begin: /\b_(\S|\S[^\n]*?\S)_(?!\w)/
      },
      // inline constrained emphasis (multi-line)
      {
        className: "emphasis",
        // must not precede or follow a word character
        begin: /_[^\s]([^\n]+\n)+([^\n]+)_/
      },
      // inline constrained emphasis using single quote (legacy)
      {
        className: "emphasis",
        // must not follow a word character or be followed by a single quote or space
        begin: "\\B'(?!['\\s])",
        end: "(\\n{2}|')",
        // allow escaped single quote followed by word char
        contains: [
          {
            begin: "\\\\'\\w",
            relevance: 0
          }
        ],
        relevance: 0
      }
    ], s = {
      className: "symbol",
      begin: "^(NOTE|TIP|IMPORTANT|WARNING|CAUTION):\\s+",
      relevance: 10
    }, l = {
      className: "bullet",
      begin: "^(\\*+|-+|\\.+|[^\\n]+?::)\\s+"
    };
    return {
      name: "AsciiDoc",
      aliases: ["adoc"],
      contains: [
        // block comment
        t.COMMENT(
          "^/{4,}\\n",
          "\\n/{4,}$",
          // can also be done as...
          // '^/{4,}$',
          // '^/{4,}$',
          { relevance: 10 }
        ),
        // line comment
        t.COMMENT(
          "^//",
          "$",
          { relevance: 0 }
        ),
        // title
        {
          className: "title",
          begin: "^\\.\\w.*$"
        },
        // example, admonition & sidebar blocks
        {
          begin: "^[=\\*]{4,}\\n",
          end: "\\n^[=\\*]{4,}$",
          relevance: 10
        },
        // headings
        {
          className: "section",
          relevance: 10,
          variants: [
            { begin: "^(={1,6})[ 	].+?([ 	]\\1)?$" },
            { begin: "^[^\\[\\]\\n]+?\\n[=\\-~\\^\\+]{2,}$" }
          ]
        },
        // document attributes
        {
          className: "meta",
          begin: "^:.+?:",
          end: "\\s",
          excludeEnd: !0,
          relevance: 10
        },
        // block attributes
        {
          className: "meta",
          begin: "^\\[.+?\\]$",
          relevance: 0
        },
        // quoteblocks
        {
          className: "quote",
          begin: "^_{4,}\\n",
          end: "\\n_{4,}$",
          relevance: 10
        },
        // listing and literal blocks
        {
          className: "code",
          begin: "^[\\-\\.]{4,}\\n",
          end: "\\n[\\-\\.]{4,}$",
          relevance: 10
        },
        // passthrough blocks
        {
          begin: "^\\+{4,}\\n",
          end: "\\n\\+{4,}$",
          contains: [
            {
              begin: "<",
              end: ">",
              subLanguage: "xml",
              relevance: 0
            }
          ],
          relevance: 10
        },
        l,
        s,
        ...i,
        ...a,
        ...o,
        // inline smart quotes
        {
          className: "string",
          variants: [
            { begin: "``.+?''" },
            { begin: "`.+?'" }
          ]
        },
        // inline unconstrained emphasis
        {
          className: "code",
          begin: /`{2}/,
          end: /(\n{2}|`{2})/
        },
        // inline code snippets (TODO should get same treatment as strong and emphasis)
        {
          className: "code",
          begin: "(`.+?`|\\+.+?\\+)",
          relevance: 0
        },
        // indented literal block
        {
          className: "code",
          begin: "^[ \\t]",
          end: "$",
          relevance: 0
        },
        r,
        // images and links
        {
          begin: "(link:)?(http|https|ftp|file|irc|image:?):\\S+?\\[[^[]*?\\]",
          returnBegin: !0,
          contains: [
            {
              begin: "(link|image:?):",
              relevance: 0
            },
            {
              className: "link",
              begin: "\\w",
              end: "[^\\[]+",
              relevance: 0
            },
            {
              className: "string",
              begin: "\\[",
              end: "\\]",
              excludeBegin: !0,
              excludeEnd: !0,
              relevance: 0
            }
          ],
          relevance: 10
        }
      ]
    };
  }
  return x0 = e, x0;
}
var N0, FN;
function zX() {
  if (FN) return N0;
  FN = 1;
  function e(t) {
    const n = t.regex, r = [
      "false",
      "synchronized",
      "int",
      "abstract",
      "float",
      "private",
      "char",
      "boolean",
      "static",
      "null",
      "if",
      "const",
      "for",
      "true",
      "while",
      "long",
      "throw",
      "strictfp",
      "finally",
      "protected",
      "import",
      "native",
      "final",
      "return",
      "void",
      "enum",
      "else",
      "extends",
      "implements",
      "break",
      "transient",
      "new",
      "catch",
      "instanceof",
      "byte",
      "super",
      "volatile",
      "case",
      "assert",
      "short",
      "package",
      "default",
      "double",
      "public",
      "try",
      "this",
      "switch",
      "continue",
      "throws",
      "privileged",
      "aspectOf",
      "adviceexecution",
      "proceed",
      "cflowbelow",
      "cflow",
      "initialization",
      "preinitialization",
      "staticinitialization",
      "withincode",
      "target",
      "within",
      "execution",
      "getWithinTypeName",
      "handler",
      "thisJoinPoint",
      "thisJoinPointStaticPart",
      "thisEnclosingJoinPointStaticPart",
      "declare",
      "parents",
      "warning",
      "error",
      "soft",
      "precedence",
      "thisAspectInstance"
    ], i = [
      "get",
      "set",
      "args",
      "call"
    ];
    return {
      name: "AspectJ",
      keywords: r,
      illegal: /<\/|#/,
      contains: [
        t.COMMENT(
          /\/\*\*/,
          /\*\//,
          {
            relevance: 0,
            contains: [
              {
                // eat up @'s in emails to prevent them to be recognized as doctags
                begin: /\w+@/,
                relevance: 0
              },
              {
                className: "doctag",
                begin: /@[A-Za-z]+/
              }
            ]
          }
        ),
        t.C_LINE_COMMENT_MODE,
        t.C_BLOCK_COMMENT_MODE,
        t.APOS_STRING_MODE,
        t.QUOTE_STRING_MODE,
        {
          className: "class",
          beginKeywords: "aspect",
          end: /[{;=]/,
          excludeEnd: !0,
          illegal: /[:;"\[\]]/,
          contains: [
            { beginKeywords: "extends implements pertypewithin perthis pertarget percflowbelow percflow issingleton" },
            t.UNDERSCORE_TITLE_MODE,
            {
              begin: /\([^\)]*/,
              end: /[)]+/,
              keywords: r.concat(i),
              excludeEnd: !1
            }
          ]
        },
        {
          className: "class",
          beginKeywords: "class interface",
          end: /[{;=]/,
          excludeEnd: !0,
          relevance: 0,
          keywords: "class interface",
          illegal: /[:"\[\]]/,
          contains: [
            { beginKeywords: "extends implements" },
            t.UNDERSCORE_TITLE_MODE
          ]
        },
        {
          // AspectJ Constructs
          beginKeywords: "pointcut after before around throwing returning",
          end: /[)]/,
          excludeEnd: !1,
          illegal: /["\[\]]/,
          contains: [
            {
              begin: n.concat(t.UNDERSCORE_IDENT_RE, /\s*\(/),
              returnBegin: !0,
              contains: [t.UNDERSCORE_TITLE_MODE]
            }
          ]
        },
        {
          begin: /[:]/,
          returnBegin: !0,
          end: /[{;]/,
          relevance: 0,
          excludeEnd: !1,
          keywords: r,
          illegal: /["\[\]]/,
          contains: [
            {
              begin: n.concat(t.UNDERSCORE_IDENT_RE, /\s*\(/),
              keywords: r.concat(i),
              relevance: 0
            },
            t.QUOTE_STRING_MODE
          ]
        },
        {
          // this prevents 'new Name(...), or throw ...' from being recognized as a function definition
          beginKeywords: "new throw",
          relevance: 0
        },
        {
          // the function class is a bit different for AspectJ compared to the Java language
          className: "function",
          begin: /\w+ +\w+(\.\w+)?\s*\([^\)]*\)\s*((throws)[\w\s,]+)?[\{;]/,
          returnBegin: !0,
          end: /[{;=]/,
          keywords: r,
          excludeEnd: !0,
          contains: [
            {
              begin: n.concat(t.UNDERSCORE_IDENT_RE, /\s*\(/),
              returnBegin: !0,
              relevance: 0,
              contains: [t.UNDERSCORE_TITLE_MODE]
            },
            {
              className: "params",
              begin: /\(/,
              end: /\)/,
              relevance: 0,
              keywords: r,
              contains: [
                t.APOS_STRING_MODE,
                t.QUOTE_STRING_MODE,
                t.C_NUMBER_MODE,
                t.C_BLOCK_COMMENT_MODE
              ]
            },
            t.C_LINE_COMMENT_MODE,
            t.C_BLOCK_COMMENT_MODE
          ]
        },
        t.C_NUMBER_MODE,
        {
          // annotation is also used in this language
          className: "meta",
          begin: /@[A-Za-z]+/
        }
      ]
    };
  }
  return N0 = e, N0;
}
var D0, BN;
function VX() {
  if (BN) return D0;
  BN = 1;
  function e(t) {
    const n = { begin: "`[\\s\\S]" };
    return {
      name: "AutoHotkey",
      case_insensitive: !0,
      aliases: ["ahk"],
      keywords: {
        keyword: "Break Continue Critical Exit ExitApp Gosub Goto New OnExit Pause return SetBatchLines SetTimer Suspend Thread Throw Until ahk_id ahk_class ahk_pid ahk_exe ahk_group",
        literal: "true false NOT AND OR",
        built_in: "ComSpec Clipboard ClipboardAll ErrorLevel"
      },
      contains: [
        n,
        t.inherit(t.QUOTE_STRING_MODE, { contains: [n] }),
        t.COMMENT(";", "$", { relevance: 0 }),
        t.C_BLOCK_COMMENT_MODE,
        {
          className: "number",
          begin: t.NUMBER_RE,
          relevance: 0
        },
        {
          // subst would be the most accurate however fails the point of
          // highlighting. variable is comparably the most accurate that actually
          // has some effect
          className: "variable",
          begin: "%[a-zA-Z0-9#_$@]+%"
        },
        {
          className: "built_in",
          begin: "^\\s*\\w+\\s*(,|%)"
          // I don't really know if this is totally relevant
        },
        {
          // symbol would be most accurate however is highlighted just like
          // built_in and that makes up a lot of AutoHotkey code meaning that it
          // would fail to highlight anything
          className: "title",
          variants: [
            { begin: '^[^\\n";]+::(?!=)' },
            {
              begin: '^[^\\n";]+:(?!=)',
              // zero relevance as it catches a lot of things
              // followed by a single ':' in many languages
              relevance: 0
            }
          ]
        },
        {
          className: "meta",
          begin: "^\\s*#\\w+",
          end: "$",
          relevance: 0
        },
        {
          className: "built_in",
          begin: "A_[a-zA-Z0-9]+"
        },
        {
          // consecutive commas, not for highlighting but just for relevance
          begin: ",\\s*,"
        }
      ]
    };
  }
  return D0 = e, D0;
}
var I0, $N;
function WX() {
  if ($N) return I0;
  $N = 1;
  function e(t) {
    const n = "ByRef Case Const ContinueCase ContinueLoop Dim Do Else ElseIf EndFunc EndIf EndSelect EndSwitch EndWith Enum Exit ExitLoop For Func Global If In Local Next ReDim Return Select Static Step Switch Then To Until Volatile WEnd While With", r = [
      "EndRegion",
      "forcedef",
      "forceref",
      "ignorefunc",
      "include",
      "include-once",
      "NoTrayIcon",
      "OnAutoItStartRegister",
      "pragma",
      "Region",
      "RequireAdmin",
      "Tidy_Off",
      "Tidy_On",
      "Tidy_Parameters"
    ], i = "True False And Null Not Or Default", a = "Abs ACos AdlibRegister AdlibUnRegister Asc AscW ASin Assign ATan AutoItSetOption AutoItWinGetTitle AutoItWinSetTitle Beep Binary BinaryLen BinaryMid BinaryToString BitAND BitNOT BitOR BitRotate BitShift BitXOR BlockInput Break Call CDTray Ceiling Chr ChrW ClipGet ClipPut ConsoleRead ConsoleWrite ConsoleWriteError ControlClick ControlCommand ControlDisable ControlEnable ControlFocus ControlGetFocus ControlGetHandle ControlGetPos ControlGetText ControlHide ControlListView ControlMove ControlSend ControlSetText ControlShow ControlTreeView Cos Dec DirCopy DirCreate DirGetSize DirMove DirRemove DllCall DllCallAddress DllCallbackFree DllCallbackGetPtr DllCallbackRegister DllClose DllOpen DllStructCreate DllStructGetData DllStructGetPtr DllStructGetSize DllStructSetData DriveGetDrive DriveGetFileSystem DriveGetLabel DriveGetSerial DriveGetType DriveMapAdd DriveMapDel DriveMapGet DriveSetLabel DriveSpaceFree DriveSpaceTotal DriveStatus EnvGet EnvSet EnvUpdate Eval Execute Exp FileChangeDir FileClose FileCopy FileCreateNTFSLink FileCreateShortcut FileDelete FileExists FileFindFirstFile FileFindNextFile FileFlush FileGetAttrib FileGetEncoding FileGetLongName FileGetPos FileGetShortcut FileGetShortName FileGetSize FileGetTime FileGetVersion FileInstall FileMove FileOpen FileOpenDialog FileRead FileReadLine FileReadToArray FileRecycle FileRecycleEmpty FileSaveDialog FileSelectFolder FileSetAttrib FileSetEnd FileSetPos FileSetTime FileWrite FileWriteLine Floor FtpSetProxy FuncName GUICreate GUICtrlCreateAvi GUICtrlCreateButton GUICtrlCreateCheckbox GUICtrlCreateCombo GUICtrlCreateContextMenu GUICtrlCreateDate GUICtrlCreateDummy GUICtrlCreateEdit GUICtrlCreateGraphic GUICtrlCreateGroup GUICtrlCreateIcon GUICtrlCreateInput GUICtrlCreateLabel GUICtrlCreateList GUICtrlCreateListView GUICtrlCreateListViewItem GUICtrlCreateMenu GUICtrlCreateMenuItem GUICtrlCreateMonthCal GUICtrlCreateObj GUICtrlCreatePic GUICtrlCreateProgress GUICtrlCreateRadio GUICtrlCreateSlider GUICtrlCreateTab GUICtrlCreateTabItem GUICtrlCreateTreeView GUICtrlCreateTreeViewItem GUICtrlCreateUpdown GUICtrlDelete GUICtrlGetHandle GUICtrlGetState GUICtrlRead GUICtrlRecvMsg GUICtrlRegisterListViewSort GUICtrlSendMsg GUICtrlSendToDummy GUICtrlSetBkColor GUICtrlSetColor GUICtrlSetCursor GUICtrlSetData GUICtrlSetDefBkColor GUICtrlSetDefColor GUICtrlSetFont GUICtrlSetGraphic GUICtrlSetImage GUICtrlSetLimit GUICtrlSetOnEvent GUICtrlSetPos GUICtrlSetResizing GUICtrlSetState GUICtrlSetStyle GUICtrlSetTip GUIDelete GUIGetCursorInfo GUIGetMsg GUIGetStyle GUIRegisterMsg GUISetAccelerators GUISetBkColor GUISetCoord GUISetCursor GUISetFont GUISetHelp GUISetIcon GUISetOnEvent GUISetState GUISetStyle GUIStartGroup GUISwitch Hex HotKeySet HttpSetProxy HttpSetUserAgent HWnd InetClose InetGet InetGetInfo InetGetSize InetRead IniDelete IniRead IniReadSection IniReadSectionNames IniRenameSection IniWrite IniWriteSection InputBox Int IsAdmin IsArray IsBinary IsBool IsDeclared IsDllStruct IsFloat IsFunc IsHWnd IsInt IsKeyword IsNumber IsObj IsPtr IsString Log MemGetStats Mod MouseClick MouseClickDrag MouseDown MouseGetCursor MouseGetPos MouseMove MouseUp MouseWheel MsgBox Number ObjCreate ObjCreateInterface ObjEvent ObjGet ObjName OnAutoItExitRegister OnAutoItExitUnRegister Ping PixelChecksum PixelGetColor PixelSearch ProcessClose ProcessExists ProcessGetStats ProcessList ProcessSetPriority ProcessWait ProcessWaitClose ProgressOff ProgressOn ProgressSet Ptr Random RegDelete RegEnumKey RegEnumVal RegRead RegWrite Round Run RunAs RunAsWait RunWait Send SendKeepActive SetError SetExtended ShellExecute ShellExecuteWait Shutdown Sin Sleep SoundPlay SoundSetWaveVolume SplashImageOn SplashOff SplashTextOn Sqrt SRandom StatusbarGetText StderrRead StdinWrite StdioClose StdoutRead String StringAddCR StringCompare StringFormat StringFromASCIIArray StringInStr StringIsAlNum StringIsAlpha StringIsASCII StringIsDigit StringIsFloat StringIsInt StringIsLower StringIsSpace StringIsUpper StringIsXDigit StringLeft StringLen StringLower StringMid StringRegExp StringRegExpReplace StringReplace StringReverse StringRight StringSplit StringStripCR StringStripWS StringToASCIIArray StringToBinary StringTrimLeft StringTrimRight StringUpper Tan TCPAccept TCPCloseSocket TCPConnect TCPListen TCPNameToIP TCPRecv TCPSend TCPShutdown, UDPShutdown TCPStartup, UDPStartup TimerDiff TimerInit ToolTip TrayCreateItem TrayCreateMenu TrayGetMsg TrayItemDelete TrayItemGetHandle TrayItemGetState TrayItemGetText TrayItemSetOnEvent TrayItemSetState TrayItemSetText TraySetClick TraySetIcon TraySetOnEvent TraySetPauseIcon TraySetState TraySetToolTip TrayTip UBound UDPBind UDPCloseSocket UDPOpen UDPRecv UDPSend VarGetType WinActivate WinActive WinClose WinExists WinFlash WinGetCaretPos WinGetClassList WinGetClientSize WinGetHandle WinGetPos WinGetProcess WinGetState WinGetText WinGetTitle WinKill WinList WinMenuSelectItem WinMinimizeAll WinMinimizeAllUndo WinMove WinSetOnTop WinSetState WinSetTitle WinSetTrans WinWait WinWaitActive WinWaitClose WinWaitNotActive", o = { variants: [
      t.COMMENT(";", "$", { relevance: 0 }),
      t.COMMENT("#cs", "#ce"),
      t.COMMENT("#comments-start", "#comments-end")
    ] }, s = { begin: "\\$[A-z0-9_]+" }, l = {
      className: "string",
      variants: [
        {
          begin: /"/,
          end: /"/,
          contains: [
            {
              begin: /""/,
              relevance: 0
            }
          ]
        },
        {
          begin: /'/,
          end: /'/,
          contains: [
            {
              begin: /''/,
              relevance: 0
            }
          ]
        }
      ]
    }, u = { variants: [
      t.BINARY_NUMBER_MODE,
      t.C_NUMBER_MODE
    ] }, c = {
      className: "meta",
      begin: "#",
      end: "$",
      keywords: { keyword: r },
      contains: [
        {
          begin: /\\\n/,
          relevance: 0
        },
        {
          beginKeywords: "include",
          keywords: { keyword: "include" },
          end: "$",
          contains: [
            l,
            {
              className: "string",
              variants: [
                {
                  begin: "<",
                  end: ">"
                },
                {
                  begin: /"/,
                  end: /"/,
                  contains: [
                    {
                      begin: /""/,
                      relevance: 0
                    }
                  ]
                },
                {
                  begin: /'/,
                  end: /'/,
                  contains: [
                    {
                      begin: /''/,
                      relevance: 0
                    }
                  ]
                }
              ]
            }
          ]
        },
        l,
        o
      ]
    }, d = {
      className: "symbol",
      // begin: '@',
      // end: '$',
      // keywords: 'AppDataCommonDir AppDataDir AutoItExe AutoItPID AutoItVersion AutoItX64 COM_EventObj CommonFilesDir Compiled ComputerName ComSpec CPUArch CR CRLF DesktopCommonDir DesktopDepth DesktopDir DesktopHeight DesktopRefresh DesktopWidth DocumentsCommonDir error exitCode exitMethod extended FavoritesCommonDir FavoritesDir GUI_CtrlHandle GUI_CtrlId GUI_DragFile GUI_DragId GUI_DropId GUI_WinHandle HomeDrive HomePath HomeShare HotKeyPressed HOUR IPAddress1 IPAddress2 IPAddress3 IPAddress4 KBLayout LF LocalAppDataDir LogonDNSDomain LogonDomain LogonServer MDAY MIN MON MSEC MUILang MyDocumentsDir NumParams OSArch OSBuild OSLang OSServicePack OSType OSVersion ProgramFilesDir ProgramsCommonDir ProgramsDir ScriptDir ScriptFullPath ScriptLineNumber ScriptName SEC StartMenuCommonDir StartMenuDir StartupCommonDir StartupDir SW_DISABLE SW_ENABLE SW_HIDE SW_LOCK SW_MAXIMIZE SW_MINIMIZE SW_RESTORE SW_SHOW SW_SHOWDEFAULT SW_SHOWMAXIMIZED SW_SHOWMINIMIZED SW_SHOWMINNOACTIVE SW_SHOWNA SW_SHOWNOACTIVATE SW_SHOWNORMAL SW_UNLOCK SystemDir TAB TempDir TRAY_ID TrayIconFlashing TrayIconVisible UserName UserProfileDir WDAY WindowsDir WorkingDir YDAY YEAR',
      // relevance: 5
      begin: "@[A-z0-9_]+"
    }, f = {
      beginKeywords: "Func",
      end: "$",
      illegal: "\\$|\\[|%",
      contains: [
        t.inherit(t.UNDERSCORE_TITLE_MODE, { className: "title.function" }),
        {
          className: "params",
          begin: "\\(",
          end: "\\)",
          contains: [
            s,
            l,
            u
          ]
        }
      ]
    };
    return {
      name: "AutoIt",
      case_insensitive: !0,
      illegal: /\/\*/,
      keywords: {
        keyword: n,
        built_in: a,
        literal: i
      },
      contains: [
        o,
        s,
        l,
        u,
        c,
        d,
        f
      ]
    };
  }
  return I0 = e, I0;
}
var L0, UN;
function KX() {
  if (UN) return L0;
  UN = 1;
  function e(t) {
    return {
      name: "AVR Assembly",
      case_insensitive: !0,
      keywords: {
        $pattern: "\\.?" + t.IDENT_RE,
        keyword: (
          /* mnemonic */
          "adc add adiw and andi asr bclr bld brbc brbs brcc brcs break breq brge brhc brhs brid brie brlo brlt brmi brne brpl brsh brtc brts brvc brvs bset bst call cbi cbr clc clh cli cln clr cls clt clv clz com cp cpc cpi cpse dec eicall eijmp elpm eor fmul fmuls fmulsu icall ijmp in inc jmp ld ldd ldi lds lpm lsl lsr mov movw mul muls mulsu neg nop or ori out pop push rcall ret reti rjmp rol ror sbc sbr sbrc sbrs sec seh sbi sbci sbic sbis sbiw sei sen ser ses set sev sez sleep spm st std sts sub subi swap tst wdr"
        ),
        built_in: (
          /* general purpose registers */
          "r0 r1 r2 r3 r4 r5 r6 r7 r8 r9 r10 r11 r12 r13 r14 r15 r16 r17 r18 r19 r20 r21 r22 r23 r24 r25 r26 r27 r28 r29 r30 r31 x|0 xh xl y|0 yh yl z|0 zh zl ucsr1c udr1 ucsr1a ucsr1b ubrr1l ubrr1h ucsr0c ubrr0h tccr3c tccr3a tccr3b tcnt3h tcnt3l ocr3ah ocr3al ocr3bh ocr3bl ocr3ch ocr3cl icr3h icr3l etimsk etifr tccr1c ocr1ch ocr1cl twcr twdr twar twsr twbr osccal xmcra xmcrb eicra spmcsr spmcr portg ddrg ping portf ddrf sreg sph spl xdiv rampz eicrb eimsk gimsk gicr eifr gifr timsk tifr mcucr mcucsr tccr0 tcnt0 ocr0 assr tccr1a tccr1b tcnt1h tcnt1l ocr1ah ocr1al ocr1bh ocr1bl icr1h icr1l tccr2 tcnt2 ocr2 ocdr wdtcr sfior eearh eearl eedr eecr porta ddra pina portb ddrb pinb portc ddrc pinc portd ddrd pind spdr spsr spcr udr0 ucsr0a ucsr0b ubrr0l acsr admux adcsr adch adcl porte ddre pine pinf"
        ),
        meta: ".byte .cseg .db .def .device .dseg .dw .endmacro .equ .eseg .exit .include .list .listmac .macro .nolist .org .set"
      },
      contains: [
        t.C_BLOCK_COMMENT_MODE,
        t.COMMENT(
          ";",
          "$",
          { relevance: 0 }
        ),
        t.C_NUMBER_MODE,
        // 0x..., decimal, float
        t.BINARY_NUMBER_MODE,
        // 0b...
        {
          className: "number",
          begin: "\\b(\\$[a-zA-Z0-9]+|0o[0-7]+)"
          // $..., 0o...
        },
        t.QUOTE_STRING_MODE,
        {
          className: "string",
          begin: "'",
          end: "[^\\\\]'",
          illegal: "[^\\\\][^']"
        },
        {
          className: "symbol",
          begin: "^[A-Za-z0-9_.$]+:"
        },
        {
          className: "meta",
          begin: "#",
          end: "$"
        },
        {
          // substitution within a macro
          className: "subst",
          begin: "@[0-9]+"
        }
      ]
    };
  }
  return L0 = e, L0;
}
var k0, qN;
function jX() {
  if (qN) return k0;
  qN = 1;
  function e(t) {
    const n = {
      className: "variable",
      variants: [
        { begin: /\$[\w\d#@][\w\d_]*/ },
        { begin: /\$\{(.*?)\}/ }
      ]
    }, r = "BEGIN END if else while do for in break continue delete next nextfile function func exit|10", i = {
      className: "string",
      contains: [t.BACKSLASH_ESCAPE],
      variants: [
        {
          begin: /(u|b)?r?'''/,
          end: /'''/,
          relevance: 10
        },
        {
          begin: /(u|b)?r?"""/,
          end: /"""/,
          relevance: 10
        },
        {
          begin: /(u|r|ur)'/,
          end: /'/,
          relevance: 10
        },
        {
          begin: /(u|r|ur)"/,
          end: /"/,
          relevance: 10
        },
        {
          begin: /(b|br)'/,
          end: /'/
        },
        {
          begin: /(b|br)"/,
          end: /"/
        },
        t.APOS_STRING_MODE,
        t.QUOTE_STRING_MODE
      ]
    };
    return {
      name: "Awk",
      keywords: { keyword: r },
      contains: [
        n,
        i,
        t.REGEXP_MODE,
        t.HASH_COMMENT_MODE,
        t.NUMBER_MODE
      ]
    };
  }
  return k0 = e, k0;
}
var M0, GN;
function QX() {
  if (GN) return M0;
  GN = 1;
  function e(t) {
    const n = t.UNDERSCORE_IDENT_RE, o = {
      keyword: [
        "abstract",
        "as",
        "asc",
        "avg",
        "break",
        "breakpoint",
        "by",
        "byref",
        "case",
        "catch",
        "changecompany",
        "class",
        "client",
        "client",
        "common",
        "const",
        "continue",
        "count",
        "crosscompany",
        "delegate",
        "delete_from",
        "desc",
        "display",
        "div",
        "do",
        "edit",
        "else",
        "eventhandler",
        "exists",
        "extends",
        "final",
        "finally",
        "firstfast",
        "firstonly",
        "firstonly1",
        "firstonly10",
        "firstonly100",
        "firstonly1000",
        "flush",
        "for",
        "forceliterals",
        "forcenestedloop",
        "forceplaceholders",
        "forceselectorder",
        "forupdate",
        "from",
        "generateonly",
        "group",
        "hint",
        "if",
        "implements",
        "in",
        "index",
        "insert_recordset",
        "interface",
        "internal",
        "is",
        "join",
        "like",
        "maxof",
        "minof",
        "mod",
        "namespace",
        "new",
        "next",
        "nofetch",
        "notexists",
        "optimisticlock",
        "order",
        "outer",
        "pessimisticlock",
        "print",
        "private",
        "protected",
        "public",
        "readonly",
        "repeatableread",
        "retry",
        "return",
        "reverse",
        "select",
        "server",
        "setting",
        "static",
        "sum",
        "super",
        "switch",
        "this",
        "throw",
        "try",
        "ttsabort",
        "ttsbegin",
        "ttscommit",
        "unchecked",
        "update_recordset",
        "using",
        "validtimestate",
        "void",
        "where",
        "while"
      ],
      built_in: [
        "anytype",
        "boolean",
        "byte",
        "char",
        "container",
        "date",
        "double",
        "enum",
        "guid",
        "int",
        "int64",
        "long",
        "real",
        "short",
        "str",
        "utcdatetime",
        "var"
      ],
      literal: [
        "default",
        "false",
        "null",
        "true"
      ]
    }, s = {
      variants: [
        { match: [
          /(class|interface)\s+/,
          n,
          /\s+(extends|implements)\s+/,
          n
        ] },
        { match: [
          /class\s+/,
          n
        ] }
      ],
      scope: {
        2: "title.class",
        4: "title.class.inherited"
      },
      keywords: o
    };
    return {
      name: "X++",
      aliases: ["x++"],
      keywords: o,
      contains: [
        t.C_LINE_COMMENT_MODE,
        t.C_BLOCK_COMMENT_MODE,
        t.APOS_STRING_MODE,
        t.QUOTE_STRING_MODE,
        t.C_NUMBER_MODE,
        {
          className: "meta",
          begin: "#",
          end: "$"
        },
        s
      ]
    };
  }
  return M0 = e, M0;
}
var P0, YN;
function XX() {
  if (YN) return P0;
  YN = 1;
  function e(t) {
    const n = t.regex, r = {}, i = {
      begin: /\$\{/,
      end: /\}/,
      contains: [
        "self",
        {
          begin: /:-/,
          contains: [r]
        }
        // default values
      ]
    };
    Object.assign(r, {
      className: "variable",
      variants: [
        { begin: n.concat(
          /\$[\w\d#@][\w\d_]*/,
          // negative look-ahead tries to avoid matching patterns that are not
          // Perl at all like $ident$, @ident@, etc.
          "(?![\\w\\d])(?![$])"
        ) },
        i
      ]
    });
    const a = {
      className: "subst",
      begin: /\$\(/,
      end: /\)/,
      contains: [t.BACKSLASH_ESCAPE]
    }, o = {
      begin: /<<-?\s*(?=\w+)/,
      starts: { contains: [
        t.END_SAME_AS_BEGIN({
          begin: /(\w+)/,
          end: /(\w+)/,
          className: "string"
        })
      ] }
    }, s = {
      className: "string",
      begin: /"/,
      end: /"/,
      contains: [
        t.BACKSLASH_ESCAPE,
        r,
        a
      ]
    };
    a.contains.push(s);
    const l = {
      match: /\\"/
    }, u = {
      className: "string",
      begin: /'/,
      end: /'/
    }, c = {
      match: /\\'/
    }, d = {
      begin: /\$?\(\(/,
      end: /\)\)/,
      contains: [
        {
          begin: /\d+#[0-9a-f]+/,
          className: "number"
        },
        t.NUMBER_MODE,
        r
      ]
    }, f = [
      "fish",
      "bash",
      "zsh",
      "sh",
      "csh",
      "ksh",
      "tcsh",
      "dash",
      "scsh"
    ], h = t.SHEBANG({
      binary: `(${f.join("|")})`,
      relevance: 10
    }), m = {
      className: "function",
      begin: /\w[\w\d_]*\s*\(\s*\)\s*\{/,
      returnBegin: !0,
      contains: [t.inherit(t.TITLE_MODE, { begin: /\w[\w\d_]*/ })],
      relevance: 0
    }, v = [
      "if",
      "then",
      "else",
      "elif",
      "fi",
      "for",
      "while",
      "until",
      "in",
      "do",
      "done",
      "case",
      "esac",
      "function",
      "select"
    ], b = [
      "true",
      "false"
    ], y = { match: /(\/[a-z._-]+)+/ }, g = [
      "break",
      "cd",
      "continue",
      "eval",
      "exec",
      "exit",
      "export",
      "getopts",
      "hash",
      "pwd",
      "readonly",
      "return",
      "shift",
      "test",
      "times",
      "trap",
      "umask",
      "unset"
    ], E = [
      "alias",
      "bind",
      "builtin",
      "caller",
      "command",
      "declare",
      "echo",
      "enable",
      "help",
      "let",
      "local",
      "logout",
      "mapfile",
      "printf",
      "read",
      "readarray",
      "source",
      "type",
      "typeset",
      "ulimit",
      "unalias"
    ], S = [
      "autoload",
      "bg",
      "bindkey",
      "bye",
      "cap",
      "chdir",
      "clone",
      "comparguments",
      "compcall",
      "compctl",
      "compdescribe",
      "compfiles",
      "compgroups",
      "compquote",
      "comptags",
      "comptry",
      "compvalues",
      "dirs",
      "disable",
      "disown",
      "echotc",
      "echoti",
      "emulate",
      "fc",
      "fg",
      "float",
      "functions",
      "getcap",
      "getln",
      "history",
      "integer",
      "jobs",
      "kill",
      "limit",
      "log",
      "noglob",
      "popd",
      "print",
      "pushd",
      "pushln",
      "rehash",
      "sched",
      "setcap",
      "setopt",
      "stat",
      "suspend",
      "ttyctl",
      "unfunction",
      "unhash",
      "unlimit",
      "unsetopt",
      "vared",
      "wait",
      "whence",
      "where",
      "which",
      "zcompile",
      "zformat",
      "zftp",
      "zle",
      "zmodload",
      "zparseopts",
      "zprof",
      "zpty",
      "zregexparse",
      "zsocket",
      "zstyle",
      "ztcp"
    ], C = [
      "chcon",
      "chgrp",
      "chown",
      "chmod",
      "cp",
      "dd",
      "df",
      "dir",
      "dircolors",
      "ln",
      "ls",
      "mkdir",
      "mkfifo",
      "mknod",
      "mktemp",
      "mv",
      "realpath",
      "rm",
      "rmdir",
      "shred",
      "sync",
      "touch",
      "truncate",
      "vdir",
      "b2sum",
      "base32",
      "base64",
      "cat",
      "cksum",
      "comm",
      "csplit",
      "cut",
      "expand",
      "fmt",
      "fold",
      "head",
      "join",
      "md5sum",
      "nl",
      "numfmt",
      "od",
      "paste",
      "ptx",
      "pr",
      "sha1sum",
      "sha224sum",
      "sha256sum",
      "sha384sum",
      "sha512sum",
      "shuf",
      "sort",
      "split",
      "sum",
      "tac",
      "tail",
      "tr",
      "tsort",
      "unexpand",
      "uniq",
      "wc",
      "arch",
      "basename",
      "chroot",
      "date",
      "dirname",
      "du",
      "echo",
      "env",
      "expr",
      "factor",
      // "false", // keyword literal already
      "groups",
      "hostid",
      "id",
      "link",
      "logname",
      "nice",
      "nohup",
      "nproc",
      "pathchk",
      "pinky",
      "printenv",
      "printf",
      "pwd",
      "readlink",
      "runcon",
      "seq",
      "sleep",
      "stat",
      "stdbuf",
      "stty",
      "tee",
      "test",
      "timeout",
      // "true", // keyword literal already
      "tty",
      "uname",
      "unlink",
      "uptime",
      "users",
      "who",
      "whoami",
      "yes"
    ];
    return {
      name: "Bash",
      aliases: ["sh"],
      keywords: {
        $pattern: /\b[a-z][a-z0-9._-]+\b/,
        keyword: v,
        literal: b,
        built_in: [
          ...g,
          ...E,
          // Shell modifiers
          "set",
          "shopt",
          ...S,
          ...C
        ]
      },
      contains: [
        h,
        // to catch known shells and boost relevancy
        t.SHEBANG(),
        // to catch unknown shells but still highlight the shebang
        m,
        d,
        t.HASH_COMMENT_MODE,
        o,
        y,
        s,
        l,
        u,
        c,
        r
      ]
    };
  }
  return P0 = e, P0;
}
var F0, HN;
function ZX() {
  if (HN) return F0;
  HN = 1;
  function e(t) {
    return {
      name: "BASIC",
      case_insensitive: !0,
      illegal: "^.",
      // Support explicitly typed variables that end with $%! or #.
      keywords: {
        $pattern: "[a-zA-Z][a-zA-Z0-9_$%!#]*",
        keyword: [
          "ABS",
          "ASC",
          "AND",
          "ATN",
          "AUTO|0",
          "BEEP",
          "BLOAD|10",
          "BSAVE|10",
          "CALL",
          "CALLS",
          "CDBL",
          "CHAIN",
          "CHDIR",
          "CHR$|10",
          "CINT",
          "CIRCLE",
          "CLEAR",
          "CLOSE",
          "CLS",
          "COLOR",
          "COM",
          "COMMON",
          "CONT",
          "COS",
          "CSNG",
          "CSRLIN",
          "CVD",
          "CVI",
          "CVS",
          "DATA",
          "DATE$",
          "DEFDBL",
          "DEFINT",
          "DEFSNG",
          "DEFSTR",
          "DEF|0",
          "SEG",
          "USR",
          "DELETE",
          "DIM",
          "DRAW",
          "EDIT",
          "END",
          "ENVIRON",
          "ENVIRON$",
          "EOF",
          "EQV",
          "ERASE",
          "ERDEV",
          "ERDEV$",
          "ERL",
          "ERR",
          "ERROR",
          "EXP",
          "FIELD",
          "FILES",
          "FIX",
          "FOR|0",
          "FRE",
          "GET",
          "GOSUB|10",
          "GOTO",
          "HEX$",
          "IF",
          "THEN",
          "ELSE|0",
          "INKEY$",
          "INP",
          "INPUT",
          "INPUT#",
          "INPUT$",
          "INSTR",
          "IMP",
          "INT",
          "IOCTL",
          "IOCTL$",
          "KEY",
          "ON",
          "OFF",
          "LIST",
          "KILL",
          "LEFT$",
          "LEN",
          "LET",
          "LINE",
          "LLIST",
          "LOAD",
          "LOC",
          "LOCATE",
          "LOF",
          "LOG",
          "LPRINT",
          "USING",
          "LSET",
          "MERGE",
          "MID$",
          "MKDIR",
          "MKD$",
          "MKI$",
          "MKS$",
          "MOD",
          "NAME",
          "NEW",
          "NEXT",
          "NOISE",
          "NOT",
          "OCT$",
          "ON",
          "OR",
          "PEN",
          "PLAY",
          "STRIG",
          "OPEN",
          "OPTION",
          "BASE",
          "OUT",
          "PAINT",
          "PALETTE",
          "PCOPY",
          "PEEK",
          "PMAP",
          "POINT",
          "POKE",
          "POS",
          "PRINT",
          "PRINT]",
          "PSET",
          "PRESET",
          "PUT",
          "RANDOMIZE",
          "READ",
          "REM",
          "RENUM",
          "RESET|0",
          "RESTORE",
          "RESUME",
          "RETURN|0",
          "RIGHT$",
          "RMDIR",
          "RND",
          "RSET",
          "RUN",
          "SAVE",
          "SCREEN",
          "SGN",
          "SHELL",
          "SIN",
          "SOUND",
          "SPACE$",
          "SPC",
          "SQR",
          "STEP",
          "STICK",
          "STOP",
          "STR$",
          "STRING$",
          "SWAP",
          "SYSTEM",
          "TAB",
          "TAN",
          "TIME$",
          "TIMER",
          "TROFF",
          "TRON",
          "TO",
          "USR",
          "VAL",
          "VARPTR",
          "VARPTR$",
          "VIEW",
          "WAIT",
          "WHILE",
          "WEND",
          "WIDTH",
          "WINDOW",
          "WRITE",
          "XOR"
        ]
      },
      contains: [
        t.QUOTE_STRING_MODE,
        t.COMMENT("REM", "$", { relevance: 10 }),
        t.COMMENT("'", "$", { relevance: 0 }),
        {
          // Match line numbers
          className: "symbol",
          begin: "^[0-9]+ ",
          relevance: 10
        },
        {
          // Match typed numeric constants (1000, 12.34!, 1.2e5, 1.5#, 1.2D2)
          className: "number",
          begin: "\\b\\d+(\\.\\d+)?([edED]\\d+)?[#!]?",
          relevance: 0
        },
        {
          // Match hexadecimal numbers (&Hxxxx)
          className: "number",
          begin: "(&[hH][0-9a-fA-F]{1,4})"
        },
        {
          // Match octal numbers (&Oxxxxxx)
          className: "number",
          begin: "(&[oO][0-7]{1,6})"
        }
      ]
    };
  }
  return F0 = e, F0;
}
var B0, zN;
function JX() {
  if (zN) return B0;
  zN = 1;
  function e(t) {
    return {
      name: "Backus–Naur Form",
      contains: [
        // Attribute
        {
          className: "attribute",
          begin: /</,
          end: />/
        },
        // Specific
        {
          begin: /::=/,
          end: /$/,
          contains: [
            {
              begin: /</,
              end: />/
            },
            // Common
            t.C_LINE_COMMENT_MODE,
            t.C_BLOCK_COMMENT_MODE,
            t.APOS_STRING_MODE,
            t.QUOTE_STRING_MODE
          ]
        }
      ]
    };
  }
  return B0 = e, B0;
}
var $0, VN;
function eZ() {
  if (VN) return $0;
  VN = 1;
  function e(t) {
    const n = {
      className: "literal",
      begin: /[+-]+/,
      relevance: 0
    };
    return {
      name: "Brainfuck",
      aliases: ["bf"],
      contains: [
        t.COMMENT(
          /[^\[\]\.,\+\-<> \r\n]/,
          /[\[\]\.,\+\-<> \r\n]/,
          {
            contains: [
              {
                match: /[ ]+[^\[\]\.,\+\-<> \r\n]/,
                relevance: 0
              }
            ],
            returnEnd: !0,
            relevance: 0
          }
        ),
        {
          className: "title",
          begin: "[\\[\\]]",
          relevance: 0
        },
        {
          className: "string",
          begin: "[\\.,]",
          relevance: 0
        },
        {
          // this mode works as the only relevance counter
          // it looks ahead to find the start of a run of literals
          // so only the runs are counted as relevant
          begin: /(?=\+\+|--)/,
          contains: [n]
        },
        n
      ]
    };
  }
  return $0 = e, $0;
}
var U0, WN;
function tZ() {
  if (WN) return U0;
  WN = 1;
  function e(t) {
    const n = t.regex, r = t.COMMENT("//", "$", { contains: [{ begin: /\\\n/ }] }), i = "decltype\\(auto\\)", a = "[a-zA-Z_]\\w*::", s = "(" + i + "|" + n.optional(a) + "[a-zA-Z_]\\w*" + n.optional("<[^<>]+>") + ")", l = {
      className: "type",
      variants: [
        { begin: "\\b[a-z\\d_]*_t\\b" },
        { match: /\batomic_[a-z]{3,6}\b/ }
      ]
    }, c = {
      className: "string",
      variants: [
        {
          begin: '(u8?|U|L)?"',
          end: '"',
          illegal: "\\n",
          contains: [t.BACKSLASH_ESCAPE]
        },
        {
          begin: "(u8?|U|L)?'(" + "\\\\(x[0-9A-Fa-f]{2}|u[0-9A-Fa-f]{4,8}|[0-7]{3}|\\S)" + "|.)",
          end: "'",
          illegal: "."
        },
        t.END_SAME_AS_BEGIN({
          begin: /(?:u8?|U|L)?R"([^()\\ ]{0,16})\(/,
          end: /\)([^()\\ ]{0,16})"/
        })
      ]
    }, d = {
      className: "number",
      variants: [
        { begin: "\\b(0b[01']+)" },
        { begin: "(-?)\\b([\\d']+(\\.[\\d']*)?|\\.[\\d']+)((ll|LL|l|L)(u|U)?|(u|U)(ll|LL|l|L)?|f|F|b|B)" },
        { begin: "(-?)(\\b0[xX][a-fA-F0-9']+|(\\b[\\d']+(\\.[\\d']*)?|\\.[\\d']+)([eE][-+]?[\\d']+)?)" }
      ],
      relevance: 0
    }, f = {
      className: "meta",
      begin: /#\s*[a-z]+\b/,
      end: /$/,
      keywords: { keyword: "if else elif endif define undef warning error line pragma _Pragma ifdef ifndef include" },
      contains: [
        {
          begin: /\\\n/,
          relevance: 0
        },
        t.inherit(c, { className: "string" }),
        {
          className: "string",
          begin: /<.*?>/
        },
        r,
        t.C_BLOCK_COMMENT_MODE
      ]
    }, h = {
      className: "title",
      begin: n.optional(a) + t.IDENT_RE,
      relevance: 0
    }, m = n.optional(a) + t.IDENT_RE + "\\s*\\(", y = {
      keyword: [
        "asm",
        "auto",
        "break",
        "case",
        "continue",
        "default",
        "do",
        "else",
        "enum",
        "extern",
        "for",
        "fortran",
        "goto",
        "if",
        "inline",
        "register",
        "restrict",
        "return",
        "sizeof",
        "struct",
        "switch",
        "typedef",
        "union",
        "volatile",
        "while",
        "_Alignas",
        "_Alignof",
        "_Atomic",
        "_Generic",
        "_Noreturn",
        "_Static_assert",
        "_Thread_local",
        // aliases
        "alignas",
        "alignof",
        "noreturn",
        "static_assert",
        "thread_local",
        // not a C keyword but is, for all intents and purposes, treated exactly like one.
        "_Pragma"
      ],
      type: [
        "float",
        "double",
        "signed",
        "unsigned",
        "int",
        "short",
        "long",
        "char",
        "void",
        "_Bool",
        "_Complex",
        "_Imaginary",
        "_Decimal32",
        "_Decimal64",
        "_Decimal128",
        // modifiers
        "const",
        "static",
        // aliases
        "complex",
        "bool",
        "imaginary"
      ],
      literal: "true false NULL",
      // TODO: apply hinting work similar to what was done in cpp.js
      built_in: "std string wstring cin cout cerr clog stdin stdout stderr stringstream istringstream ostringstream auto_ptr deque list queue stack vector map set pair bitset multiset multimap unordered_set unordered_map unordered_multiset unordered_multimap priority_queue make_pair array shared_ptr abort terminate abs acos asin atan2 atan calloc ceil cosh cos exit exp fabs floor fmod fprintf fputs free frexp fscanf future isalnum isalpha iscntrl isdigit isgraph islower isprint ispunct isspace isupper isxdigit tolower toupper labs ldexp log10 log malloc realloc memchr memcmp memcpy memset modf pow printf putchar puts scanf sinh sin snprintf sprintf sqrt sscanf strcat strchr strcmp strcpy strcspn strlen strncat strncmp strncpy strpbrk strrchr strspn strstr tanh tan vfprintf vprintf vsprintf endl initializer_list unique_ptr"
    }, g = [
      f,
      l,
      r,
      t.C_BLOCK_COMMENT_MODE,
      d,
      c
    ], E = {
      // This mode covers expression context where we can't expect a function
      // definition and shouldn't highlight anything that looks like one:
      // `return some()`, `else if()`, `(x*sum(1, 2))`
      variants: [
        {
          begin: /=/,
          end: /;/
        },
        {
          begin: /\(/,
          end: /\)/
        },
        {
          beginKeywords: "new throw return else",
          end: /;/
        }
      ],
      keywords: y,
      contains: g.concat([
        {
          begin: /\(/,
          end: /\)/,
          keywords: y,
          contains: g.concat(["self"]),
          relevance: 0
        }
      ]),
      relevance: 0
    }, S = {
      begin: "(" + s + "[\\*&\\s]+)+" + m,
      returnBegin: !0,
      end: /[{;=]/,
      excludeEnd: !0,
      keywords: y,
      illegal: /[^\w\s\*&:<>.]/,
      contains: [
        {
          // to prevent it from being confused as the function title
          begin: i,
          keywords: y,
          relevance: 0
        },
        {
          begin: m,
          returnBegin: !0,
          contains: [t.inherit(h, { className: "title.function" })],
          relevance: 0
        },
        // allow for multiple declarations, e.g.:
        // extern void f(int), g(char);
        {
          relevance: 0,
          match: /,/
        },
        {
          className: "params",
          begin: /\(/,
          end: /\)/,
          keywords: y,
          relevance: 0,
          contains: [
            r,
            t.C_BLOCK_COMMENT_MODE,
            c,
            d,
            l,
            // Count matching parentheses.
            {
              begin: /\(/,
              end: /\)/,
              keywords: y,
              relevance: 0,
              contains: [
                "self",
                r,
                t.C_BLOCK_COMMENT_MODE,
                c,
                d,
                l
              ]
            }
          ]
        },
        l,
        r,
        t.C_BLOCK_COMMENT_MODE,
        f
      ]
    };
    return {
      name: "C",
      aliases: ["h"],
      keywords: y,
      // Until differentiations are added between `c` and `cpp`, `c` will
      // not be auto-detected to avoid auto-detect conflicts between C and C++
      disableAutodetect: !0,
      illegal: "</",
      contains: [].concat(
        E,
        S,
        g,
        [
          f,
          {
            begin: t.IDENT_RE + "::",
            keywords: y
          },
          {
            className: "class",
            beginKeywords: "enum class struct union",
            end: /[{;:<>=]/,
            contains: [
              { beginKeywords: "final class struct" },
              t.TITLE_MODE
            ]
          }
        ]
      ),
      exports: {
        preprocessor: f,
        strings: c,
        keywords: y
      }
    };
  }
  return U0 = e, U0;
}
var q0, KN;
function nZ() {
  if (KN) return q0;
  KN = 1;
  function e(t) {
    const n = t.regex, r = [
      "div",
      "mod",
      "in",
      "and",
      "or",
      "not",
      "xor",
      "asserterror",
      "begin",
      "case",
      "do",
      "downto",
      "else",
      "end",
      "exit",
      "for",
      "local",
      "if",
      "of",
      "repeat",
      "then",
      "to",
      "until",
      "while",
      "with",
      "var"
    ], i = "false true", a = [
      t.C_LINE_COMMENT_MODE,
      t.COMMENT(
        /\{/,
        /\}/,
        { relevance: 0 }
      ),
      t.COMMENT(
        /\(\*/,
        /\*\)/,
        { relevance: 10 }
      )
    ], o = {
      className: "string",
      begin: /'/,
      end: /'/,
      contains: [{ begin: /''/ }]
    }, s = {
      className: "string",
      begin: /(#\d+)+/
    }, l = {
      className: "number",
      begin: "\\b\\d+(\\.\\d+)?(DT|D|T)",
      relevance: 0
    }, u = {
      className: "string",
      // not a string technically but makes sense to be highlighted in the same style
      begin: '"',
      end: '"'
    }, c = {
      match: [
        /procedure/,
        /\s+/,
        /[a-zA-Z_][\w@]*/,
        /\s*/
      ],
      scope: {
        1: "keyword",
        3: "title.function"
      },
      contains: [
        {
          className: "params",
          begin: /\(/,
          end: /\)/,
          keywords: r,
          contains: [
            o,
            s,
            t.NUMBER_MODE
          ]
        },
        ...a
      ]
    }, d = [
      "Table",
      "Form",
      "Report",
      "Dataport",
      "Codeunit",
      "XMLport",
      "MenuSuite",
      "Page",
      "Query"
    ], f = {
      match: [
        /OBJECT/,
        /\s+/,
        n.either(...d),
        /\s+/,
        /\d+/,
        /\s+(?=[^\s])/,
        /.*/,
        /$/
      ],
      relevance: 3,
      scope: {
        1: "keyword",
        3: "type",
        5: "number",
        7: "title"
      }
    };
    return {
      name: "C/AL",
      case_insensitive: !0,
      keywords: {
        keyword: r,
        literal: i
      },
      illegal: /\/\*/,
      contains: [
        {
          match: /[\w]+(?=\=)/,
          scope: "attribute",
          relevance: 0
        },
        o,
        s,
        l,
        u,
        t.NUMBER_MODE,
        f,
        c
      ]
    };
  }
  return q0 = e, q0;
}
var G0, jN;
function rZ() {
  if (jN) return G0;
  jN = 1;
  function e(t) {
    const n = [
      "struct",
      "enum",
      "interface",
      "union",
      "group",
      "import",
      "using",
      "const",
      "annotation",
      "extends",
      "in",
      "of",
      "on",
      "as",
      "with",
      "from",
      "fixed"
    ], r = [
      "Void",
      "Bool",
      "Int8",
      "Int16",
      "Int32",
      "Int64",
      "UInt8",
      "UInt16",
      "UInt32",
      "UInt64",
      "Float32",
      "Float64",
      "Text",
      "Data",
      "AnyPointer",
      "AnyStruct",
      "Capability",
      "List"
    ], i = [
      "true",
      "false"
    ], a = {
      variants: [
        { match: [
          /(struct|enum|interface)/,
          /\s+/,
          t.IDENT_RE
        ] },
        { match: [
          /extends/,
          /\s*\(/,
          t.IDENT_RE,
          /\s*\)/
        ] }
      ],
      scope: {
        1: "keyword",
        3: "title.class"
      }
    };
    return {
      name: "Cap’n Proto",
      aliases: ["capnp"],
      keywords: {
        keyword: n,
        type: r,
        literal: i
      },
      contains: [
        t.QUOTE_STRING_MODE,
        t.NUMBER_MODE,
        t.HASH_COMMENT_MODE,
        {
          className: "meta",
          begin: /@0x[\w\d]{16};/,
          illegal: /\n/
        },
        {
          className: "symbol",
          begin: /@\d+\b/
        },
        a
      ]
    };
  }
  return G0 = e, G0;
}
var Y0, QN;
function iZ() {
  if (QN) return Y0;
  QN = 1;
  function e(t) {
    const n = [
      "assembly",
      "module",
      "package",
      "import",
      "alias",
      "class",
      "interface",
      "object",
      "given",
      "value",
      "assign",
      "void",
      "function",
      "new",
      "of",
      "extends",
      "satisfies",
      "abstracts",
      "in",
      "out",
      "return",
      "break",
      "continue",
      "throw",
      "assert",
      "dynamic",
      "if",
      "else",
      "switch",
      "case",
      "for",
      "while",
      "try",
      "catch",
      "finally",
      "then",
      "let",
      "this",
      "outer",
      "super",
      "is",
      "exists",
      "nonempty"
    ], r = [
      "shared",
      "abstract",
      "formal",
      "default",
      "actual",
      "variable",
      "late",
      "native",
      "deprecated",
      "final",
      "sealed",
      "annotation",
      "suppressWarnings",
      "small"
    ], i = [
      "doc",
      "by",
      "license",
      "see",
      "throws",
      "tagged"
    ], a = {
      className: "subst",
      excludeBegin: !0,
      excludeEnd: !0,
      begin: /``/,
      end: /``/,
      keywords: n,
      relevance: 10
    }, o = [
      {
        // verbatim string
        className: "string",
        begin: '"""',
        end: '"""',
        relevance: 10
      },
      {
        // string literal or template
        className: "string",
        begin: '"',
        end: '"',
        contains: [a]
      },
      {
        // character literal
        className: "string",
        begin: "'",
        end: "'"
      },
      {
        // numeric literal
        className: "number",
        begin: "#[0-9a-fA-F_]+|\\$[01_]+|[0-9_]+(?:\\.[0-9_](?:[eE][+-]?\\d+)?)?[kMGTPmunpf]?",
        relevance: 0
      }
    ];
    return a.contains = o, {
      name: "Ceylon",
      keywords: {
        keyword: n.concat(r),
        meta: i
      },
      illegal: "\\$[^01]|#[^0-9a-fA-F]",
      contains: [
        t.C_LINE_COMMENT_MODE,
        t.COMMENT("/\\*", "\\*/", { contains: ["self"] }),
        {
          // compiler annotation
          className: "meta",
          begin: '@[a-z]\\w*(?::"[^"]*")?'
        }
      ].concat(o)
    };
  }
  return Y0 = e, Y0;
}
var H0, XN;
function aZ() {
  if (XN) return H0;
  XN = 1;
  function e(t) {
    return {
      name: "Clean",
      aliases: [
        "icl",
        "dcl"
      ],
      keywords: {
        keyword: [
          "if",
          "let",
          "in",
          "with",
          "where",
          "case",
          "of",
          "class",
          "instance",
          "otherwise",
          "implementation",
          "definition",
          "system",
          "module",
          "from",
          "import",
          "qualified",
          "as",
          "special",
          "code",
          "inline",
          "foreign",
          "export",
          "ccall",
          "stdcall",
          "generic",
          "derive",
          "infix",
          "infixl",
          "infixr"
        ],
        built_in: "Int Real Char Bool",
        literal: "True False"
      },
      contains: [
        t.C_LINE_COMMENT_MODE,
        t.C_BLOCK_COMMENT_MODE,
        t.APOS_STRING_MODE,
        t.QUOTE_STRING_MODE,
        t.C_NUMBER_MODE,
        {
          // relevance booster
          begin: "->|<-[|:]?|#!?|>>=|\\{\\||\\|\\}|:==|=:|<>"
        }
      ]
    };
  }
  return H0 = e, H0;
}
var z0, ZN;
function oZ() {
  if (ZN) return z0;
  ZN = 1;
  function e(t) {
    const n = "a-zA-Z_\\-!.?+*=<>&'", r = "[#]?[" + n + "][" + n + "0-9/;:$#]*", i = "def defonce defprotocol defstruct defmulti defmethod defn- defn defmacro deftype defrecord", a = {
      $pattern: r,
      built_in: (
        // Clojure keywords
        i + " cond apply if-not if-let if not not= =|0 <|0 >|0 <=|0 >=|0 ==|0 +|0 /|0 *|0 -|0 rem quot neg? pos? delay? symbol? keyword? true? false? integer? empty? coll? list? set? ifn? fn? associative? sequential? sorted? counted? reversible? number? decimal? class? distinct? isa? float? rational? reduced? ratio? odd? even? char? seq? vector? string? map? nil? contains? zero? instance? not-every? not-any? libspec? -> ->> .. . inc compare do dotimes mapcat take remove take-while drop letfn drop-last take-last drop-while while intern condp case reduced cycle split-at split-with repeat replicate iterate range merge zipmap declare line-seq sort comparator sort-by dorun doall nthnext nthrest partition eval doseq await await-for let agent atom send send-off release-pending-sends add-watch mapv filterv remove-watch agent-error restart-agent set-error-handler error-handler set-error-mode! error-mode shutdown-agents quote var fn loop recur throw try monitor-enter monitor-exit macroexpand macroexpand-1 for dosync and or when when-not when-let comp juxt partial sequence memoize constantly complement identity assert peek pop doto proxy first rest cons cast coll last butlast sigs reify second ffirst fnext nfirst nnext meta with-meta ns in-ns create-ns import refer keys select-keys vals key val rseq name namespace promise into transient persistent! conj! assoc! dissoc! pop! disj! use class type num float double short byte boolean bigint biginteger bigdec print-method print-dup throw-if printf format load compile get-in update-in pr pr-on newline flush read slurp read-line subvec with-open memfn time re-find re-groups rand-int rand mod locking assert-valid-fdecl alias resolve ref deref refset swap! reset! set-validator! compare-and-set! alter-meta! reset-meta! commute get-validator alter ref-set ref-history-count ref-min-history ref-max-history ensure sync io! new next conj set! to-array future future-call into-array aset gen-class reduce map filter find empty hash-map hash-set sorted-map sorted-map-by sorted-set sorted-set-by vec vector seq flatten reverse assoc dissoc list disj get union difference intersection extend extend-type extend-protocol int nth delay count concat chunk chunk-buffer chunk-append chunk-first chunk-rest max min dec unchecked-inc-int unchecked-inc unchecked-dec-inc unchecked-dec unchecked-negate unchecked-add-int unchecked-add unchecked-subtract-int unchecked-subtract chunk-next chunk-cons chunked-seq? prn vary-meta lazy-seq spread list* str find-keyword keyword symbol gensym force rationalize"
      )
    }, o = {
      begin: r,
      relevance: 0
    }, s = {
      scope: "number",
      relevance: 0,
      variants: [
        { match: /[-+]?0[xX][0-9a-fA-F]+N?/ },
        // hexadecimal                 // 0x2a
        { match: /[-+]?0[0-7]+N?/ },
        // octal                       // 052
        { match: /[-+]?[1-9][0-9]?[rR][0-9a-zA-Z]+N?/ },
        // variable radix from 2 to 36 // 2r101010, 8r52, 36r16
        { match: /[-+]?[0-9]+\/[0-9]+N?/ },
        // ratio                       // 1/2
        { match: /[-+]?[0-9]+((\.[0-9]*([eE][+-]?[0-9]+)?M?)|([eE][+-]?[0-9]+M?|M))/ },
        // float        // 0.42 4.2E-1M 42E1 42M
        { match: /[-+]?([1-9][0-9]*|0)N?/ }
        // int (don't match leading 0) // 42 42N
      ]
    }, l = {
      scope: "character",
      variants: [
        { match: /\\o[0-3]?[0-7]{1,2}/ },
        // Unicode Octal 0 - 377
        { match: /\\u[0-9a-fA-F]{4}/ },
        // Unicode Hex 0000 - FFFF
        { match: /\\(newline|space|tab|formfeed|backspace|return)/ },
        // special characters
        {
          match: /\\\S/,
          relevance: 0
        }
        // any non-whitespace char
      ]
    }, u = {
      scope: "regex",
      begin: /#"/,
      end: /"/,
      contains: [t.BACKSLASH_ESCAPE]
    }, c = t.inherit(t.QUOTE_STRING_MODE, { illegal: null }), d = {
      scope: "punctuation",
      match: /,/,
      relevance: 0
    }, f = t.COMMENT(
      ";",
      "$",
      { relevance: 0 }
    ), h = {
      className: "literal",
      begin: /\b(true|false|nil)\b/
    }, m = {
      begin: "\\[|(#::?" + r + ")?\\{",
      end: "[\\]\\}]",
      relevance: 0
    }, v = {
      className: "symbol",
      begin: "[:]{1,2}" + r
    }, b = {
      begin: "\\(",
      end: "\\)"
    }, y = {
      endsWithParent: !0,
      relevance: 0
    }, g = {
      keywords: a,
      className: "name",
      begin: r,
      relevance: 0,
      starts: y
    }, E = [
      d,
      b,
      l,
      u,
      c,
      f,
      v,
      m,
      s,
      h,
      o
    ], S = {
      beginKeywords: i,
      keywords: {
        $pattern: r,
        keyword: i
      },
      end: '(\\[|#|\\d|"|:|\\{|\\)|\\(|$)',
      contains: [
        {
          className: "title",
          begin: r,
          relevance: 0,
          excludeEnd: !0,
          // we can only have a single title
          endsParent: !0
        }
      ].concat(E)
    };
    return b.contains = [
      S,
      g,
      y
    ], y.contains = E, m.contains = E, {
      name: "Clojure",
      aliases: [
        "clj",
        "edn"
      ],
      illegal: /\S/,
      contains: [
        d,
        b,
        l,
        u,
        c,
        f,
        v,
        m,
        s,
        h
      ]
    };
  }
  return z0 = e, z0;
}
var V0, JN;
function sZ() {
  if (JN) return V0;
  JN = 1;
  function e(t) {
    return {
      name: "Clojure REPL",
      contains: [
        {
          className: "meta.prompt",
          begin: /^([\w.-]+|\s*#_)?=>/,
          starts: {
            end: /$/,
            subLanguage: "clojure"
          }
        }
      ]
    };
  }
  return V0 = e, V0;
}
var W0, eD;
function lZ() {
  if (eD) return W0;
  eD = 1;
  function e(t) {
    return {
      name: "CMake",
      aliases: ["cmake.in"],
      case_insensitive: !0,
      keywords: { keyword: (
        // scripting commands
        "break cmake_host_system_information cmake_minimum_required cmake_parse_arguments cmake_policy configure_file continue elseif else endforeach endfunction endif endmacro endwhile execute_process file find_file find_library find_package find_path find_program foreach function get_cmake_property get_directory_property get_filename_component get_property if include include_guard list macro mark_as_advanced math message option return separate_arguments set_directory_properties set_property set site_name string unset variable_watch while add_compile_definitions add_compile_options add_custom_command add_custom_target add_definitions add_dependencies add_executable add_library add_link_options add_subdirectory add_test aux_source_directory build_command create_test_sourcelist define_property enable_language enable_testing export fltk_wrap_ui get_source_file_property get_target_property get_test_property include_directories include_external_msproject include_regular_expression install link_directories link_libraries load_cache project qt_wrap_cpp qt_wrap_ui remove_definitions set_source_files_properties set_target_properties set_tests_properties source_group target_compile_definitions target_compile_features target_compile_options target_include_directories target_link_directories target_link_libraries target_link_options target_sources try_compile try_run ctest_build ctest_configure ctest_coverage ctest_empty_binary_directory ctest_memcheck ctest_read_custom_files ctest_run_script ctest_sleep ctest_start ctest_submit ctest_test ctest_update ctest_upload build_name exec_program export_library_dependencies install_files install_programs install_targets load_command make_directory output_required_files remove subdir_depends subdirs use_mangled_mesa utility_source variable_requires write_file qt5_use_modules qt5_use_package qt5_wrap_cpp on off true false and or not command policy target test exists is_newer_than is_directory is_symlink is_absolute matches less greater equal less_equal greater_equal strless strgreater strequal strless_equal strgreater_equal version_less version_greater version_equal version_less_equal version_greater_equal in_list defined"
      ) },
      contains: [
        {
          className: "variable",
          begin: /\$\{/,
          end: /\}/
        },
        t.COMMENT(/#\[\[/, /]]/),
        t.HASH_COMMENT_MODE,
        t.QUOTE_STRING_MODE,
        t.NUMBER_MODE
      ]
    };
  }
  return W0 = e, W0;
}
var K0, tD;
function uZ() {
  if (tD) return K0;
  tD = 1;
  const e = [
    "as",
    // for exports
    "in",
    "of",
    "if",
    "for",
    "while",
    "finally",
    "var",
    "new",
    "function",
    "do",
    "return",
    "void",
    "else",
    "break",
    "catch",
    "instanceof",
    "with",
    "throw",
    "case",
    "default",
    "try",
    "switch",
    "continue",
    "typeof",
    "delete",
    "let",
    "yield",
    "const",
    "class",
    // JS handles these with a special rule
    // "get",
    // "set",
    "debugger",
    "async",
    "await",
    "static",
    "import",
    "from",
    "export",
    "extends"
  ], t = [
    "true",
    "false",
    "null",
    "undefined",
    "NaN",
    "Infinity"
  ], n = [
    // Fundamental objects
    "Object",
    "Function",
    "Boolean",
    "Symbol",
    // numbers and dates
    "Math",
    "Date",
    "Number",
    "BigInt",
    // text
    "String",
    "RegExp",
    // Indexed collections
    "Array",
    "Float32Array",
    "Float64Array",
    "Int8Array",
    "Uint8Array",
    "Uint8ClampedArray",
    "Int16Array",
    "Int32Array",
    "Uint16Array",
    "Uint32Array",
    "BigInt64Array",
    "BigUint64Array",
    // Keyed collections
    "Set",
    "Map",
    "WeakSet",
    "WeakMap",
    // Structured data
    "ArrayBuffer",
    "SharedArrayBuffer",
    "Atomics",
    "DataView",
    "JSON",
    // Control abstraction objects
    "Promise",
    "Generator",
    "GeneratorFunction",
    "AsyncFunction",
    // Reflection
    "Reflect",
    "Proxy",
    // Internationalization
    "Intl",
    // WebAssembly
    "WebAssembly"
  ], r = [
    "Error",
    "EvalError",
    "InternalError",
    "RangeError",
    "ReferenceError",
    "SyntaxError",
    "TypeError",
    "URIError"
  ], i = [
    "setInterval",
    "setTimeout",
    "clearInterval",
    "clearTimeout",
    "require",
    "exports",
    "eval",
    "isFinite",
    "isNaN",
    "parseFloat",
    "parseInt",
    "decodeURI",
    "decodeURIComponent",
    "encodeURI",
    "encodeURIComponent",
    "escape",
    "unescape"
  ], a = [].concat(
    i,
    n,
    r
  );
  function o(s) {
    const l = [
      "npm",
      "print"
    ], u = [
      "yes",
      "no",
      "on",
      "off"
    ], c = [
      "then",
      "unless",
      "until",
      "loop",
      "by",
      "when",
      "and",
      "or",
      "is",
      "isnt",
      "not"
    ], d = [
      "var",
      "const",
      "let",
      "function",
      "static"
    ], f = (C) => (T) => !C.includes(T), h = {
      keyword: e.concat(c).filter(f(d)),
      literal: t.concat(u),
      built_in: a.concat(l)
    }, m = "[A-Za-z$_][0-9A-Za-z$_]*", v = {
      className: "subst",
      begin: /#\{/,
      end: /\}/,
      keywords: h
    }, b = [
      s.BINARY_NUMBER_MODE,
      s.inherit(s.C_NUMBER_MODE, { starts: {
        end: "(\\s*/)?",
        relevance: 0
      } }),
      // a number tries to eat the following slash to prevent treating it as a regexp
      {
        className: "string",
        variants: [
          {
            begin: /'''/,
            end: /'''/,
            contains: [s.BACKSLASH_ESCAPE]
          },
          {
            begin: /'/,
            end: /'/,
            contains: [s.BACKSLASH_ESCAPE]
          },
          {
            begin: /"""/,
            end: /"""/,
            contains: [
              s.BACKSLASH_ESCAPE,
              v
            ]
          },
          {
            begin: /"/,
            end: /"/,
            contains: [
              s.BACKSLASH_ESCAPE,
              v
            ]
          }
        ]
      },
      {
        className: "regexp",
        variants: [
          {
            begin: "///",
            end: "///",
            contains: [
              v,
              s.HASH_COMMENT_MODE
            ]
          },
          {
            begin: "//[gim]{0,3}(?=\\W)",
            relevance: 0
          },
          {
            // regex can't start with space to parse x / 2 / 3 as two divisions
            // regex can't start with *, and it supports an "illegal" in the main mode
            begin: /\/(?![ *]).*?(?![\\]).\/[gim]{0,3}(?=\W)/
          }
        ]
      },
      {
        begin: "@" + m
        // relevance booster
      },
      {
        subLanguage: "javascript",
        excludeBegin: !0,
        excludeEnd: !0,
        variants: [
          {
            begin: "```",
            end: "```"
          },
          {
            begin: "`",
            end: "`"
          }
        ]
      }
    ];
    v.contains = b;
    const y = s.inherit(s.TITLE_MODE, { begin: m }), g = "(\\(.*\\)\\s*)?\\B[-=]>", E = {
      className: "params",
      begin: "\\([^\\(]",
      returnBegin: !0,
      /* We need another contained nameless mode to not have every nested
      pair of parens to be called "params" */
      contains: [
        {
          begin: /\(/,
          end: /\)/,
          keywords: h,
          contains: ["self"].concat(b)
        }
      ]
    }, S = {
      variants: [
        { match: [
          /class\s+/,
          m,
          /\s+extends\s+/,
          m
        ] },
        { match: [
          /class\s+/,
          m
        ] }
      ],
      scope: {
        2: "title.class",
        4: "title.class.inherited"
      },
      keywords: h
    };
    return {
      name: "CoffeeScript",
      aliases: [
        "coffee",
        "cson",
        "iced"
      ],
      keywords: h,
      illegal: /\/\*/,
      contains: [
        ...b,
        s.COMMENT("###", "###"),
        s.HASH_COMMENT_MODE,
        {
          className: "function",
          begin: "^\\s*" + m + "\\s*=\\s*" + g,
          end: "[-=]>",
          returnBegin: !0,
          contains: [
            y,
            E
          ]
        },
        {
          // anonymous function start
          begin: /[:\(,=]\s*/,
          relevance: 0,
          contains: [
            {
              className: "function",
              begin: g,
              end: "[-=]>",
              returnBegin: !0,
              contains: [E]
            }
          ]
        },
        S,
        {
          begin: m + ":",
          end: ":",
          returnBegin: !0,
          returnEnd: !0,
          relevance: 0
        }
      ]
    };
  }
  return K0 = o, K0;
}
var j0, nD;
function cZ() {
  if (nD) return j0;
  nD = 1;
  function e(t) {
    return {
      name: "Coq",
      keywords: {
        keyword: [
          "_|0",
          "as",
          "at",
          "cofix",
          "else",
          "end",
          "exists",
          "exists2",
          "fix",
          "for",
          "forall",
          "fun",
          "if",
          "IF",
          "in",
          "let",
          "match",
          "mod",
          "Prop",
          "return",
          "Set",
          "then",
          "Type",
          "using",
          "where",
          "with",
          "Abort",
          "About",
          "Add",
          "Admit",
          "Admitted",
          "All",
          "Arguments",
          "Assumptions",
          "Axiom",
          "Back",
          "BackTo",
          "Backtrack",
          "Bind",
          "Blacklist",
          "Canonical",
          "Cd",
          "Check",
          "Class",
          "Classes",
          "Close",
          "Coercion",
          "Coercions",
          "CoFixpoint",
          "CoInductive",
          "Collection",
          "Combined",
          "Compute",
          "Conjecture",
          "Conjectures",
          "Constant",
          "constr",
          "Constraint",
          "Constructors",
          "Context",
          "Corollary",
          "CreateHintDb",
          "Cut",
          "Declare",
          "Defined",
          "Definition",
          "Delimit",
          "Dependencies",
          "Dependent",
          "Derive",
          "Drop",
          "eauto",
          "End",
          "Equality",
          "Eval",
          "Example",
          "Existential",
          "Existentials",
          "Existing",
          "Export",
          "exporting",
          "Extern",
          "Extract",
          "Extraction",
          "Fact",
          "Field",
          "Fields",
          "File",
          "Fixpoint",
          "Focus",
          "for",
          "From",
          "Function",
          "Functional",
          "Generalizable",
          "Global",
          "Goal",
          "Grab",
          "Grammar",
          "Graph",
          "Guarded",
          "Heap",
          "Hint",
          "HintDb",
          "Hints",
          "Hypotheses",
          "Hypothesis",
          "ident",
          "Identity",
          "If",
          "Immediate",
          "Implicit",
          "Import",
          "Include",
          "Inductive",
          "Infix",
          "Info",
          "Initial",
          "Inline",
          "Inspect",
          "Instance",
          "Instances",
          "Intro",
          "Intros",
          "Inversion",
          "Inversion_clear",
          "Language",
          "Left",
          "Lemma",
          "Let",
          "Libraries",
          "Library",
          "Load",
          "LoadPath",
          "Local",
          "Locate",
          "Ltac",
          "ML",
          "Mode",
          "Module",
          "Modules",
          "Monomorphic",
          "Morphism",
          "Next",
          "NoInline",
          "Notation",
          "Obligation",
          "Obligations",
          "Opaque",
          "Open",
          "Optimize",
          "Options",
          "Parameter",
          "Parameters",
          "Parametric",
          "Path",
          "Paths",
          "pattern",
          "Polymorphic",
          "Preterm",
          "Print",
          "Printing",
          "Program",
          "Projections",
          "Proof",
          "Proposition",
          "Pwd",
          "Qed",
          "Quit",
          "Rec",
          "Record",
          "Recursive",
          "Redirect",
          "Relation",
          "Remark",
          "Remove",
          "Require",
          "Reserved",
          "Reset",
          "Resolve",
          "Restart",
          "Rewrite",
          "Right",
          "Ring",
          "Rings",
          "Save",
          "Scheme",
          "Scope",
          "Scopes",
          "Script",
          "Search",
          "SearchAbout",
          "SearchHead",
          "SearchPattern",
          "SearchRewrite",
          "Section",
          "Separate",
          "Set",
          "Setoid",
          "Show",
          "Solve",
          "Sorted",
          "Step",
          "Strategies",
          "Strategy",
          "Structure",
          "SubClass",
          "Table",
          "Tables",
          "Tactic",
          "Term",
          "Test",
          "Theorem",
          "Time",
          "Timeout",
          "Transparent",
          "Type",
          "Typeclasses",
          "Types",
          "Undelimit",
          "Undo",
          "Unfocus",
          "Unfocused",
          "Unfold",
          "Universe",
          "Universes",
          "Unset",
          "Unshelve",
          "using",
          "Variable",
          "Variables",
          "Variant",
          "Verbose",
          "Visibility",
          "where",
          "with"
        ],
        built_in: [
          "abstract",
          "absurd",
          "admit",
          "after",
          "apply",
          "as",
          "assert",
          "assumption",
          "at",
          "auto",
          "autorewrite",
          "autounfold",
          "before",
          "bottom",
          "btauto",
          "by",
          "case",
          "case_eq",
          "cbn",
          "cbv",
          "change",
          "classical_left",
          "classical_right",
          "clear",
          "clearbody",
          "cofix",
          "compare",
          "compute",
          "congruence",
          "constr_eq",
          "constructor",
          "contradict",
          "contradiction",
          "cut",
          "cutrewrite",
          "cycle",
          "decide",
          "decompose",
          "dependent",
          "destruct",
          "destruction",
          "dintuition",
          "discriminate",
          "discrR",
          "do",
          "double",
          "dtauto",
          "eapply",
          "eassumption",
          "eauto",
          "ecase",
          "econstructor",
          "edestruct",
          "ediscriminate",
          "eelim",
          "eexact",
          "eexists",
          "einduction",
          "einjection",
          "eleft",
          "elim",
          "elimtype",
          "enough",
          "equality",
          "erewrite",
          "eright",
          "esimplify_eq",
          "esplit",
          "evar",
          "exact",
          "exactly_once",
          "exfalso",
          "exists",
          "f_equal",
          "fail",
          "field",
          "field_simplify",
          "field_simplify_eq",
          "first",
          "firstorder",
          "fix",
          "fold",
          "fourier",
          "functional",
          "generalize",
          "generalizing",
          "gfail",
          "give_up",
          "has_evar",
          "hnf",
          "idtac",
          "in",
          "induction",
          "injection",
          "instantiate",
          "intro",
          "intro_pattern",
          "intros",
          "intuition",
          "inversion",
          "inversion_clear",
          "is_evar",
          "is_var",
          "lapply",
          "lazy",
          "left",
          "lia",
          "lra",
          "move",
          "native_compute",
          "nia",
          "nsatz",
          "omega",
          "once",
          "pattern",
          "pose",
          "progress",
          "proof",
          "psatz",
          "quote",
          "record",
          "red",
          "refine",
          "reflexivity",
          "remember",
          "rename",
          "repeat",
          "replace",
          "revert",
          "revgoals",
          "rewrite",
          "rewrite_strat",
          "right",
          "ring",
          "ring_simplify",
          "rtauto",
          "set",
          "setoid_reflexivity",
          "setoid_replace",
          "setoid_rewrite",
          "setoid_symmetry",
          "setoid_transitivity",
          "shelve",
          "shelve_unifiable",
          "simpl",
          "simple",
          "simplify_eq",
          "solve",
          "specialize",
          "split",
          "split_Rabs",
          "split_Rmult",
          "stepl",
          "stepr",
          "subst",
          "sum",
          "swap",
          "symmetry",
          "tactic",
          "tauto",
          "time",
          "timeout",
          "top",
          "transitivity",
          "trivial",
          "try",
          "tryif",
          "unfold",
          "unify",
          "until",
          "using",
          "vm_compute",
          "with"
        ]
      },
      contains: [
        t.QUOTE_STRING_MODE,
        t.COMMENT("\\(\\*", "\\*\\)"),
        t.C_NUMBER_MODE,
        {
          className: "type",
          excludeBegin: !0,
          begin: "\\|\\s*",
          end: "\\w+"
        },
        {
          // relevance booster
          begin: /[-=]>/
        }
      ]
    };
  }
  return j0 = e, j0;
}
var Q0, rD;
function dZ() {
  if (rD) return Q0;
  rD = 1;
  function e(t) {
    return {
      name: "Caché Object Script",
      case_insensitive: !0,
      aliases: ["cls"],
      keywords: "property parameter class classmethod clientmethod extends as break catch close continue do d|0 else elseif for goto halt hang h|0 if job j|0 kill k|0 lock l|0 merge new open quit q|0 read r|0 return set s|0 tcommit throw trollback try tstart use view while write w|0 xecute x|0 zkill znspace zn ztrap zwrite zw zzdump zzwrite print zbreak zinsert zload zprint zremove zsave zzprint mv mvcall mvcrt mvdim mvprint zquit zsync ascii",
      contains: [
        {
          className: "number",
          begin: "\\b(\\d+(\\.\\d*)?|\\.\\d+)",
          relevance: 0
        },
        {
          className: "string",
          variants: [
            {
              begin: '"',
              end: '"',
              contains: [
                {
                  // escaped
                  begin: '""',
                  relevance: 0
                }
              ]
            }
          ]
        },
        t.C_LINE_COMMENT_MODE,
        t.C_BLOCK_COMMENT_MODE,
        {
          className: "comment",
          begin: /;/,
          end: "$",
          relevance: 0
        },
        {
          // Functions and user-defined functions: write $ztime(60*60*3), $$myFunc(10), $$^Val(1)
          className: "built_in",
          begin: /(?:\$\$?|\.\.)\^?[a-zA-Z]+/
        },
        {
          // Macro command: quit $$$OK
          className: "built_in",
          begin: /\$\$\$[a-zA-Z]+/
        },
        {
          // Special (global) variables: write %request.Content; Built-in classes: %Library.Integer
          className: "built_in",
          begin: /%[a-z]+(?:\.[a-z]+)*/
        },
        {
          // Global variable: set ^globalName = 12 write ^globalName
          className: "symbol",
          begin: /\^%?[a-zA-Z][\w]*/
        },
        {
          // Some control constructions: do ##class(Package.ClassName).Method(), ##super()
          className: "keyword",
          begin: /##class|##super|#define|#dim/
        },
        // sub-languages: are not fully supported by hljs by 11/15/2015
        // left for the future implementation.
        {
          begin: /&sql\(/,
          end: /\)/,
          excludeBegin: !0,
          excludeEnd: !0,
          subLanguage: "sql"
        },
        {
          begin: /&(js|jscript|javascript)</,
          end: />/,
          excludeBegin: !0,
          excludeEnd: !0,
          subLanguage: "javascript"
        },
        {
          // this brakes first and last tag, but this is the only way to embed a valid html
          begin: /&html<\s*</,
          end: />\s*>/,
          subLanguage: "xml"
        }
      ]
    };
  }
  return Q0 = e, Q0;
}
var X0, iD;
function fZ() {
  if (iD) return X0;
  iD = 1;
  function e(t) {
    const n = t.regex, r = t.COMMENT("//", "$", { contains: [{ begin: /\\\n/ }] }), i = "decltype\\(auto\\)", a = "[a-zA-Z_]\\w*::", s = "(?!struct)(" + i + "|" + n.optional(a) + "[a-zA-Z_]\\w*" + n.optional("<[^<>]+>") + ")", l = {
      className: "type",
      begin: "\\b[a-z\\d_]*_t\\b"
    }, c = {
      className: "string",
      variants: [
        {
          begin: '(u8?|U|L)?"',
          end: '"',
          illegal: "\\n",
          contains: [t.BACKSLASH_ESCAPE]
        },
        {
          begin: "(u8?|U|L)?'(" + "\\\\(x[0-9A-Fa-f]{2}|u[0-9A-Fa-f]{4,8}|[0-7]{3}|\\S)" + "|.)",
          end: "'",
          illegal: "."
        },
        t.END_SAME_AS_BEGIN({
          begin: /(?:u8?|U|L)?R"([^()\\ ]{0,16})\(/,
          end: /\)([^()\\ ]{0,16})"/
        })
      ]
    }, d = {
      className: "number",
      variants: [
        { begin: "\\b(0b[01']+)" },
        { begin: "(-?)\\b([\\d']+(\\.[\\d']*)?|\\.[\\d']+)((ll|LL|l|L)(u|U)?|(u|U)(ll|LL|l|L)?|f|F|b|B)" },
        { begin: "(-?)(\\b0[xX][a-fA-F0-9']+|(\\b[\\d']+(\\.[\\d']*)?|\\.[\\d']+)([eE][-+]?[\\d']+)?)" }
      ],
      relevance: 0
    }, f = {
      className: "meta",
      begin: /#\s*[a-z]+\b/,
      end: /$/,
      keywords: { keyword: "if else elif endif define undef warning error line pragma _Pragma ifdef ifndef include" },
      contains: [
        {
          begin: /\\\n/,
          relevance: 0
        },
        t.inherit(c, { className: "string" }),
        {
          className: "string",
          begin: /<.*?>/
        },
        r,
        t.C_BLOCK_COMMENT_MODE
      ]
    }, h = {
      className: "title",
      begin: n.optional(a) + t.IDENT_RE,
      relevance: 0
    }, m = n.optional(a) + t.IDENT_RE + "\\s*\\(", v = [
      "alignas",
      "alignof",
      "and",
      "and_eq",
      "asm",
      "atomic_cancel",
      "atomic_commit",
      "atomic_noexcept",
      "auto",
      "bitand",
      "bitor",
      "break",
      "case",
      "catch",
      "class",
      "co_await",
      "co_return",
      "co_yield",
      "compl",
      "concept",
      "const_cast|10",
      "consteval",
      "constexpr",
      "constinit",
      "continue",
      "decltype",
      "default",
      "delete",
      "do",
      "dynamic_cast|10",
      "else",
      "enum",
      "explicit",
      "export",
      "extern",
      "false",
      "final",
      "for",
      "friend",
      "goto",
      "if",
      "import",
      "inline",
      "module",
      "mutable",
      "namespace",
      "new",
      "noexcept",
      "not",
      "not_eq",
      "nullptr",
      "operator",
      "or",
      "or_eq",
      "override",
      "private",
      "protected",
      "public",
      "reflexpr",
      "register",
      "reinterpret_cast|10",
      "requires",
      "return",
      "sizeof",
      "static_assert",
      "static_cast|10",
      "struct",
      "switch",
      "synchronized",
      "template",
      "this",
      "thread_local",
      "throw",
      "transaction_safe",
      "transaction_safe_dynamic",
      "true",
      "try",
      "typedef",
      "typeid",
      "typename",
      "union",
      "using",
      "virtual",
      "volatile",
      "while",
      "xor",
      "xor_eq"
    ], b = [
      "bool",
      "char",
      "char16_t",
      "char32_t",
      "char8_t",
      "double",
      "float",
      "int",
      "long",
      "short",
      "void",
      "wchar_t",
      "unsigned",
      "signed",
      "const",
      "static"
    ], y = [
      "any",
      "auto_ptr",
      "barrier",
      "binary_semaphore",
      "bitset",
      "complex",
      "condition_variable",
      "condition_variable_any",
      "counting_semaphore",
      "deque",
      "false_type",
      "future",
      "imaginary",
      "initializer_list",
      "istringstream",
      "jthread",
      "latch",
      "lock_guard",
      "multimap",
      "multiset",
      "mutex",
      "optional",
      "ostringstream",
      "packaged_task",
      "pair",
      "promise",
      "priority_queue",
      "queue",
      "recursive_mutex",
      "recursive_timed_mutex",
      "scoped_lock",
      "set",
      "shared_future",
      "shared_lock",
      "shared_mutex",
      "shared_timed_mutex",
      "shared_ptr",
      "stack",
      "string_view",
      "stringstream",
      "timed_mutex",
      "thread",
      "true_type",
      "tuple",
      "unique_lock",
      "unique_ptr",
      "unordered_map",
      "unordered_multimap",
      "unordered_multiset",
      "unordered_set",
      "variant",
      "vector",
      "weak_ptr",
      "wstring",
      "wstring_view"
    ], g = [
      "abort",
      "abs",
      "acos",
      "apply",
      "as_const",
      "asin",
      "atan",
      "atan2",
      "calloc",
      "ceil",
      "cerr",
      "cin",
      "clog",
      "cos",
      "cosh",
      "cout",
      "declval",
      "endl",
      "exchange",
      "exit",
      "exp",
      "fabs",
      "floor",
      "fmod",
      "forward",
      "fprintf",
      "fputs",
      "free",
      "frexp",
      "fscanf",
      "future",
      "invoke",
      "isalnum",
      "isalpha",
      "iscntrl",
      "isdigit",
      "isgraph",
      "islower",
      "isprint",
      "ispunct",
      "isspace",
      "isupper",
      "isxdigit",
      "labs",
      "launder",
      "ldexp",
      "log",
      "log10",
      "make_pair",
      "make_shared",
      "make_shared_for_overwrite",
      "make_tuple",
      "make_unique",
      "malloc",
      "memchr",
      "memcmp",
      "memcpy",
      "memset",
      "modf",
      "move",
      "pow",
      "printf",
      "putchar",
      "puts",
      "realloc",
      "scanf",
      "sin",
      "sinh",
      "snprintf",
      "sprintf",
      "sqrt",
      "sscanf",
      "std",
      "stderr",
      "stdin",
      "stdout",
      "strcat",
      "strchr",
      "strcmp",
      "strcpy",
      "strcspn",
      "strlen",
      "strncat",
      "strncmp",
      "strncpy",
      "strpbrk",
      "strrchr",
      "strspn",
      "strstr",
      "swap",
      "tan",
      "tanh",
      "terminate",
      "to_underlying",
      "tolower",
      "toupper",
      "vfprintf",
      "visit",
      "vprintf",
      "vsprintf"
    ], C = {
      type: b,
      keyword: v,
      literal: [
        "NULL",
        "false",
        "nullopt",
        "nullptr",
        "true"
      ],
      built_in: ["_Pragma"],
      _type_hints: y
    }, T = {
      className: "function.dispatch",
      relevance: 0,
      keywords: {
        // Only for relevance, not highlighting.
        _hint: g
      },
      begin: n.concat(
        /\b/,
        /(?!decltype)/,
        /(?!if)/,
        /(?!for)/,
        /(?!switch)/,
        /(?!while)/,
        t.IDENT_RE,
        n.lookahead(/(<[^<>]+>|)\s*\(/)
      )
    }, O = [
      T,
      f,
      l,
      r,
      t.C_BLOCK_COMMENT_MODE,
      d,
      c
    ], R = {
      // This mode covers expression context where we can't expect a function
      // definition and shouldn't highlight anything that looks like one:
      // `return some()`, `else if()`, `(x*sum(1, 2))`
      variants: [
        {
          begin: /=/,
          end: /;/
        },
        {
          begin: /\(/,
          end: /\)/
        },
        {
          beginKeywords: "new throw return else",
          end: /;/
        }
      ],
      keywords: C,
      contains: O.concat([
        {
          begin: /\(/,
          end: /\)/,
          keywords: C,
          contains: O.concat(["self"]),
          relevance: 0
        }
      ]),
      relevance: 0
    }, D = {
      className: "function",
      begin: "(" + s + "[\\*&\\s]+)+" + m,
      returnBegin: !0,
      end: /[{;=]/,
      excludeEnd: !0,
      keywords: C,
      illegal: /[^\w\s\*&:<>.]/,
      contains: [
        {
          // to prevent it from being confused as the function title
          begin: i,
          keywords: C,
          relevance: 0
        },
        {
          begin: m,
          returnBegin: !0,
          contains: [h],
          relevance: 0
        },
        // needed because we do not have look-behind on the below rule
        // to prevent it from grabbing the final : in a :: pair
        {
          begin: /::/,
          relevance: 0
        },
        // initializers
        {
          begin: /:/,
          endsWithParent: !0,
          contains: [
            c,
            d
          ]
        },
        // allow for multiple declarations, e.g.:
        // extern void f(int), g(char);
        {
          relevance: 0,
          match: /,/
        },
        {
          className: "params",
          begin: /\(/,
          end: /\)/,
          keywords: C,
          relevance: 0,
          contains: [
            r,
            t.C_BLOCK_COMMENT_MODE,
            c,
            d,
            l,
            // Count matching parentheses.
            {
              begin: /\(/,
              end: /\)/,
              keywords: C,
              relevance: 0,
              contains: [
                "self",
                r,
                t.C_BLOCK_COMMENT_MODE,
                c,
                d,
                l
              ]
            }
          ]
        },
        l,
        r,
        t.C_BLOCK_COMMENT_MODE,
        f
      ]
    };
    return {
      name: "C++",
      aliases: [
        "cc",
        "c++",
        "h++",
        "hpp",
        "hh",
        "hxx",
        "cxx"
      ],
      keywords: C,
      illegal: "</",
      classNameAliases: { "function.dispatch": "built_in" },
      contains: [].concat(
        R,
        D,
        T,
        O,
        [
          f,
          {
            // containers: ie, `vector <int> rooms (9);`
            begin: "\\b(deque|list|queue|priority_queue|pair|stack|vector|map|set|bitset|multiset|multimap|unordered_map|unordered_set|unordered_multiset|unordered_multimap|array|tuple|optional|variant|function)\\s*<(?!<)",
            end: ">",
            keywords: C,
            contains: [
              "self",
              l
            ]
          },
          {
            begin: t.IDENT_RE + "::",
            keywords: C
          },
          {
            match: [
              // extra complexity to deal with `enum class` and `enum struct`
              /\b(?:enum(?:\s+(?:class|struct))?|class|struct|union)/,
              /\s+/,
              /\w+/
            ],
            className: {
              1: "keyword",
              3: "title.class"
            }
          }
        ]
      )
    };
  }
  return X0 = e, X0;
}
var Z0, aD;
function pZ() {
  if (aD) return Z0;
  aD = 1;
  function e(t) {
    const n = "primitive rsc_template", r = "group clone ms master location colocation order fencing_topology rsc_ticket acl_target acl_group user role tag xml";
    return {
      name: "crmsh",
      aliases: [
        "crm",
        "pcmk"
      ],
      case_insensitive: !0,
      keywords: {
        keyword: "params meta operations op rule attributes utilization" + " " + "read write deny defined not_defined in_range date spec in ref reference attribute type xpath version and or lt gt tag lte gte eq ne \\" + " " + "number string",
        literal: "Master Started Slave Stopped start promote demote stop monitor true false"
      },
      contains: [
        t.HASH_COMMENT_MODE,
        {
          beginKeywords: "node",
          starts: {
            end: "\\s*([\\w_-]+:)?",
            starts: {
              className: "title",
              end: "\\s*[\\$\\w_][\\w_-]*"
            }
          }
        },
        {
          beginKeywords: n,
          starts: {
            className: "title",
            end: "\\s*[\\$\\w_][\\w_-]*",
            starts: { end: "\\s*@?[\\w_][\\w_\\.:-]*" }
          }
        },
        {
          begin: "\\b(" + r.split(" ").join("|") + ")\\s+",
          keywords: r,
          starts: {
            className: "title",
            end: "[\\$\\w_][\\w_-]*"
          }
        },
        {
          beginKeywords: "property rsc_defaults op_defaults",
          starts: {
            className: "title",
            end: "\\s*([\\w_-]+:)?"
          }
        },
        t.QUOTE_STRING_MODE,
        {
          className: "meta",
          begin: "(ocf|systemd|service|lsb):[\\w_:-]+",
          relevance: 0
        },
        {
          className: "number",
          begin: "\\b\\d+(\\.\\d+)?(ms|s|h|m)?",
          relevance: 0
        },
        {
          className: "literal",
          begin: "[-]?(infinity|inf)",
          relevance: 0
        },
        {
          className: "attr",
          begin: /([A-Za-z$_#][\w_-]+)=/,
          relevance: 0
        },
        {
          className: "tag",
          begin: "</?",
          end: "/?>",
          relevance: 0
        }
      ]
    };
  }
  return Z0 = e, Z0;
}
var J0, oD;
function mZ() {
  if (oD) return J0;
  oD = 1;
  function e(t) {
    const n = "(_?[ui](8|16|32|64|128))?", r = "(_?f(32|64))?", i = "[a-zA-Z_]\\w*[!?=]?", a = "[a-zA-Z_]\\w*[!?=]?|[-+~]@|<<|>>|[=!]~|===?|<=>|[<>]=?|\\*\\*|[-/+%^&*~|]|//|//=|&[-+*]=?|&\\*\\*|\\[\\][=?]?", o = "[A-Za-z_]\\w*(::\\w+)*(\\?|!)?", s = {
      $pattern: i,
      keyword: "abstract alias annotation as as? asm begin break case class def do else elsif end ensure enum extend for fun if include instance_sizeof is_a? lib macro module next nil? of out pointerof private protected rescue responds_to? return require select self sizeof struct super then type typeof union uninitialized unless until verbatim when while with yield __DIR__ __END_LINE__ __FILE__ __LINE__",
      literal: "false nil true"
    }, l = {
      className: "subst",
      begin: /#\{/,
      end: /\}/,
      keywords: s
    }, u = {
      // negative-look forward attemps to prevent false matches like:
      // @ident@ or $ident$ that might indicate this is not ruby at all
      className: "variable",
      begin: "(\\$\\W)|((\\$|@@?)(\\w+))(?=[^@$?])(?![A-Za-z])(?![@$?'])"
    }, c = {
      className: "template-variable",
      variants: [
        {
          begin: "\\{\\{",
          end: "\\}\\}"
        },
        {
          begin: "\\{%",
          end: "%\\}"
        }
      ],
      keywords: s
    };
    function d(g, E) {
      const S = [
        {
          begin: g,
          end: E
        }
      ];
      return S[0].contains = S, S;
    }
    const f = {
      className: "string",
      contains: [
        t.BACKSLASH_ESCAPE,
        l
      ],
      variants: [
        {
          begin: /'/,
          end: /'/
        },
        {
          begin: /"/,
          end: /"/
        },
        {
          begin: /`/,
          end: /`/
        },
        {
          begin: "%[Qwi]?\\(",
          end: "\\)",
          contains: d("\\(", "\\)")
        },
        {
          begin: "%[Qwi]?\\[",
          end: "\\]",
          contains: d("\\[", "\\]")
        },
        {
          begin: "%[Qwi]?\\{",
          end: /\}/,
          contains: d(/\{/, /\}/)
        },
        {
          begin: "%[Qwi]?<",
          end: ">",
          contains: d("<", ">")
        },
        {
          begin: "%[Qwi]?\\|",
          end: "\\|"
        },
        {
          begin: /<<-\w+$/,
          end: /^\s*\w+$/
        }
      ],
      relevance: 0
    }, h = {
      className: "string",
      variants: [
        {
          begin: "%q\\(",
          end: "\\)",
          contains: d("\\(", "\\)")
        },
        {
          begin: "%q\\[",
          end: "\\]",
          contains: d("\\[", "\\]")
        },
        {
          begin: "%q\\{",
          end: /\}/,
          contains: d(/\{/, /\}/)
        },
        {
          begin: "%q<",
          end: ">",
          contains: d("<", ">")
        },
        {
          begin: "%q\\|",
          end: "\\|"
        },
        {
          begin: /<<-'\w+'$/,
          end: /^\s*\w+$/
        }
      ],
      relevance: 0
    }, m = {
      begin: "(?!%\\})(" + t.RE_STARTERS_RE + "|\\n|\\b(case|if|select|unless|until|when|while)\\b)\\s*",
      keywords: "case if select unless until when while",
      contains: [
        {
          className: "regexp",
          contains: [
            t.BACKSLASH_ESCAPE,
            l
          ],
          variants: [
            {
              begin: "//[a-z]*",
              relevance: 0
            },
            {
              begin: "/(?!\\/)",
              end: "/[a-z]*"
            }
          ]
        }
      ],
      relevance: 0
    }, v = {
      className: "regexp",
      contains: [
        t.BACKSLASH_ESCAPE,
        l
      ],
      variants: [
        {
          begin: "%r\\(",
          end: "\\)",
          contains: d("\\(", "\\)")
        },
        {
          begin: "%r\\[",
          end: "\\]",
          contains: d("\\[", "\\]")
        },
        {
          begin: "%r\\{",
          end: /\}/,
          contains: d(/\{/, /\}/)
        },
        {
          begin: "%r<",
          end: ">",
          contains: d("<", ">")
        },
        {
          begin: "%r\\|",
          end: "\\|"
        }
      ],
      relevance: 0
    }, b = {
      className: "meta",
      begin: "@\\[",
      end: "\\]",
      contains: [t.inherit(t.QUOTE_STRING_MODE, { className: "string" })]
    }, y = [
      c,
      f,
      h,
      v,
      m,
      b,
      u,
      t.HASH_COMMENT_MODE,
      {
        className: "class",
        beginKeywords: "class module struct",
        end: "$|;",
        illegal: /=/,
        contains: [
          t.HASH_COMMENT_MODE,
          t.inherit(t.TITLE_MODE, { begin: o }),
          {
            // relevance booster for inheritance
            begin: "<"
          }
        ]
      },
      {
        className: "class",
        beginKeywords: "lib enum union",
        end: "$|;",
        illegal: /=/,
        contains: [
          t.HASH_COMMENT_MODE,
          t.inherit(t.TITLE_MODE, { begin: o })
        ]
      },
      {
        beginKeywords: "annotation",
        end: "$|;",
        illegal: /=/,
        contains: [
          t.HASH_COMMENT_MODE,
          t.inherit(t.TITLE_MODE, { begin: o })
        ],
        relevance: 2
      },
      {
        className: "function",
        beginKeywords: "def",
        end: /\B\b/,
        contains: [
          t.inherit(t.TITLE_MODE, {
            begin: a,
            endsParent: !0
          })
        ]
      },
      {
        className: "function",
        beginKeywords: "fun macro",
        end: /\B\b/,
        contains: [
          t.inherit(t.TITLE_MODE, {
            begin: a,
            endsParent: !0
          })
        ],
        relevance: 2
      },
      {
        className: "symbol",
        begin: t.UNDERSCORE_IDENT_RE + "(!|\\?)?:",
        relevance: 0
      },
      {
        className: "symbol",
        begin: ":",
        contains: [
          f,
          { begin: a }
        ],
        relevance: 0
      },
      {
        className: "number",
        variants: [
          { begin: "\\b0b([01_]+)" + n },
          { begin: "\\b0o([0-7_]+)" + n },
          { begin: "\\b0x([A-Fa-f0-9_]+)" + n },
          { begin: "\\b([1-9][0-9_]*[0-9]|[0-9])(\\.[0-9][0-9_]*)?([eE]_?[-+]?[0-9_]*)?" + r + "(?!_)" },
          { begin: "\\b([1-9][0-9_]*|0)" + n }
        ],
        relevance: 0
      }
    ];
    return l.contains = y, c.contains = y.slice(1), {
      name: "Crystal",
      aliases: ["cr"],
      keywords: s,
      contains: y
    };
  }
  return J0 = e, J0;
}
var eE, sD;
function hZ() {
  if (sD) return eE;
  sD = 1;
  function e(t) {
    const n = [
      "bool",
      "byte",
      "char",
      "decimal",
      "delegate",
      "double",
      "dynamic",
      "enum",
      "float",
      "int",
      "long",
      "nint",
      "nuint",
      "object",
      "sbyte",
      "short",
      "string",
      "ulong",
      "uint",
      "ushort"
    ], r = [
      "public",
      "private",
      "protected",
      "static",
      "internal",
      "protected",
      "abstract",
      "async",
      "extern",
      "override",
      "unsafe",
      "virtual",
      "new",
      "sealed",
      "partial"
    ], i = [
      "default",
      "false",
      "null",
      "true"
    ], a = [
      "abstract",
      "as",
      "base",
      "break",
      "case",
      "catch",
      "class",
      "const",
      "continue",
      "do",
      "else",
      "event",
      "explicit",
      "extern",
      "finally",
      "fixed",
      "for",
      "foreach",
      "goto",
      "if",
      "implicit",
      "in",
      "interface",
      "internal",
      "is",
      "lock",
      "namespace",
      "new",
      "operator",
      "out",
      "override",
      "params",
      "private",
      "protected",
      "public",
      "readonly",
      "record",
      "ref",
      "return",
      "scoped",
      "sealed",
      "sizeof",
      "stackalloc",
      "static",
      "struct",
      "switch",
      "this",
      "throw",
      "try",
      "typeof",
      "unchecked",
      "unsafe",
      "using",
      "virtual",
      "void",
      "volatile",
      "while"
    ], o = [
      "add",
      "alias",
      "and",
      "ascending",
      "async",
      "await",
      "by",
      "descending",
      "equals",
      "from",
      "get",
      "global",
      "group",
      "init",
      "into",
      "join",
      "let",
      "nameof",
      "not",
      "notnull",
      "on",
      "or",
      "orderby",
      "partial",
      "remove",
      "select",
      "set",
      "unmanaged",
      "value|0",
      "var",
      "when",
      "where",
      "with",
      "yield"
    ], s = {
      keyword: a.concat(o),
      built_in: n,
      literal: i
    }, l = t.inherit(t.TITLE_MODE, { begin: "[a-zA-Z](\\.?\\w)*" }), u = {
      className: "number",
      variants: [
        { begin: "\\b(0b[01']+)" },
        { begin: "(-?)\\b([\\d']+(\\.[\\d']*)?|\\.[\\d']+)(u|U|l|L|ul|UL|f|F|b|B)" },
        { begin: "(-?)(\\b0[xX][a-fA-F0-9']+|(\\b[\\d']+(\\.[\\d']*)?|\\.[\\d']+)([eE][-+]?[\\d']+)?)" }
      ],
      relevance: 0
    }, c = {
      className: "string",
      begin: '@"',
      end: '"',
      contains: [{ begin: '""' }]
    }, d = t.inherit(c, { illegal: /\n/ }), f = {
      className: "subst",
      begin: /\{/,
      end: /\}/,
      keywords: s
    }, h = t.inherit(f, { illegal: /\n/ }), m = {
      className: "string",
      begin: /\$"/,
      end: '"',
      illegal: /\n/,
      contains: [
        { begin: /\{\{/ },
        { begin: /\}\}/ },
        t.BACKSLASH_ESCAPE,
        h
      ]
    }, v = {
      className: "string",
      begin: /\$@"/,
      end: '"',
      contains: [
        { begin: /\{\{/ },
        { begin: /\}\}/ },
        { begin: '""' },
        f
      ]
    }, b = t.inherit(v, {
      illegal: /\n/,
      contains: [
        { begin: /\{\{/ },
        { begin: /\}\}/ },
        { begin: '""' },
        h
      ]
    });
    f.contains = [
      v,
      m,
      c,
      t.APOS_STRING_MODE,
      t.QUOTE_STRING_MODE,
      u,
      t.C_BLOCK_COMMENT_MODE
    ], h.contains = [
      b,
      m,
      d,
      t.APOS_STRING_MODE,
      t.QUOTE_STRING_MODE,
      u,
      t.inherit(t.C_BLOCK_COMMENT_MODE, { illegal: /\n/ })
    ];
    const y = { variants: [
      v,
      m,
      c,
      t.APOS_STRING_MODE,
      t.QUOTE_STRING_MODE
    ] }, g = {
      begin: "<",
      end: ">",
      contains: [
        { beginKeywords: "in out" },
        l
      ]
    }, E = t.IDENT_RE + "(<" + t.IDENT_RE + "(\\s*,\\s*" + t.IDENT_RE + ")*>)?(\\[\\])?", S = {
      // prevents expressions like `@class` from incorrect flagging
      // `class` as a keyword
      begin: "@" + t.IDENT_RE,
      relevance: 0
    };
    return {
      name: "C#",
      aliases: [
        "cs",
        "c#"
      ],
      keywords: s,
      illegal: /::/,
      contains: [
        t.COMMENT(
          "///",
          "$",
          {
            returnBegin: !0,
            contains: [
              {
                className: "doctag",
                variants: [
                  {
                    begin: "///",
                    relevance: 0
                  },
                  { begin: "<!--|-->" },
                  {
                    begin: "</?",
                    end: ">"
                  }
                ]
              }
            ]
          }
        ),
        t.C_LINE_COMMENT_MODE,
        t.C_BLOCK_COMMENT_MODE,
        {
          className: "meta",
          begin: "#",
          end: "$",
          keywords: { keyword: "if else elif endif define undef warning error line region endregion pragma checksum" }
        },
        y,
        u,
        {
          beginKeywords: "class interface",
          relevance: 0,
          end: /[{;=]/,
          illegal: /[^\s:,]/,
          contains: [
            { beginKeywords: "where class" },
            l,
            g,
            t.C_LINE_COMMENT_MODE,
            t.C_BLOCK_COMMENT_MODE
          ]
        },
        {
          beginKeywords: "namespace",
          relevance: 0,
          end: /[{;=]/,
          illegal: /[^\s:]/,
          contains: [
            l,
            t.C_LINE_COMMENT_MODE,
            t.C_BLOCK_COMMENT_MODE
          ]
        },
        {
          beginKeywords: "record",
          relevance: 0,
          end: /[{;=]/,
          illegal: /[^\s:]/,
          contains: [
            l,
            g,
            t.C_LINE_COMMENT_MODE,
            t.C_BLOCK_COMMENT_MODE
          ]
        },
        {
          // [Attributes("")]
          className: "meta",
          begin: "^\\s*\\[(?=[\\w])",
          excludeBegin: !0,
          end: "\\]",
          excludeEnd: !0,
          contains: [
            {
              className: "string",
              begin: /"/,
              end: /"/
            }
          ]
        },
        {
          // Expression keywords prevent 'keyword Name(...)' from being
          // recognized as a function definition
          beginKeywords: "new return throw await else",
          relevance: 0
        },
        {
          className: "function",
          begin: "(" + E + "\\s+)+" + t.IDENT_RE + "\\s*(<[^=]+>\\s*)?\\(",
          returnBegin: !0,
          end: /\s*[{;=]/,
          excludeEnd: !0,
          keywords: s,
          contains: [
            // prevents these from being highlighted `title`
            {
              beginKeywords: r.join(" "),
              relevance: 0
            },
            {
              begin: t.IDENT_RE + "\\s*(<[^=]+>\\s*)?\\(",
              returnBegin: !0,
              contains: [
                t.TITLE_MODE,
                g
              ],
              relevance: 0
            },
            { match: /\(\)/ },
            {
              className: "params",
              begin: /\(/,
              end: /\)/,
              excludeBegin: !0,
              excludeEnd: !0,
              keywords: s,
              relevance: 0,
              contains: [
                y,
                u,
                t.C_BLOCK_COMMENT_MODE
              ]
            },
            t.C_LINE_COMMENT_MODE,
            t.C_BLOCK_COMMENT_MODE
          ]
        },
        S
      ]
    };
  }
  return eE = e, eE;
}
var tE, lD;
function gZ() {
  if (lD) return tE;
  lD = 1;
  function e(t) {
    return {
      name: "CSP",
      case_insensitive: !1,
      keywords: {
        $pattern: "[a-zA-Z][a-zA-Z0-9_-]*",
        keyword: [
          "base-uri",
          "child-src",
          "connect-src",
          "default-src",
          "font-src",
          "form-action",
          "frame-ancestors",
          "frame-src",
          "img-src",
          "manifest-src",
          "media-src",
          "object-src",
          "plugin-types",
          "report-uri",
          "sandbox",
          "script-src",
          "style-src",
          "trusted-types",
          "unsafe-hashes",
          "worker-src"
        ]
      },
      contains: [
        {
          className: "string",
          begin: "'",
          end: "'"
        },
        {
          className: "attribute",
          begin: "^Content",
          end: ":",
          excludeEnd: !0
        }
      ]
    };
  }
  return tE = e, tE;
}
var nE, uD;
function _Z() {
  if (uD) return nE;
  uD = 1;
  const e = (s) => ({
    IMPORTANT: {
      scope: "meta",
      begin: "!important"
    },
    BLOCK_COMMENT: s.C_BLOCK_COMMENT_MODE,
    HEXCOLOR: {
      scope: "number",
      begin: /#(([0-9a-fA-F]{3,4})|(([0-9a-fA-F]{2}){3,4}))\b/
    },
    FUNCTION_DISPATCH: {
      className: "built_in",
      begin: /[\w-]+(?=\()/
    },
    ATTRIBUTE_SELECTOR_MODE: {
      scope: "selector-attr",
      begin: /\[/,
      end: /\]/,
      illegal: "$",
      contains: [
        s.APOS_STRING_MODE,
        s.QUOTE_STRING_MODE
      ]
    },
    CSS_NUMBER_MODE: {
      scope: "number",
      begin: s.NUMBER_RE + "(%|em|ex|ch|rem|vw|vh|vmin|vmax|cm|mm|in|pt|pc|px|deg|grad|rad|turn|s|ms|Hz|kHz|dpi|dpcm|dppx)?",
      relevance: 0
    },
    CSS_VARIABLE: {
      className: "attr",
      begin: /--[A-Za-z_][A-Za-z0-9_-]*/
    }
  }), t = [
    "a",
    "abbr",
    "address",
    "article",
    "aside",
    "audio",
    "b",
    "blockquote",
    "body",
    "button",
    "canvas",
    "caption",
    "cite",
    "code",
    "dd",
    "del",
    "details",
    "dfn",
    "div",
    "dl",
    "dt",
    "em",
    "fieldset",
    "figcaption",
    "figure",
    "footer",
    "form",
    "h1",
    "h2",
    "h3",
    "h4",
    "h5",
    "h6",
    "header",
    "hgroup",
    "html",
    "i",
    "iframe",
    "img",
    "input",
    "ins",
    "kbd",
    "label",
    "legend",
    "li",
    "main",
    "mark",
    "menu",
    "nav",
    "object",
    "ol",
    "p",
    "q",
    "quote",
    "samp",
    "section",
    "span",
    "strong",
    "summary",
    "sup",
    "table",
    "tbody",
    "td",
    "textarea",
    "tfoot",
    "th",
    "thead",
    "time",
    "tr",
    "ul",
    "var",
    "video"
  ], n = [
    "any-hover",
    "any-pointer",
    "aspect-ratio",
    "color",
    "color-gamut",
    "color-index",
    "device-aspect-ratio",
    "device-height",
    "device-width",
    "display-mode",
    "forced-colors",
    "grid",
    "height",
    "hover",
    "inverted-colors",
    "monochrome",
    "orientation",
    "overflow-block",
    "overflow-inline",
    "pointer",
    "prefers-color-scheme",
    "prefers-contrast",
    "prefers-reduced-motion",
    "prefers-reduced-transparency",
    "resolution",
    "scan",
    "scripting",
    "update",
    "width",
    // TODO: find a better solution?
    "min-width",
    "max-width",
    "min-height",
    "max-height"
  ], r = [
    "active",
    "any-link",
    "blank",
    "checked",
    "current",
    "default",
    "defined",
    "dir",
    // dir()
    "disabled",
    "drop",
    "empty",
    "enabled",
    "first",
    "first-child",
    "first-of-type",
    "fullscreen",
    "future",
    "focus",
    "focus-visible",
    "focus-within",
    "has",
    // has()
    "host",
    // host or host()
    "host-context",
    // host-context()
    "hover",
    "indeterminate",
    "in-range",
    "invalid",
    "is",
    // is()
    "lang",
    // lang()
    "last-child",
    "last-of-type",
    "left",
    "link",
    "local-link",
    "not",
    // not()
    "nth-child",
    // nth-child()
    "nth-col",
    // nth-col()
    "nth-last-child",
    // nth-last-child()
    "nth-last-col",
    // nth-last-col()
    "nth-last-of-type",
    //nth-last-of-type()
    "nth-of-type",
    //nth-of-type()
    "only-child",
    "only-of-type",
    "optional",
    "out-of-range",
    "past",
    "placeholder-shown",
    "read-only",
    "read-write",
    "required",
    "right",
    "root",
    "scope",
    "target",
    "target-within",
    "user-invalid",
    "valid",
    "visited",
    "where"
    // where()
  ], i = [
    "after",
    "backdrop",
    "before",
    "cue",
    "cue-region",
    "first-letter",
    "first-line",
    "grammar-error",
    "marker",
    "part",
    "placeholder",
    "selection",
    "slotted",
    "spelling-error"
  ], a = [
    "align-content",
    "align-items",
    "align-self",
    "all",
    "animation",
    "animation-delay",
    "animation-direction",
    "animation-duration",
    "animation-fill-mode",
    "animation-iteration-count",
    "animation-name",
    "animation-play-state",
    "animation-timing-function",
    "backface-visibility",
    "background",
    "background-attachment",
    "background-blend-mode",
    "background-clip",
    "background-color",
    "background-image",
    "background-origin",
    "background-position",
    "background-repeat",
    "background-size",
    "block-size",
    "border",
    "border-block",
    "border-block-color",
    "border-block-end",
    "border-block-end-color",
    "border-block-end-style",
    "border-block-end-width",
    "border-block-start",
    "border-block-start-color",
    "border-block-start-style",
    "border-block-start-width",
    "border-block-style",
    "border-block-width",
    "border-bottom",
    "border-bottom-color",
    "border-bottom-left-radius",
    "border-bottom-right-radius",
    "border-bottom-style",
    "border-bottom-width",
    "border-collapse",
    "border-color",
    "border-image",
    "border-image-outset",
    "border-image-repeat",
    "border-image-slice",
    "border-image-source",
    "border-image-width",
    "border-inline",
    "border-inline-color",
    "border-inline-end",
    "border-inline-end-color",
    "border-inline-end-style",
    "border-inline-end-width",
    "border-inline-start",
    "border-inline-start-color",
    "border-inline-start-style",
    "border-inline-start-width",
    "border-inline-style",
    "border-inline-width",
    "border-left",
    "border-left-color",
    "border-left-style",
    "border-left-width",
    "border-radius",
    "border-right",
    "border-right-color",
    "border-right-style",
    "border-right-width",
    "border-spacing",
    "border-style",
    "border-top",
    "border-top-color",
    "border-top-left-radius",
    "border-top-right-radius",
    "border-top-style",
    "border-top-width",
    "border-width",
    "bottom",
    "box-decoration-break",
    "box-shadow",
    "box-sizing",
    "break-after",
    "break-before",
    "break-inside",
    "caption-side",
    "caret-color",
    "clear",
    "clip",
    "clip-path",
    "clip-rule",
    "color",
    "column-count",
    "column-fill",
    "column-gap",
    "column-rule",
    "column-rule-color",
    "column-rule-style",
    "column-rule-width",
    "column-span",
    "column-width",
    "columns",
    "contain",
    "content",
    "content-visibility",
    "counter-increment",
    "counter-reset",
    "cue",
    "cue-after",
    "cue-before",
    "cursor",
    "direction",
    "display",
    "empty-cells",
    "filter",
    "flex",
    "flex-basis",
    "flex-direction",
    "flex-flow",
    "flex-grow",
    "flex-shrink",
    "flex-wrap",
    "float",
    "flow",
    "font",
    "font-display",
    "font-family",
    "font-feature-settings",
    "font-kerning",
    "font-language-override",
    "font-size",
    "font-size-adjust",
    "font-smoothing",
    "font-stretch",
    "font-style",
    "font-synthesis",
    "font-variant",
    "font-variant-caps",
    "font-variant-east-asian",
    "font-variant-ligatures",
    "font-variant-numeric",
    "font-variant-position",
    "font-variation-settings",
    "font-weight",
    "gap",
    "glyph-orientation-vertical",
    "grid",
    "grid-area",
    "grid-auto-columns",
    "grid-auto-flow",
    "grid-auto-rows",
    "grid-column",
    "grid-column-end",
    "grid-column-start",
    "grid-gap",
    "grid-row",
    "grid-row-end",
    "grid-row-start",
    "grid-template",
    "grid-template-areas",
    "grid-template-columns",
    "grid-template-rows",
    "hanging-punctuation",
    "height",
    "hyphens",
    "icon",
    "image-orientation",
    "image-rendering",
    "image-resolution",
    "ime-mode",
    "inline-size",
    "isolation",
    "justify-content",
    "left",
    "letter-spacing",
    "line-break",
    "line-height",
    "list-style",
    "list-style-image",
    "list-style-position",
    "list-style-type",
    "margin",
    "margin-block",
    "margin-block-end",
    "margin-block-start",
    "margin-bottom",
    "margin-inline",
    "margin-inline-end",
    "margin-inline-start",
    "margin-left",
    "margin-right",
    "margin-top",
    "marks",
    "mask",
    "mask-border",
    "mask-border-mode",
    "mask-border-outset",
    "mask-border-repeat",
    "mask-border-slice",
    "mask-border-source",
    "mask-border-width",
    "mask-clip",
    "mask-composite",
    "mask-image",
    "mask-mode",
    "mask-origin",
    "mask-position",
    "mask-repeat",
    "mask-size",
    "mask-type",
    "max-block-size",
    "max-height",
    "max-inline-size",
    "max-width",
    "min-block-size",
    "min-height",
    "min-inline-size",
    "min-width",
    "mix-blend-mode",
    "nav-down",
    "nav-index",
    "nav-left",
    "nav-right",
    "nav-up",
    "none",
    "normal",
    "object-fit",
    "object-position",
    "opacity",
    "order",
    "orphans",
    "outline",
    "outline-color",
    "outline-offset",
    "outline-style",
    "outline-width",
    "overflow",
    "overflow-wrap",
    "overflow-x",
    "overflow-y",
    "padding",
    "padding-block",
    "padding-block-end",
    "padding-block-start",
    "padding-bottom",
    "padding-inline",
    "padding-inline-end",
    "padding-inline-start",
    "padding-left",
    "padding-right",
    "padding-top",
    "page-break-after",
    "page-break-before",
    "page-break-inside",
    "pause",
    "pause-after",
    "pause-before",
    "perspective",
    "perspective-origin",
    "pointer-events",
    "position",
    "quotes",
    "resize",
    "rest",
    "rest-after",
    "rest-before",
    "right",
    "row-gap",
    "scroll-margin",
    "scroll-margin-block",
    "scroll-margin-block-end",
    "scroll-margin-block-start",
    "scroll-margin-bottom",
    "scroll-margin-inline",
    "scroll-margin-inline-end",
    "scroll-margin-inline-start",
    "scroll-margin-left",
    "scroll-margin-right",
    "scroll-margin-top",
    "scroll-padding",
    "scroll-padding-block",
    "scroll-padding-block-end",
    "scroll-padding-block-start",
    "scroll-padding-bottom",
    "scroll-padding-inline",
    "scroll-padding-inline-end",
    "scroll-padding-inline-start",
    "scroll-padding-left",
    "scroll-padding-right",
    "scroll-padding-top",
    "scroll-snap-align",
    "scroll-snap-stop",
    "scroll-snap-type",
    "scrollbar-color",
    "scrollbar-gutter",
    "scrollbar-width",
    "shape-image-threshold",
    "shape-margin",
    "shape-outside",
    "speak",
    "speak-as",
    "src",
    // @font-face
    "tab-size",
    "table-layout",
    "text-align",
    "text-align-all",
    "text-align-last",
    "text-combine-upright",
    "text-decoration",
    "text-decoration-color",
    "text-decoration-line",
    "text-decoration-style",
    "text-emphasis",
    "text-emphasis-color",
    "text-emphasis-position",
    "text-emphasis-style",
    "text-indent",
    "text-justify",
    "text-orientation",
    "text-overflow",
    "text-rendering",
    "text-shadow",
    "text-transform",
    "text-underline-position",
    "top",
    "transform",
    "transform-box",
    "transform-origin",
    "transform-style",
    "transition",
    "transition-delay",
    "transition-duration",
    "transition-property",
    "transition-timing-function",
    "unicode-bidi",
    "vertical-align",
    "visibility",
    "voice-balance",
    "voice-duration",
    "voice-family",
    "voice-pitch",
    "voice-range",
    "voice-rate",
    "voice-stress",
    "voice-volume",
    "white-space",
    "widows",
    "width",
    "will-change",
    "word-break",
    "word-spacing",
    "word-wrap",
    "writing-mode",
    "z-index"
    // reverse makes sure longer attributes `font-weight` are matched fully
    // instead of getting false positives on say `font`
  ].reverse();
  function o(s) {
    const l = s.regex, u = e(s), c = { begin: /-(webkit|moz|ms|o)-(?=[a-z])/ }, d = "and or not only", f = /@-?\w[\w]*(-\w+)*/, h = "[a-zA-Z-][a-zA-Z0-9_-]*", m = [
      s.APOS_STRING_MODE,
      s.QUOTE_STRING_MODE
    ];
    return {
      name: "CSS",
      case_insensitive: !0,
      illegal: /[=|'\$]/,
      keywords: { keyframePosition: "from to" },
      classNameAliases: {
        // for visual continuity with `tag {}` and because we
        // don't have a great class for this?
        keyframePosition: "selector-tag"
      },
      contains: [
        u.BLOCK_COMMENT,
        c,
        // to recognize keyframe 40% etc which are outside the scope of our
        // attribute value mode
        u.CSS_NUMBER_MODE,
        {
          className: "selector-id",
          begin: /#[A-Za-z0-9_-]+/,
          relevance: 0
        },
        {
          className: "selector-class",
          begin: "\\." + h,
          relevance: 0
        },
        u.ATTRIBUTE_SELECTOR_MODE,
        {
          className: "selector-pseudo",
          variants: [
            { begin: ":(" + r.join("|") + ")" },
            { begin: ":(:)?(" + i.join("|") + ")" }
          ]
        },
        // we may actually need this (12/2020)
        // { // pseudo-selector params
        //   begin: /\(/,
        //   end: /\)/,
        //   contains: [ hljs.CSS_NUMBER_MODE ]
        // },
        u.CSS_VARIABLE,
        {
          className: "attribute",
          begin: "\\b(" + a.join("|") + ")\\b"
        },
        // attribute values
        {
          begin: /:/,
          end: /[;}{]/,
          contains: [
            u.BLOCK_COMMENT,
            u.HEXCOLOR,
            u.IMPORTANT,
            u.CSS_NUMBER_MODE,
            ...m,
            // needed to highlight these as strings and to avoid issues with
            // illegal characters that might be inside urls that would tigger the
            // languages illegal stack
            {
              begin: /(url|data-uri)\(/,
              end: /\)/,
              relevance: 0,
              // from keywords
              keywords: { built_in: "url data-uri" },
              contains: [
                ...m,
                {
                  className: "string",
                  // any character other than `)` as in `url()` will be the start
                  // of a string, which ends with `)` (from the parent mode)
                  begin: /[^)]/,
                  endsWithParent: !0,
                  excludeEnd: !0
                }
              ]
            },
            u.FUNCTION_DISPATCH
          ]
        },
        {
          begin: l.lookahead(/@/),
          end: "[{;]",
          relevance: 0,
          illegal: /:/,
          // break on Less variables @var: ...
          contains: [
            {
              className: "keyword",
              begin: f
            },
            {
              begin: /\s/,
              endsWithParent: !0,
              excludeEnd: !0,
              relevance: 0,
              keywords: {
                $pattern: /[a-z-]+/,
                keyword: d,
                attribute: n.join(" ")
              },
              contains: [
                {
                  begin: /[a-z-]+(?=:)/,
                  className: "attribute"
                },
                ...m,
                u.CSS_NUMBER_MODE
              ]
            }
          ]
        },
        {
          className: "selector-tag",
          begin: "\\b(" + t.join("|") + ")\\b"
        }
      ]
    };
  }
  return nE = o, nE;
}
var rE, cD;
function vZ() {
  if (cD) return rE;
  cD = 1;
  function e(t) {
    const n = {
      $pattern: t.UNDERSCORE_IDENT_RE,
      keyword: "abstract alias align asm assert auto body break byte case cast catch class const continue debug default delete deprecated do else enum export extern final finally for foreach foreach_reverse|10 goto if immutable import in inout int interface invariant is lazy macro mixin module new nothrow out override package pragma private protected public pure ref return scope shared static struct super switch synchronized template this throw try typedef typeid typeof union unittest version void volatile while with __FILE__ __LINE__ __gshared|10 __thread __traits __DATE__ __EOF__ __TIME__ __TIMESTAMP__ __VENDOR__ __VERSION__",
      built_in: "bool cdouble cent cfloat char creal dchar delegate double dstring float function idouble ifloat ireal long real short string ubyte ucent uint ulong ushort wchar wstring",
      literal: "false null true"
    }, r = "(0|[1-9][\\d_]*)", i = "(0|[1-9][\\d_]*|\\d[\\d_]*|[\\d_]+?\\d)", a = "0[bB][01_]+", o = "([\\da-fA-F][\\da-fA-F_]*|_[\\da-fA-F][\\da-fA-F_]*)", s = "0[xX]" + o, l = "([eE][+-]?" + i + ")", u = "(" + i + "(\\.\\d*|" + l + ")|\\d+\\." + i + "|\\." + r + l + "?)", c = "(0[xX](" + o + "\\." + o + "|\\.?" + o + ")[pP][+-]?" + i + ")", d = "(" + r + "|" + a + "|" + s + ")", f = "(" + c + "|" + u + ")", h = `\\\\(['"\\?\\\\abfnrtv]|u[\\dA-Fa-f]{4}|[0-7]{1,3}|x[\\dA-Fa-f]{2}|U[\\dA-Fa-f]{8})|&[a-zA-Z\\d]{2,};`, m = {
      className: "number",
      begin: "\\b" + d + "(L|u|U|Lu|LU|uL|UL)?",
      relevance: 0
    }, v = {
      className: "number",
      begin: "\\b(" + f + "([fF]|L|i|[fF]i|Li)?|" + d + "(i|[fF]i|Li))",
      relevance: 0
    }, b = {
      className: "string",
      begin: "'(" + h + "|.)",
      end: "'",
      illegal: "."
    }, g = {
      className: "string",
      begin: '"',
      contains: [{
        begin: h,
        relevance: 0
      }],
      end: '"[cwd]?'
    }, E = {
      className: "string",
      begin: '[rq]"',
      end: '"[cwd]?',
      relevance: 5
    }, S = {
      className: "string",
      begin: "`",
      end: "`[cwd]?"
    }, C = {
      className: "string",
      begin: 'x"[\\da-fA-F\\s\\n\\r]*"[cwd]?',
      relevance: 10
    }, T = {
      className: "string",
      begin: 'q"\\{',
      end: '\\}"'
    }, O = {
      className: "meta",
      begin: "^#!",
      end: "$",
      relevance: 5
    }, R = {
      className: "meta",
      begin: "#(line)",
      end: "$",
      relevance: 5
    }, D = {
      className: "keyword",
      begin: "@[a-zA-Z_][a-zA-Z_\\d]*"
    }, q = t.COMMENT(
      "\\/\\+",
      "\\+\\/",
      {
        contains: ["self"],
        relevance: 10
      }
    );
    return {
      name: "D",
      keywords: n,
      contains: [
        t.C_LINE_COMMENT_MODE,
        t.C_BLOCK_COMMENT_MODE,
        q,
        C,
        g,
        E,
        S,
        T,
        v,
        m,
        b,
        O,
        R,
        D
      ]
    };
  }
  return rE = e, rE;
}
var iE, dD;
function bZ() {
  if (dD) return iE;
  dD = 1;
  function e(t) {
    const n = t.regex, r = {
      begin: /<\/?[A-Za-z_]/,
      end: ">",
      subLanguage: "xml",
      relevance: 0
    }, i = {
      begin: "^[-\\*]{3,}",
      end: "$"
    }, a = {
      className: "code",
      variants: [
        // TODO: fix to allow these to work with sublanguage also
        { begin: "(`{3,})[^`](.|\\n)*?\\1`*[ ]*" },
        { begin: "(~{3,})[^~](.|\\n)*?\\1~*[ ]*" },
        // needed to allow markdown as a sublanguage to work
        {
          begin: "```",
          end: "```+[ ]*$"
        },
        {
          begin: "~~~",
          end: "~~~+[ ]*$"
        },
        { begin: "`.+?`" },
        {
          begin: "(?=^( {4}|\\t))",
          // use contains to gobble up multiple lines to allow the block to be whatever size
          // but only have a single open/close tag vs one per line
          contains: [
            {
              begin: "^( {4}|\\t)",
              end: "(\\n)$"
            }
          ],
          relevance: 0
        }
      ]
    }, o = {
      className: "bullet",
      begin: "^[ 	]*([*+-]|(\\d+\\.))(?=\\s+)",
      end: "\\s+",
      excludeEnd: !0
    }, s = {
      begin: /^\[[^\n]+\]:/,
      returnBegin: !0,
      contains: [
        {
          className: "symbol",
          begin: /\[/,
          end: /\]/,
          excludeBegin: !0,
          excludeEnd: !0
        },
        {
          className: "link",
          begin: /:\s*/,
          end: /$/,
          excludeBegin: !0
        }
      ]
    }, l = /[A-Za-z][A-Za-z0-9+.-]*/, u = {
      variants: [
        // too much like nested array access in so many languages
        // to have any real relevance
        {
          begin: /\[.+?\]\[.*?\]/,
          relevance: 0
        },
        // popular internet URLs
        {
          begin: /\[.+?\]\(((data|javascript|mailto):|(?:http|ftp)s?:\/\/).*?\)/,
          relevance: 2
        },
        {
          begin: n.concat(/\[.+?\]\(/, l, /:\/\/.*?\)/),
          relevance: 2
        },
        // relative urls
        {
          begin: /\[.+?\]\([./?&#].*?\)/,
          relevance: 1
        },
        // whatever else, lower relevance (might not be a link at all)
        {
          begin: /\[.*?\]\(.*?\)/,
          relevance: 0
        }
      ],
      returnBegin: !0,
      contains: [
        {
          // empty strings for alt or link text
          match: /\[(?=\])/
        },
        {
          className: "string",
          relevance: 0,
          begin: "\\[",
          end: "\\]",
          excludeBegin: !0,
          returnEnd: !0
        },
        {
          className: "link",
          relevance: 0,
          begin: "\\]\\(",
          end: "\\)",
          excludeBegin: !0,
          excludeEnd: !0
        },
        {
          className: "symbol",
          relevance: 0,
          begin: "\\]\\[",
          end: "\\]",
          excludeBegin: !0,
          excludeEnd: !0
        }
      ]
    }, c = {
      className: "strong",
      contains: [],
      // defined later
      variants: [
        {
          begin: /_{2}(?!\s)/,
          end: /_{2}/
        },
        {
          begin: /\*{2}(?!\s)/,
          end: /\*{2}/
        }
      ]
    }, d = {
      className: "emphasis",
      contains: [],
      // defined later
      variants: [
        {
          begin: /\*(?![*\s])/,
          end: /\*/
        },
        {
          begin: /_(?![_\s])/,
          end: /_/,
          relevance: 0
        }
      ]
    }, f = t.inherit(c, { contains: [] }), h = t.inherit(d, { contains: [] });
    c.contains.push(h), d.contains.push(f);
    let m = [
      r,
      u
    ];
    return [
      c,
      d,
      f,
      h
    ].forEach((y) => {
      y.contains = y.contains.concat(m);
    }), m = m.concat(c, d), {
      name: "Markdown",
      aliases: [
        "md",
        "mkdown",
        "mkd"
      ],
      contains: [
        {
          className: "section",
          variants: [
            {
              begin: "^#{1,6}",
              end: "$",
              contains: m
            },
            {
              begin: "(?=^.+?\\n[=-]{2,}$)",
              contains: [
                { begin: "^[=-]*$" },
                {
                  begin: "^",
                  end: "\\n",
                  contains: m
                }
              ]
            }
          ]
        },
        r,
        o,
        c,
        d,
        {
          className: "quote",
          begin: "^>\\s+",
          contains: m,
          end: "$"
        },
        a,
        i,
        u,
        s
      ]
    };
  }
  return iE = e, iE;
}
var aE, fD;
function EZ() {
  if (fD) return aE;
  fD = 1;
  function e(t) {
    const n = {
      className: "subst",
      variants: [{ begin: "\\$[A-Za-z0-9_]+" }]
    }, r = {
      className: "subst",
      variants: [
        {
          begin: /\$\{/,
          end: /\}/
        }
      ],
      keywords: "true false null this is new super"
    }, i = {
      className: "string",
      variants: [
        {
          begin: "r'''",
          end: "'''"
        },
        {
          begin: 'r"""',
          end: '"""'
        },
        {
          begin: "r'",
          end: "'",
          illegal: "\\n"
        },
        {
          begin: 'r"',
          end: '"',
          illegal: "\\n"
        },
        {
          begin: "'''",
          end: "'''",
          contains: [
            t.BACKSLASH_ESCAPE,
            n,
            r
          ]
        },
        {
          begin: '"""',
          end: '"""',
          contains: [
            t.BACKSLASH_ESCAPE,
            n,
            r
          ]
        },
        {
          begin: "'",
          end: "'",
          illegal: "\\n",
          contains: [
            t.BACKSLASH_ESCAPE,
            n,
            r
          ]
        },
        {
          begin: '"',
          end: '"',
          illegal: "\\n",
          contains: [
            t.BACKSLASH_ESCAPE,
            n,
            r
          ]
        }
      ]
    };
    r.contains = [
      t.C_NUMBER_MODE,
      i
    ];
    const a = [
      // dart:core
      "Comparable",
      "DateTime",
      "Duration",
      "Function",
      "Iterable",
      "Iterator",
      "List",
      "Map",
      "Match",
      "Object",
      "Pattern",
      "RegExp",
      "Set",
      "Stopwatch",
      "String",
      "StringBuffer",
      "StringSink",
      "Symbol",
      "Type",
      "Uri",
      "bool",
      "double",
      "int",
      "num",
      // dart:html
      "Element",
      "ElementList"
    ], o = a.map((u) => `${u}?`);
    return {
      name: "Dart",
      keywords: {
        keyword: [
          "abstract",
          "as",
          "assert",
          "async",
          "await",
          "base",
          "break",
          "case",
          "catch",
          "class",
          "const",
          "continue",
          "covariant",
          "default",
          "deferred",
          "do",
          "dynamic",
          "else",
          "enum",
          "export",
          "extends",
          "extension",
          "external",
          "factory",
          "false",
          "final",
          "finally",
          "for",
          "Function",
          "get",
          "hide",
          "if",
          "implements",
          "import",
          "in",
          "interface",
          "is",
          "late",
          "library",
          "mixin",
          "new",
          "null",
          "on",
          "operator",
          "part",
          "required",
          "rethrow",
          "return",
          "sealed",
          "set",
          "show",
          "static",
          "super",
          "switch",
          "sync",
          "this",
          "throw",
          "true",
          "try",
          "typedef",
          "var",
          "void",
          "when",
          "while",
          "with",
          "yield"
        ],
        built_in: a.concat(o).concat([
          // dart:core
          "Never",
          "Null",
          "dynamic",
          "print",
          // dart:html
          "document",
          "querySelector",
          "querySelectorAll",
          "window"
        ]),
        $pattern: /[A-Za-z][A-Za-z0-9_]*\??/
      },
      contains: [
        i,
        t.COMMENT(
          /\/\*\*(?!\/)/,
          /\*\//,
          {
            subLanguage: "markdown",
            relevance: 0
          }
        ),
        t.COMMENT(
          /\/{3,} ?/,
          /$/,
          { contains: [
            {
              subLanguage: "markdown",
              begin: ".",
              end: "$",
              relevance: 0
            }
          ] }
        ),
        t.C_LINE_COMMENT_MODE,
        t.C_BLOCK_COMMENT_MODE,
        {
          className: "class",
          beginKeywords: "class interface",
          end: /\{/,
          excludeEnd: !0,
          contains: [
            { beginKeywords: "extends implements" },
            t.UNDERSCORE_TITLE_MODE
          ]
        },
        t.C_NUMBER_MODE,
        {
          className: "meta",
          begin: "@[A-Za-z]+"
        },
        {
          begin: "=>"
          // No markup, just a relevance booster
        }
      ]
    };
  }
  return aE = e, aE;
}
var oE, pD;
function SZ() {
  if (pD) return oE;
  pD = 1;
  function e(t) {
    const n = [
      "exports",
      "register",
      "file",
      "shl",
      "array",
      "record",
      "property",
      "for",
      "mod",
      "while",
      "set",
      "ally",
      "label",
      "uses",
      "raise",
      "not",
      "stored",
      "class",
      "safecall",
      "var",
      "interface",
      "or",
      "private",
      "static",
      "exit",
      "index",
      "inherited",
      "to",
      "else",
      "stdcall",
      "override",
      "shr",
      "asm",
      "far",
      "resourcestring",
      "finalization",
      "packed",
      "virtual",
      "out",
      "and",
      "protected",
      "library",
      "do",
      "xorwrite",
      "goto",
      "near",
      "function",
      "end",
      "div",
      "overload",
      "object",
      "unit",
      "begin",
      "string",
      "on",
      "inline",
      "repeat",
      "until",
      "destructor",
      "write",
      "message",
      "program",
      "with",
      "read",
      "initialization",
      "except",
      "default",
      "nil",
      "if",
      "case",
      "cdecl",
      "in",
      "downto",
      "threadvar",
      "of",
      "try",
      "pascal",
      "const",
      "external",
      "constructor",
      "type",
      "public",
      "then",
      "implementation",
      "finally",
      "published",
      "procedure",
      "absolute",
      "reintroduce",
      "operator",
      "as",
      "is",
      "abstract",
      "alias",
      "assembler",
      "bitpacked",
      "break",
      "continue",
      "cppdecl",
      "cvar",
      "enumerator",
      "experimental",
      "platform",
      "deprecated",
      "unimplemented",
      "dynamic",
      "export",
      "far16",
      "forward",
      "generic",
      "helper",
      "implements",
      "interrupt",
      "iochecks",
      "local",
      "name",
      "nodefault",
      "noreturn",
      "nostackframe",
      "oldfpccall",
      "otherwise",
      "saveregisters",
      "softfloat",
      "specialize",
      "strict",
      "unaligned",
      "varargs"
    ], r = [
      t.C_LINE_COMMENT_MODE,
      t.COMMENT(/\{/, /\}/, { relevance: 0 }),
      t.COMMENT(/\(\*/, /\*\)/, { relevance: 10 })
    ], i = {
      className: "meta",
      variants: [
        {
          begin: /\{\$/,
          end: /\}/
        },
        {
          begin: /\(\*\$/,
          end: /\*\)/
        }
      ]
    }, a = {
      className: "string",
      begin: /'/,
      end: /'/,
      contains: [{ begin: /''/ }]
    }, o = {
      className: "number",
      relevance: 0,
      // Source: https://www.freepascal.org/docs-html/ref/refse6.html
      variants: [
        {
          // Hexadecimal notation, e.g., $7F.
          begin: "\\$[0-9A-Fa-f]+"
        },
        {
          // Octal notation, e.g., &42.
          begin: "&[0-7]+"
        },
        {
          // Binary notation, e.g., %1010.
          begin: "%[01]+"
        }
      ]
    }, s = {
      className: "string",
      begin: /(#\d+)+/
    }, l = {
      begin: t.IDENT_RE + "\\s*=\\s*class\\s*\\(",
      returnBegin: !0,
      contains: [t.TITLE_MODE]
    }, u = {
      className: "function",
      beginKeywords: "function constructor destructor procedure",
      end: /[:;]/,
      keywords: "function constructor|10 destructor|10 procedure|10",
      contains: [
        t.TITLE_MODE,
        {
          className: "params",
          begin: /\(/,
          end: /\)/,
          keywords: n,
          contains: [
            a,
            s,
            i
          ].concat(r)
        },
        i
      ].concat(r)
    };
    return {
      name: "Delphi",
      aliases: [
        "dpr",
        "dfm",
        "pas",
        "pascal"
      ],
      case_insensitive: !0,
      keywords: n,
      illegal: /"|\$[G-Zg-z]|\/\*|<\/|\|/,
      contains: [
        a,
        s,
        t.NUMBER_MODE,
        o,
        l,
        u,
        i
      ].concat(r)
    };
  }
  return oE = e, oE;
}
var sE, mD;
function yZ() {
  if (mD) return sE;
  mD = 1;
  function e(t) {
    const n = t.regex;
    return {
      name: "Diff",
      aliases: ["patch"],
      contains: [
        {
          className: "meta",
          relevance: 10,
          match: n.either(
            /^@@ +-\d+,\d+ +\+\d+,\d+ +@@/,
            /^\*\*\* +\d+,\d+ +\*\*\*\*$/,
            /^--- +\d+,\d+ +----$/
          )
        },
        {
          className: "comment",
          variants: [
            {
              begin: n.either(
                /Index: /,
                /^index/,
                /={3,}/,
                /^-{3}/,
                /^\*{3} /,
                /^\+{3}/,
                /^diff --git/
              ),
              end: /$/
            },
            { match: /^\*{15}$/ }
          ]
        },
        {
          className: "addition",
          begin: /^\+/,
          end: /$/
        },
        {
          className: "deletion",
          begin: /^-/,
          end: /$/
        },
        {
          className: "addition",
          begin: /^!/,
          end: /$/
        }
      ]
    };
  }
  return sE = e, sE;
}
var lE, hD;
function TZ() {
  if (hD) return lE;
  hD = 1;
  function e(t) {
    const n = {
      begin: /\|[A-Za-z]+:?/,
      keywords: { name: "truncatewords removetags linebreaksbr yesno get_digit timesince random striptags filesizeformat escape linebreaks length_is ljust rjust cut urlize fix_ampersands title floatformat capfirst pprint divisibleby add make_list unordered_list urlencode timeuntil urlizetrunc wordcount stringformat linenumbers slice date dictsort dictsortreversed default_if_none pluralize lower join center default truncatewords_html upper length phone2numeric wordwrap time addslashes slugify first escapejs force_escape iriencode last safe safeseq truncatechars localize unlocalize localtime utc timezone" },
      contains: [
        t.QUOTE_STRING_MODE,
        t.APOS_STRING_MODE
      ]
    };
    return {
      name: "Django",
      aliases: ["jinja"],
      case_insensitive: !0,
      subLanguage: "xml",
      contains: [
        t.COMMENT(/\{%\s*comment\s*%\}/, /\{%\s*endcomment\s*%\}/),
        t.COMMENT(/\{#/, /#\}/),
        {
          className: "template-tag",
          begin: /\{%/,
          end: /%\}/,
          contains: [
            {
              className: "name",
              begin: /\w+/,
              keywords: { name: "comment endcomment load templatetag ifchanged endifchanged if endif firstof for endfor ifnotequal endifnotequal widthratio extends include spaceless endspaceless regroup ifequal endifequal ssi now with cycle url filter endfilter debug block endblock else autoescape endautoescape csrf_token empty elif endwith static trans blocktrans endblocktrans get_static_prefix get_media_prefix plural get_current_language language get_available_languages get_current_language_bidi get_language_info get_language_info_list localize endlocalize localtime endlocaltime timezone endtimezone get_current_timezone verbatim" },
              starts: {
                endsWithParent: !0,
                keywords: "in by as",
                contains: [n],
                relevance: 0
              }
            }
          ]
        },
        {
          className: "template-variable",
          begin: /\{\{/,
          end: /\}\}/,
          contains: [n]
        }
      ]
    };
  }
  return lE = e, lE;
}
var uE, gD;
function CZ() {
  if (gD) return uE;
  gD = 1;
  function e(t) {
    return {
      name: "DNS Zone",
      aliases: [
        "bind",
        "zone"
      ],
      keywords: [
        "IN",
        "A",
        "AAAA",
        "AFSDB",
        "APL",
        "CAA",
        "CDNSKEY",
        "CDS",
        "CERT",
        "CNAME",
        "DHCID",
        "DLV",
        "DNAME",
        "DNSKEY",
        "DS",
        "HIP",
        "IPSECKEY",
        "KEY",
        "KX",
        "LOC",
        "MX",
        "NAPTR",
        "NS",
        "NSEC",
        "NSEC3",
        "NSEC3PARAM",
        "PTR",
        "RRSIG",
        "RP",
        "SIG",
        "SOA",
        "SRV",
        "SSHFP",
        "TA",
        "TKEY",
        "TLSA",
        "TSIG",
        "TXT"
      ],
      contains: [
        t.COMMENT(";", "$", { relevance: 0 }),
        {
          className: "meta",
          begin: /^\$(TTL|GENERATE|INCLUDE|ORIGIN)\b/
        },
        // IPv6
        {
          className: "number",
          begin: "((([0-9A-Fa-f]{1,4}:){7}([0-9A-Fa-f]{1,4}|:))|(([0-9A-Fa-f]{1,4}:){6}(:[0-9A-Fa-f]{1,4}|((25[0-5]|2[0-4]\\d|1\\d\\d|[1-9]?\\d)(\\.(25[0-5]|2[0-4]\\d|1\\d\\d|[1-9]?\\d)){3})|:))|(([0-9A-Fa-f]{1,4}:){5}(((:[0-9A-Fa-f]{1,4}){1,2})|:((25[0-5]|2[0-4]\\d|1\\d\\d|[1-9]?\\d)(\\.(25[0-5]|2[0-4]\\d|1\\d\\d|[1-9]?\\d)){3})|:))|(([0-9A-Fa-f]{1,4}:){4}(((:[0-9A-Fa-f]{1,4}){1,3})|((:[0-9A-Fa-f]{1,4})?:((25[0-5]|2[0-4]\\d|1\\d\\d|[1-9]?\\d)(\\.(25[0-5]|2[0-4]\\d|1\\d\\d|[1-9]?\\d)){3}))|:))|(([0-9A-Fa-f]{1,4}:){3}(((:[0-9A-Fa-f]{1,4}){1,4})|((:[0-9A-Fa-f]{1,4}){0,2}:((25[0-5]|2[0-4]\\d|1\\d\\d|[1-9]?\\d)(\\.(25[0-5]|2[0-4]\\d|1\\d\\d|[1-9]?\\d)){3}))|:))|(([0-9A-Fa-f]{1,4}:){2}(((:[0-9A-Fa-f]{1,4}){1,5})|((:[0-9A-Fa-f]{1,4}){0,3}:((25[0-5]|2[0-4]\\d|1\\d\\d|[1-9]?\\d)(\\.(25[0-5]|2[0-4]\\d|1\\d\\d|[1-9]?\\d)){3}))|:))|(([0-9A-Fa-f]{1,4}:){1}(((:[0-9A-Fa-f]{1,4}){1,6})|((:[0-9A-Fa-f]{1,4}){0,4}:((25[0-5]|2[0-4]\\d|1\\d\\d|[1-9]?\\d)(\\.(25[0-5]|2[0-4]\\d|1\\d\\d|[1-9]?\\d)){3}))|:))|(:(((:[0-9A-Fa-f]{1,4}){1,7})|((:[0-9A-Fa-f]{1,4}){0,5}:((25[0-5]|2[0-4]\\d|1\\d\\d|[1-9]?\\d)(\\.(25[0-5]|2[0-4]\\d|1\\d\\d|[1-9]?\\d)){3}))|:)))\\b"
        },
        // IPv4
        {
          className: "number",
          begin: "((25[0-5]|(2[0-4]|1{0,1}[0-9]){0,1}[0-9]).){3,3}(25[0-5]|(2[0-4]|1{0,1}[0-9]){0,1}[0-9])\\b"
        },
        t.inherit(t.NUMBER_MODE, { begin: /\b\d+[dhwm]?/ })
      ]
    };
  }
  return uE = e, uE;
}
var cE, _D;
function AZ() {
  if (_D) return cE;
  _D = 1;
  function e(t) {
    return {
      name: "Dockerfile",
      aliases: ["docker"],
      case_insensitive: !0,
      keywords: [
        "from",
        "maintainer",
        "expose",
        "env",
        "arg",
        "user",
        "onbuild",
        "stopsignal"
      ],
      contains: [
        t.HASH_COMMENT_MODE,
        t.APOS_STRING_MODE,
        t.QUOTE_STRING_MODE,
        t.NUMBER_MODE,
        {
          beginKeywords: "run cmd entrypoint volume add copy workdir label healthcheck shell",
          starts: {
            end: /[^\\]$/,
            subLanguage: "bash"
          }
        }
      ],
      illegal: "</"
    };
  }
  return cE = e, cE;
}
var dE, vD;
function OZ() {
  if (vD) return dE;
  vD = 1;
  function e(t) {
    const n = t.COMMENT(
      /^\s*@?rem\b/,
      /$/,
      { relevance: 10 }
    );
    return {
      name: "Batch file (DOS)",
      aliases: [
        "bat",
        "cmd"
      ],
      case_insensitive: !0,
      illegal: /\/\*/,
      keywords: {
        keyword: [
          "if",
          "else",
          "goto",
          "for",
          "in",
          "do",
          "call",
          "exit",
          "not",
          "exist",
          "errorlevel",
          "defined",
          "equ",
          "neq",
          "lss",
          "leq",
          "gtr",
          "geq"
        ],
        built_in: [
          "prn",
          "nul",
          "lpt3",
          "lpt2",
          "lpt1",
          "con",
          "com4",
          "com3",
          "com2",
          "com1",
          "aux",
          "shift",
          "cd",
          "dir",
          "echo",
          "setlocal",
          "endlocal",
          "set",
          "pause",
          "copy",
          "append",
          "assoc",
          "at",
          "attrib",
          "break",
          "cacls",
          "cd",
          "chcp",
          "chdir",
          "chkdsk",
          "chkntfs",
          "cls",
          "cmd",
          "color",
          "comp",
          "compact",
          "convert",
          "date",
          "dir",
          "diskcomp",
          "diskcopy",
          "doskey",
          "erase",
          "fs",
          "find",
          "findstr",
          "format",
          "ftype",
          "graftabl",
          "help",
          "keyb",
          "label",
          "md",
          "mkdir",
          "mode",
          "more",
          "move",
          "path",
          "pause",
          "print",
          "popd",
          "pushd",
          "promt",
          "rd",
          "recover",
          "rem",
          "rename",
          "replace",
          "restore",
          "rmdir",
          "shift",
          "sort",
          "start",
          "subst",
          "time",
          "title",
          "tree",
          "type",
          "ver",
          "verify",
          "vol",
          // winutils
          "ping",
          "net",
          "ipconfig",
          "taskkill",
          "xcopy",
          "ren",
          "del"
        ]
      },
      contains: [
        {
          className: "variable",
          begin: /%%[^ ]|%[^ ]+?%|![^ ]+?!/
        },
        {
          className: "function",
          begin: {
            className: "symbol",
            begin: "^\\s*[A-Za-z._?][A-Za-z0-9_$#@~.?]*(:|\\s+label)",
            relevance: 0
          }.begin,
          end: "goto:eof",
          contains: [
            t.inherit(t.TITLE_MODE, { begin: "([_a-zA-Z]\\w*\\.)*([_a-zA-Z]\\w*:)?[_a-zA-Z]\\w*" }),
            n
          ]
        },
        {
          className: "number",
          begin: "\\b\\d+",
          relevance: 0
        },
        n
      ]
    };
  }
  return dE = e, dE;
}
var fE, bD;
function RZ() {
  if (bD) return fE;
  bD = 1;
  function e(t) {
    return {
      keywords: "dsconfig",
      contains: [
        {
          className: "keyword",
          begin: "^dsconfig",
          end: /\s/,
          excludeEnd: !0,
          relevance: 10
        },
        {
          className: "built_in",
          begin: /(list|create|get|set|delete)-(\w+)/,
          end: /\s/,
          excludeEnd: !0,
          illegal: "!@#$%^&*()",
          relevance: 10
        },
        {
          className: "built_in",
          begin: /--(\w+)/,
          end: /\s/,
          excludeEnd: !0
        },
        {
          className: "string",
          begin: /"/,
          end: /"/
        },
        {
          className: "string",
          begin: /'/,
          end: /'/
        },
        {
          className: "string",
          begin: /[\w\-?]+:\w+/,
          end: /\W/,
          relevance: 0
        },
        {
          className: "string",
          begin: /\w+(\-\w+)*/,
          end: /(?=\W)/,
          relevance: 0
        },
        t.HASH_COMMENT_MODE
      ]
    };
  }
  return fE = e, fE;
}
var pE, ED;
function wZ() {
  if (ED) return pE;
  ED = 1;
  function e(t) {
    const n = {
      className: "string",
      variants: [
        t.inherit(t.QUOTE_STRING_MODE, { begin: '((u8?|U)|L)?"' }),
        {
          begin: '(u8?|U)?R"',
          end: '"',
          contains: [t.BACKSLASH_ESCAPE]
        },
        {
          begin: "'\\\\?.",
          end: "'",
          illegal: "."
        }
      ]
    }, r = {
      className: "number",
      variants: [
        { begin: "\\b(\\d+(\\.\\d*)?|\\.\\d+)(u|U|l|L|ul|UL|f|F)" },
        { begin: t.C_NUMBER_RE }
      ],
      relevance: 0
    }, i = {
      className: "meta",
      begin: "#",
      end: "$",
      keywords: { keyword: "if else elif endif define undef ifdef ifndef" },
      contains: [
        {
          begin: /\\\n/,
          relevance: 0
        },
        {
          beginKeywords: "include",
          end: "$",
          keywords: { keyword: "include" },
          contains: [
            t.inherit(n, { className: "string" }),
            {
              className: "string",
              begin: "<",
              end: ">",
              illegal: "\\n"
            }
          ]
        },
        n,
        t.C_LINE_COMMENT_MODE,
        t.C_BLOCK_COMMENT_MODE
      ]
    }, a = {
      className: "variable",
      begin: /&[a-z\d_]*\b/
    }, o = {
      className: "keyword",
      begin: "/[a-z][a-z\\d-]*/"
    }, s = {
      className: "symbol",
      begin: "^\\s*[a-zA-Z_][a-zA-Z\\d_]*:"
    }, l = {
      className: "params",
      relevance: 0,
      begin: "<",
      end: ">",
      contains: [
        r,
        a
      ]
    }, u = {
      className: "title.class",
      begin: /[a-zA-Z_][a-zA-Z\d_@-]*(?=\s\{)/,
      relevance: 0.2
    }, c = {
      className: "title.class",
      begin: /^\/(?=\s*\{)/,
      relevance: 10
    }, d = {
      match: /[a-z][a-z-,]+(?=;)/,
      relevance: 0,
      scope: "attr"
    }, f = {
      relevance: 0,
      match: [
        /[a-z][a-z-,]+/,
        /\s*/,
        /=/
      ],
      scope: {
        1: "attr",
        3: "operator"
      }
    }, h = {
      scope: "punctuation",
      relevance: 0,
      // `};` combined is just to avoid tons of useless punctuation nodes
      match: /\};|[;{}]/
    };
    return {
      name: "Device Tree",
      contains: [
        c,
        a,
        o,
        s,
        u,
        f,
        d,
        l,
        t.C_LINE_COMMENT_MODE,
        t.C_BLOCK_COMMENT_MODE,
        r,
        n,
        i,
        h,
        {
          begin: t.IDENT_RE + "::",
          keywords: ""
        }
      ]
    };
  }
  return pE = e, pE;
}
var mE, SD;
function xZ() {
  if (SD) return mE;
  SD = 1;
  function e(t) {
    return {
      name: "Dust",
      aliases: ["dst"],
      case_insensitive: !0,
      subLanguage: "xml",
      contains: [
        {
          className: "template-tag",
          begin: /\{[#\/]/,
          end: /\}/,
          illegal: /;/,
          contains: [
            {
              className: "name",
              begin: /[a-zA-Z\.-]+/,
              starts: {
                endsWithParent: !0,
                relevance: 0,
                contains: [t.QUOTE_STRING_MODE]
              }
            }
          ]
        },
        {
          className: "template-variable",
          begin: /\{/,
          end: /\}/,
          illegal: /;/,
          keywords: "if eq ne lt lte gt gte select default math sep"
        }
      ]
    };
  }
  return mE = e, mE;
}
var hE, yD;
function NZ() {
  if (yD) return hE;
  yD = 1;
  function e(t) {
    const n = t.COMMENT(/\(\*/, /\*\)/), r = {
      className: "attribute",
      begin: /^[ ]*[a-zA-Z]+([\s_-]+[a-zA-Z]+)*/
    }, a = {
      begin: /=/,
      end: /[.;]/,
      contains: [
        n,
        {
          className: "meta",
          begin: /\?.*\?/
        },
        {
          // terminals
          className: "string",
          variants: [
            t.APOS_STRING_MODE,
            t.QUOTE_STRING_MODE,
            {
              begin: "`",
              end: "`"
            }
          ]
        }
      ]
    };
    return {
      name: "Extended Backus-Naur Form",
      illegal: /\S/,
      contains: [
        n,
        r,
        a
      ]
    };
  }
  return hE = e, hE;
}
var gE, TD;
function DZ() {
  if (TD) return gE;
  TD = 1;
  function e(t) {
    const n = t.regex, r = "[a-zA-Z_][a-zA-Z0-9_.]*(!|\\?)?", i = "[a-zA-Z_]\\w*[!?=]?|[-+~]@|<<|>>|=~|===?|<=>|[<>]=?|\\*\\*|[-/+%^&*~`|]|\\[\\]=?", s = {
      $pattern: r,
      keyword: [
        "after",
        "alias",
        "and",
        "case",
        "catch",
        "cond",
        "defstruct",
        "defguard",
        "do",
        "else",
        "end",
        "fn",
        "for",
        "if",
        "import",
        "in",
        "not",
        "or",
        "quote",
        "raise",
        "receive",
        "require",
        "reraise",
        "rescue",
        "try",
        "unless",
        "unquote",
        "unquote_splicing",
        "use",
        "when",
        "with|0"
      ],
      literal: [
        "false",
        "nil",
        "true"
      ]
    }, l = {
      className: "subst",
      begin: /#\{/,
      end: /\}/,
      keywords: s
    }, u = {
      className: "number",
      begin: "(\\b0o[0-7_]+)|(\\b0b[01_]+)|(\\b0x[0-9a-fA-F_]+)|(-?\\b[0-9][0-9_]*(\\.[0-9_]+([eE][-+]?[0-9]+)?)?)",
      relevance: 0
    }, d = {
      match: /\\[\s\S]/,
      scope: "char.escape",
      relevance: 0
    }, f = `[/|([{<"']`, h = [
      {
        begin: /"/,
        end: /"/
      },
      {
        begin: /'/,
        end: /'/
      },
      {
        begin: /\//,
        end: /\//
      },
      {
        begin: /\|/,
        end: /\|/
      },
      {
        begin: /\(/,
        end: /\)/
      },
      {
        begin: /\[/,
        end: /\]/
      },
      {
        begin: /\{/,
        end: /\}/
      },
      {
        begin: /</,
        end: />/
      }
    ], m = (T) => ({
      scope: "char.escape",
      begin: n.concat(/\\/, T),
      relevance: 0
    }), v = {
      className: "string",
      begin: "~[a-z](?=" + f + ")",
      contains: h.map((T) => t.inherit(
        T,
        { contains: [
          m(T.end),
          d,
          l
        ] }
      ))
    }, b = {
      className: "string",
      begin: "~[A-Z](?=" + f + ")",
      contains: h.map((T) => t.inherit(
        T,
        { contains: [m(T.end)] }
      ))
    }, y = {
      className: "regex",
      variants: [
        {
          begin: "~r(?=" + f + ")",
          contains: h.map((T) => t.inherit(
            T,
            {
              end: n.concat(T.end, /[uismxfU]{0,7}/),
              contains: [
                m(T.end),
                d,
                l
              ]
            }
          ))
        },
        {
          begin: "~R(?=" + f + ")",
          contains: h.map(
            (T) => t.inherit(
              T,
              {
                end: n.concat(T.end, /[uismxfU]{0,7}/),
                contains: [m(T.end)]
              }
            )
          )
        }
      ]
    }, g = {
      className: "string",
      contains: [
        t.BACKSLASH_ESCAPE,
        l
      ],
      variants: [
        {
          begin: /"""/,
          end: /"""/
        },
        {
          begin: /'''/,
          end: /'''/
        },
        {
          begin: /~S"""/,
          end: /"""/,
          contains: []
          // override default
        },
        {
          begin: /~S"/,
          end: /"/,
          contains: []
          // override default
        },
        {
          begin: /~S'''/,
          end: /'''/,
          contains: []
          // override default
        },
        {
          begin: /~S'/,
          end: /'/,
          contains: []
          // override default
        },
        {
          begin: /'/,
          end: /'/
        },
        {
          begin: /"/,
          end: /"/
        }
      ]
    }, E = {
      className: "function",
      beginKeywords: "def defp defmacro defmacrop",
      end: /\B\b/,
      // the mode is ended by the title
      contains: [
        t.inherit(t.TITLE_MODE, {
          begin: r,
          endsParent: !0
        })
      ]
    }, S = t.inherit(E, {
      className: "class",
      beginKeywords: "defimpl defmodule defprotocol defrecord",
      end: /\bdo\b|$|;/
    }), C = [
      g,
      y,
      b,
      v,
      t.HASH_COMMENT_MODE,
      S,
      E,
      { begin: "::" },
      {
        className: "symbol",
        begin: ":(?![\\s:])",
        contains: [
          g,
          { begin: i }
        ],
        relevance: 0
      },
      {
        className: "symbol",
        begin: r + ":(?!:)",
        relevance: 0
      },
      {
        // Usage of a module, struct, etc.
        className: "title.class",
        begin: /(\b[A-Z][a-zA-Z0-9_]+)/,
        relevance: 0
      },
      u,
      {
        className: "variable",
        begin: "(\\$\\W)|((\\$|@@?)(\\w+))"
      }
      // -> has been removed, capnproto always uses this grammar construct
    ];
    return l.contains = C, {
      name: "Elixir",
      aliases: [
        "ex",
        "exs"
      ],
      keywords: s,
      contains: C
    };
  }
  return gE = e, gE;
}
var _E, CD;
function IZ() {
  if (CD) return _E;
  CD = 1;
  function e(t) {
    const n = { variants: [
      t.COMMENT("--", "$"),
      t.COMMENT(
        /\{-/,
        /-\}/,
        { contains: ["self"] }
      )
    ] }, r = {
      className: "type",
      begin: "\\b[A-Z][\\w']*",
      // TODO: other constructors (built-in, infix).
      relevance: 0
    }, i = {
      begin: "\\(",
      end: "\\)",
      illegal: '"',
      contains: [
        {
          className: "type",
          begin: "\\b[A-Z][\\w]*(\\((\\.\\.|,|\\w+)\\))?"
        },
        n
      ]
    }, a = {
      begin: /\{/,
      end: /\}/,
      contains: i.contains
    }, o = {
      className: "string",
      begin: "'\\\\?.",
      end: "'",
      illegal: "."
    };
    return {
      name: "Elm",
      keywords: [
        "let",
        "in",
        "if",
        "then",
        "else",
        "case",
        "of",
        "where",
        "module",
        "import",
        "exposing",
        "type",
        "alias",
        "as",
        "infix",
        "infixl",
        "infixr",
        "port",
        "effect",
        "command",
        "subscription"
      ],
      contains: [
        // Top-level constructions.
        {
          beginKeywords: "port effect module",
          end: "exposing",
          keywords: "port effect module where command subscription exposing",
          contains: [
            i,
            n
          ],
          illegal: "\\W\\.|;"
        },
        {
          begin: "import",
          end: "$",
          keywords: "import as exposing",
          contains: [
            i,
            n
          ],
          illegal: "\\W\\.|;"
        },
        {
          begin: "type",
          end: "$",
          keywords: "type alias",
          contains: [
            r,
            i,
            a,
            n
          ]
        },
        {
          beginKeywords: "infix infixl infixr",
          end: "$",
          contains: [
            t.C_NUMBER_MODE,
            n
          ]
        },
        {
          begin: "port",
          end: "$",
          keywords: "port",
          contains: [n]
        },
        // Literals and names.
        o,
        t.QUOTE_STRING_MODE,
        t.C_NUMBER_MODE,
        r,
        t.inherit(t.TITLE_MODE, { begin: "^[_a-z][\\w']*" }),
        n,
        {
          // No markup, relevance booster
          begin: "->|<-"
        }
      ],
      illegal: /;/
    };
  }
  return _E = e, _E;
}
var vE, AD;
function LZ() {
  if (AD) return vE;
  AD = 1;
  function e(t) {
    const n = t.regex, r = "([a-zA-Z_]\\w*[!?=]?|[-+~]@|<<|>>|=~|===?|<=>|[<>]=?|\\*\\*|[-/+%^&*~`|]|\\[\\]=?)", i = n.either(
      /\b([A-Z]+[a-z0-9]+)+/,
      // ends in caps
      /\b([A-Z]+[a-z0-9]+)+[A-Z]+/
    ), a = n.concat(i, /(::\w+)*/), s = {
      "variable.constant": [
        "__FILE__",
        "__LINE__",
        "__ENCODING__"
      ],
      "variable.language": [
        "self",
        "super"
      ],
      keyword: [
        "alias",
        "and",
        "begin",
        "BEGIN",
        "break",
        "case",
        "class",
        "defined",
        "do",
        "else",
        "elsif",
        "end",
        "END",
        "ensure",
        "for",
        "if",
        "in",
        "module",
        "next",
        "not",
        "or",
        "redo",
        "require",
        "rescue",
        "retry",
        "return",
        "then",
        "undef",
        "unless",
        "until",
        "when",
        "while",
        "yield",
        ...[
          "include",
          "extend",
          "prepend",
          "public",
          "private",
          "protected",
          "raise",
          "throw"
        ]
      ],
      built_in: [
        "proc",
        "lambda",
        "attr_accessor",
        "attr_reader",
        "attr_writer",
        "define_method",
        "private_constant",
        "module_function"
      ],
      literal: [
        "true",
        "false",
        "nil"
      ]
    }, l = {
      className: "doctag",
      begin: "@[A-Za-z]+"
    }, u = {
      begin: "#<",
      end: ">"
    }, c = [
      t.COMMENT(
        "#",
        "$",
        { contains: [l] }
      ),
      t.COMMENT(
        "^=begin",
        "^=end",
        {
          contains: [l],
          relevance: 10
        }
      ),
      t.COMMENT("^__END__", t.MATCH_NOTHING_RE)
    ], d = {
      className: "subst",
      begin: /#\{/,
      end: /\}/,
      keywords: s
    }, f = {
      className: "string",
      contains: [
        t.BACKSLASH_ESCAPE,
        d
      ],
      variants: [
        {
          begin: /'/,
          end: /'/
        },
        {
          begin: /"/,
          end: /"/
        },
        {
          begin: /`/,
          end: /`/
        },
        {
          begin: /%[qQwWx]?\(/,
          end: /\)/
        },
        {
          begin: /%[qQwWx]?\[/,
          end: /\]/
        },
        {
          begin: /%[qQwWx]?\{/,
          end: /\}/
        },
        {
          begin: /%[qQwWx]?</,
          end: />/
        },
        {
          begin: /%[qQwWx]?\//,
          end: /\//
        },
        {
          begin: /%[qQwWx]?%/,
          end: /%/
        },
        {
          begin: /%[qQwWx]?-/,
          end: /-/
        },
        {
          begin: /%[qQwWx]?\|/,
          end: /\|/
        },
        // in the following expressions, \B in the beginning suppresses recognition of ?-sequences
        // where ? is the last character of a preceding identifier, as in: `func?4`
        { begin: /\B\?(\\\d{1,3})/ },
        { begin: /\B\?(\\x[A-Fa-f0-9]{1,2})/ },
        { begin: /\B\?(\\u\{?[A-Fa-f0-9]{1,6}\}?)/ },
        { begin: /\B\?(\\M-\\C-|\\M-\\c|\\c\\M-|\\M-|\\C-\\M-)[\x20-\x7e]/ },
        { begin: /\B\?\\(c|C-)[\x20-\x7e]/ },
        { begin: /\B\?\\?\S/ },
        // heredocs
        {
          // this guard makes sure that we have an entire heredoc and not a false
          // positive (auto-detect, etc.)
          begin: n.concat(
            /<<[-~]?'?/,
            n.lookahead(/(\w+)(?=\W)[^\n]*\n(?:[^\n]*\n)*?\s*\1\b/)
          ),
          contains: [
            t.END_SAME_AS_BEGIN({
              begin: /(\w+)/,
              end: /(\w+)/,
              contains: [
                t.BACKSLASH_ESCAPE,
                d
              ]
            })
          ]
        }
      ]
    }, h = "[1-9](_?[0-9])*|0", m = "[0-9](_?[0-9])*", v = {
      className: "number",
      relevance: 0,
      variants: [
        // decimal integer/float, optionally exponential or rational, optionally imaginary
        { begin: `\\b(${h})(\\.(${m}))?([eE][+-]?(${m})|r)?i?\\b` },
        // explicit decimal/binary/octal/hexadecimal integer,
        // optionally rational and/or imaginary
        { begin: "\\b0[dD][0-9](_?[0-9])*r?i?\\b" },
        { begin: "\\b0[bB][0-1](_?[0-1])*r?i?\\b" },
        { begin: "\\b0[oO][0-7](_?[0-7])*r?i?\\b" },
        { begin: "\\b0[xX][0-9a-fA-F](_?[0-9a-fA-F])*r?i?\\b" },
        // 0-prefixed implicit octal integer, optionally rational and/or imaginary
        { begin: "\\b0(_?[0-7])+r?i?\\b" }
      ]
    }, b = {
      variants: [
        {
          match: /\(\)/
        },
        {
          className: "params",
          begin: /\(/,
          end: /(?=\))/,
          excludeBegin: !0,
          endsParent: !0,
          keywords: s
        }
      ]
    }, O = [
      f,
      {
        variants: [
          {
            match: [
              /class\s+/,
              a,
              /\s+<\s+/,
              a
            ]
          },
          {
            match: [
              /\b(class|module)\s+/,
              a
            ]
          }
        ],
        scope: {
          2: "title.class",
          4: "title.class.inherited"
        },
        keywords: s
      },
      {
        match: [
          /(include|extend)\s+/,
          a
        ],
        scope: {
          2: "title.class"
        },
        keywords: s
      },
      {
        relevance: 0,
        match: [
          a,
          /\.new[. (]/
        ],
        scope: {
          1: "title.class"
        }
      },
      {
        relevance: 0,
        match: /\b[A-Z][A-Z_0-9]+\b/,
        className: "variable.constant"
      },
      {
        relevance: 0,
        match: i,
        scope: "title.class"
      },
      {
        match: [
          /def/,
          /\s+/,
          r
        ],
        scope: {
          1: "keyword",
          3: "title.function"
        },
        contains: [
          b
        ]
      },
      {
        // swallow namespace qualifiers before symbols
        begin: t.IDENT_RE + "::"
      },
      {
        className: "symbol",
        begin: t.UNDERSCORE_IDENT_RE + "(!|\\?)?:",
        relevance: 0
      },
      {
        className: "symbol",
        begin: ":(?!\\s)",
        contains: [
          f,
          { begin: r }
        ],
        relevance: 0
      },
      v,
      {
        // negative-look forward attempts to prevent false matches like:
        // @ident@ or $ident$ that might indicate this is not ruby at all
        className: "variable",
        begin: "(\\$\\W)|((\\$|@@?)(\\w+))(?=[^@$?])(?![A-Za-z])(?![@$?'])"
      },
      {
        className: "params",
        begin: /\|/,
        end: /\|/,
        excludeBegin: !0,
        excludeEnd: !0,
        relevance: 0,
        // this could be a lot of things (in other languages) other than params
        keywords: s
      },
      {
        // regexp container
        begin: "(" + t.RE_STARTERS_RE + "|unless)\\s*",
        keywords: "unless",
        contains: [
          {
            className: "regexp",
            contains: [
              t.BACKSLASH_ESCAPE,
              d
            ],
            illegal: /\n/,
            variants: [
              {
                begin: "/",
                end: "/[a-z]*"
              },
              {
                begin: /%r\{/,
                end: /\}[a-z]*/
              },
              {
                begin: "%r\\(",
                end: "\\)[a-z]*"
              },
              {
                begin: "%r!",
                end: "![a-z]*"
              },
              {
                begin: "%r\\[",
                end: "\\][a-z]*"
              }
            ]
          }
        ].concat(u, c),
        relevance: 0
      }
    ].concat(u, c);
    d.contains = O, b.contains = O;
    const $ = [
      {
        begin: /^\s*=>/,
        starts: {
          end: "$",
          contains: O
        }
      },
      {
        className: "meta.prompt",
        begin: "^(" + "[>?]>" + "|" + "[\\w#]+\\(\\w+\\):\\d+:\\d+[>*]" + "|" + "(\\w+-)?\\d+\\.\\d+\\.\\d+(p\\d+)?[^\\d][^>]+>" + ")(?=[ ])",
        starts: {
          end: "$",
          keywords: s,
          contains: O
        }
      }
    ];
    return c.unshift(u), {
      name: "Ruby",
      aliases: [
        "rb",
        "gemspec",
        "podspec",
        "thor",
        "irb"
      ],
      keywords: s,
      illegal: /\/\*/,
      contains: [t.SHEBANG({ binary: "ruby" })].concat($).concat(c).concat(O)
    };
  }
  return vE = e, vE;
}
var bE, OD;
function kZ() {
  if (OD) return bE;
  OD = 1;
  function e(t) {
    return {
      name: "ERB",
      subLanguage: "xml",
      contains: [
        t.COMMENT("<%#", "%>"),
        {
          begin: "<%[%=-]?",
          end: "[%-]?%>",
          subLanguage: "ruby",
          excludeBegin: !0,
          excludeEnd: !0
        }
      ]
    };
  }
  return bE = e, bE;
}
var EE, RD;
function MZ() {
  if (RD) return EE;
  RD = 1;
  function e(t) {
    const n = t.regex;
    return {
      name: "Erlang REPL",
      keywords: {
        built_in: "spawn spawn_link self",
        keyword: "after and andalso|10 band begin bnot bor bsl bsr bxor case catch cond div end fun if let not of or orelse|10 query receive rem try when xor"
      },
      contains: [
        {
          className: "meta.prompt",
          begin: "^[0-9]+> ",
          relevance: 10
        },
        t.COMMENT("%", "$"),
        {
          className: "number",
          begin: "\\b(\\d+(_\\d+)*#[a-fA-F0-9]+(_[a-fA-F0-9]+)*|\\d+(_\\d+)*(\\.\\d+(_\\d+)*)?([eE][-+]?\\d+)?)",
          relevance: 0
        },
        t.APOS_STRING_MODE,
        t.QUOTE_STRING_MODE,
        { begin: n.concat(
          /\?(::)?/,
          /([A-Z]\w*)/,
          // at least one identifier
          /((::)[A-Z]\w*)*/
          // perhaps more
        ) },
        { begin: "->" },
        { begin: "ok" },
        { begin: "!" },
        {
          begin: "(\\b[a-z'][a-zA-Z0-9_']*:[a-z'][a-zA-Z0-9_']*)|(\\b[a-z'][a-zA-Z0-9_']*)",
          relevance: 0
        },
        {
          begin: "[A-Z][a-zA-Z0-9_']*",
          relevance: 0
        }
      ]
    };
  }
  return EE = e, EE;
}
var SE, wD;
function PZ() {
  if (wD) return SE;
  wD = 1;
  function e(t) {
    const n = "[a-z'][a-zA-Z0-9_']*", r = "(" + n + ":" + n + "|" + n + ")", i = {
      keyword: "after and andalso|10 band begin bnot bor bsl bzr bxor case catch cond div end fun if let not of orelse|10 query receive rem try when xor",
      literal: "false true"
    }, a = t.COMMENT("%", "$"), o = {
      className: "number",
      begin: "\\b(\\d+(_\\d+)*#[a-fA-F0-9]+(_[a-fA-F0-9]+)*|\\d+(_\\d+)*(\\.\\d+(_\\d+)*)?([eE][-+]?\\d+)?)",
      relevance: 0
    }, s = { begin: "fun\\s+" + n + "/\\d+" }, l = {
      begin: r + "\\(",
      end: "\\)",
      returnBegin: !0,
      relevance: 0,
      contains: [
        {
          begin: r,
          relevance: 0
        },
        {
          begin: "\\(",
          end: "\\)",
          endsWithParent: !0,
          returnEnd: !0,
          relevance: 0
          // "contains" defined later
        }
      ]
    }, u = {
      begin: /\{/,
      end: /\}/,
      relevance: 0
      // "contains" defined later
    }, c = {
      begin: "\\b_([A-Z][A-Za-z0-9_]*)?",
      relevance: 0
    }, d = {
      begin: "[A-Z][a-zA-Z0-9_]*",
      relevance: 0
    }, f = {
      begin: "#" + t.UNDERSCORE_IDENT_RE,
      relevance: 0,
      returnBegin: !0,
      contains: [
        {
          begin: "#" + t.UNDERSCORE_IDENT_RE,
          relevance: 0
        },
        {
          begin: /\{/,
          end: /\}/,
          relevance: 0
          // "contains" defined later
        }
      ]
    }, h = {
      beginKeywords: "fun receive if try case",
      end: "end",
      keywords: i
    };
    h.contains = [
      a,
      s,
      t.inherit(t.APOS_STRING_MODE, { className: "" }),
      h,
      l,
      t.QUOTE_STRING_MODE,
      o,
      u,
      c,
      d,
      f
    ];
    const m = [
      a,
      s,
      h,
      l,
      t.QUOTE_STRING_MODE,
      o,
      u,
      c,
      d,
      f
    ];
    l.contains[1].contains = m, u.contains = m, f.contains[1].contains = m;
    const v = [
      "-module",
      "-record",
      "-undef",
      "-export",
      "-ifdef",
      "-ifndef",
      "-author",
      "-copyright",
      "-doc",
      "-vsn",
      "-import",
      "-include",
      "-include_lib",
      "-compile",
      "-define",
      "-else",
      "-endif",
      "-file",
      "-behaviour",
      "-behavior",
      "-spec"
    ], b = {
      className: "params",
      begin: "\\(",
      end: "\\)",
      contains: m
    };
    return {
      name: "Erlang",
      aliases: ["erl"],
      keywords: i,
      illegal: "(</|\\*=|\\+=|-=|/\\*|\\*/|\\(\\*|\\*\\))",
      contains: [
        {
          className: "function",
          begin: "^" + n + "\\s*\\(",
          end: "->",
          returnBegin: !0,
          illegal: "\\(|#|//|/\\*|\\\\|:|;",
          contains: [
            b,
            t.inherit(t.TITLE_MODE, { begin: n })
          ],
          starts: {
            end: ";|\\.",
            keywords: i,
            contains: m
          }
        },
        a,
        {
          begin: "^-",
          end: "\\.",
          relevance: 0,
          excludeEnd: !0,
          returnBegin: !0,
          keywords: {
            $pattern: "-" + t.IDENT_RE,
            keyword: v.map((y) => `${y}|1.5`).join(" ")
          },
          contains: [b]
        },
        o,
        t.QUOTE_STRING_MODE,
        f,
        c,
        d,
        u,
        { begin: /\.$/ }
        // relevance booster
      ]
    };
  }
  return SE = e, SE;
}
var yE, xD;
function FZ() {
  if (xD) return yE;
  xD = 1;
  function e(t) {
    return {
      name: "Excel formulae",
      aliases: [
        "xlsx",
        "xls"
      ],
      case_insensitive: !0,
      keywords: {
        $pattern: /[a-zA-Z][\w\.]*/,
        built_in: [
          "ABS",
          "ACCRINT",
          "ACCRINTM",
          "ACOS",
          "ACOSH",
          "ACOT",
          "ACOTH",
          "AGGREGATE",
          "ADDRESS",
          "AMORDEGRC",
          "AMORLINC",
          "AND",
          "ARABIC",
          "AREAS",
          "ASC",
          "ASIN",
          "ASINH",
          "ATAN",
          "ATAN2",
          "ATANH",
          "AVEDEV",
          "AVERAGE",
          "AVERAGEA",
          "AVERAGEIF",
          "AVERAGEIFS",
          "BAHTTEXT",
          "BASE",
          "BESSELI",
          "BESSELJ",
          "BESSELK",
          "BESSELY",
          "BETADIST",
          "BETA.DIST",
          "BETAINV",
          "BETA.INV",
          "BIN2DEC",
          "BIN2HEX",
          "BIN2OCT",
          "BINOMDIST",
          "BINOM.DIST",
          "BINOM.DIST.RANGE",
          "BINOM.INV",
          "BITAND",
          "BITLSHIFT",
          "BITOR",
          "BITRSHIFT",
          "BITXOR",
          "CALL",
          "CEILING",
          "CEILING.MATH",
          "CEILING.PRECISE",
          "CELL",
          "CHAR",
          "CHIDIST",
          "CHIINV",
          "CHITEST",
          "CHISQ.DIST",
          "CHISQ.DIST.RT",
          "CHISQ.INV",
          "CHISQ.INV.RT",
          "CHISQ.TEST",
          "CHOOSE",
          "CLEAN",
          "CODE",
          "COLUMN",
          "COLUMNS",
          "COMBIN",
          "COMBINA",
          "COMPLEX",
          "CONCAT",
          "CONCATENATE",
          "CONFIDENCE",
          "CONFIDENCE.NORM",
          "CONFIDENCE.T",
          "CONVERT",
          "CORREL",
          "COS",
          "COSH",
          "COT",
          "COTH",
          "COUNT",
          "COUNTA",
          "COUNTBLANK",
          "COUNTIF",
          "COUNTIFS",
          "COUPDAYBS",
          "COUPDAYS",
          "COUPDAYSNC",
          "COUPNCD",
          "COUPNUM",
          "COUPPCD",
          "COVAR",
          "COVARIANCE.P",
          "COVARIANCE.S",
          "CRITBINOM",
          "CSC",
          "CSCH",
          "CUBEKPIMEMBER",
          "CUBEMEMBER",
          "CUBEMEMBERPROPERTY",
          "CUBERANKEDMEMBER",
          "CUBESET",
          "CUBESETCOUNT",
          "CUBEVALUE",
          "CUMIPMT",
          "CUMPRINC",
          "DATE",
          "DATEDIF",
          "DATEVALUE",
          "DAVERAGE",
          "DAY",
          "DAYS",
          "DAYS360",
          "DB",
          "DBCS",
          "DCOUNT",
          "DCOUNTA",
          "DDB",
          "DEC2BIN",
          "DEC2HEX",
          "DEC2OCT",
          "DECIMAL",
          "DEGREES",
          "DELTA",
          "DEVSQ",
          "DGET",
          "DISC",
          "DMAX",
          "DMIN",
          "DOLLAR",
          "DOLLARDE",
          "DOLLARFR",
          "DPRODUCT",
          "DSTDEV",
          "DSTDEVP",
          "DSUM",
          "DURATION",
          "DVAR",
          "DVARP",
          "EDATE",
          "EFFECT",
          "ENCODEURL",
          "EOMONTH",
          "ERF",
          "ERF.PRECISE",
          "ERFC",
          "ERFC.PRECISE",
          "ERROR.TYPE",
          "EUROCONVERT",
          "EVEN",
          "EXACT",
          "EXP",
          "EXPON.DIST",
          "EXPONDIST",
          "FACT",
          "FACTDOUBLE",
          "FALSE|0",
          "F.DIST",
          "FDIST",
          "F.DIST.RT",
          "FILTERXML",
          "FIND",
          "FINDB",
          "F.INV",
          "F.INV.RT",
          "FINV",
          "FISHER",
          "FISHERINV",
          "FIXED",
          "FLOOR",
          "FLOOR.MATH",
          "FLOOR.PRECISE",
          "FORECAST",
          "FORECAST.ETS",
          "FORECAST.ETS.CONFINT",
          "FORECAST.ETS.SEASONALITY",
          "FORECAST.ETS.STAT",
          "FORECAST.LINEAR",
          "FORMULATEXT",
          "FREQUENCY",
          "F.TEST",
          "FTEST",
          "FV",
          "FVSCHEDULE",
          "GAMMA",
          "GAMMA.DIST",
          "GAMMADIST",
          "GAMMA.INV",
          "GAMMAINV",
          "GAMMALN",
          "GAMMALN.PRECISE",
          "GAUSS",
          "GCD",
          "GEOMEAN",
          "GESTEP",
          "GETPIVOTDATA",
          "GROWTH",
          "HARMEAN",
          "HEX2BIN",
          "HEX2DEC",
          "HEX2OCT",
          "HLOOKUP",
          "HOUR",
          "HYPERLINK",
          "HYPGEOM.DIST",
          "HYPGEOMDIST",
          "IF",
          "IFERROR",
          "IFNA",
          "IFS",
          "IMABS",
          "IMAGINARY",
          "IMARGUMENT",
          "IMCONJUGATE",
          "IMCOS",
          "IMCOSH",
          "IMCOT",
          "IMCSC",
          "IMCSCH",
          "IMDIV",
          "IMEXP",
          "IMLN",
          "IMLOG10",
          "IMLOG2",
          "IMPOWER",
          "IMPRODUCT",
          "IMREAL",
          "IMSEC",
          "IMSECH",
          "IMSIN",
          "IMSINH",
          "IMSQRT",
          "IMSUB",
          "IMSUM",
          "IMTAN",
          "INDEX",
          "INDIRECT",
          "INFO",
          "INT",
          "INTERCEPT",
          "INTRATE",
          "IPMT",
          "IRR",
          "ISBLANK",
          "ISERR",
          "ISERROR",
          "ISEVEN",
          "ISFORMULA",
          "ISLOGICAL",
          "ISNA",
          "ISNONTEXT",
          "ISNUMBER",
          "ISODD",
          "ISREF",
          "ISTEXT",
          "ISO.CEILING",
          "ISOWEEKNUM",
          "ISPMT",
          "JIS",
          "KURT",
          "LARGE",
          "LCM",
          "LEFT",
          "LEFTB",
          "LEN",
          "LENB",
          "LINEST",
          "LN",
          "LOG",
          "LOG10",
          "LOGEST",
          "LOGINV",
          "LOGNORM.DIST",
          "LOGNORMDIST",
          "LOGNORM.INV",
          "LOOKUP",
          "LOWER",
          "MATCH",
          "MAX",
          "MAXA",
          "MAXIFS",
          "MDETERM",
          "MDURATION",
          "MEDIAN",
          "MID",
          "MIDBs",
          "MIN",
          "MINIFS",
          "MINA",
          "MINUTE",
          "MINVERSE",
          "MIRR",
          "MMULT",
          "MOD",
          "MODE",
          "MODE.MULT",
          "MODE.SNGL",
          "MONTH",
          "MROUND",
          "MULTINOMIAL",
          "MUNIT",
          "N",
          "NA",
          "NEGBINOM.DIST",
          "NEGBINOMDIST",
          "NETWORKDAYS",
          "NETWORKDAYS.INTL",
          "NOMINAL",
          "NORM.DIST",
          "NORMDIST",
          "NORMINV",
          "NORM.INV",
          "NORM.S.DIST",
          "NORMSDIST",
          "NORM.S.INV",
          "NORMSINV",
          "NOT",
          "NOW",
          "NPER",
          "NPV",
          "NUMBERVALUE",
          "OCT2BIN",
          "OCT2DEC",
          "OCT2HEX",
          "ODD",
          "ODDFPRICE",
          "ODDFYIELD",
          "ODDLPRICE",
          "ODDLYIELD",
          "OFFSET",
          "OR",
          "PDURATION",
          "PEARSON",
          "PERCENTILE.EXC",
          "PERCENTILE.INC",
          "PERCENTILE",
          "PERCENTRANK.EXC",
          "PERCENTRANK.INC",
          "PERCENTRANK",
          "PERMUT",
          "PERMUTATIONA",
          "PHI",
          "PHONETIC",
          "PI",
          "PMT",
          "POISSON.DIST",
          "POISSON",
          "POWER",
          "PPMT",
          "PRICE",
          "PRICEDISC",
          "PRICEMAT",
          "PROB",
          "PRODUCT",
          "PROPER",
          "PV",
          "QUARTILE",
          "QUARTILE.EXC",
          "QUARTILE.INC",
          "QUOTIENT",
          "RADIANS",
          "RAND",
          "RANDBETWEEN",
          "RANK.AVG",
          "RANK.EQ",
          "RANK",
          "RATE",
          "RECEIVED",
          "REGISTER.ID",
          "REPLACE",
          "REPLACEB",
          "REPT",
          "RIGHT",
          "RIGHTB",
          "ROMAN",
          "ROUND",
          "ROUNDDOWN",
          "ROUNDUP",
          "ROW",
          "ROWS",
          "RRI",
          "RSQ",
          "RTD",
          "SEARCH",
          "SEARCHB",
          "SEC",
          "SECH",
          "SECOND",
          "SERIESSUM",
          "SHEET",
          "SHEETS",
          "SIGN",
          "SIN",
          "SINH",
          "SKEW",
          "SKEW.P",
          "SLN",
          "SLOPE",
          "SMALL",
          "SQL.REQUEST",
          "SQRT",
          "SQRTPI",
          "STANDARDIZE",
          "STDEV",
          "STDEV.P",
          "STDEV.S",
          "STDEVA",
          "STDEVP",
          "STDEVPA",
          "STEYX",
          "SUBSTITUTE",
          "SUBTOTAL",
          "SUM",
          "SUMIF",
          "SUMIFS",
          "SUMPRODUCT",
          "SUMSQ",
          "SUMX2MY2",
          "SUMX2PY2",
          "SUMXMY2",
          "SWITCH",
          "SYD",
          "T",
          "TAN",
          "TANH",
          "TBILLEQ",
          "TBILLPRICE",
          "TBILLYIELD",
          "T.DIST",
          "T.DIST.2T",
          "T.DIST.RT",
          "TDIST",
          "TEXT",
          "TEXTJOIN",
          "TIME",
          "TIMEVALUE",
          "T.INV",
          "T.INV.2T",
          "TINV",
          "TODAY",
          "TRANSPOSE",
          "TREND",
          "TRIM",
          "TRIMMEAN",
          "TRUE|0",
          "TRUNC",
          "T.TEST",
          "TTEST",
          "TYPE",
          "UNICHAR",
          "UNICODE",
          "UPPER",
          "VALUE",
          "VAR",
          "VAR.P",
          "VAR.S",
          "VARA",
          "VARP",
          "VARPA",
          "VDB",
          "VLOOKUP",
          "WEBSERVICE",
          "WEEKDAY",
          "WEEKNUM",
          "WEIBULL",
          "WEIBULL.DIST",
          "WORKDAY",
          "WORKDAY.INTL",
          "XIRR",
          "XNPV",
          "XOR",
          "YEAR",
          "YEARFRAC",
          "YIELD",
          "YIELDDISC",
          "YIELDMAT",
          "Z.TEST",
          "ZTEST"
        ]
      },
      contains: [
        {
          /* matches a beginning equal sign found in Excel formula examples */
          begin: /^=/,
          end: /[^=]/,
          returnEnd: !0,
          illegal: /=/,
          /* only allow single equal sign at front of line */
          relevance: 10
        },
        /* technically, there can be more than 2 letters in column names, but this prevents conflict with some keywords */
        {
          /* matches a reference to a single cell */
          className: "symbol",
          begin: /\b[A-Z]{1,2}\d+\b/,
          end: /[^\d]/,
          excludeEnd: !0,
          relevance: 0
        },
        {
          /* matches a reference to a range of cells */
          className: "symbol",
          begin: /[A-Z]{0,2}\d*:[A-Z]{0,2}\d*/,
          relevance: 0
        },
        t.BACKSLASH_ESCAPE,
        t.QUOTE_STRING_MODE,
        {
          className: "number",
          begin: t.NUMBER_RE + "(%)?",
          relevance: 0
        },
        /* Excel formula comments are done by putting the comment in a function call to N() */
        t.COMMENT(
          /\bN\(/,
          /\)/,
          {
            excludeBegin: !0,
            excludeEnd: !0,
            illegal: /\n/
          }
        )
      ]
    };
  }
  return yE = e, yE;
}
var TE, ND;
function BZ() {
  if (ND) return TE;
  ND = 1;
  function e(t) {
    return {
      name: "FIX",
      contains: [
        {
          begin: /[^\u2401\u0001]+/,
          end: /[\u2401\u0001]/,
          excludeEnd: !0,
          returnBegin: !0,
          returnEnd: !1,
          contains: [
            {
              begin: /([^\u2401\u0001=]+)/,
              end: /=([^\u2401\u0001=]+)/,
              returnEnd: !0,
              returnBegin: !1,
              className: "attr"
            },
            {
              begin: /=/,
              end: /([\u2401\u0001])/,
              excludeEnd: !0,
              excludeBegin: !0,
              className: "string"
            }
          ]
        }
      ],
      case_insensitive: !0
    };
  }
  return TE = e, TE;
}
var CE, DD;
function $Z() {
  if (DD) return CE;
  DD = 1;
  function e(t) {
    const n = {
      className: "string",
      begin: /'(.|\\[xXuU][a-zA-Z0-9]+)'/
    }, r = {
      className: "string",
      variants: [
        {
          begin: '"',
          end: '"'
        }
      ]
    }, a = {
      className: "function",
      beginKeywords: "def",
      end: /[:={\[(\n;]/,
      excludeEnd: !0,
      contains: [{
        className: "title",
        relevance: 0,
        begin: /[^0-9\n\t "'(),.`{}\[\]:;][^\n\t "'(),.`{}\[\]:;]+|[^0-9\n\t "'(),.`{}\[\]:;=]/
      }]
    };
    return {
      name: "Flix",
      keywords: {
        keyword: [
          "case",
          "class",
          "def",
          "else",
          "enum",
          "if",
          "impl",
          "import",
          "in",
          "lat",
          "rel",
          "index",
          "let",
          "match",
          "namespace",
          "switch",
          "type",
          "yield",
          "with"
        ],
        literal: [
          "true",
          "false"
        ]
      },
      contains: [
        t.C_LINE_COMMENT_MODE,
        t.C_BLOCK_COMMENT_MODE,
        n,
        r,
        a,
        t.C_NUMBER_MODE
      ]
    };
  }
  return CE = e, CE;
}
var AE, ID;
function UZ() {
  if (ID) return AE;
  ID = 1;
  function e(t) {
    const n = t.regex, r = {
      className: "params",
      begin: "\\(",
      end: "\\)"
    }, i = { variants: [
      t.COMMENT("!", "$", { relevance: 0 }),
      // allow FORTRAN 77 style comments
      t.COMMENT("^C[ ]", "$", { relevance: 0 }),
      t.COMMENT("^C$", "$", { relevance: 0 })
    ] }, a = /(_[a-z_\d]+)?/, o = /([de][+-]?\d+)?/, s = {
      className: "number",
      variants: [
        { begin: n.concat(/\b\d+/, /\.(\d*)/, o, a) },
        { begin: n.concat(/\b\d+/, o, a) },
        { begin: n.concat(/\.\d+/, o, a) }
      ],
      relevance: 0
    }, l = {
      className: "function",
      beginKeywords: "subroutine function program",
      illegal: "[${=\\n]",
      contains: [
        t.UNDERSCORE_TITLE_MODE,
        r
      ]
    }, u = {
      className: "string",
      relevance: 0,
      variants: [
        t.APOS_STRING_MODE,
        t.QUOTE_STRING_MODE
      ]
    };
    return {
      name: "Fortran",
      case_insensitive: !0,
      aliases: [
        "f90",
        "f95"
      ],
      keywords: {
        keyword: [
          "kind",
          "do",
          "concurrent",
          "local",
          "shared",
          "while",
          "private",
          "call",
          "intrinsic",
          "where",
          "elsewhere",
          "type",
          "endtype",
          "endmodule",
          "endselect",
          "endinterface",
          "end",
          "enddo",
          "endif",
          "if",
          "forall",
          "endforall",
          "only",
          "contains",
          "default",
          "return",
          "stop",
          "then",
          "block",
          "endblock",
          "endassociate",
          "public",
          "subroutine|10",
          "function",
          "program",
          ".and.",
          ".or.",
          ".not.",
          ".le.",
          ".eq.",
          ".ge.",
          ".gt.",
          ".lt.",
          "goto",
          "save",
          "else",
          "use",
          "module",
          "select",
          "case",
          "access",
          "blank",
          "direct",
          "exist",
          "file",
          "fmt",
          "form",
          "formatted",
          "iostat",
          "name",
          "named",
          "nextrec",
          "number",
          "opened",
          "rec",
          "recl",
          "sequential",
          "status",
          "unformatted",
          "unit",
          "continue",
          "format",
          "pause",
          "cycle",
          "exit",
          "c_null_char",
          "c_alert",
          "c_backspace",
          "c_form_feed",
          "flush",
          "wait",
          "decimal",
          "round",
          "iomsg",
          "synchronous",
          "nopass",
          "non_overridable",
          "pass",
          "protected",
          "volatile",
          "abstract",
          "extends",
          "import",
          "non_intrinsic",
          "value",
          "deferred",
          "generic",
          "final",
          "enumerator",
          "class",
          "associate",
          "bind",
          "enum",
          "c_int",
          "c_short",
          "c_long",
          "c_long_long",
          "c_signed_char",
          "c_size_t",
          "c_int8_t",
          "c_int16_t",
          "c_int32_t",
          "c_int64_t",
          "c_int_least8_t",
          "c_int_least16_t",
          "c_int_least32_t",
          "c_int_least64_t",
          "c_int_fast8_t",
          "c_int_fast16_t",
          "c_int_fast32_t",
          "c_int_fast64_t",
          "c_intmax_t",
          "C_intptr_t",
          "c_float",
          "c_double",
          "c_long_double",
          "c_float_complex",
          "c_double_complex",
          "c_long_double_complex",
          "c_bool",
          "c_char",
          "c_null_ptr",
          "c_null_funptr",
          "c_new_line",
          "c_carriage_return",
          "c_horizontal_tab",
          "c_vertical_tab",
          "iso_c_binding",
          "c_loc",
          "c_funloc",
          "c_associated",
          "c_f_pointer",
          "c_ptr",
          "c_funptr",
          "iso_fortran_env",
          "character_storage_size",
          "error_unit",
          "file_storage_size",
          "input_unit",
          "iostat_end",
          "iostat_eor",
          "numeric_storage_size",
          "output_unit",
          "c_f_procpointer",
          "ieee_arithmetic",
          "ieee_support_underflow_control",
          "ieee_get_underflow_mode",
          "ieee_set_underflow_mode",
          "newunit",
          "contiguous",
          "recursive",
          "pad",
          "position",
          "action",
          "delim",
          "readwrite",
          "eor",
          "advance",
          "nml",
          "interface",
          "procedure",
          "namelist",
          "include",
          "sequence",
          "elemental",
          "pure",
          "impure",
          "integer",
          "real",
          "character",
          "complex",
          "logical",
          "codimension",
          "dimension",
          "allocatable|10",
          "parameter",
          "external",
          "implicit|10",
          "none",
          "double",
          "precision",
          "assign",
          "intent",
          "optional",
          "pointer",
          "target",
          "in",
          "out",
          "common",
          "equivalence",
          "data"
        ],
        literal: [
          ".False.",
          ".True."
        ],
        built_in: [
          "alog",
          "alog10",
          "amax0",
          "amax1",
          "amin0",
          "amin1",
          "amod",
          "cabs",
          "ccos",
          "cexp",
          "clog",
          "csin",
          "csqrt",
          "dabs",
          "dacos",
          "dasin",
          "datan",
          "datan2",
          "dcos",
          "dcosh",
          "ddim",
          "dexp",
          "dint",
          "dlog",
          "dlog10",
          "dmax1",
          "dmin1",
          "dmod",
          "dnint",
          "dsign",
          "dsin",
          "dsinh",
          "dsqrt",
          "dtan",
          "dtanh",
          "float",
          "iabs",
          "idim",
          "idint",
          "idnint",
          "ifix",
          "isign",
          "max0",
          "max1",
          "min0",
          "min1",
          "sngl",
          "algama",
          "cdabs",
          "cdcos",
          "cdexp",
          "cdlog",
          "cdsin",
          "cdsqrt",
          "cqabs",
          "cqcos",
          "cqexp",
          "cqlog",
          "cqsin",
          "cqsqrt",
          "dcmplx",
          "dconjg",
          "derf",
          "derfc",
          "dfloat",
          "dgamma",
          "dimag",
          "dlgama",
          "iqint",
          "qabs",
          "qacos",
          "qasin",
          "qatan",
          "qatan2",
          "qcmplx",
          "qconjg",
          "qcos",
          "qcosh",
          "qdim",
          "qerf",
          "qerfc",
          "qexp",
          "qgamma",
          "qimag",
          "qlgama",
          "qlog",
          "qlog10",
          "qmax1",
          "qmin1",
          "qmod",
          "qnint",
          "qsign",
          "qsin",
          "qsinh",
          "qsqrt",
          "qtan",
          "qtanh",
          "abs",
          "acos",
          "aimag",
          "aint",
          "anint",
          "asin",
          "atan",
          "atan2",
          "char",
          "cmplx",
          "conjg",
          "cos",
          "cosh",
          "exp",
          "ichar",
          "index",
          "int",
          "log",
          "log10",
          "max",
          "min",
          "nint",
          "sign",
          "sin",
          "sinh",
          "sqrt",
          "tan",
          "tanh",
          "print",
          "write",
          "dim",
          "lge",
          "lgt",
          "lle",
          "llt",
          "mod",
          "nullify",
          "allocate",
          "deallocate",
          "adjustl",
          "adjustr",
          "all",
          "allocated",
          "any",
          "associated",
          "bit_size",
          "btest",
          "ceiling",
          "count",
          "cshift",
          "date_and_time",
          "digits",
          "dot_product",
          "eoshift",
          "epsilon",
          "exponent",
          "floor",
          "fraction",
          "huge",
          "iand",
          "ibclr",
          "ibits",
          "ibset",
          "ieor",
          "ior",
          "ishft",
          "ishftc",
          "lbound",
          "len_trim",
          "matmul",
          "maxexponent",
          "maxloc",
          "maxval",
          "merge",
          "minexponent",
          "minloc",
          "minval",
          "modulo",
          "mvbits",
          "nearest",
          "pack",
          "present",
          "product",
          "radix",
          "random_number",
          "random_seed",
          "range",
          "repeat",
          "reshape",
          "rrspacing",
          "scale",
          "scan",
          "selected_int_kind",
          "selected_real_kind",
          "set_exponent",
          "shape",
          "size",
          "spacing",
          "spread",
          "sum",
          "system_clock",
          "tiny",
          "transpose",
          "trim",
          "ubound",
          "unpack",
          "verify",
          "achar",
          "iachar",
          "transfer",
          "dble",
          "entry",
          "dprod",
          "cpu_time",
          "command_argument_count",
          "get_command",
          "get_command_argument",
          "get_environment_variable",
          "is_iostat_end",
          "ieee_arithmetic",
          "ieee_support_underflow_control",
          "ieee_get_underflow_mode",
          "ieee_set_underflow_mode",
          "is_iostat_eor",
          "move_alloc",
          "new_line",
          "selected_char_kind",
          "same_type_as",
          "extends_type_of",
          "acosh",
          "asinh",
          "atanh",
          "bessel_j0",
          "bessel_j1",
          "bessel_jn",
          "bessel_y0",
          "bessel_y1",
          "bessel_yn",
          "erf",
          "erfc",
          "erfc_scaled",
          "gamma",
          "log_gamma",
          "hypot",
          "norm2",
          "atomic_define",
          "atomic_ref",
          "execute_command_line",
          "leadz",
          "trailz",
          "storage_size",
          "merge_bits",
          "bge",
          "bgt",
          "ble",
          "blt",
          "dshiftl",
          "dshiftr",
          "findloc",
          "iall",
          "iany",
          "iparity",
          "image_index",
          "lcobound",
          "ucobound",
          "maskl",
          "maskr",
          "num_images",
          "parity",
          "popcnt",
          "poppar",
          "shifta",
          "shiftl",
          "shiftr",
          "this_image",
          "sync",
          "change",
          "team",
          "co_broadcast",
          "co_max",
          "co_min",
          "co_sum",
          "co_reduce"
        ]
      },
      illegal: /\/\*/,
      contains: [
        u,
        l,
        // allow `C = value` for assignments so they aren't misdetected
        // as Fortran 77 style comments
        {
          begin: /^C\s*=(?!=)/,
          relevance: 0
        },
        i,
        s
      ]
    };
  }
  return AE = e, AE;
}
var OE, LD;
function qZ() {
  if (LD) return OE;
  LD = 1;
  function e(s) {
    return new RegExp(s.replace(/[-/\\^$*+?.()|[\]{}]/g, "\\$&"), "m");
  }
  function t(s) {
    return s ? typeof s == "string" ? s : s.source : null;
  }
  function n(s) {
    return r("(?=", s, ")");
  }
  function r(...s) {
    return s.map((u) => t(u)).join("");
  }
  function i(s) {
    const l = s[s.length - 1];
    return typeof l == "object" && l.constructor === Object ? (s.splice(s.length - 1, 1), l) : {};
  }
  function a(...s) {
    return "(" + (i(s).capture ? "" : "?:") + s.map((c) => t(c)).join("|") + ")";
  }
  function o(s) {
    const l = [
      "abstract",
      "and",
      "as",
      "assert",
      "base",
      "begin",
      "class",
      "default",
      "delegate",
      "do",
      "done",
      "downcast",
      "downto",
      "elif",
      "else",
      "end",
      "exception",
      "extern",
      // "false", // literal
      "finally",
      "fixed",
      "for",
      "fun",
      "function",
      "global",
      "if",
      "in",
      "inherit",
      "inline",
      "interface",
      "internal",
      "lazy",
      "let",
      "match",
      "member",
      "module",
      "mutable",
      "namespace",
      "new",
      // "not", // built_in
      // "null", // literal
      "of",
      "open",
      "or",
      "override",
      "private",
      "public",
      "rec",
      "return",
      "static",
      "struct",
      "then",
      "to",
      // "true", // literal
      "try",
      "type",
      "upcast",
      "use",
      "val",
      "void",
      "when",
      "while",
      "with",
      "yield"
    ], u = {
      // monad builder keywords (matches before non-bang keywords)
      scope: "keyword",
      match: /\b(yield|return|let|do|match|use)!/
    }, c = [
      "if",
      "else",
      "endif",
      "line",
      "nowarn",
      "light",
      "r",
      "i",
      "I",
      "load",
      "time",
      "help",
      "quit"
    ], d = [
      "true",
      "false",
      "null",
      "Some",
      "None",
      "Ok",
      "Error",
      "infinity",
      "infinityf",
      "nan",
      "nanf"
    ], f = [
      "__LINE__",
      "__SOURCE_DIRECTORY__",
      "__SOURCE_FILE__"
    ], h = [
      // basic types
      "bool",
      "byte",
      "sbyte",
      "int8",
      "int16",
      "int32",
      "uint8",
      "uint16",
      "uint32",
      "int",
      "uint",
      "int64",
      "uint64",
      "nativeint",
      "unativeint",
      "decimal",
      "float",
      "double",
      "float32",
      "single",
      "char",
      "string",
      "unit",
      "bigint",
      // other native types or lowercase aliases
      "option",
      "voption",
      "list",
      "array",
      "seq",
      "byref",
      "exn",
      "inref",
      "nativeptr",
      "obj",
      "outref",
      "voidptr",
      // other important FSharp types
      "Result"
    ], v = {
      keyword: l,
      literal: d,
      built_in: [
        // Somewhat arbitrary list of builtin functions and values.
        // Most of them are declared in Microsoft.FSharp.Core
        // I tried to stay relevant by adding only the most idiomatic
        // and most used symbols that are not already declared as types.
        "not",
        "ref",
        "raise",
        "reraise",
        "dict",
        "readOnlyDict",
        "set",
        "get",
        "enum",
        "sizeof",
        "typeof",
        "typedefof",
        "nameof",
        "nullArg",
        "invalidArg",
        "invalidOp",
        "id",
        "fst",
        "snd",
        "ignore",
        "lock",
        "using",
        "box",
        "unbox",
        "tryUnbox",
        "printf",
        "printfn",
        "sprintf",
        "eprintf",
        "eprintfn",
        "fprintf",
        "fprintfn",
        "failwith",
        "failwithf"
      ],
      "variable.constant": f
    }, y = {
      variants: [
        s.COMMENT(/\(\*(?!\))/, /\*\)/, {
          contains: ["self"]
        }),
        s.C_LINE_COMMENT_MODE
      ]
    }, g = /[a-zA-Z_](\w|')*/, E = {
      scope: "variable",
      begin: /``/,
      end: /``/
    }, S = /\B('|\^)/, C = {
      scope: "symbol",
      variants: [
        // the type name is a quoted identifier:
        { match: r(S, /``.*?``/) },
        // the type name is a normal identifier (we don't use IDENTIFIER_RE because there cannot be another apostrophe here):
        { match: r(S, s.UNDERSCORE_IDENT_RE) }
      ],
      relevance: 0
    }, T = function({ includeEqual: oe }) {
      let ae;
      oe ? ae = "!%&*+-/<=>@^|~?" : ae = "!%&*+-/<>@^|~?";
      const pe = Array.from(ae), Se = r("[", ...pe.map(e), "]"), Re = a(Se, /\./), Ye = r(Re, n(Re)), nt = a(
        r(Ye, Re, "*"),
        // Matches at least 2 chars operators
        r(Se, "+")
        // Matches at least one char operators
      );
      return {
        scope: "operator",
        match: a(
          // symbolic operators:
          nt,
          // other symbolic keywords:
          // Type casting and conversion operators:
          /:\?>/,
          /:\?/,
          /:>/,
          /:=/,
          // Reference cell assignment
          /::?/,
          // : or ::
          /\$/
        ),
        // A single $ can be used as an operator
        relevance: 0
      };
    }, O = T({ includeEqual: !0 }), R = T({ includeEqual: !1 }), D = function(oe, ae) {
      return {
        begin: r(
          // a type annotation is a
          oe,
          // should be a colon or the 'of' keyword
          n(
            // that has to be followed by
            r(
              /\s*/,
              // optional space
              a(
                // then either of:
                /\w/,
                // word
                /'/,
                // generic type name
                /\^/,
                // generic type name
                /#/,
                // flexible type name
                /``/,
                // quoted type name
                /\(/,
                // parens type expression
                /{\|/
                // anonymous type annotation
              )
            )
          )
        ),
        beginScope: ae,
        // BUG: because ending with \n is necessary for some cases, multi-line type annotations are not properly supported.
        // Examples where \n is required at the end:
        // - abstract member definitions in classes: abstract Property : int * string
        // - return type annotations: let f f' = f' () : returnTypeAnnotation
        // - record fields definitions: { A : int \n B : string }
        end: n(
          a(
            /\n/,
            /=/
          )
        ),
        relevance: 0,
        // we need the known types, and we need the type constraint keywords and literals. e.g.: when 'a : null
        keywords: s.inherit(v, { type: h }),
        contains: [
          y,
          C,
          s.inherit(E, { scope: null }),
          // match to avoid strange patterns inside that may break the parsing
          R
        ]
      };
    }, q = D(/:/, "operator"), $ = D(/\bof\b/, "keyword"), P = {
      begin: [
        /(^|\s+)/,
        // prevents matching the following: `match s.stype with`
        /type/,
        /\s+/,
        g
      ],
      beginScope: {
        2: "keyword",
        4: "title.class"
      },
      end: n(/\(|=|$/),
      keywords: v,
      // match keywords in type constraints. e.g.: when 'a : null
      contains: [
        y,
        s.inherit(E, { scope: null }),
        // match to avoid strange patterns inside that may break the parsing
        C,
        {
          // For visual consistency, highlight type brackets as operators.
          scope: "operator",
          match: /<|>/
        },
        q
        // generic types can have constraints, which are type annotations. e.g. type MyType<'T when 'T : delegate<obj * string>> =
      ]
    }, Y = {
      // computation expressions:
      scope: "computation-expression",
      // BUG: might conflict with record deconstruction. e.g. let f { Name = name } = name // will highlight f
      match: /\b[_a-z]\w*(?=\s*\{)/
    }, L = {
      // preprocessor directives and fsi commands:
      begin: [
        /^\s*/,
        r(/#/, a(...c)),
        /\b/
      ],
      beginScope: { 2: "meta" },
      end: n(/\s|$/)
    }, x = {
      variants: [
        s.BINARY_NUMBER_MODE,
        s.C_NUMBER_MODE
      ]
    }, I = {
      scope: "string",
      begin: /"/,
      end: /"/,
      contains: [
        s.BACKSLASH_ESCAPE
      ]
    }, k = {
      scope: "string",
      begin: /@"/,
      end: /"/,
      contains: [
        {
          match: /""/
          // escaped "
        },
        s.BACKSLASH_ESCAPE
      ]
    }, B = {
      scope: "string",
      begin: /"""/,
      end: /"""/,
      relevance: 2
    }, W = {
      scope: "subst",
      begin: /\{/,
      end: /\}/,
      keywords: v
    }, Z = {
      scope: "string",
      begin: /\$"/,
      end: /"/,
      contains: [
        {
          match: /\{\{/
          // escaped {
        },
        {
          match: /\}\}/
          // escaped }
        },
        s.BACKSLASH_ESCAPE,
        W
      ]
    }, V = {
      scope: "string",
      begin: /(\$@|@\$)"/,
      end: /"/,
      contains: [
        {
          match: /\{\{/
          // escaped {
        },
        {
          match: /\}\}/
          // escaped }
        },
        {
          match: /""/
        },
        s.BACKSLASH_ESCAPE,
        W
      ]
    }, K = {
      scope: "string",
      begin: /\$"""/,
      end: /"""/,
      contains: [
        {
          match: /\{\{/
          // escaped {
        },
        {
          match: /\}\}/
          // escaped }
        },
        W
      ],
      relevance: 2
    }, ne = {
      scope: "string",
      match: r(
        /'/,
        a(
          /[^\\']/,
          // either a single non escaped char...
          /\\(?:.|\d{3}|x[a-fA-F\d]{2}|u[a-fA-F\d]{4}|U[a-fA-F\d]{8})/
          // ...or an escape sequence
        ),
        /'/
      )
    };
    return W.contains = [
      V,
      Z,
      k,
      I,
      ne,
      u,
      y,
      E,
      q,
      Y,
      L,
      x,
      C,
      O
    ], {
      name: "F#",
      aliases: [
        "fs",
        "f#"
      ],
      keywords: v,
      illegal: /\/\*/,
      classNameAliases: {
        "computation-expression": "keyword"
      },
      contains: [
        u,
        {
          variants: [
            K,
            V,
            Z,
            B,
            k,
            I,
            ne
          ]
        },
        y,
        E,
        P,
        {
          // e.g. [<Attributes("")>] or [<``module``: MyCustomAttributeThatWorksOnModules>]
          // or [<Sealed; NoEquality; NoComparison; CompiledName("FSharpAsync`1")>]
          scope: "meta",
          begin: /\[</,
          end: />\]/,
          relevance: 2,
          contains: [
            E,
            // can contain any constant value
            B,
            k,
            I,
            ne,
            x
          ]
        },
        $,
        q,
        Y,
        L,
        x,
        C,
        O
      ]
    };
  }
  return OE = o, OE;
}
var RE, kD;
function GZ() {
  if (kD) return RE;
  kD = 1;
  function e(t) {
    const n = t.regex, r = {
      keyword: "abort acronym acronyms alias all and assign binary card diag display else eq file files for free ge gt if integer le loop lt maximizing minimizing model models ne negative no not option options or ord positive prod put putpage puttl repeat sameas semicont semiint smax smin solve sos1 sos2 sum system table then until using while xor yes",
      literal: "eps inf na",
      built_in: "abs arccos arcsin arctan arctan2 Beta betaReg binomial ceil centropy cos cosh cvPower div div0 eDist entropy errorf execSeed exp fact floor frac gamma gammaReg log logBeta logGamma log10 log2 mapVal max min mod ncpCM ncpF ncpVUpow ncpVUsin normal pi poly power randBinomial randLinear randTriangle round rPower sigmoid sign signPower sin sinh slexp sllog10 slrec sqexp sqlog10 sqr sqrec sqrt tan tanh trunc uniform uniformInt vcPower bool_and bool_eqv bool_imp bool_not bool_or bool_xor ifThen rel_eq rel_ge rel_gt rel_le rel_lt rel_ne gday gdow ghour gleap gmillisec gminute gmonth gsecond gyear jdate jnow jstart jtime errorLevel execError gamsRelease gamsVersion handleCollect handleDelete handleStatus handleSubmit heapFree heapLimit heapSize jobHandle jobKill jobStatus jobTerminate licenseLevel licenseStatus maxExecError sleep timeClose timeComp timeElapsed timeExec timeStart"
    }, i = {
      className: "params",
      begin: /\(/,
      end: /\)/,
      excludeBegin: !0,
      excludeEnd: !0
    }, a = {
      className: "symbol",
      variants: [
        { begin: /=[lgenxc]=/ },
        { begin: /\$/ }
      ]
    }, o = {
      // One-line quoted comment string
      className: "comment",
      variants: [
        {
          begin: "'",
          end: "'"
        },
        {
          begin: '"',
          end: '"'
        }
      ],
      illegal: "\\n",
      contains: [t.BACKSLASH_ESCAPE]
    }, s = {
      begin: "/",
      end: "/",
      keywords: r,
      contains: [
        o,
        t.C_LINE_COMMENT_MODE,
        t.C_BLOCK_COMMENT_MODE,
        t.QUOTE_STRING_MODE,
        t.APOS_STRING_MODE,
        t.C_NUMBER_MODE
      ]
    }, l = /[a-z0-9&#*=?@\\><:,()$[\]_.{}!+%^-]+/, u = {
      // Parameter/set/variable description text
      begin: /[a-z][a-z0-9_]*(\([a-z0-9_, ]*\))?[ \t]+/,
      excludeBegin: !0,
      end: "$",
      endsWithParent: !0,
      contains: [
        o,
        s,
        {
          className: "comment",
          // one comment word, then possibly more
          begin: n.concat(
            l,
            // [ ] because \s would be too broad (matching newlines)
            n.anyNumberOfTimes(n.concat(/[ ]+/, l))
          ),
          relevance: 0
        }
      ]
    };
    return {
      name: "GAMS",
      aliases: ["gms"],
      case_insensitive: !0,
      keywords: r,
      contains: [
        t.COMMENT(/^\$ontext/, /^\$offtext/),
        {
          className: "meta",
          begin: "^\\$[a-z0-9]+",
          end: "$",
          returnBegin: !0,
          contains: [
            {
              className: "keyword",
              begin: "^\\$[a-z0-9]+"
            }
          ]
        },
        t.COMMENT("^\\*", "$"),
        t.C_LINE_COMMENT_MODE,
        t.C_BLOCK_COMMENT_MODE,
        t.QUOTE_STRING_MODE,
        t.APOS_STRING_MODE,
        // Declarations
        {
          beginKeywords: "set sets parameter parameters variable variables scalar scalars equation equations",
          end: ";",
          contains: [
            t.COMMENT("^\\*", "$"),
            t.C_LINE_COMMENT_MODE,
            t.C_BLOCK_COMMENT_MODE,
            t.QUOTE_STRING_MODE,
            t.APOS_STRING_MODE,
            s,
            u
          ]
        },
        {
          // table environment
          beginKeywords: "table",
          end: ";",
          returnBegin: !0,
          contains: [
            {
              // table header row
              beginKeywords: "table",
              end: "$",
              contains: [u]
            },
            t.COMMENT("^\\*", "$"),
            t.C_LINE_COMMENT_MODE,
            t.C_BLOCK_COMMENT_MODE,
            t.QUOTE_STRING_MODE,
            t.APOS_STRING_MODE,
            t.C_NUMBER_MODE
            // Table does not contain DESCTEXT or ASSIGNMENT
          ]
        },
        // Function definitions
        {
          className: "function",
          begin: /^[a-z][a-z0-9_,\-+' ()$]+\.{2}/,
          returnBegin: !0,
          contains: [
            {
              // Function title
              className: "title",
              begin: /^[a-z0-9_]+/
            },
            i,
            a
          ]
        },
        t.C_NUMBER_MODE,
        a
      ]
    };
  }
  return RE = e, RE;
}
var wE, MD;
function YZ() {
  if (MD) return wE;
  MD = 1;
  function e(t) {
    const n = {
      keyword: "bool break call callexe checkinterrupt clear clearg closeall cls comlog compile continue create debug declare delete disable dlibrary dllcall do dos ed edit else elseif enable end endfor endif endp endo errorlog errorlogat expr external fn for format goto gosub graph if keyword let lib library line load loadarray loadexe loadf loadk loadm loadp loads loadx local locate loopnextindex lprint lpwidth lshow matrix msym ndpclex new open output outwidth plot plotsym pop prcsn print printdos proc push retp return rndcon rndmod rndmult rndseed run save saveall screen scroll setarray show sparse stop string struct system trace trap threadfor threadendfor threadbegin threadjoin threadstat threadend until use while winprint ne ge le gt lt and xor or not eq eqv",
      built_in: "abs acf aconcat aeye amax amean AmericanBinomCall AmericanBinomCall_Greeks AmericanBinomCall_ImpVol AmericanBinomPut AmericanBinomPut_Greeks AmericanBinomPut_ImpVol AmericanBSCall AmericanBSCall_Greeks AmericanBSCall_ImpVol AmericanBSPut AmericanBSPut_Greeks AmericanBSPut_ImpVol amin amult annotationGetDefaults annotationSetBkd annotationSetFont annotationSetLineColor annotationSetLineStyle annotationSetLineThickness annualTradingDays arccos arcsin areshape arrayalloc arrayindex arrayinit arraytomat asciiload asclabel astd astds asum atan atan2 atranspose axmargin balance band bandchol bandcholsol bandltsol bandrv bandsolpd bar base10 begwind besselj bessely beta box boxcox cdfBeta cdfBetaInv cdfBinomial cdfBinomialInv cdfBvn cdfBvn2 cdfBvn2e cdfCauchy cdfCauchyInv cdfChic cdfChii cdfChinc cdfChincInv cdfExp cdfExpInv cdfFc cdfFnc cdfFncInv cdfGam cdfGenPareto cdfHyperGeo cdfLaplace cdfLaplaceInv cdfLogistic cdfLogisticInv cdfmControlCreate cdfMvn cdfMvn2e cdfMvnce cdfMvne cdfMvt2e cdfMvtce cdfMvte cdfN cdfN2 cdfNc cdfNegBinomial cdfNegBinomialInv cdfNi cdfPoisson cdfPoissonInv cdfRayleigh cdfRayleighInv cdfTc cdfTci cdfTnc cdfTvn cdfWeibull cdfWeibullInv cdir ceil ChangeDir chdir chiBarSquare chol choldn cholsol cholup chrs close code cols colsf combinate combinated complex con cond conj cons ConScore contour conv convertsatostr convertstrtosa corrm corrms corrvc corrx corrxs cos cosh counts countwts crossprd crout croutp csrcol csrlin csvReadM csvReadSA cumprodc cumsumc curve cvtos datacreate datacreatecomplex datalist dataload dataloop dataopen datasave date datestr datestring datestrymd dayinyr dayofweek dbAddDatabase dbClose dbCommit dbCreateQuery dbExecQuery dbGetConnectOptions dbGetDatabaseName dbGetDriverName dbGetDrivers dbGetHostName dbGetLastErrorNum dbGetLastErrorText dbGetNumericalPrecPolicy dbGetPassword dbGetPort dbGetTableHeaders dbGetTables dbGetUserName dbHasFeature dbIsDriverAvailable dbIsOpen dbIsOpenError dbOpen dbQueryBindValue dbQueryClear dbQueryCols dbQueryExecPrepared dbQueryFetchAllM dbQueryFetchAllSA dbQueryFetchOneM dbQueryFetchOneSA dbQueryFinish dbQueryGetBoundValue dbQueryGetBoundValues dbQueryGetField dbQueryGetLastErrorNum dbQueryGetLastErrorText dbQueryGetLastInsertID dbQueryGetLastQuery dbQueryGetPosition dbQueryIsActive dbQueryIsForwardOnly dbQueryIsNull dbQueryIsSelect dbQueryIsValid dbQueryPrepare dbQueryRows dbQuerySeek dbQuerySeekFirst dbQuerySeekLast dbQuerySeekNext dbQuerySeekPrevious dbQuerySetForwardOnly dbRemoveDatabase dbRollback dbSetConnectOptions dbSetDatabaseName dbSetHostName dbSetNumericalPrecPolicy dbSetPort dbSetUserName dbTransaction DeleteFile delif delrows denseToSp denseToSpRE denToZero design det detl dfft dffti diag diagrv digamma doswin DOSWinCloseall DOSWinOpen dotfeq dotfeqmt dotfge dotfgemt dotfgt dotfgtmt dotfle dotflemt dotflt dotfltmt dotfne dotfnemt draw drop dsCreate dstat dstatmt dstatmtControlCreate dtdate dtday dttime dttodtv dttostr dttoutc dtvnormal dtvtodt dtvtoutc dummy dummybr dummydn eig eigh eighv eigv elapsedTradingDays endwind envget eof eqSolve eqSolvemt eqSolvemtControlCreate eqSolvemtOutCreate eqSolveset erf erfc erfccplx erfcplx error etdays ethsec etstr EuropeanBinomCall EuropeanBinomCall_Greeks EuropeanBinomCall_ImpVol EuropeanBinomPut EuropeanBinomPut_Greeks EuropeanBinomPut_ImpVol EuropeanBSCall EuropeanBSCall_Greeks EuropeanBSCall_ImpVol EuropeanBSPut EuropeanBSPut_Greeks EuropeanBSPut_ImpVol exctsmpl exec execbg exp extern eye fcheckerr fclearerr feq feqmt fflush fft ffti fftm fftmi fftn fge fgemt fgets fgetsa fgetsat fgetst fgt fgtmt fileinfo filesa fle flemt floor flt fltmt fmod fne fnemt fonts fopen formatcv formatnv fputs fputst fseek fstrerror ftell ftocv ftos ftostrC gamma gammacplx gammaii gausset gdaAppend gdaCreate gdaDStat gdaDStatMat gdaGetIndex gdaGetName gdaGetNames gdaGetOrders gdaGetType gdaGetTypes gdaGetVarInfo gdaIsCplx gdaLoad gdaPack gdaRead gdaReadByIndex gdaReadSome gdaReadSparse gdaReadStruct gdaReportVarInfo gdaSave gdaUpdate gdaUpdateAndPack gdaVars gdaWrite gdaWrite32 gdaWriteSome getarray getdims getf getGAUSShome getmatrix getmatrix4D getname getnamef getNextTradingDay getNextWeekDay getnr getorders getpath getPreviousTradingDay getPreviousWeekDay getRow getscalar3D getscalar4D getTrRow getwind glm gradcplx gradMT gradMTm gradMTT gradMTTm gradp graphprt graphset hasimag header headermt hess hessMT hessMTg hessMTgw hessMTm hessMTmw hessMTT hessMTTg hessMTTgw hessMTTm hessMTw hessp hist histf histp hsec imag indcv indexcat indices indices2 indicesf indicesfn indnv indsav integrate1d integrateControlCreate intgrat2 intgrat3 inthp1 inthp2 inthp3 inthp4 inthpControlCreate intquad1 intquad2 intquad3 intrleav intrleavsa intrsect intsimp inv invpd invswp iscplx iscplxf isden isinfnanmiss ismiss key keyav keyw lag lag1 lagn lapEighb lapEighi lapEighvb lapEighvi lapgEig lapgEigh lapgEighv lapgEigv lapgSchur lapgSvdcst lapgSvds lapgSvdst lapSvdcusv lapSvds lapSvdusv ldlp ldlsol linSolve listwise ln lncdfbvn lncdfbvn2 lncdfmvn lncdfn lncdfn2 lncdfnc lnfact lngammacplx lnpdfmvn lnpdfmvt lnpdfn lnpdft loadd loadstruct loadwind loess loessmt loessmtControlCreate log loglog logx logy lower lowmat lowmat1 ltrisol lu lusol machEpsilon make makevars makewind margin matalloc matinit mattoarray maxbytes maxc maxindc maxv maxvec mbesselei mbesselei0 mbesselei1 mbesseli mbesseli0 mbesseli1 meanc median mergeby mergevar minc minindc minv miss missex missrv moment momentd movingave movingaveExpwgt movingaveWgt nextindex nextn nextnevn nextwind ntos null null1 numCombinations ols olsmt olsmtControlCreate olsqr olsqr2 olsqrmt ones optn optnevn orth outtyp pacf packedToSp packr parse pause pdfCauchy pdfChi pdfExp pdfGenPareto pdfHyperGeo pdfLaplace pdfLogistic pdfn pdfPoisson pdfRayleigh pdfWeibull pi pinv pinvmt plotAddArrow plotAddBar plotAddBox plotAddHist plotAddHistF plotAddHistP plotAddPolar plotAddScatter plotAddShape plotAddTextbox plotAddTS plotAddXY plotArea plotBar plotBox plotClearLayout plotContour plotCustomLayout plotGetDefaults plotHist plotHistF plotHistP plotLayout plotLogLog plotLogX plotLogY plotOpenWindow plotPolar plotSave plotScatter plotSetAxesPen plotSetBar plotSetBarFill plotSetBarStacked plotSetBkdColor plotSetFill plotSetGrid plotSetLegend plotSetLineColor plotSetLineStyle plotSetLineSymbol plotSetLineThickness plotSetNewWindow plotSetTitle plotSetWhichYAxis plotSetXAxisShow plotSetXLabel plotSetXRange plotSetXTicInterval plotSetXTicLabel plotSetYAxisShow plotSetYLabel plotSetYRange plotSetZAxisShow plotSetZLabel plotSurface plotTS plotXY polar polychar polyeval polygamma polyint polymake polymat polymroot polymult polyroot pqgwin previousindex princomp printfm printfmt prodc psi putarray putf putvals pvCreate pvGetIndex pvGetParNames pvGetParVector pvLength pvList pvPack pvPacki pvPackm pvPackmi pvPacks pvPacksi pvPacksm pvPacksmi pvPutParVector pvTest pvUnpack QNewton QNewtonmt QNewtonmtControlCreate QNewtonmtOutCreate QNewtonSet QProg QProgmt QProgmtInCreate qqr qqre qqrep qr qre qrep qrsol qrtsol qtyr qtyre qtyrep quantile quantiled qyr qyre qyrep qz rank rankindx readr real reclassify reclassifyCuts recode recserar recsercp recserrc rerun rescale reshape rets rev rfft rffti rfftip rfftn rfftnp rfftp rndBernoulli rndBeta rndBinomial rndCauchy rndChiSquare rndCon rndCreateState rndExp rndGamma rndGeo rndGumbel rndHyperGeo rndi rndKMbeta rndKMgam rndKMi rndKMn rndKMnb rndKMp rndKMu rndKMvm rndLaplace rndLCbeta rndLCgam rndLCi rndLCn rndLCnb rndLCp rndLCu rndLCvm rndLogNorm rndMTu rndMVn rndMVt rndn rndnb rndNegBinomial rndp rndPoisson rndRayleigh rndStateSkip rndu rndvm rndWeibull rndWishart rotater round rows rowsf rref sampleData satostrC saved saveStruct savewind scale scale3d scalerr scalinfnanmiss scalmiss schtoc schur searchsourcepath seekr select selif seqa seqm setdif setdifsa setvars setvwrmode setwind shell shiftr sin singleindex sinh sleep solpd sortc sortcc sortd sorthc sorthcc sortind sortindc sortmc sortr sortrc spBiconjGradSol spChol spConjGradSol spCreate spDenseSubmat spDiagRvMat spEigv spEye spLDL spline spLU spNumNZE spOnes spreadSheetReadM spreadSheetReadSA spreadSheetWrite spScale spSubmat spToDense spTrTDense spTScalar spZeros sqpSolve sqpSolveMT sqpSolveMTControlCreate sqpSolveMTlagrangeCreate sqpSolveMToutCreate sqpSolveSet sqrt statements stdc stdsc stocv stof strcombine strindx strlen strput strrindx strsect strsplit strsplitPad strtodt strtof strtofcplx strtriml strtrimr strtrunc strtruncl strtruncpad strtruncr submat subscat substute subvec sumc sumr surface svd svd1 svd2 svdcusv svds svdusv sysstate tab tan tanh tempname time timedt timestr timeutc title tkf2eps tkf2ps tocart todaydt toeplitz token topolar trapchk trigamma trimr trunc type typecv typef union unionsa uniqindx uniqindxsa unique uniquesa upmat upmat1 upper utctodt utctodtv utrisol vals varCovMS varCovXS varget vargetl varmall varmares varput varputl vartypef vcm vcms vcx vcxs vec vech vecr vector vget view viewxyz vlist vnamecv volume vput vread vtypecv wait waitc walkindex where window writer xlabel xlsGetSheetCount xlsGetSheetSize xlsGetSheetTypes xlsMakeRange xlsReadM xlsReadSA xlsWrite xlsWriteM xlsWriteSA xpnd xtics xy xyz ylabel ytics zeros zeta zlabel ztics cdfEmpirical dot h5create h5open h5read h5readAttribute h5write h5writeAttribute ldl plotAddErrorBar plotAddSurface plotCDFEmpirical plotSetColormap plotSetContourLabels plotSetLegendFont plotSetTextInterpreter plotSetXTicCount plotSetYTicCount plotSetZLevels powerm strjoin sylvester strtrim",
      literal: "DB_AFTER_LAST_ROW DB_ALL_TABLES DB_BATCH_OPERATIONS DB_BEFORE_FIRST_ROW DB_BLOB DB_EVENT_NOTIFICATIONS DB_FINISH_QUERY DB_HIGH_PRECISION DB_LAST_INSERT_ID DB_LOW_PRECISION_DOUBLE DB_LOW_PRECISION_INT32 DB_LOW_PRECISION_INT64 DB_LOW_PRECISION_NUMBERS DB_MULTIPLE_RESULT_SETS DB_NAMED_PLACEHOLDERS DB_POSITIONAL_PLACEHOLDERS DB_PREPARED_QUERIES DB_QUERY_SIZE DB_SIMPLE_LOCKING DB_SYSTEM_TABLES DB_TABLES DB_TRANSACTIONS DB_UNICODE DB_VIEWS __STDIN __STDOUT __STDERR __FILE_DIR"
    }, r = t.COMMENT("@", "@"), i = {
      className: "meta",
      begin: "#",
      end: "$",
      keywords: { keyword: "define definecs|10 undef ifdef ifndef iflight ifdllcall ifmac ifos2win ifunix else endif lineson linesoff srcfile srcline" },
      contains: [
        {
          begin: /\\\n/,
          relevance: 0
        },
        {
          beginKeywords: "include",
          end: "$",
          keywords: { keyword: "include" },
          contains: [
            {
              className: "string",
              begin: '"',
              end: '"',
              illegal: "\\n"
            }
          ]
        },
        t.C_LINE_COMMENT_MODE,
        t.C_BLOCK_COMMENT_MODE,
        r
      ]
    }, a = {
      begin: /\bstruct\s+/,
      end: /\s/,
      keywords: "struct",
      contains: [
        {
          className: "type",
          begin: t.UNDERSCORE_IDENT_RE,
          relevance: 0
        }
      ]
    }, o = [
      {
        className: "params",
        begin: /\(/,
        end: /\)/,
        excludeBegin: !0,
        excludeEnd: !0,
        endsWithParent: !0,
        relevance: 0,
        contains: [
          {
            // dots
            className: "literal",
            begin: /\.\.\./
          },
          t.C_NUMBER_MODE,
          t.C_BLOCK_COMMENT_MODE,
          r,
          a
        ]
      }
    ], s = {
      className: "title",
      begin: t.UNDERSCORE_IDENT_RE,
      relevance: 0
    }, l = function(h, m, v) {
      const b = t.inherit(
        {
          className: "function",
          beginKeywords: h,
          end: m,
          excludeEnd: !0,
          contains: [].concat(o)
        },
        {}
      );
      return b.contains.push(s), b.contains.push(t.C_NUMBER_MODE), b.contains.push(t.C_BLOCK_COMMENT_MODE), b.contains.push(r), b;
    }, u = {
      // these are explicitly named internal function calls
      className: "built_in",
      begin: "\\b(" + n.built_in.split(" ").join("|") + ")\\b"
    }, c = {
      className: "string",
      begin: '"',
      end: '"',
      contains: [t.BACKSLASH_ESCAPE],
      relevance: 0
    }, d = {
      // className: "fn_ref",
      begin: t.UNDERSCORE_IDENT_RE + "\\s*\\(",
      returnBegin: !0,
      keywords: n,
      relevance: 0,
      contains: [
        { beginKeywords: n.keyword },
        u,
        {
          // ambiguously named function calls get a relevance of 0
          className: "built_in",
          begin: t.UNDERSCORE_IDENT_RE,
          relevance: 0
        }
      ]
    }, f = {
      // className: "fn_ref_params",
      begin: /\(/,
      end: /\)/,
      relevance: 0,
      keywords: {
        built_in: n.built_in,
        literal: n.literal
      },
      contains: [
        t.C_NUMBER_MODE,
        t.C_BLOCK_COMMENT_MODE,
        r,
        u,
        d,
        c,
        "self"
      ]
    };
    return d.contains.push(f), {
      name: "GAUSS",
      aliases: ["gss"],
      case_insensitive: !0,
      // language is case-insensitive
      keywords: n,
      illegal: /(\{[%#]|[%#]\}| <- )/,
      contains: [
        t.C_NUMBER_MODE,
        t.C_LINE_COMMENT_MODE,
        t.C_BLOCK_COMMENT_MODE,
        r,
        c,
        i,
        {
          className: "keyword",
          begin: /\bexternal (matrix|string|array|sparse matrix|struct|proc|keyword|fn)/
        },
        l("proc keyword", ";"),
        l("fn", "="),
        {
          beginKeywords: "for threadfor",
          end: /;/,
          // end: /\(/,
          relevance: 0,
          contains: [
            t.C_BLOCK_COMMENT_MODE,
            r,
            f
          ]
        },
        {
          // custom method guard
          // excludes method names from keyword processing
          variants: [
            { begin: t.UNDERSCORE_IDENT_RE + "\\." + t.UNDERSCORE_IDENT_RE },
            { begin: t.UNDERSCORE_IDENT_RE + "\\s*=" }
          ],
          relevance: 0
        },
        d,
        a
      ]
    };
  }
  return wE = e, wE;
}
var xE, PD;
function HZ() {
  if (PD) return xE;
  PD = 1;
  function e(t) {
    const n = "[A-Z_][A-Z0-9_.]*", r = "%", i = {
      $pattern: n,
      keyword: "IF DO WHILE ENDWHILE CALL ENDIF SUB ENDSUB GOTO REPEAT ENDREPEAT EQ LT GT NE GE LE OR XOR"
    }, a = {
      className: "meta",
      begin: "([O])([0-9]+)"
    }, o = t.inherit(t.C_NUMBER_MODE, { begin: "([-+]?((\\.\\d+)|(\\d+)(\\.\\d*)?))|" + t.C_NUMBER_RE }), s = [
      t.C_LINE_COMMENT_MODE,
      t.C_BLOCK_COMMENT_MODE,
      t.COMMENT(/\(/, /\)/),
      o,
      t.inherit(t.APOS_STRING_MODE, { illegal: null }),
      t.inherit(t.QUOTE_STRING_MODE, { illegal: null }),
      {
        className: "name",
        begin: "([G])([0-9]+\\.?[0-9]?)"
      },
      {
        className: "name",
        begin: "([M])([0-9]+\\.?[0-9]?)"
      },
      {
        className: "attr",
        begin: "(VC|VS|#)",
        end: "(\\d+)"
      },
      {
        className: "attr",
        begin: "(VZOFX|VZOFY|VZOFZ)"
      },
      {
        className: "built_in",
        begin: "(ATAN|ABS|ACOS|ASIN|SIN|COS|EXP|FIX|FUP|ROUND|LN|TAN)(\\[)",
        contains: [o],
        end: "\\]"
      },
      {
        className: "symbol",
        variants: [
          {
            begin: "N",
            end: "\\d+",
            illegal: "\\W"
          }
        ]
      }
    ];
    return {
      name: "G-code (ISO 6983)",
      aliases: ["nc"],
      // Some implementations (CNC controls) of G-code are interoperable with uppercase and lowercase letters seamlessly.
      // However, most prefer all uppercase and uppercase is customary.
      case_insensitive: !0,
      keywords: i,
      contains: [
        {
          className: "meta",
          begin: r
        },
        a
      ].concat(s)
    };
  }
  return xE = e, xE;
}
var NE, FD;
function zZ() {
  if (FD) return NE;
  FD = 1;
  function e(t) {
    return {
      name: "Gherkin",
      aliases: ["feature"],
      keywords: "Feature Background Ability Business Need Scenario Scenarios Scenario Outline Scenario Template Examples Given And Then But When",
      contains: [
        {
          className: "symbol",
          begin: "\\*",
          relevance: 0
        },
        {
          className: "meta",
          begin: "@[^@\\s]+"
        },
        {
          begin: "\\|",
          end: "\\|\\w*$",
          contains: [
            {
              className: "string",
              begin: "[^|]+"
            }
          ]
        },
        {
          className: "variable",
          begin: "<",
          end: ">"
        },
        t.HASH_COMMENT_MODE,
        {
          className: "string",
          begin: '"""',
          end: '"""'
        },
        t.QUOTE_STRING_MODE
      ]
    };
  }
  return NE = e, NE;
}
var DE, BD;
function VZ() {
  if (BD) return DE;
  BD = 1;
  function e(t) {
    return {
      name: "GLSL",
      keywords: {
        keyword: (
          // Statements
          "break continue discard do else for if return while switch case default attribute binding buffer ccw centroid centroid varying coherent column_major const cw depth_any depth_greater depth_less depth_unchanged early_fragment_tests equal_spacing flat fractional_even_spacing fractional_odd_spacing highp in index inout invariant invocations isolines layout line_strip lines lines_adjacency local_size_x local_size_y local_size_z location lowp max_vertices mediump noperspective offset origin_upper_left out packed patch pixel_center_integer point_mode points precise precision quads r11f_g11f_b10f r16 r16_snorm r16f r16i r16ui r32f r32i r32ui r8 r8_snorm r8i r8ui readonly restrict rg16 rg16_snorm rg16f rg16i rg16ui rg32f rg32i rg32ui rg8 rg8_snorm rg8i rg8ui rgb10_a2 rgb10_a2ui rgba16 rgba16_snorm rgba16f rgba16i rgba16ui rgba32f rgba32i rgba32ui rgba8 rgba8_snorm rgba8i rgba8ui row_major sample shared smooth std140 std430 stream triangle_strip triangles triangles_adjacency uniform varying vertices volatile writeonly"
        ),
        type: "atomic_uint bool bvec2 bvec3 bvec4 dmat2 dmat2x2 dmat2x3 dmat2x4 dmat3 dmat3x2 dmat3x3 dmat3x4 dmat4 dmat4x2 dmat4x3 dmat4x4 double dvec2 dvec3 dvec4 float iimage1D iimage1DArray iimage2D iimage2DArray iimage2DMS iimage2DMSArray iimage2DRect iimage3D iimageBuffer iimageCube iimageCubeArray image1D image1DArray image2D image2DArray image2DMS image2DMSArray image2DRect image3D imageBuffer imageCube imageCubeArray int isampler1D isampler1DArray isampler2D isampler2DArray isampler2DMS isampler2DMSArray isampler2DRect isampler3D isamplerBuffer isamplerCube isamplerCubeArray ivec2 ivec3 ivec4 mat2 mat2x2 mat2x3 mat2x4 mat3 mat3x2 mat3x3 mat3x4 mat4 mat4x2 mat4x3 mat4x4 sampler1D sampler1DArray sampler1DArrayShadow sampler1DShadow sampler2D sampler2DArray sampler2DArrayShadow sampler2DMS sampler2DMSArray sampler2DRect sampler2DRectShadow sampler2DShadow sampler3D samplerBuffer samplerCube samplerCubeArray samplerCubeArrayShadow samplerCubeShadow image1D uimage1DArray uimage2D uimage2DArray uimage2DMS uimage2DMSArray uimage2DRect uimage3D uimageBuffer uimageCube uimageCubeArray uint usampler1D usampler1DArray usampler2D usampler2DArray usampler2DMS usampler2DMSArray usampler2DRect usampler3D samplerBuffer usamplerCube usamplerCubeArray uvec2 uvec3 uvec4 vec2 vec3 vec4 void",
        built_in: (
          // Constants
          "gl_MaxAtomicCounterBindings gl_MaxAtomicCounterBufferSize gl_MaxClipDistances gl_MaxClipPlanes gl_MaxCombinedAtomicCounterBuffers gl_MaxCombinedAtomicCounters gl_MaxCombinedImageUniforms gl_MaxCombinedImageUnitsAndFragmentOutputs gl_MaxCombinedTextureImageUnits gl_MaxComputeAtomicCounterBuffers gl_MaxComputeAtomicCounters gl_MaxComputeImageUniforms gl_MaxComputeTextureImageUnits gl_MaxComputeUniformComponents gl_MaxComputeWorkGroupCount gl_MaxComputeWorkGroupSize gl_MaxDrawBuffers gl_MaxFragmentAtomicCounterBuffers gl_MaxFragmentAtomicCounters gl_MaxFragmentImageUniforms gl_MaxFragmentInputComponents gl_MaxFragmentInputVectors gl_MaxFragmentUniformComponents gl_MaxFragmentUniformVectors gl_MaxGeometryAtomicCounterBuffers gl_MaxGeometryAtomicCounters gl_MaxGeometryImageUniforms gl_MaxGeometryInputComponents gl_MaxGeometryOutputComponents gl_MaxGeometryOutputVertices gl_MaxGeometryTextureImageUnits gl_MaxGeometryTotalOutputComponents gl_MaxGeometryUniformComponents gl_MaxGeometryVaryingComponents gl_MaxImageSamples gl_MaxImageUnits gl_MaxLights gl_MaxPatchVertices gl_MaxProgramTexelOffset gl_MaxTessControlAtomicCounterBuffers gl_MaxTessControlAtomicCounters gl_MaxTessControlImageUniforms gl_MaxTessControlInputComponents gl_MaxTessControlOutputComponents gl_MaxTessControlTextureImageUnits gl_MaxTessControlTotalOutputComponents gl_MaxTessControlUniformComponents gl_MaxTessEvaluationAtomicCounterBuffers gl_MaxTessEvaluationAtomicCounters gl_MaxTessEvaluationImageUniforms gl_MaxTessEvaluationInputComponents gl_MaxTessEvaluationOutputComponents gl_MaxTessEvaluationTextureImageUnits gl_MaxTessEvaluationUniformComponents gl_MaxTessGenLevel gl_MaxTessPatchComponents gl_MaxTextureCoords gl_MaxTextureImageUnits gl_MaxTextureUnits gl_MaxVaryingComponents gl_MaxVaryingFloats gl_MaxVaryingVectors gl_MaxVertexAtomicCounterBuffers gl_MaxVertexAtomicCounters gl_MaxVertexAttribs gl_MaxVertexImageUniforms gl_MaxVertexOutputComponents gl_MaxVertexOutputVectors gl_MaxVertexTextureImageUnits gl_MaxVertexUniformComponents gl_MaxVertexUniformVectors gl_MaxViewports gl_MinProgramTexelOffset gl_BackColor gl_BackLightModelProduct gl_BackLightProduct gl_BackMaterial gl_BackSecondaryColor gl_ClipDistance gl_ClipPlane gl_ClipVertex gl_Color gl_DepthRange gl_EyePlaneQ gl_EyePlaneR gl_EyePlaneS gl_EyePlaneT gl_Fog gl_FogCoord gl_FogFragCoord gl_FragColor gl_FragCoord gl_FragData gl_FragDepth gl_FrontColor gl_FrontFacing gl_FrontLightModelProduct gl_FrontLightProduct gl_FrontMaterial gl_FrontSecondaryColor gl_GlobalInvocationID gl_InstanceID gl_InvocationID gl_Layer gl_LightModel gl_LightSource gl_LocalInvocationID gl_LocalInvocationIndex gl_ModelViewMatrix gl_ModelViewMatrixInverse gl_ModelViewMatrixInverseTranspose gl_ModelViewMatrixTranspose gl_ModelViewProjectionMatrix gl_ModelViewProjectionMatrixInverse gl_ModelViewProjectionMatrixInverseTranspose gl_ModelViewProjectionMatrixTranspose gl_MultiTexCoord0 gl_MultiTexCoord1 gl_MultiTexCoord2 gl_MultiTexCoord3 gl_MultiTexCoord4 gl_MultiTexCoord5 gl_MultiTexCoord6 gl_MultiTexCoord7 gl_Normal gl_NormalMatrix gl_NormalScale gl_NumSamples gl_NumWorkGroups gl_ObjectPlaneQ gl_ObjectPlaneR gl_ObjectPlaneS gl_ObjectPlaneT gl_PatchVerticesIn gl_Point gl_PointCoord gl_PointSize gl_Position gl_PrimitiveID gl_PrimitiveIDIn gl_ProjectionMatrix gl_ProjectionMatrixInverse gl_ProjectionMatrixInverseTranspose gl_ProjectionMatrixTranspose gl_SampleID gl_SampleMask gl_SampleMaskIn gl_SamplePosition gl_SecondaryColor gl_TessCoord gl_TessLevelInner gl_TessLevelOuter gl_TexCoord gl_TextureEnvColor gl_TextureMatrix gl_TextureMatrixInverse gl_TextureMatrixInverseTranspose gl_TextureMatrixTranspose gl_Vertex gl_VertexID gl_ViewportIndex gl_WorkGroupID gl_WorkGroupSize gl_in gl_out EmitStreamVertex EmitVertex EndPrimitive EndStreamPrimitive abs acos acosh all any asin asinh atan atanh atomicAdd atomicAnd atomicCompSwap atomicCounter atomicCounterDecrement atomicCounterIncrement atomicExchange atomicMax atomicMin atomicOr atomicXor barrier bitCount bitfieldExtract bitfieldInsert bitfieldReverse ceil clamp cos cosh cross dFdx dFdy degrees determinant distance dot equal exp exp2 faceforward findLSB findMSB floatBitsToInt floatBitsToUint floor fma fract frexp ftransform fwidth greaterThan greaterThanEqual groupMemoryBarrier imageAtomicAdd imageAtomicAnd imageAtomicCompSwap imageAtomicExchange imageAtomicMax imageAtomicMin imageAtomicOr imageAtomicXor imageLoad imageSize imageStore imulExtended intBitsToFloat interpolateAtCentroid interpolateAtOffset interpolateAtSample inverse inversesqrt isinf isnan ldexp length lessThan lessThanEqual log log2 matrixCompMult max memoryBarrier memoryBarrierAtomicCounter memoryBarrierBuffer memoryBarrierImage memoryBarrierShared min mix mod modf noise1 noise2 noise3 noise4 normalize not notEqual outerProduct packDouble2x32 packHalf2x16 packSnorm2x16 packSnorm4x8 packUnorm2x16 packUnorm4x8 pow radians reflect refract round roundEven shadow1D shadow1DLod shadow1DProj shadow1DProjLod shadow2D shadow2DLod shadow2DProj shadow2DProjLod sign sin sinh smoothstep sqrt step tan tanh texelFetch texelFetchOffset texture texture1D texture1DLod texture1DProj texture1DProjLod texture2D texture2DLod texture2DProj texture2DProjLod texture3D texture3DLod texture3DProj texture3DProjLod textureCube textureCubeLod textureGather textureGatherOffset textureGatherOffsets textureGrad textureGradOffset textureLod textureLodOffset textureOffset textureProj textureProjGrad textureProjGradOffset textureProjLod textureProjLodOffset textureProjOffset textureQueryLevels textureQueryLod textureSize transpose trunc uaddCarry uintBitsToFloat umulExtended unpackDouble2x32 unpackHalf2x16 unpackSnorm2x16 unpackSnorm4x8 unpackUnorm2x16 unpackUnorm4x8 usubBorrow"
        ),
        literal: "true false"
      },
      illegal: '"',
      contains: [
        t.C_LINE_COMMENT_MODE,
        t.C_BLOCK_COMMENT_MODE,
        t.C_NUMBER_MODE,
        {
          className: "meta",
          begin: "#",
          end: "$"
        }
      ]
    };
  }
  return DE = e, DE;
}
var IE, $D;
function WZ() {
  if ($D) return IE;
  $D = 1;
  function e(t) {
    return {
      name: "GML",
      case_insensitive: !1,
      // language is case-insensitive
      keywords: {
        keyword: [
          "#endregion",
          "#macro",
          "#region",
          "and",
          "begin",
          "break",
          "case",
          "constructor",
          "continue",
          "default",
          "delete",
          "div",
          "do",
          "else",
          "end",
          "enum",
          "exit",
          "for",
          "function",
          "globalvar",
          "if",
          "mod",
          "not",
          "or",
          "repeat",
          "return",
          "switch",
          "then",
          "until",
          "var",
          "while",
          "with",
          "xor"
        ],
        built_in: [
          "abs",
          "achievement_available",
          "achievement_event",
          "achievement_get_challenges",
          "achievement_get_info",
          "achievement_get_pic",
          "achievement_increment",
          "achievement_load_friends",
          "achievement_load_leaderboard",
          "achievement_load_progress",
          "achievement_login",
          "achievement_login_status",
          "achievement_logout",
          "achievement_post",
          "achievement_post_score",
          "achievement_reset",
          "achievement_send_challenge",
          "achievement_show",
          "achievement_show_achievements",
          "achievement_show_challenge_notifications",
          "achievement_show_leaderboards",
          "action_inherited",
          "action_kill_object",
          "ads_disable",
          "ads_enable",
          "ads_engagement_active",
          "ads_engagement_available",
          "ads_engagement_launch",
          "ads_event",
          "ads_event_preload",
          "ads_get_display_height",
          "ads_get_display_width",
          "ads_interstitial_available",
          "ads_interstitial_display",
          "ads_move",
          "ads_set_reward_callback",
          "ads_setup",
          "alarm_get",
          "alarm_set",
          "analytics_event",
          "analytics_event_ext",
          "angle_difference",
          "ansi_char",
          "application_get_position",
          "application_surface_draw_enable",
          "application_surface_enable",
          "application_surface_is_enabled",
          "arccos",
          "arcsin",
          "arctan",
          "arctan2",
          "array_copy",
          "array_create",
          "array_delete",
          "array_equals",
          "array_height_2d",
          "array_insert",
          "array_length",
          "array_length_1d",
          "array_length_2d",
          "array_pop",
          "array_push",
          "array_resize",
          "array_sort",
          "asset_get_index",
          "asset_get_type",
          "audio_channel_num",
          "audio_create_buffer_sound",
          "audio_create_play_queue",
          "audio_create_stream",
          "audio_create_sync_group",
          "audio_debug",
          "audio_destroy_stream",
          "audio_destroy_sync_group",
          "audio_emitter_create",
          "audio_emitter_exists",
          "audio_emitter_falloff",
          "audio_emitter_free",
          "audio_emitter_gain",
          "audio_emitter_get_gain",
          "audio_emitter_get_listener_mask",
          "audio_emitter_get_pitch",
          "audio_emitter_get_vx",
          "audio_emitter_get_vy",
          "audio_emitter_get_vz",
          "audio_emitter_get_x",
          "audio_emitter_get_y",
          "audio_emitter_get_z",
          "audio_emitter_pitch",
          "audio_emitter_position",
          "audio_emitter_set_listener_mask",
          "audio_emitter_velocity",
          "audio_exists",
          "audio_falloff_set_model",
          "audio_free_buffer_sound",
          "audio_free_play_queue",
          "audio_get_listener_count",
          "audio_get_listener_info",
          "audio_get_listener_mask",
          "audio_get_master_gain",
          "audio_get_name",
          "audio_get_recorder_count",
          "audio_get_recorder_info",
          "audio_get_type",
          "audio_group_is_loaded",
          "audio_group_load",
          "audio_group_load_progress",
          "audio_group_name",
          "audio_group_set_gain",
          "audio_group_stop_all",
          "audio_group_unload",
          "audio_is_paused",
          "audio_is_playing",
          "audio_listener_get_data",
          "audio_listener_orientation",
          "audio_listener_position",
          "audio_listener_set_orientation",
          "audio_listener_set_position",
          "audio_listener_set_velocity",
          "audio_listener_velocity",
          "audio_master_gain",
          "audio_music_gain",
          "audio_music_is_playing",
          "audio_pause_all",
          "audio_pause_music",
          "audio_pause_sound",
          "audio_pause_sync_group",
          "audio_play_in_sync_group",
          "audio_play_music",
          "audio_play_sound",
          "audio_play_sound_at",
          "audio_play_sound_on",
          "audio_queue_sound",
          "audio_resume_all",
          "audio_resume_music",
          "audio_resume_sound",
          "audio_resume_sync_group",
          "audio_set_listener_mask",
          "audio_set_master_gain",
          "audio_sound_gain",
          "audio_sound_get_gain",
          "audio_sound_get_listener_mask",
          "audio_sound_get_pitch",
          "audio_sound_get_track_position",
          "audio_sound_length",
          "audio_sound_pitch",
          "audio_sound_set_listener_mask",
          "audio_sound_set_track_position",
          "audio_start_recording",
          "audio_start_sync_group",
          "audio_stop_all",
          "audio_stop_music",
          "audio_stop_recording",
          "audio_stop_sound",
          "audio_stop_sync_group",
          "audio_sync_group_debug",
          "audio_sync_group_get_track_pos",
          "audio_sync_group_is_playing",
          "audio_system",
          "background_get_height",
          "background_get_width",
          "base64_decode",
          "base64_encode",
          "browser_input_capture",
          "buffer_async_group_begin",
          "buffer_async_group_end",
          "buffer_async_group_option",
          "buffer_base64_decode",
          "buffer_base64_decode_ext",
          "buffer_base64_encode",
          "buffer_copy",
          "buffer_copy_from_vertex_buffer",
          "buffer_create",
          "buffer_create_from_vertex_buffer",
          "buffer_create_from_vertex_buffer_ext",
          "buffer_delete",
          "buffer_exists",
          "buffer_fill",
          "buffer_get_address",
          "buffer_get_alignment",
          "buffer_get_size",
          "buffer_get_surface",
          "buffer_get_type",
          "buffer_load",
          "buffer_load_async",
          "buffer_load_ext",
          "buffer_load_partial",
          "buffer_md5",
          "buffer_peek",
          "buffer_poke",
          "buffer_read",
          "buffer_resize",
          "buffer_save",
          "buffer_save_async",
          "buffer_save_ext",
          "buffer_seek",
          "buffer_set_surface",
          "buffer_sha1",
          "buffer_sizeof",
          "buffer_tell",
          "buffer_write",
          "camera_apply",
          "camera_create",
          "camera_create_view",
          "camera_destroy",
          "camera_get_active",
          "camera_get_begin_script",
          "camera_get_default",
          "camera_get_end_script",
          "camera_get_proj_mat",
          "camera_get_update_script",
          "camera_get_view_angle",
          "camera_get_view_border_x",
          "camera_get_view_border_y",
          "camera_get_view_height",
          "camera_get_view_mat",
          "camera_get_view_speed_x",
          "camera_get_view_speed_y",
          "camera_get_view_target",
          "camera_get_view_width",
          "camera_get_view_x",
          "camera_get_view_y",
          "camera_set_begin_script",
          "camera_set_default",
          "camera_set_end_script",
          "camera_set_proj_mat",
          "camera_set_update_script",
          "camera_set_view_angle",
          "camera_set_view_border",
          "camera_set_view_mat",
          "camera_set_view_pos",
          "camera_set_view_size",
          "camera_set_view_speed",
          "camera_set_view_target",
          "ceil",
          "choose",
          "chr",
          "clamp",
          "clickable_add",
          "clickable_add_ext",
          "clickable_change",
          "clickable_change_ext",
          "clickable_delete",
          "clickable_exists",
          "clickable_set_style",
          "clipboard_get_text",
          "clipboard_has_text",
          "clipboard_set_text",
          "cloud_file_save",
          "cloud_string_save",
          "cloud_synchronise",
          "code_is_compiled",
          "collision_circle",
          "collision_circle_list",
          "collision_ellipse",
          "collision_ellipse_list",
          "collision_line",
          "collision_line_list",
          "collision_point",
          "collision_point_list",
          "collision_rectangle",
          "collision_rectangle_list",
          "color_get_blue",
          "color_get_green",
          "color_get_hue",
          "color_get_red",
          "color_get_saturation",
          "color_get_value",
          "colour_get_blue",
          "colour_get_green",
          "colour_get_hue",
          "colour_get_red",
          "colour_get_saturation",
          "colour_get_value",
          "cos",
          "darccos",
          "darcsin",
          "darctan",
          "darctan2",
          "date_compare_date",
          "date_compare_datetime",
          "date_compare_time",
          "date_create_datetime",
          "date_current_datetime",
          "date_date_of",
          "date_date_string",
          "date_datetime_string",
          "date_day_span",
          "date_days_in_month",
          "date_days_in_year",
          "date_get_day",
          "date_get_day_of_year",
          "date_get_hour",
          "date_get_hour_of_year",
          "date_get_minute",
          "date_get_minute_of_year",
          "date_get_month",
          "date_get_second",
          "date_get_second_of_year",
          "date_get_timezone",
          "date_get_week",
          "date_get_weekday",
          "date_get_year",
          "date_hour_span",
          "date_inc_day",
          "date_inc_hour",
          "date_inc_minute",
          "date_inc_month",
          "date_inc_second",
          "date_inc_week",
          "date_inc_year",
          "date_is_today",
          "date_leap_year",
          "date_minute_span",
          "date_month_span",
          "date_second_span",
          "date_set_timezone",
          "date_time_of",
          "date_time_string",
          "date_valid_datetime",
          "date_week_span",
          "date_year_span",
          "dcos",
          "debug_event",
          "debug_get_callstack",
          "degtorad",
          "device_get_tilt_x",
          "device_get_tilt_y",
          "device_get_tilt_z",
          "device_is_keypad_open",
          "device_mouse_check_button",
          "device_mouse_check_button_pressed",
          "device_mouse_check_button_released",
          "device_mouse_dbclick_enable",
          "device_mouse_raw_x",
          "device_mouse_raw_y",
          "device_mouse_x",
          "device_mouse_x_to_gui",
          "device_mouse_y",
          "device_mouse_y_to_gui",
          "directory_create",
          "directory_destroy",
          "directory_exists",
          "display_get_dpi_x",
          "display_get_dpi_y",
          "display_get_gui_height",
          "display_get_gui_width",
          "display_get_height",
          "display_get_orientation",
          "display_get_sleep_margin",
          "display_get_timing_method",
          "display_get_width",
          "display_mouse_get_x",
          "display_mouse_get_y",
          "display_mouse_set",
          "display_reset",
          "display_set_gui_maximise",
          "display_set_gui_maximize",
          "display_set_gui_size",
          "display_set_sleep_margin",
          "display_set_timing_method",
          "display_set_ui_visibility",
          "distance_to_object",
          "distance_to_point",
          "dot_product",
          "dot_product_3d",
          "dot_product_3d_normalised",
          "dot_product_3d_normalized",
          "dot_product_normalised",
          "dot_product_normalized",
          "draw_arrow",
          "draw_background",
          "draw_background_ext",
          "draw_background_part_ext",
          "draw_background_tiled",
          "draw_button",
          "draw_circle",
          "draw_circle_color",
          "draw_circle_colour",
          "draw_clear",
          "draw_clear_alpha",
          "draw_ellipse",
          "draw_ellipse_color",
          "draw_ellipse_colour",
          "draw_enable_alphablend",
          "draw_enable_drawevent",
          "draw_enable_swf_aa",
          "draw_flush",
          "draw_get_alpha",
          "draw_get_color",
          "draw_get_colour",
          "draw_get_lighting",
          "draw_get_swf_aa_level",
          "draw_getpixel",
          "draw_getpixel_ext",
          "draw_healthbar",
          "draw_highscore",
          "draw_light_define_ambient",
          "draw_light_define_direction",
          "draw_light_define_point",
          "draw_light_enable",
          "draw_light_get",
          "draw_light_get_ambient",
          "draw_line",
          "draw_line_color",
          "draw_line_colour",
          "draw_line_width",
          "draw_line_width_color",
          "draw_line_width_colour",
          "draw_path",
          "draw_point",
          "draw_point_color",
          "draw_point_colour",
          "draw_primitive_begin",
          "draw_primitive_begin_texture",
          "draw_primitive_end",
          "draw_rectangle",
          "draw_rectangle_color",
          "draw_rectangle_colour",
          "draw_roundrect",
          "draw_roundrect_color",
          "draw_roundrect_color_ext",
          "draw_roundrect_colour",
          "draw_roundrect_colour_ext",
          "draw_roundrect_ext",
          "draw_self",
          "draw_set_alpha",
          "draw_set_alpha_test",
          "draw_set_alpha_test_ref_value",
          "draw_set_blend_mode",
          "draw_set_blend_mode_ext",
          "draw_set_circle_precision",
          "draw_set_color",
          "draw_set_color_write_enable",
          "draw_set_colour",
          "draw_set_font",
          "draw_set_halign",
          "draw_set_lighting",
          "draw_set_swf_aa_level",
          "draw_set_valign",
          "draw_skeleton",
          "draw_skeleton_collision",
          "draw_skeleton_instance",
          "draw_skeleton_time",
          "draw_sprite",
          "draw_sprite_ext",
          "draw_sprite_general",
          "draw_sprite_part",
          "draw_sprite_part_ext",
          "draw_sprite_pos",
          "draw_sprite_stretched",
          "draw_sprite_stretched_ext",
          "draw_sprite_tiled",
          "draw_sprite_tiled_ext",
          "draw_surface",
          "draw_surface_ext",
          "draw_surface_general",
          "draw_surface_part",
          "draw_surface_part_ext",
          "draw_surface_stretched",
          "draw_surface_stretched_ext",
          "draw_surface_tiled",
          "draw_surface_tiled_ext",
          "draw_text",
          "draw_text_color",
          "draw_text_colour",
          "draw_text_ext",
          "draw_text_ext_color",
          "draw_text_ext_colour",
          "draw_text_ext_transformed",
          "draw_text_ext_transformed_color",
          "draw_text_ext_transformed_colour",
          "draw_text_transformed",
          "draw_text_transformed_color",
          "draw_text_transformed_colour",
          "draw_texture_flush",
          "draw_tile",
          "draw_tilemap",
          "draw_triangle",
          "draw_triangle_color",
          "draw_triangle_colour",
          "draw_vertex",
          "draw_vertex_color",
          "draw_vertex_colour",
          "draw_vertex_texture",
          "draw_vertex_texture_color",
          "draw_vertex_texture_colour",
          "ds_exists",
          "ds_grid_add",
          "ds_grid_add_disk",
          "ds_grid_add_grid_region",
          "ds_grid_add_region",
          "ds_grid_clear",
          "ds_grid_copy",
          "ds_grid_create",
          "ds_grid_destroy",
          "ds_grid_get",
          "ds_grid_get_disk_max",
          "ds_grid_get_disk_mean",
          "ds_grid_get_disk_min",
          "ds_grid_get_disk_sum",
          "ds_grid_get_max",
          "ds_grid_get_mean",
          "ds_grid_get_min",
          "ds_grid_get_sum",
          "ds_grid_height",
          "ds_grid_multiply",
          "ds_grid_multiply_disk",
          "ds_grid_multiply_grid_region",
          "ds_grid_multiply_region",
          "ds_grid_read",
          "ds_grid_resize",
          "ds_grid_set",
          "ds_grid_set_disk",
          "ds_grid_set_grid_region",
          "ds_grid_set_region",
          "ds_grid_shuffle",
          "ds_grid_sort",
          "ds_grid_value_disk_exists",
          "ds_grid_value_disk_x",
          "ds_grid_value_disk_y",
          "ds_grid_value_exists",
          "ds_grid_value_x",
          "ds_grid_value_y",
          "ds_grid_width",
          "ds_grid_write",
          "ds_list_add",
          "ds_list_clear",
          "ds_list_copy",
          "ds_list_create",
          "ds_list_delete",
          "ds_list_destroy",
          "ds_list_empty",
          "ds_list_find_index",
          "ds_list_find_value",
          "ds_list_insert",
          "ds_list_mark_as_list",
          "ds_list_mark_as_map",
          "ds_list_read",
          "ds_list_replace",
          "ds_list_set",
          "ds_list_shuffle",
          "ds_list_size",
          "ds_list_sort",
          "ds_list_write",
          "ds_map_add",
          "ds_map_add_list",
          "ds_map_add_map",
          "ds_map_clear",
          "ds_map_copy",
          "ds_map_create",
          "ds_map_delete",
          "ds_map_destroy",
          "ds_map_empty",
          "ds_map_exists",
          "ds_map_find_first",
          "ds_map_find_last",
          "ds_map_find_next",
          "ds_map_find_previous",
          "ds_map_find_value",
          "ds_map_read",
          "ds_map_replace",
          "ds_map_replace_list",
          "ds_map_replace_map",
          "ds_map_secure_load",
          "ds_map_secure_load_buffer",
          "ds_map_secure_save",
          "ds_map_secure_save_buffer",
          "ds_map_set",
          "ds_map_size",
          "ds_map_write",
          "ds_priority_add",
          "ds_priority_change_priority",
          "ds_priority_clear",
          "ds_priority_copy",
          "ds_priority_create",
          "ds_priority_delete_max",
          "ds_priority_delete_min",
          "ds_priority_delete_value",
          "ds_priority_destroy",
          "ds_priority_empty",
          "ds_priority_find_max",
          "ds_priority_find_min",
          "ds_priority_find_priority",
          "ds_priority_read",
          "ds_priority_size",
          "ds_priority_write",
          "ds_queue_clear",
          "ds_queue_copy",
          "ds_queue_create",
          "ds_queue_dequeue",
          "ds_queue_destroy",
          "ds_queue_empty",
          "ds_queue_enqueue",
          "ds_queue_head",
          "ds_queue_read",
          "ds_queue_size",
          "ds_queue_tail",
          "ds_queue_write",
          "ds_set_precision",
          "ds_stack_clear",
          "ds_stack_copy",
          "ds_stack_create",
          "ds_stack_destroy",
          "ds_stack_empty",
          "ds_stack_pop",
          "ds_stack_push",
          "ds_stack_read",
          "ds_stack_size",
          "ds_stack_top",
          "ds_stack_write",
          "dsin",
          "dtan",
          "effect_clear",
          "effect_create_above",
          "effect_create_below",
          "environment_get_variable",
          "event_inherited",
          "event_perform",
          "event_perform_object",
          "event_user",
          "exp",
          "external_call",
          "external_define",
          "external_free",
          "facebook_accesstoken",
          "facebook_check_permission",
          "facebook_dialog",
          "facebook_graph_request",
          "facebook_init",
          "facebook_launch_offerwall",
          "facebook_login",
          "facebook_logout",
          "facebook_post_message",
          "facebook_request_publish_permissions",
          "facebook_request_read_permissions",
          "facebook_send_invite",
          "facebook_status",
          "facebook_user_id",
          "file_attributes",
          "file_bin_close",
          "file_bin_open",
          "file_bin_position",
          "file_bin_read_byte",
          "file_bin_rewrite",
          "file_bin_seek",
          "file_bin_size",
          "file_bin_write_byte",
          "file_copy",
          "file_delete",
          "file_exists",
          "file_find_close",
          "file_find_first",
          "file_find_next",
          "file_rename",
          "file_text_close",
          "file_text_eof",
          "file_text_eoln",
          "file_text_open_append",
          "file_text_open_from_string",
          "file_text_open_read",
          "file_text_open_write",
          "file_text_read_real",
          "file_text_read_string",
          "file_text_readln",
          "file_text_write_real",
          "file_text_write_string",
          "file_text_writeln",
          "filename_change_ext",
          "filename_dir",
          "filename_drive",
          "filename_ext",
          "filename_name",
          "filename_path",
          "floor",
          "font_add",
          "font_add_enable_aa",
          "font_add_get_enable_aa",
          "font_add_sprite",
          "font_add_sprite_ext",
          "font_delete",
          "font_exists",
          "font_get_bold",
          "font_get_first",
          "font_get_fontname",
          "font_get_italic",
          "font_get_last",
          "font_get_name",
          "font_get_size",
          "font_get_texture",
          "font_get_uvs",
          "font_replace",
          "font_replace_sprite",
          "font_replace_sprite_ext",
          "font_set_cache_size",
          "font_texture_page_size",
          "frac",
          "game_end",
          "game_get_speed",
          "game_load",
          "game_load_buffer",
          "game_restart",
          "game_save",
          "game_save_buffer",
          "game_set_speed",
          "gamepad_axis_count",
          "gamepad_axis_value",
          "gamepad_button_check",
          "gamepad_button_check_pressed",
          "gamepad_button_check_released",
          "gamepad_button_count",
          "gamepad_button_value",
          "gamepad_get_axis_deadzone",
          "gamepad_get_button_threshold",
          "gamepad_get_description",
          "gamepad_get_device_count",
          "gamepad_is_connected",
          "gamepad_is_supported",
          "gamepad_set_axis_deadzone",
          "gamepad_set_button_threshold",
          "gamepad_set_color",
          "gamepad_set_colour",
          "gamepad_set_vibration",
          "gesture_double_tap_distance",
          "gesture_double_tap_time",
          "gesture_drag_distance",
          "gesture_drag_time",
          "gesture_flick_speed",
          "gesture_get_double_tap_distance",
          "gesture_get_double_tap_time",
          "gesture_get_drag_distance",
          "gesture_get_drag_time",
          "gesture_get_flick_speed",
          "gesture_get_pinch_angle_away",
          "gesture_get_pinch_angle_towards",
          "gesture_get_pinch_distance",
          "gesture_get_rotate_angle",
          "gesture_get_rotate_time",
          "gesture_get_tap_count",
          "gesture_pinch_angle_away",
          "gesture_pinch_angle_towards",
          "gesture_pinch_distance",
          "gesture_rotate_angle",
          "gesture_rotate_time",
          "gesture_tap_count",
          "get_integer",
          "get_integer_async",
          "get_login_async",
          "get_open_filename",
          "get_open_filename_ext",
          "get_save_filename",
          "get_save_filename_ext",
          "get_string",
          "get_string_async",
          "get_timer",
          "gml_pragma",
          "gml_release_mode",
          "gpu_get_alphatestenable",
          "gpu_get_alphatestfunc",
          "gpu_get_alphatestref",
          "gpu_get_blendenable",
          "gpu_get_blendmode",
          "gpu_get_blendmode_dest",
          "gpu_get_blendmode_destalpha",
          "gpu_get_blendmode_ext",
          "gpu_get_blendmode_ext_sepalpha",
          "gpu_get_blendmode_src",
          "gpu_get_blendmode_srcalpha",
          "gpu_get_colorwriteenable",
          "gpu_get_colourwriteenable",
          "gpu_get_cullmode",
          "gpu_get_fog",
          "gpu_get_lightingenable",
          "gpu_get_state",
          "gpu_get_tex_filter",
          "gpu_get_tex_filter_ext",
          "gpu_get_tex_max_aniso",
          "gpu_get_tex_max_aniso_ext",
          "gpu_get_tex_max_mip",
          "gpu_get_tex_max_mip_ext",
          "gpu_get_tex_min_mip",
          "gpu_get_tex_min_mip_ext",
          "gpu_get_tex_mip_bias",
          "gpu_get_tex_mip_bias_ext",
          "gpu_get_tex_mip_enable",
          "gpu_get_tex_mip_enable_ext",
          "gpu_get_tex_mip_filter",
          "gpu_get_tex_mip_filter_ext",
          "gpu_get_tex_repeat",
          "gpu_get_tex_repeat_ext",
          "gpu_get_texfilter",
          "gpu_get_texfilter_ext",
          "gpu_get_texrepeat",
          "gpu_get_texrepeat_ext",
          "gpu_get_zfunc",
          "gpu_get_ztestenable",
          "gpu_get_zwriteenable",
          "gpu_pop_state",
          "gpu_push_state",
          "gpu_set_alphatestenable",
          "gpu_set_alphatestfunc",
          "gpu_set_alphatestref",
          "gpu_set_blendenable",
          "gpu_set_blendmode",
          "gpu_set_blendmode_ext",
          "gpu_set_blendmode_ext_sepalpha",
          "gpu_set_colorwriteenable",
          "gpu_set_colourwriteenable",
          "gpu_set_cullmode",
          "gpu_set_fog",
          "gpu_set_lightingenable",
          "gpu_set_state",
          "gpu_set_tex_filter",
          "gpu_set_tex_filter_ext",
          "gpu_set_tex_max_aniso",
          "gpu_set_tex_max_aniso_ext",
          "gpu_set_tex_max_mip",
          "gpu_set_tex_max_mip_ext",
          "gpu_set_tex_min_mip",
          "gpu_set_tex_min_mip_ext",
          "gpu_set_tex_mip_bias",
          "gpu_set_tex_mip_bias_ext",
          "gpu_set_tex_mip_enable",
          "gpu_set_tex_mip_enable_ext",
          "gpu_set_tex_mip_filter",
          "gpu_set_tex_mip_filter_ext",
          "gpu_set_tex_repeat",
          "gpu_set_tex_repeat_ext",
          "gpu_set_texfilter",
          "gpu_set_texfilter_ext",
          "gpu_set_texrepeat",
          "gpu_set_texrepeat_ext",
          "gpu_set_zfunc",
          "gpu_set_ztestenable",
          "gpu_set_zwriteenable",
          "highscore_add",
          "highscore_clear",
          "highscore_name",
          "highscore_value",
          "http_get",
          "http_get_file",
          "http_post_string",
          "http_request",
          "iap_acquire",
          "iap_activate",
          "iap_consume",
          "iap_enumerate_products",
          "iap_product_details",
          "iap_purchase_details",
          "iap_restore_all",
          "iap_status",
          "ini_close",
          "ini_key_delete",
          "ini_key_exists",
          "ini_open",
          "ini_open_from_string",
          "ini_read_real",
          "ini_read_string",
          "ini_section_delete",
          "ini_section_exists",
          "ini_write_real",
          "ini_write_string",
          "instance_activate_all",
          "instance_activate_layer",
          "instance_activate_object",
          "instance_activate_region",
          "instance_change",
          "instance_copy",
          "instance_create",
          "instance_create_depth",
          "instance_create_layer",
          "instance_deactivate_all",
          "instance_deactivate_layer",
          "instance_deactivate_object",
          "instance_deactivate_region",
          "instance_destroy",
          "instance_exists",
          "instance_find",
          "instance_furthest",
          "instance_id_get",
          "instance_nearest",
          "instance_number",
          "instance_place",
          "instance_place_list",
          "instance_position",
          "instance_position_list",
          "int64",
          "io_clear",
          "irandom",
          "irandom_range",
          "is_array",
          "is_bool",
          "is_infinity",
          "is_int32",
          "is_int64",
          "is_matrix",
          "is_method",
          "is_nan",
          "is_numeric",
          "is_ptr",
          "is_real",
          "is_string",
          "is_struct",
          "is_undefined",
          "is_vec3",
          "is_vec4",
          "json_decode",
          "json_encode",
          "keyboard_check",
          "keyboard_check_direct",
          "keyboard_check_pressed",
          "keyboard_check_released",
          "keyboard_clear",
          "keyboard_get_map",
          "keyboard_get_numlock",
          "keyboard_key_press",
          "keyboard_key_release",
          "keyboard_set_map",
          "keyboard_set_numlock",
          "keyboard_unset_map",
          "keyboard_virtual_height",
          "keyboard_virtual_hide",
          "keyboard_virtual_show",
          "keyboard_virtual_status",
          "layer_add_instance",
          "layer_background_alpha",
          "layer_background_blend",
          "layer_background_change",
          "layer_background_create",
          "layer_background_destroy",
          "layer_background_exists",
          "layer_background_get_alpha",
          "layer_background_get_blend",
          "layer_background_get_htiled",
          "layer_background_get_id",
          "layer_background_get_index",
          "layer_background_get_speed",
          "layer_background_get_sprite",
          "layer_background_get_stretch",
          "layer_background_get_visible",
          "layer_background_get_vtiled",
          "layer_background_get_xscale",
          "layer_background_get_yscale",
          "layer_background_htiled",
          "layer_background_index",
          "layer_background_speed",
          "layer_background_sprite",
          "layer_background_stretch",
          "layer_background_visible",
          "layer_background_vtiled",
          "layer_background_xscale",
          "layer_background_yscale",
          "layer_create",
          "layer_depth",
          "layer_destroy",
          "layer_destroy_instances",
          "layer_element_move",
          "layer_exists",
          "layer_force_draw_depth",
          "layer_get_all",
          "layer_get_all_elements",
          "layer_get_depth",
          "layer_get_element_layer",
          "layer_get_element_type",
          "layer_get_forced_depth",
          "layer_get_hspeed",
          "layer_get_id",
          "layer_get_id_at_depth",
          "layer_get_name",
          "layer_get_script_begin",
          "layer_get_script_end",
          "layer_get_shader",
          "layer_get_target_room",
          "layer_get_visible",
          "layer_get_vspeed",
          "layer_get_x",
          "layer_get_y",
          "layer_has_instance",
          "layer_hspeed",
          "layer_instance_get_instance",
          "layer_is_draw_depth_forced",
          "layer_reset_target_room",
          "layer_script_begin",
          "layer_script_end",
          "layer_set_target_room",
          "layer_set_visible",
          "layer_shader",
          "layer_sprite_alpha",
          "layer_sprite_angle",
          "layer_sprite_blend",
          "layer_sprite_change",
          "layer_sprite_create",
          "layer_sprite_destroy",
          "layer_sprite_exists",
          "layer_sprite_get_alpha",
          "layer_sprite_get_angle",
          "layer_sprite_get_blend",
          "layer_sprite_get_id",
          "layer_sprite_get_index",
          "layer_sprite_get_speed",
          "layer_sprite_get_sprite",
          "layer_sprite_get_x",
          "layer_sprite_get_xscale",
          "layer_sprite_get_y",
          "layer_sprite_get_yscale",
          "layer_sprite_index",
          "layer_sprite_speed",
          "layer_sprite_x",
          "layer_sprite_xscale",
          "layer_sprite_y",
          "layer_sprite_yscale",
          "layer_tile_alpha",
          "layer_tile_blend",
          "layer_tile_change",
          "layer_tile_create",
          "layer_tile_destroy",
          "layer_tile_exists",
          "layer_tile_get_alpha",
          "layer_tile_get_blend",
          "layer_tile_get_region",
          "layer_tile_get_sprite",
          "layer_tile_get_visible",
          "layer_tile_get_x",
          "layer_tile_get_xscale",
          "layer_tile_get_y",
          "layer_tile_get_yscale",
          "layer_tile_region",
          "layer_tile_visible",
          "layer_tile_x",
          "layer_tile_xscale",
          "layer_tile_y",
          "layer_tile_yscale",
          "layer_tilemap_create",
          "layer_tilemap_destroy",
          "layer_tilemap_exists",
          "layer_tilemap_get_id",
          "layer_vspeed",
          "layer_x",
          "layer_y",
          "lengthdir_x",
          "lengthdir_y",
          "lerp",
          "ln",
          "load_csv",
          "log10",
          "log2",
          "logn",
          "make_color_hsv",
          "make_color_rgb",
          "make_colour_hsv",
          "make_colour_rgb",
          "math_get_epsilon",
          "math_set_epsilon",
          "matrix_build",
          "matrix_build_identity",
          "matrix_build_lookat",
          "matrix_build_projection_ortho",
          "matrix_build_projection_perspective",
          "matrix_build_projection_perspective_fov",
          "matrix_get",
          "matrix_multiply",
          "matrix_set",
          "matrix_stack_clear",
          "matrix_stack_is_empty",
          "matrix_stack_multiply",
          "matrix_stack_pop",
          "matrix_stack_push",
          "matrix_stack_set",
          "matrix_stack_top",
          "matrix_transform_vertex",
          "max",
          "md5_file",
          "md5_string_unicode",
          "md5_string_utf8",
          "mean",
          "median",
          "merge_color",
          "merge_colour",
          "min",
          "motion_add",
          "motion_set",
          "mouse_check_button",
          "mouse_check_button_pressed",
          "mouse_check_button_released",
          "mouse_clear",
          "mouse_wheel_down",
          "mouse_wheel_up",
          "move_bounce_all",
          "move_bounce_solid",
          "move_contact_all",
          "move_contact_solid",
          "move_outside_all",
          "move_outside_solid",
          "move_random",
          "move_snap",
          "move_towards_point",
          "move_wrap",
          "mp_grid_add_cell",
          "mp_grid_add_instances",
          "mp_grid_add_rectangle",
          "mp_grid_clear_all",
          "mp_grid_clear_cell",
          "mp_grid_clear_rectangle",
          "mp_grid_create",
          "mp_grid_destroy",
          "mp_grid_draw",
          "mp_grid_get_cell",
          "mp_grid_path",
          "mp_grid_to_ds_grid",
          "mp_linear_path",
          "mp_linear_path_object",
          "mp_linear_step",
          "mp_linear_step_object",
          "mp_potential_path",
          "mp_potential_path_object",
          "mp_potential_settings",
          "mp_potential_step",
          "mp_potential_step_object",
          "network_connect",
          "network_connect_raw",
          "network_create_server",
          "network_create_server_raw",
          "network_create_socket",
          "network_create_socket_ext",
          "network_destroy",
          "network_resolve",
          "network_send_broadcast",
          "network_send_packet",
          "network_send_raw",
          "network_send_udp",
          "network_send_udp_raw",
          "network_set_config",
          "network_set_timeout",
          "object_exists",
          "object_get_depth",
          "object_get_mask",
          "object_get_name",
          "object_get_parent",
          "object_get_persistent",
          "object_get_physics",
          "object_get_solid",
          "object_get_sprite",
          "object_get_visible",
          "object_is_ancestor",
          "object_set_mask",
          "object_set_persistent",
          "object_set_solid",
          "object_set_sprite",
          "object_set_visible",
          "ord",
          "os_get_config",
          "os_get_info",
          "os_get_language",
          "os_get_region",
          "os_is_network_connected",
          "os_is_paused",
          "os_lock_orientation",
          "os_powersave_enable",
          "parameter_count",
          "parameter_string",
          "part_emitter_burst",
          "part_emitter_clear",
          "part_emitter_create",
          "part_emitter_destroy",
          "part_emitter_destroy_all",
          "part_emitter_exists",
          "part_emitter_region",
          "part_emitter_stream",
          "part_particles_clear",
          "part_particles_count",
          "part_particles_create",
          "part_particles_create_color",
          "part_particles_create_colour",
          "part_system_automatic_draw",
          "part_system_automatic_update",
          "part_system_clear",
          "part_system_create",
          "part_system_create_layer",
          "part_system_depth",
          "part_system_destroy",
          "part_system_draw_order",
          "part_system_drawit",
          "part_system_exists",
          "part_system_get_layer",
          "part_system_layer",
          "part_system_position",
          "part_system_update",
          "part_type_alpha1",
          "part_type_alpha2",
          "part_type_alpha3",
          "part_type_blend",
          "part_type_clear",
          "part_type_color1",
          "part_type_color2",
          "part_type_color3",
          "part_type_color_hsv",
          "part_type_color_mix",
          "part_type_color_rgb",
          "part_type_colour1",
          "part_type_colour2",
          "part_type_colour3",
          "part_type_colour_hsv",
          "part_type_colour_mix",
          "part_type_colour_rgb",
          "part_type_create",
          "part_type_death",
          "part_type_destroy",
          "part_type_direction",
          "part_type_exists",
          "part_type_gravity",
          "part_type_life",
          "part_type_orientation",
          "part_type_scale",
          "part_type_shape",
          "part_type_size",
          "part_type_speed",
          "part_type_sprite",
          "part_type_step",
          "path_add",
          "path_add_point",
          "path_append",
          "path_assign",
          "path_change_point",
          "path_clear_points",
          "path_delete",
          "path_delete_point",
          "path_duplicate",
          "path_end",
          "path_exists",
          "path_flip",
          "path_get_closed",
          "path_get_kind",
          "path_get_length",
          "path_get_name",
          "path_get_number",
          "path_get_point_speed",
          "path_get_point_x",
          "path_get_point_y",
          "path_get_precision",
          "path_get_speed",
          "path_get_time",
          "path_get_x",
          "path_get_y",
          "path_insert_point",
          "path_mirror",
          "path_rescale",
          "path_reverse",
          "path_rotate",
          "path_set_closed",
          "path_set_kind",
          "path_set_precision",
          "path_shift",
          "path_start",
          "physics_apply_angular_impulse",
          "physics_apply_force",
          "physics_apply_impulse",
          "physics_apply_local_force",
          "physics_apply_local_impulse",
          "physics_apply_torque",
          "physics_draw_debug",
          "physics_fixture_add_point",
          "physics_fixture_bind",
          "physics_fixture_bind_ext",
          "physics_fixture_create",
          "physics_fixture_delete",
          "physics_fixture_set_angular_damping",
          "physics_fixture_set_awake",
          "physics_fixture_set_box_shape",
          "physics_fixture_set_chain_shape",
          "physics_fixture_set_circle_shape",
          "physics_fixture_set_collision_group",
          "physics_fixture_set_density",
          "physics_fixture_set_edge_shape",
          "physics_fixture_set_friction",
          "physics_fixture_set_kinematic",
          "physics_fixture_set_linear_damping",
          "physics_fixture_set_polygon_shape",
          "physics_fixture_set_restitution",
          "physics_fixture_set_sensor",
          "physics_get_density",
          "physics_get_friction",
          "physics_get_restitution",
          "physics_joint_delete",
          "physics_joint_distance_create",
          "physics_joint_enable_motor",
          "physics_joint_friction_create",
          "physics_joint_gear_create",
          "physics_joint_get_value",
          "physics_joint_prismatic_create",
          "physics_joint_pulley_create",
          "physics_joint_revolute_create",
          "physics_joint_rope_create",
          "physics_joint_set_value",
          "physics_joint_weld_create",
          "physics_joint_wheel_create",
          "physics_mass_properties",
          "physics_particle_count",
          "physics_particle_create",
          "physics_particle_delete",
          "physics_particle_delete_region_box",
          "physics_particle_delete_region_circle",
          "physics_particle_delete_region_poly",
          "physics_particle_draw",
          "physics_particle_draw_ext",
          "physics_particle_get_damping",
          "physics_particle_get_data",
          "physics_particle_get_data_particle",
          "physics_particle_get_density",
          "physics_particle_get_gravity_scale",
          "physics_particle_get_group_flags",
          "physics_particle_get_max_count",
          "physics_particle_get_radius",
          "physics_particle_group_add_point",
          "physics_particle_group_begin",
          "physics_particle_group_box",
          "physics_particle_group_circle",
          "physics_particle_group_count",
          "physics_particle_group_delete",
          "physics_particle_group_end",
          "physics_particle_group_get_ang_vel",
          "physics_particle_group_get_angle",
          "physics_particle_group_get_centre_x",
          "physics_particle_group_get_centre_y",
          "physics_particle_group_get_data",
          "physics_particle_group_get_inertia",
          "physics_particle_group_get_mass",
          "physics_particle_group_get_vel_x",
          "physics_particle_group_get_vel_y",
          "physics_particle_group_get_x",
          "physics_particle_group_get_y",
          "physics_particle_group_join",
          "physics_particle_group_polygon",
          "physics_particle_set_category_flags",
          "physics_particle_set_damping",
          "physics_particle_set_density",
          "physics_particle_set_flags",
          "physics_particle_set_gravity_scale",
          "physics_particle_set_group_flags",
          "physics_particle_set_max_count",
          "physics_particle_set_radius",
          "physics_pause_enable",
          "physics_remove_fixture",
          "physics_set_density",
          "physics_set_friction",
          "physics_set_restitution",
          "physics_test_overlap",
          "physics_world_create",
          "physics_world_draw_debug",
          "physics_world_gravity",
          "physics_world_update_iterations",
          "physics_world_update_speed",
          "place_empty",
          "place_free",
          "place_meeting",
          "place_snapped",
          "point_direction",
          "point_distance",
          "point_distance_3d",
          "point_in_circle",
          "point_in_rectangle",
          "point_in_triangle",
          "position_change",
          "position_destroy",
          "position_empty",
          "position_meeting",
          "power",
          "ptr",
          "push_cancel_local_notification",
          "push_get_first_local_notification",
          "push_get_next_local_notification",
          "push_local_notification",
          "radtodeg",
          "random",
          "random_get_seed",
          "random_range",
          "random_set_seed",
          "randomise",
          "randomize",
          "real",
          "rectangle_in_circle",
          "rectangle_in_rectangle",
          "rectangle_in_triangle",
          "room_add",
          "room_assign",
          "room_duplicate",
          "room_exists",
          "room_get_camera",
          "room_get_name",
          "room_get_viewport",
          "room_goto",
          "room_goto_next",
          "room_goto_previous",
          "room_instance_add",
          "room_instance_clear",
          "room_next",
          "room_previous",
          "room_restart",
          "room_set_background_color",
          "room_set_background_colour",
          "room_set_camera",
          "room_set_height",
          "room_set_persistent",
          "room_set_view",
          "room_set_view_enabled",
          "room_set_viewport",
          "room_set_width",
          "round",
          "screen_save",
          "screen_save_part",
          "script_execute",
          "script_exists",
          "script_get_name",
          "sha1_file",
          "sha1_string_unicode",
          "sha1_string_utf8",
          "shader_current",
          "shader_enable_corner_id",
          "shader_get_name",
          "shader_get_sampler_index",
          "shader_get_uniform",
          "shader_is_compiled",
          "shader_reset",
          "shader_set",
          "shader_set_uniform_f",
          "shader_set_uniform_f_array",
          "shader_set_uniform_i",
          "shader_set_uniform_i_array",
          "shader_set_uniform_matrix",
          "shader_set_uniform_matrix_array",
          "shaders_are_supported",
          "shop_leave_rating",
          "show_debug_message",
          "show_debug_overlay",
          "show_error",
          "show_message",
          "show_message_async",
          "show_question",
          "show_question_async",
          "sign",
          "sin",
          "skeleton_animation_clear",
          "skeleton_animation_get",
          "skeleton_animation_get_duration",
          "skeleton_animation_get_ext",
          "skeleton_animation_get_frame",
          "skeleton_animation_get_frames",
          "skeleton_animation_list",
          "skeleton_animation_mix",
          "skeleton_animation_set",
          "skeleton_animation_set_ext",
          "skeleton_animation_set_frame",
          "skeleton_attachment_create",
          "skeleton_attachment_get",
          "skeleton_attachment_set",
          "skeleton_bone_data_get",
          "skeleton_bone_data_set",
          "skeleton_bone_state_get",
          "skeleton_bone_state_set",
          "skeleton_collision_draw_set",
          "skeleton_get_bounds",
          "skeleton_get_minmax",
          "skeleton_get_num_bounds",
          "skeleton_skin_get",
          "skeleton_skin_list",
          "skeleton_skin_set",
          "skeleton_slot_data",
          "sprite_add",
          "sprite_add_from_surface",
          "sprite_assign",
          "sprite_collision_mask",
          "sprite_create_from_surface",
          "sprite_delete",
          "sprite_duplicate",
          "sprite_exists",
          "sprite_flush",
          "sprite_flush_multi",
          "sprite_get_bbox_bottom",
          "sprite_get_bbox_left",
          "sprite_get_bbox_right",
          "sprite_get_bbox_top",
          "sprite_get_height",
          "sprite_get_name",
          "sprite_get_number",
          "sprite_get_speed",
          "sprite_get_speed_type",
          "sprite_get_texture",
          "sprite_get_tpe",
          "sprite_get_uvs",
          "sprite_get_width",
          "sprite_get_xoffset",
          "sprite_get_yoffset",
          "sprite_merge",
          "sprite_prefetch",
          "sprite_prefetch_multi",
          "sprite_replace",
          "sprite_save",
          "sprite_save_strip",
          "sprite_set_alpha_from_sprite",
          "sprite_set_cache_size",
          "sprite_set_cache_size_ext",
          "sprite_set_offset",
          "sprite_set_speed",
          "sqr",
          "sqrt",
          "steam_activate_overlay",
          "steam_activate_overlay_browser",
          "steam_activate_overlay_store",
          "steam_activate_overlay_user",
          "steam_available_languages",
          "steam_clear_achievement",
          "steam_create_leaderboard",
          "steam_current_game_language",
          "steam_download_friends_scores",
          "steam_download_scores",
          "steam_download_scores_around_user",
          "steam_file_delete",
          "steam_file_exists",
          "steam_file_persisted",
          "steam_file_read",
          "steam_file_share",
          "steam_file_size",
          "steam_file_write",
          "steam_file_write_file",
          "steam_get_achievement",
          "steam_get_app_id",
          "steam_get_persona_name",
          "steam_get_quota_free",
          "steam_get_quota_total",
          "steam_get_stat_avg_rate",
          "steam_get_stat_float",
          "steam_get_stat_int",
          "steam_get_user_account_id",
          "steam_get_user_persona_name",
          "steam_get_user_steam_id",
          "steam_initialised",
          "steam_is_cloud_enabled_for_account",
          "steam_is_cloud_enabled_for_app",
          "steam_is_overlay_activated",
          "steam_is_overlay_enabled",
          "steam_is_screenshot_requested",
          "steam_is_user_logged_on",
          "steam_reset_all_stats",
          "steam_reset_all_stats_achievements",
          "steam_send_screenshot",
          "steam_set_achievement",
          "steam_set_stat_avg_rate",
          "steam_set_stat_float",
          "steam_set_stat_int",
          "steam_stats_ready",
          "steam_ugc_create_item",
          "steam_ugc_create_query_all",
          "steam_ugc_create_query_all_ex",
          "steam_ugc_create_query_user",
          "steam_ugc_create_query_user_ex",
          "steam_ugc_download",
          "steam_ugc_get_item_install_info",
          "steam_ugc_get_item_update_info",
          "steam_ugc_get_item_update_progress",
          "steam_ugc_get_subscribed_items",
          "steam_ugc_num_subscribed_items",
          "steam_ugc_query_add_excluded_tag",
          "steam_ugc_query_add_required_tag",
          "steam_ugc_query_set_allow_cached_response",
          "steam_ugc_query_set_cloud_filename_filter",
          "steam_ugc_query_set_match_any_tag",
          "steam_ugc_query_set_ranked_by_trend_days",
          "steam_ugc_query_set_return_long_description",
          "steam_ugc_query_set_return_total_only",
          "steam_ugc_query_set_search_text",
          "steam_ugc_request_item_details",
          "steam_ugc_send_query",
          "steam_ugc_set_item_content",
          "steam_ugc_set_item_description",
          "steam_ugc_set_item_preview",
          "steam_ugc_set_item_tags",
          "steam_ugc_set_item_title",
          "steam_ugc_set_item_visibility",
          "steam_ugc_start_item_update",
          "steam_ugc_submit_item_update",
          "steam_ugc_subscribe_item",
          "steam_ugc_unsubscribe_item",
          "steam_upload_score",
          "steam_upload_score_buffer",
          "steam_upload_score_buffer_ext",
          "steam_upload_score_ext",
          "steam_user_installed_dlc",
          "steam_user_owns_dlc",
          "string",
          "string_byte_at",
          "string_byte_length",
          "string_char_at",
          "string_copy",
          "string_count",
          "string_delete",
          "string_digits",
          "string_format",
          "string_hash_to_newline",
          "string_height",
          "string_height_ext",
          "string_insert",
          "string_length",
          "string_letters",
          "string_lettersdigits",
          "string_lower",
          "string_ord_at",
          "string_pos",
          "string_repeat",
          "string_replace",
          "string_replace_all",
          "string_set_byte_at",
          "string_upper",
          "string_width",
          "string_width_ext",
          "surface_copy",
          "surface_copy_part",
          "surface_create",
          "surface_create_ext",
          "surface_depth_disable",
          "surface_exists",
          "surface_free",
          "surface_get_depth_disable",
          "surface_get_height",
          "surface_get_texture",
          "surface_get_width",
          "surface_getpixel",
          "surface_getpixel_ext",
          "surface_reset_target",
          "surface_resize",
          "surface_save",
          "surface_save_part",
          "surface_set_target",
          "surface_set_target_ext",
          "tan",
          "texture_get_height",
          "texture_get_texel_height",
          "texture_get_texel_width",
          "texture_get_uvs",
          "texture_get_width",
          "texture_global_scale",
          "texture_set_stage",
          "tile_get_empty",
          "tile_get_flip",
          "tile_get_index",
          "tile_get_mirror",
          "tile_get_rotate",
          "tile_set_empty",
          "tile_set_flip",
          "tile_set_index",
          "tile_set_mirror",
          "tile_set_rotate",
          "tilemap_clear",
          "tilemap_get",
          "tilemap_get_at_pixel",
          "tilemap_get_cell_x_at_pixel",
          "tilemap_get_cell_y_at_pixel",
          "tilemap_get_frame",
          "tilemap_get_global_mask",
          "tilemap_get_height",
          "tilemap_get_mask",
          "tilemap_get_tile_height",
          "tilemap_get_tile_width",
          "tilemap_get_tileset",
          "tilemap_get_width",
          "tilemap_get_x",
          "tilemap_get_y",
          "tilemap_set",
          "tilemap_set_at_pixel",
          "tilemap_set_global_mask",
          "tilemap_set_mask",
          "tilemap_tileset",
          "tilemap_x",
          "tilemap_y",
          "timeline_add",
          "timeline_clear",
          "timeline_delete",
          "timeline_exists",
          "timeline_get_name",
          "timeline_max_moment",
          "timeline_moment_add_script",
          "timeline_moment_clear",
          "timeline_size",
          "typeof",
          "url_get_domain",
          "url_open",
          "url_open_ext",
          "url_open_full",
          "variable_global_exists",
          "variable_global_get",
          "variable_global_set",
          "variable_instance_exists",
          "variable_instance_get",
          "variable_instance_get_names",
          "variable_instance_set",
          "variable_struct_exists",
          "variable_struct_get",
          "variable_struct_get_names",
          "variable_struct_names_count",
          "variable_struct_remove",
          "variable_struct_set",
          "vertex_argb",
          "vertex_begin",
          "vertex_color",
          "vertex_colour",
          "vertex_create_buffer",
          "vertex_create_buffer_ext",
          "vertex_create_buffer_from_buffer",
          "vertex_create_buffer_from_buffer_ext",
          "vertex_delete_buffer",
          "vertex_end",
          "vertex_float1",
          "vertex_float2",
          "vertex_float3",
          "vertex_float4",
          "vertex_format_add_color",
          "vertex_format_add_colour",
          "vertex_format_add_custom",
          "vertex_format_add_normal",
          "vertex_format_add_position",
          "vertex_format_add_position_3d",
          "vertex_format_add_texcoord",
          "vertex_format_add_textcoord",
          "vertex_format_begin",
          "vertex_format_delete",
          "vertex_format_end",
          "vertex_freeze",
          "vertex_get_buffer_size",
          "vertex_get_number",
          "vertex_normal",
          "vertex_position",
          "vertex_position_3d",
          "vertex_submit",
          "vertex_texcoord",
          "vertex_ubyte4",
          "view_get_camera",
          "view_get_hport",
          "view_get_surface_id",
          "view_get_visible",
          "view_get_wport",
          "view_get_xport",
          "view_get_yport",
          "view_set_camera",
          "view_set_hport",
          "view_set_surface_id",
          "view_set_visible",
          "view_set_wport",
          "view_set_xport",
          "view_set_yport",
          "virtual_key_add",
          "virtual_key_delete",
          "virtual_key_hide",
          "virtual_key_show",
          "win8_appbar_add_element",
          "win8_appbar_enable",
          "win8_appbar_remove_element",
          "win8_device_touchscreen_available",
          "win8_license_initialize_sandbox",
          "win8_license_trial_version",
          "win8_livetile_badge_clear",
          "win8_livetile_badge_notification",
          "win8_livetile_notification_begin",
          "win8_livetile_notification_end",
          "win8_livetile_notification_expiry",
          "win8_livetile_notification_image_add",
          "win8_livetile_notification_secondary_begin",
          "win8_livetile_notification_tag",
          "win8_livetile_notification_text_add",
          "win8_livetile_queue_enable",
          "win8_livetile_tile_clear",
          "win8_livetile_tile_notification",
          "win8_search_add_suggestions",
          "win8_search_disable",
          "win8_search_enable",
          "win8_secondarytile_badge_notification",
          "win8_secondarytile_delete",
          "win8_secondarytile_pin",
          "win8_settingscharm_add_entry",
          "win8_settingscharm_add_html_entry",
          "win8_settingscharm_add_xaml_entry",
          "win8_settingscharm_get_xaml_property",
          "win8_settingscharm_remove_entry",
          "win8_settingscharm_set_xaml_property",
          "win8_share_file",
          "win8_share_image",
          "win8_share_screenshot",
          "win8_share_text",
          "win8_share_url",
          "window_center",
          "window_device",
          "window_get_caption",
          "window_get_color",
          "window_get_colour",
          "window_get_cursor",
          "window_get_fullscreen",
          "window_get_height",
          "window_get_visible_rects",
          "window_get_width",
          "window_get_x",
          "window_get_y",
          "window_handle",
          "window_has_focus",
          "window_mouse_get_x",
          "window_mouse_get_y",
          "window_mouse_set",
          "window_set_caption",
          "window_set_color",
          "window_set_colour",
          "window_set_cursor",
          "window_set_fullscreen",
          "window_set_max_height",
          "window_set_max_width",
          "window_set_min_height",
          "window_set_min_width",
          "window_set_position",
          "window_set_rectangle",
          "window_set_size",
          "window_view_mouse_get_x",
          "window_view_mouse_get_y",
          "window_views_mouse_get_x",
          "window_views_mouse_get_y",
          "winphone_license_trial_version",
          "winphone_tile_back_content",
          "winphone_tile_back_content_wide",
          "winphone_tile_back_image",
          "winphone_tile_back_image_wide",
          "winphone_tile_back_title",
          "winphone_tile_background_color",
          "winphone_tile_background_colour",
          "winphone_tile_count",
          "winphone_tile_cycle_images",
          "winphone_tile_front_image",
          "winphone_tile_front_image_small",
          "winphone_tile_front_image_wide",
          "winphone_tile_icon_image",
          "winphone_tile_small_background_image",
          "winphone_tile_small_icon_image",
          "winphone_tile_title",
          "winphone_tile_wide_content",
          "zip_unzip"
        ],
        literal: [
          "all",
          "false",
          "noone",
          "pointer_invalid",
          "pointer_null",
          "true",
          "undefined"
        ],
        symbol: [
          "ANSI_CHARSET",
          "ARABIC_CHARSET",
          "BALTIC_CHARSET",
          "CHINESEBIG5_CHARSET",
          "DEFAULT_CHARSET",
          "EASTEUROPE_CHARSET",
          "GB2312_CHARSET",
          "GM_build_date",
          "GM_runtime_version",
          "GM_version",
          "GREEK_CHARSET",
          "HANGEUL_CHARSET",
          "HEBREW_CHARSET",
          "JOHAB_CHARSET",
          "MAC_CHARSET",
          "OEM_CHARSET",
          "RUSSIAN_CHARSET",
          "SHIFTJIS_CHARSET",
          "SYMBOL_CHARSET",
          "THAI_CHARSET",
          "TURKISH_CHARSET",
          "VIETNAMESE_CHARSET",
          "achievement_achievement_info",
          "achievement_filter_all_players",
          "achievement_filter_favorites_only",
          "achievement_filter_friends_only",
          "achievement_friends_info",
          "achievement_leaderboard_info",
          "achievement_our_info",
          "achievement_pic_loaded",
          "achievement_show_achievement",
          "achievement_show_bank",
          "achievement_show_friend_picker",
          "achievement_show_leaderboard",
          "achievement_show_profile",
          "achievement_show_purchase_prompt",
          "achievement_show_ui",
          "achievement_type_achievement_challenge",
          "achievement_type_score_challenge",
          "asset_font",
          "asset_object",
          "asset_path",
          "asset_room",
          "asset_script",
          "asset_shader",
          "asset_sound",
          "asset_sprite",
          "asset_tiles",
          "asset_timeline",
          "asset_unknown",
          "audio_3d",
          "audio_falloff_exponent_distance",
          "audio_falloff_exponent_distance_clamped",
          "audio_falloff_inverse_distance",
          "audio_falloff_inverse_distance_clamped",
          "audio_falloff_linear_distance",
          "audio_falloff_linear_distance_clamped",
          "audio_falloff_none",
          "audio_mono",
          "audio_new_system",
          "audio_old_system",
          "audio_stereo",
          "bm_add",
          "bm_complex",
          "bm_dest_alpha",
          "bm_dest_color",
          "bm_dest_colour",
          "bm_inv_dest_alpha",
          "bm_inv_dest_color",
          "bm_inv_dest_colour",
          "bm_inv_src_alpha",
          "bm_inv_src_color",
          "bm_inv_src_colour",
          "bm_max",
          "bm_normal",
          "bm_one",
          "bm_src_alpha",
          "bm_src_alpha_sat",
          "bm_src_color",
          "bm_src_colour",
          "bm_subtract",
          "bm_zero",
          "browser_chrome",
          "browser_edge",
          "browser_firefox",
          "browser_ie",
          "browser_ie_mobile",
          "browser_not_a_browser",
          "browser_opera",
          "browser_safari",
          "browser_safari_mobile",
          "browser_tizen",
          "browser_unknown",
          "browser_windows_store",
          "buffer_bool",
          "buffer_f16",
          "buffer_f32",
          "buffer_f64",
          "buffer_fast",
          "buffer_fixed",
          "buffer_generalerror",
          "buffer_grow",
          "buffer_invalidtype",
          "buffer_network",
          "buffer_outofbounds",
          "buffer_outofspace",
          "buffer_s16",
          "buffer_s32",
          "buffer_s8",
          "buffer_seek_end",
          "buffer_seek_relative",
          "buffer_seek_start",
          "buffer_string",
          "buffer_surface_copy",
          "buffer_text",
          "buffer_u16",
          "buffer_u32",
          "buffer_u64",
          "buffer_u8",
          "buffer_vbuffer",
          "buffer_wrap",
          "button_type",
          "c_aqua",
          "c_black",
          "c_blue",
          "c_dkgray",
          "c_fuchsia",
          "c_gray",
          "c_green",
          "c_lime",
          "c_ltgray",
          "c_maroon",
          "c_navy",
          "c_olive",
          "c_orange",
          "c_purple",
          "c_red",
          "c_silver",
          "c_teal",
          "c_white",
          "c_yellow",
          "cmpfunc_always",
          "cmpfunc_equal",
          "cmpfunc_greater",
          "cmpfunc_greaterequal",
          "cmpfunc_less",
          "cmpfunc_lessequal",
          "cmpfunc_never",
          "cmpfunc_notequal",
          "cr_appstart",
          "cr_arrow",
          "cr_beam",
          "cr_cross",
          "cr_default",
          "cr_drag",
          "cr_handpoint",
          "cr_hourglass",
          "cr_none",
          "cr_size_all",
          "cr_size_nesw",
          "cr_size_ns",
          "cr_size_nwse",
          "cr_size_we",
          "cr_uparrow",
          "cull_clockwise",
          "cull_counterclockwise",
          "cull_noculling",
          "device_emulator",
          "device_ios_ipad",
          "device_ios_ipad_retina",
          "device_ios_iphone",
          "device_ios_iphone5",
          "device_ios_iphone6",
          "device_ios_iphone6plus",
          "device_ios_iphone_retina",
          "device_ios_unknown",
          "device_tablet",
          "display_landscape",
          "display_landscape_flipped",
          "display_portrait",
          "display_portrait_flipped",
          "dll_cdecl",
          "dll_stdcall",
          "ds_type_grid",
          "ds_type_list",
          "ds_type_map",
          "ds_type_priority",
          "ds_type_queue",
          "ds_type_stack",
          "ef_cloud",
          "ef_ellipse",
          "ef_explosion",
          "ef_firework",
          "ef_flare",
          "ef_rain",
          "ef_ring",
          "ef_smoke",
          "ef_smokeup",
          "ef_snow",
          "ef_spark",
          "ef_star",
          // for example ev_ are types of events
          "ev_alarm",
          "ev_animation_end",
          "ev_boundary",
          "ev_cleanup",
          "ev_close_button",
          "ev_collision",
          "ev_create",
          "ev_destroy",
          "ev_draw",
          "ev_draw_begin",
          "ev_draw_end",
          "ev_draw_post",
          "ev_draw_pre",
          "ev_end_of_path",
          "ev_game_end",
          "ev_game_start",
          "ev_gesture",
          "ev_gesture_double_tap",
          "ev_gesture_drag_end",
          "ev_gesture_drag_start",
          "ev_gesture_dragging",
          "ev_gesture_flick",
          "ev_gesture_pinch_end",
          "ev_gesture_pinch_in",
          "ev_gesture_pinch_out",
          "ev_gesture_pinch_start",
          "ev_gesture_rotate_end",
          "ev_gesture_rotate_start",
          "ev_gesture_rotating",
          "ev_gesture_tap",
          "ev_global_gesture_double_tap",
          "ev_global_gesture_drag_end",
          "ev_global_gesture_drag_start",
          "ev_global_gesture_dragging",
          "ev_global_gesture_flick",
          "ev_global_gesture_pinch_end",
          "ev_global_gesture_pinch_in",
          "ev_global_gesture_pinch_out",
          "ev_global_gesture_pinch_start",
          "ev_global_gesture_rotate_end",
          "ev_global_gesture_rotate_start",
          "ev_global_gesture_rotating",
          "ev_global_gesture_tap",
          "ev_global_left_button",
          "ev_global_left_press",
          "ev_global_left_release",
          "ev_global_middle_button",
          "ev_global_middle_press",
          "ev_global_middle_release",
          "ev_global_right_button",
          "ev_global_right_press",
          "ev_global_right_release",
          "ev_gui",
          "ev_gui_begin",
          "ev_gui_end",
          "ev_joystick1_button1",
          "ev_joystick1_button2",
          "ev_joystick1_button3",
          "ev_joystick1_button4",
          "ev_joystick1_button5",
          "ev_joystick1_button6",
          "ev_joystick1_button7",
          "ev_joystick1_button8",
          "ev_joystick1_down",
          "ev_joystick1_left",
          "ev_joystick1_right",
          "ev_joystick1_up",
          "ev_joystick2_button1",
          "ev_joystick2_button2",
          "ev_joystick2_button3",
          "ev_joystick2_button4",
          "ev_joystick2_button5",
          "ev_joystick2_button6",
          "ev_joystick2_button7",
          "ev_joystick2_button8",
          "ev_joystick2_down",
          "ev_joystick2_left",
          "ev_joystick2_right",
          "ev_joystick2_up",
          "ev_keyboard",
          "ev_keypress",
          "ev_keyrelease",
          "ev_left_button",
          "ev_left_press",
          "ev_left_release",
          "ev_middle_button",
          "ev_middle_press",
          "ev_middle_release",
          "ev_mouse",
          "ev_mouse_enter",
          "ev_mouse_leave",
          "ev_mouse_wheel_down",
          "ev_mouse_wheel_up",
          "ev_no_button",
          "ev_no_more_health",
          "ev_no_more_lives",
          "ev_other",
          "ev_outside",
          "ev_right_button",
          "ev_right_press",
          "ev_right_release",
          "ev_room_end",
          "ev_room_start",
          "ev_step",
          "ev_step_begin",
          "ev_step_end",
          "ev_step_normal",
          "ev_trigger",
          "ev_user0",
          "ev_user1",
          "ev_user2",
          "ev_user3",
          "ev_user4",
          "ev_user5",
          "ev_user6",
          "ev_user7",
          "ev_user8",
          "ev_user9",
          "ev_user10",
          "ev_user11",
          "ev_user12",
          "ev_user13",
          "ev_user14",
          "ev_user15",
          "fa_archive",
          "fa_bottom",
          "fa_center",
          "fa_directory",
          "fa_hidden",
          "fa_left",
          "fa_middle",
          "fa_readonly",
          "fa_right",
          "fa_sysfile",
          "fa_top",
          "fa_volumeid",
          "fb_login_default",
          "fb_login_fallback_to_webview",
          "fb_login_forcing_safari",
          "fb_login_forcing_webview",
          "fb_login_no_fallback_to_webview",
          "fb_login_use_system_account",
          "gamespeed_fps",
          "gamespeed_microseconds",
          "ge_lose",
          "global",
          "gp_axislh",
          "gp_axislv",
          "gp_axisrh",
          "gp_axisrv",
          "gp_face1",
          "gp_face2",
          "gp_face3",
          "gp_face4",
          "gp_padd",
          "gp_padl",
          "gp_padr",
          "gp_padu",
          "gp_select",
          "gp_shoulderl",
          "gp_shoulderlb",
          "gp_shoulderr",
          "gp_shoulderrb",
          "gp_start",
          "gp_stickl",
          "gp_stickr",
          "iap_available",
          "iap_canceled",
          "iap_ev_consume",
          "iap_ev_product",
          "iap_ev_purchase",
          "iap_ev_restore",
          "iap_ev_storeload",
          "iap_failed",
          "iap_purchased",
          "iap_refunded",
          "iap_status_available",
          "iap_status_loading",
          "iap_status_processing",
          "iap_status_restoring",
          "iap_status_unavailable",
          "iap_status_uninitialised",
          "iap_storeload_failed",
          "iap_storeload_ok",
          "iap_unavailable",
          "input_type",
          "kbv_autocapitalize_characters",
          "kbv_autocapitalize_none",
          "kbv_autocapitalize_sentences",
          "kbv_autocapitalize_words",
          "kbv_returnkey_continue",
          "kbv_returnkey_default",
          "kbv_returnkey_done",
          "kbv_returnkey_emergency",
          "kbv_returnkey_go",
          "kbv_returnkey_google",
          "kbv_returnkey_join",
          "kbv_returnkey_next",
          "kbv_returnkey_route",
          "kbv_returnkey_search",
          "kbv_returnkey_send",
          "kbv_returnkey_yahoo",
          "kbv_type_ascii",
          "kbv_type_default",
          "kbv_type_email",
          "kbv_type_numbers",
          "kbv_type_phone",
          "kbv_type_phone_name",
          "kbv_type_url",
          "layerelementtype_background",
          "layerelementtype_instance",
          "layerelementtype_oldtilemap",
          "layerelementtype_particlesystem",
          "layerelementtype_sprite",
          "layerelementtype_tile",
          "layerelementtype_tilemap",
          "layerelementtype_undefined",
          "lb_disp_none",
          "lb_disp_numeric",
          "lb_disp_time_ms",
          "lb_disp_time_sec",
          "lb_sort_ascending",
          "lb_sort_descending",
          "lb_sort_none",
          "leaderboard_type_number",
          "leaderboard_type_time_mins_secs",
          "lighttype_dir",
          "lighttype_point",
          "local",
          "matrix_projection",
          "matrix_view",
          "matrix_world",
          "mb_any",
          "mb_left",
          "mb_middle",
          "mb_none",
          "mb_right",
          "mip_markedonly",
          "mip_off",
          "mip_on",
          "network_config_connect_timeout",
          "network_config_disable_reliable_udp",
          "network_config_enable_reliable_udp",
          "network_config_use_non_blocking_socket",
          "network_socket_bluetooth",
          "network_socket_tcp",
          "network_socket_udp",
          "network_type_connect",
          "network_type_data",
          "network_type_disconnect",
          "network_type_non_blocking_connect",
          "of_challen",
          "of_challenge_tie",
          "of_challenge_win",
          "os_3ds",
          "os_android",
          "os_bb10",
          "os_ios",
          "os_linux",
          "os_macosx",
          "os_ps3",
          "os_ps4",
          "os_psvita",
          "os_switch",
          "os_symbian",
          "os_tizen",
          "os_tvos",
          "os_unknown",
          "os_uwp",
          "os_wiiu",
          "os_win32",
          "os_win8native",
          "os_windows",
          "os_winphone",
          "os_xbox360",
          "os_xboxone",
          "other",
          "ov_achievements",
          "ov_community",
          "ov_friends",
          "ov_gamegroup",
          "ov_players",
          "ov_settings",
          "path_action_continue",
          "path_action_restart",
          "path_action_reverse",
          "path_action_stop",
          "phy_debug_render_aabb",
          "phy_debug_render_collision_pairs",
          "phy_debug_render_coms",
          "phy_debug_render_core_shapes",
          "phy_debug_render_joints",
          "phy_debug_render_obb",
          "phy_debug_render_shapes",
          "phy_joint_anchor_1_x",
          "phy_joint_anchor_1_y",
          "phy_joint_anchor_2_x",
          "phy_joint_anchor_2_y",
          "phy_joint_angle",
          "phy_joint_angle_limits",
          "phy_joint_damping_ratio",
          "phy_joint_frequency",
          "phy_joint_length_1",
          "phy_joint_length_2",
          "phy_joint_lower_angle_limit",
          "phy_joint_max_force",
          "phy_joint_max_length",
          "phy_joint_max_motor_force",
          "phy_joint_max_motor_torque",
          "phy_joint_max_torque",
          "phy_joint_motor_force",
          "phy_joint_motor_speed",
          "phy_joint_motor_torque",
          "phy_joint_reaction_force_x",
          "phy_joint_reaction_force_y",
          "phy_joint_reaction_torque",
          "phy_joint_speed",
          "phy_joint_translation",
          "phy_joint_upper_angle_limit",
          "phy_particle_data_flag_category",
          "phy_particle_data_flag_color",
          "phy_particle_data_flag_colour",
          "phy_particle_data_flag_position",
          "phy_particle_data_flag_typeflags",
          "phy_particle_data_flag_velocity",
          "phy_particle_flag_colormixing",
          "phy_particle_flag_colourmixing",
          "phy_particle_flag_elastic",
          "phy_particle_flag_powder",
          "phy_particle_flag_spring",
          "phy_particle_flag_tensile",
          "phy_particle_flag_viscous",
          "phy_particle_flag_wall",
          "phy_particle_flag_water",
          "phy_particle_flag_zombie",
          "phy_particle_group_flag_rigid",
          "phy_particle_group_flag_solid",
          "pi",
          "pr_linelist",
          "pr_linestrip",
          "pr_pointlist",
          "pr_trianglefan",
          "pr_trianglelist",
          "pr_trianglestrip",
          "ps_distr_gaussian",
          "ps_distr_invgaussian",
          "ps_distr_linear",
          "ps_shape_diamond",
          "ps_shape_ellipse",
          "ps_shape_line",
          "ps_shape_rectangle",
          "pt_shape_circle",
          "pt_shape_cloud",
          "pt_shape_disk",
          "pt_shape_explosion",
          "pt_shape_flare",
          "pt_shape_line",
          "pt_shape_pixel",
          "pt_shape_ring",
          "pt_shape_smoke",
          "pt_shape_snow",
          "pt_shape_spark",
          "pt_shape_sphere",
          "pt_shape_square",
          "pt_shape_star",
          "spritespeed_framespergameframe",
          "spritespeed_framespersecond",
          "text_type",
          "tf_anisotropic",
          "tf_linear",
          "tf_point",
          "tile_flip",
          "tile_index_mask",
          "tile_mirror",
          "tile_rotate",
          "timezone_local",
          "timezone_utc",
          "tm_countvsyncs",
          "tm_sleep",
          "ty_real",
          "ty_string",
          "ugc_filetype_community",
          "ugc_filetype_microtrans",
          "ugc_list_Favorited",
          "ugc_list_Followed",
          "ugc_list_Published",
          "ugc_list_Subscribed",
          "ugc_list_UsedOrPlayed",
          "ugc_list_VotedDown",
          "ugc_list_VotedOn",
          "ugc_list_VotedUp",
          "ugc_list_WillVoteLater",
          "ugc_match_AllGuides",
          "ugc_match_Artwork",
          "ugc_match_Collections",
          "ugc_match_ControllerBindings",
          "ugc_match_IntegratedGuides",
          "ugc_match_Items",
          "ugc_match_Items_Mtx",
          "ugc_match_Items_ReadyToUse",
          "ugc_match_Screenshots",
          "ugc_match_UsableInGame",
          "ugc_match_Videos",
          "ugc_match_WebGuides",
          "ugc_query_AcceptedForGameRankedByAcceptanceDate",
          "ugc_query_CreatedByFollowedUsersRankedByPublicationDate",
          "ugc_query_CreatedByFriendsRankedByPublicationDate",
          "ugc_query_FavoritedByFriendsRankedByPublicationDate",
          "ugc_query_NotYetRated",
          "ugc_query_RankedByNumTimesReported",
          "ugc_query_RankedByPublicationDate",
          "ugc_query_RankedByTextSearch",
          "ugc_query_RankedByTotalVotesAsc",
          "ugc_query_RankedByTrend",
          "ugc_query_RankedByVote",
          "ugc_query_RankedByVotesUp",
          "ugc_result_success",
          "ugc_sortorder_CreationOrderAsc",
          "ugc_sortorder_CreationOrderDesc",
          "ugc_sortorder_ForModeration",
          "ugc_sortorder_LastUpdatedDesc",
          "ugc_sortorder_SubscriptionDateDesc",
          "ugc_sortorder_TitleAsc",
          "ugc_sortorder_VoteScoreDesc",
          "ugc_visibility_friends_only",
          "ugc_visibility_private",
          "ugc_visibility_public",
          "vertex_type_color",
          "vertex_type_colour",
          "vertex_type_float1",
          "vertex_type_float2",
          "vertex_type_float3",
          "vertex_type_float4",
          "vertex_type_ubyte4",
          "vertex_usage_binormal",
          "vertex_usage_blendindices",
          "vertex_usage_blendweight",
          "vertex_usage_color",
          "vertex_usage_colour",
          "vertex_usage_depth",
          "vertex_usage_fog",
          "vertex_usage_normal",
          "vertex_usage_position",
          "vertex_usage_psize",
          "vertex_usage_sample",
          "vertex_usage_tangent",
          "vertex_usage_texcoord",
          "vertex_usage_textcoord",
          "vk_add",
          "vk_alt",
          "vk_anykey",
          "vk_backspace",
          "vk_control",
          "vk_decimal",
          "vk_delete",
          "vk_divide",
          "vk_down",
          "vk_end",
          "vk_enter",
          "vk_escape",
          "vk_f1",
          "vk_f2",
          "vk_f3",
          "vk_f4",
          "vk_f5",
          "vk_f6",
          "vk_f7",
          "vk_f8",
          "vk_f9",
          "vk_f10",
          "vk_f11",
          "vk_f12",
          "vk_home",
          "vk_insert",
          "vk_lalt",
          "vk_lcontrol",
          "vk_left",
          "vk_lshift",
          "vk_multiply",
          "vk_nokey",
          "vk_numpad0",
          "vk_numpad1",
          "vk_numpad2",
          "vk_numpad3",
          "vk_numpad4",
          "vk_numpad5",
          "vk_numpad6",
          "vk_numpad7",
          "vk_numpad8",
          "vk_numpad9",
          "vk_pagedown",
          "vk_pageup",
          "vk_pause",
          "vk_printscreen",
          "vk_ralt",
          "vk_rcontrol",
          "vk_return",
          "vk_right",
          "vk_rshift",
          "vk_shift",
          "vk_space",
          "vk_subtract",
          "vk_tab",
          "vk_up"
        ],
        "variable.language": [
          "alarm",
          "application_surface",
          "argument",
          "argument0",
          "argument1",
          "argument2",
          "argument3",
          "argument4",
          "argument5",
          "argument6",
          "argument7",
          "argument8",
          "argument9",
          "argument10",
          "argument11",
          "argument12",
          "argument13",
          "argument14",
          "argument15",
          "argument_count",
          "argument_relative",
          "async_load",
          "background_color",
          "background_colour",
          "background_showcolor",
          "background_showcolour",
          "bbox_bottom",
          "bbox_left",
          "bbox_right",
          "bbox_top",
          "browser_height",
          "browser_width",
          "caption_health",
          "caption_lives",
          "caption_score",
          "current_day",
          "current_hour",
          "current_minute",
          "current_month",
          "current_second",
          "current_time",
          "current_weekday",
          "current_year",
          "cursor_sprite",
          "debug_mode",
          "delta_time",
          "depth",
          "direction",
          "display_aa",
          "error_last",
          "error_occurred",
          "event_action",
          "event_data",
          "event_number",
          "event_object",
          "event_type",
          "fps",
          "fps_real",
          "friction",
          "game_display_name",
          "game_id",
          "game_project_name",
          "game_save_id",
          "gamemaker_pro",
          "gamemaker_registered",
          "gamemaker_version",
          "gravity",
          "gravity_direction",
          "health",
          "hspeed",
          "iap_data",
          "id|0",
          "image_alpha",
          "image_angle",
          "image_blend",
          "image_index",
          "image_number",
          "image_speed",
          "image_xscale",
          "image_yscale",
          "instance_count",
          "instance_id",
          "keyboard_key",
          "keyboard_lastchar",
          "keyboard_lastkey",
          "keyboard_string",
          "layer",
          "lives",
          "mask_index",
          "mouse_button",
          "mouse_lastbutton",
          "mouse_x",
          "mouse_y",
          "object_index",
          "os_browser",
          "os_device",
          "os_type",
          "os_version",
          "path_endaction",
          "path_index",
          "path_orientation",
          "path_position",
          "path_positionprevious",
          "path_scale",
          "path_speed",
          "persistent",
          "phy_active",
          "phy_angular_damping",
          "phy_angular_velocity",
          "phy_bullet",
          "phy_col_normal_x",
          "phy_col_normal_y",
          "phy_collision_points",
          "phy_collision_x",
          "phy_collision_y",
          "phy_com_x",
          "phy_com_y",
          "phy_dynamic",
          "phy_fixed_rotation",
          "phy_inertia",
          "phy_kinematic",
          "phy_linear_damping",
          "phy_linear_velocity_x",
          "phy_linear_velocity_y",
          "phy_mass",
          "phy_position_x",
          "phy_position_xprevious",
          "phy_position_y",
          "phy_position_yprevious",
          "phy_rotation",
          "phy_sleeping",
          "phy_speed",
          "phy_speed_x",
          "phy_speed_y",
          "program_directory",
          "room",
          "room_caption",
          "room_first",
          "room_height",
          "room_last",
          "room_persistent",
          "room_speed",
          "room_width",
          "score",
          "self",
          "show_health",
          "show_lives",
          "show_score",
          "solid",
          "speed",
          "sprite_height",
          "sprite_index",
          "sprite_width",
          "sprite_xoffset",
          "sprite_yoffset",
          "temp_directory",
          "timeline_index",
          "timeline_loop",
          "timeline_position",
          "timeline_running",
          "timeline_speed",
          "view_angle",
          "view_camera",
          "view_current",
          "view_enabled",
          "view_hborder",
          "view_hport",
          "view_hspeed",
          "view_hview",
          "view_object",
          "view_surface_id",
          "view_vborder",
          "view_visible",
          "view_vspeed",
          "view_wport",
          "view_wview",
          "view_xport",
          "view_xview",
          "view_yport",
          "view_yview",
          "visible",
          "vspeed",
          "webgl_enabled",
          "working_directory",
          "xprevious",
          "xstart",
          "x|0",
          "yprevious",
          "ystart",
          "y|0"
        ]
      },
      contains: [
        t.C_LINE_COMMENT_MODE,
        t.C_BLOCK_COMMENT_MODE,
        t.APOS_STRING_MODE,
        t.QUOTE_STRING_MODE,
        t.C_NUMBER_MODE
      ]
    };
  }
  return IE = e, IE;
}
var LE, UD;
function KZ() {
  if (UD) return LE;
  UD = 1;
  function e(t) {
    const o = {
      keyword: [
        "break",
        "case",
        "chan",
        "const",
        "continue",
        "default",
        "defer",
        "else",
        "fallthrough",
        "for",
        "func",
        "go",
        "goto",
        "if",
        "import",
        "interface",
        "map",
        "package",
        "range",
        "return",
        "select",
        "struct",
        "switch",
        "type",
        "var"
      ],
      type: [
        "bool",
        "byte",
        "complex64",
        "complex128",
        "error",
        "float32",
        "float64",
        "int8",
        "int16",
        "int32",
        "int64",
        "string",
        "uint8",
        "uint16",
        "uint32",
        "uint64",
        "int",
        "uint",
        "uintptr",
        "rune"
      ],
      literal: [
        "true",
        "false",
        "iota",
        "nil"
      ],
      built_in: [
        "append",
        "cap",
        "close",
        "complex",
        "copy",
        "imag",
        "len",
        "make",
        "new",
        "panic",
        "print",
        "println",
        "real",
        "recover",
        "delete"
      ]
    };
    return {
      name: "Go",
      aliases: ["golang"],
      keywords: o,
      illegal: "</",
      contains: [
        t.C_LINE_COMMENT_MODE,
        t.C_BLOCK_COMMENT_MODE,
        {
          className: "string",
          variants: [
            t.QUOTE_STRING_MODE,
            t.APOS_STRING_MODE,
            {
              begin: "`",
              end: "`"
            }
          ]
        },
        {
          className: "number",
          variants: [
            {
              begin: t.C_NUMBER_RE + "[i]",
              relevance: 1
            },
            t.C_NUMBER_MODE
          ]
        },
        {
          begin: /:=/
          // relevance booster
        },
        {
          className: "function",
          beginKeywords: "func",
          end: "\\s*(\\{|$)",
          excludeEnd: !0,
          contains: [
            t.TITLE_MODE,
            {
              className: "params",
              begin: /\(/,
              end: /\)/,
              endsParent: !0,
              keywords: o,
              illegal: /["']/
            }
          ]
        }
      ]
    };
  }
  return LE = e, LE;
}
var kE, qD;
function jZ() {
  if (qD) return kE;
  qD = 1;
  function e(t) {
    return {
      name: "Golo",
      keywords: {
        keyword: [
          "println",
          "readln",
          "print",
          "import",
          "module",
          "function",
          "local",
          "return",
          "let",
          "var",
          "while",
          "for",
          "foreach",
          "times",
          "in",
          "case",
          "when",
          "match",
          "with",
          "break",
          "continue",
          "augment",
          "augmentation",
          "each",
          "find",
          "filter",
          "reduce",
          "if",
          "then",
          "else",
          "otherwise",
          "try",
          "catch",
          "finally",
          "raise",
          "throw",
          "orIfNull",
          "DynamicObject|10",
          "DynamicVariable",
          "struct",
          "Observable",
          "map",
          "set",
          "vector",
          "list",
          "array"
        ],
        literal: [
          "true",
          "false",
          "null"
        ]
      },
      contains: [
        t.HASH_COMMENT_MODE,
        t.QUOTE_STRING_MODE,
        t.C_NUMBER_MODE,
        {
          className: "meta",
          begin: "@[A-Za-z]+"
        }
      ]
    };
  }
  return kE = e, kE;
}
var ME, GD;
function QZ() {
  if (GD) return ME;
  GD = 1;
  function e(t) {
    return {
      name: "Gradle",
      case_insensitive: !0,
      keywords: [
        "task",
        "project",
        "allprojects",
        "subprojects",
        "artifacts",
        "buildscript",
        "configurations",
        "dependencies",
        "repositories",
        "sourceSets",
        "description",
        "delete",
        "from",
        "into",
        "include",
        "exclude",
        "source",
        "classpath",
        "destinationDir",
        "includes",
        "options",
        "sourceCompatibility",
        "targetCompatibility",
        "group",
        "flatDir",
        "doLast",
        "doFirst",
        "flatten",
        "todir",
        "fromdir",
        "ant",
        "def",
        "abstract",
        "break",
        "case",
        "catch",
        "continue",
        "default",
        "do",
        "else",
        "extends",
        "final",
        "finally",
        "for",
        "if",
        "implements",
        "instanceof",
        "native",
        "new",
        "private",
        "protected",
        "public",
        "return",
        "static",
        "switch",
        "synchronized",
        "throw",
        "throws",
        "transient",
        "try",
        "volatile",
        "while",
        "strictfp",
        "package",
        "import",
        "false",
        "null",
        "super",
        "this",
        "true",
        "antlrtask",
        "checkstyle",
        "codenarc",
        "copy",
        "boolean",
        "byte",
        "char",
        "class",
        "double",
        "float",
        "int",
        "interface",
        "long",
        "short",
        "void",
        "compile",
        "runTime",
        "file",
        "fileTree",
        "abs",
        "any",
        "append",
        "asList",
        "asWritable",
        "call",
        "collect",
        "compareTo",
        "count",
        "div",
        "dump",
        "each",
        "eachByte",
        "eachFile",
        "eachLine",
        "every",
        "find",
        "findAll",
        "flatten",
        "getAt",
        "getErr",
        "getIn",
        "getOut",
        "getText",
        "grep",
        "immutable",
        "inject",
        "inspect",
        "intersect",
        "invokeMethods",
        "isCase",
        "join",
        "leftShift",
        "minus",
        "multiply",
        "newInputStream",
        "newOutputStream",
        "newPrintWriter",
        "newReader",
        "newWriter",
        "next",
        "plus",
        "pop",
        "power",
        "previous",
        "print",
        "println",
        "push",
        "putAt",
        "read",
        "readBytes",
        "readLines",
        "reverse",
        "reverseEach",
        "round",
        "size",
        "sort",
        "splitEachLine",
        "step",
        "subMap",
        "times",
        "toInteger",
        "toList",
        "tokenize",
        "upto",
        "waitForOrKill",
        "withPrintWriter",
        "withReader",
        "withStream",
        "withWriter",
        "withWriterAppend",
        "write",
        "writeLine"
      ],
      contains: [
        t.C_LINE_COMMENT_MODE,
        t.C_BLOCK_COMMENT_MODE,
        t.APOS_STRING_MODE,
        t.QUOTE_STRING_MODE,
        t.NUMBER_MODE,
        t.REGEXP_MODE
      ]
    };
  }
  return ME = e, ME;
}
var PE, YD;
function XZ() {
  if (YD) return PE;
  YD = 1;
  function e(t) {
    const n = t.regex, r = /[_A-Za-z][_0-9A-Za-z]*/;
    return {
      name: "GraphQL",
      aliases: ["gql"],
      case_insensitive: !0,
      disableAutodetect: !1,
      keywords: {
        keyword: [
          "query",
          "mutation",
          "subscription",
          "type",
          "input",
          "schema",
          "directive",
          "interface",
          "union",
          "scalar",
          "fragment",
          "enum",
          "on"
        ],
        literal: [
          "true",
          "false",
          "null"
        ]
      },
      contains: [
        t.HASH_COMMENT_MODE,
        t.QUOTE_STRING_MODE,
        t.NUMBER_MODE,
        {
          scope: "punctuation",
          match: /[.]{3}/,
          relevance: 0
        },
        {
          scope: "punctuation",
          begin: /[\!\(\)\:\=\[\]\{\|\}]{1}/,
          relevance: 0
        },
        {
          scope: "variable",
          begin: /\$/,
          end: /\W/,
          excludeEnd: !0,
          relevance: 0
        },
        {
          scope: "meta",
          match: /@\w+/,
          excludeEnd: !0
        },
        {
          scope: "symbol",
          begin: n.concat(r, n.lookahead(/\s*:/)),
          relevance: 0
        }
      ],
      illegal: [
        /[;<']/,
        /BEGIN/
      ]
    };
  }
  return PE = e, PE;
}
var FE, HD;
function ZZ() {
  if (HD) return FE;
  HD = 1;
  function e(n, r = {}) {
    return r.variants = n, r;
  }
  function t(n) {
    const r = n.regex, i = "[A-Za-z0-9_$]+", a = e([
      n.C_LINE_COMMENT_MODE,
      n.C_BLOCK_COMMENT_MODE,
      n.COMMENT(
        "/\\*\\*",
        "\\*/",
        {
          relevance: 0,
          contains: [
            {
              // eat up @'s in emails to prevent them to be recognized as doctags
              begin: /\w+@/,
              relevance: 0
            },
            {
              className: "doctag",
              begin: "@[A-Za-z]+"
            }
          ]
        }
      )
    ]), o = {
      className: "regexp",
      begin: /~?\/[^\/\n]+\//,
      contains: [n.BACKSLASH_ESCAPE]
    }, s = e([
      n.BINARY_NUMBER_MODE,
      n.C_NUMBER_MODE
    ]), l = e(
      [
        {
          begin: /"""/,
          end: /"""/
        },
        {
          begin: /'''/,
          end: /'''/
        },
        {
          begin: "\\$/",
          end: "/\\$",
          relevance: 10
        },
        n.APOS_STRING_MODE,
        n.QUOTE_STRING_MODE
      ],
      { className: "string" }
    ), u = {
      match: [
        /(class|interface|trait|enum|record|extends|implements)/,
        /\s+/,
        n.UNDERSCORE_IDENT_RE
      ],
      scope: {
        1: "keyword",
        3: "title.class"
      }
    };
    return {
      name: "Groovy",
      keywords: {
        "variable.language": "this super",
        literal: "true false null",
        type: [
          "byte",
          "short",
          "char",
          "int",
          "long",
          "boolean",
          "float",
          "double",
          "void"
        ],
        keyword: [
          // groovy specific keywords
          "def",
          "as",
          "in",
          "assert",
          "trait",
          // common keywords with Java
          "abstract",
          "static",
          "volatile",
          "transient",
          "public",
          "private",
          "protected",
          "synchronized",
          "final",
          "class",
          "interface",
          "enum",
          "if",
          "else",
          "for",
          "while",
          "switch",
          "case",
          "break",
          "default",
          "continue",
          "throw",
          "throws",
          "try",
          "catch",
          "finally",
          "implements",
          "extends",
          "new",
          "import",
          "package",
          "return",
          "instanceof",
          "var"
        ]
      },
      contains: [
        n.SHEBANG({
          binary: "groovy",
          relevance: 10
        }),
        a,
        l,
        o,
        s,
        u,
        {
          className: "meta",
          begin: "@[A-Za-z]+",
          relevance: 0
        },
        {
          // highlight map keys and named parameters as attrs
          className: "attr",
          begin: i + "[ 	]*:",
          relevance: 0
        },
        {
          // catch middle element of the ternary operator
          // to avoid highlight it as a label, named parameter, or map key
          begin: /\?/,
          end: /:/,
          relevance: 0,
          contains: [
            a,
            l,
            o,
            s,
            "self"
          ]
        },
        {
          // highlight labeled statements
          className: "symbol",
          begin: "^[ 	]*" + r.lookahead(i + ":"),
          excludeBegin: !0,
          end: i + ":",
          relevance: 0
        }
      ],
      illegal: /#|<\//
    };
  }
  return FE = t, FE;
}
var BE, zD;
function JZ() {
  if (zD) return BE;
  zD = 1;
  function e(t) {
    return {
      name: "HAML",
      case_insensitive: !0,
      contains: [
        {
          className: "meta",
          begin: "^!!!( (5|1\\.1|Strict|Frameset|Basic|Mobile|RDFa|XML\\b.*))?$",
          relevance: 10
        },
        // FIXME these comments should be allowed to span indented lines
        t.COMMENT(
          "^\\s*(!=#|=#|-#|/).*$",
          null,
          { relevance: 0 }
        ),
        {
          begin: "^\\s*(-|=|!=)(?!#)",
          end: /$/,
          subLanguage: "ruby",
          excludeBegin: !0,
          excludeEnd: !0
        },
        {
          className: "tag",
          begin: "^\\s*%",
          contains: [
            {
              className: "selector-tag",
              begin: "\\w+"
            },
            {
              className: "selector-id",
              begin: "#[\\w-]+"
            },
            {
              className: "selector-class",
              begin: "\\.[\\w-]+"
            },
            {
              begin: /\{\s*/,
              end: /\s*\}/,
              contains: [
                {
                  begin: ":\\w+\\s*=>",
                  end: ",\\s+",
                  returnBegin: !0,
                  endsWithParent: !0,
                  contains: [
                    {
                      className: "attr",
                      begin: ":\\w+"
                    },
                    t.APOS_STRING_MODE,
                    t.QUOTE_STRING_MODE,
                    {
                      begin: "\\w+",
                      relevance: 0
                    }
                  ]
                }
              ]
            },
            {
              begin: "\\(\\s*",
              end: "\\s*\\)",
              excludeEnd: !0,
              contains: [
                {
                  begin: "\\w+\\s*=",
                  end: "\\s+",
                  returnBegin: !0,
                  endsWithParent: !0,
                  contains: [
                    {
                      className: "attr",
                      begin: "\\w+",
                      relevance: 0
                    },
                    t.APOS_STRING_MODE,
                    t.QUOTE_STRING_MODE,
                    {
                      begin: "\\w+",
                      relevance: 0
                    }
                  ]
                }
              ]
            }
          ]
        },
        { begin: "^\\s*[=~]\\s*" },
        {
          begin: /#\{/,
          end: /\}/,
          subLanguage: "ruby",
          excludeBegin: !0,
          excludeEnd: !0
        }
      ]
    };
  }
  return BE = e, BE;
}
var $E, VD;
function eJ() {
  if (VD) return $E;
  VD = 1;
  function e(t) {
    const n = t.regex, r = {
      $pattern: /[\w.\/]+/,
      built_in: [
        "action",
        "bindattr",
        "collection",
        "component",
        "concat",
        "debugger",
        "each",
        "each-in",
        "get",
        "hash",
        "if",
        "in",
        "input",
        "link-to",
        "loc",
        "log",
        "lookup",
        "mut",
        "outlet",
        "partial",
        "query-params",
        "render",
        "template",
        "textarea",
        "unbound",
        "unless",
        "view",
        "with",
        "yield"
      ]
    }, i = {
      $pattern: /[\w.\/]+/,
      literal: [
        "true",
        "false",
        "undefined",
        "null"
      ]
    }, a = /""|"[^"]+"/, o = /''|'[^']+'/, s = /\[\]|\[[^\]]+\]/, l = /[^\s!"#%&'()*+,.\/;<=>@\[\\\]^`{|}~]+/, u = /(\.|\/)/, c = n.either(
      a,
      o,
      s,
      l
    ), d = n.concat(
      n.optional(/\.|\.\/|\//),
      // relative or absolute path
      c,
      n.anyNumberOfTimes(n.concat(
        u,
        c
      ))
    ), f = n.concat(
      "(",
      s,
      "|",
      l,
      ")(?==)"
    ), h = { begin: d }, m = t.inherit(h, { keywords: i }), v = {
      begin: /\(/,
      end: /\)/
      // the "contains" is added below when all necessary sub-modes are defined
    }, b = {
      // fka "attribute-assignment", parameters of the form 'key=value'
      className: "attr",
      begin: f,
      relevance: 0,
      starts: {
        begin: /=/,
        end: /=/,
        starts: { contains: [
          t.NUMBER_MODE,
          t.QUOTE_STRING_MODE,
          t.APOS_STRING_MODE,
          m,
          v
        ] }
      }
    }, y = {
      // parameters of the form '{{#with x as | y |}}...{{/with}}'
      begin: /as\s+\|/,
      keywords: { keyword: "as" },
      end: /\|/,
      contains: [
        {
          // define sub-mode in order to prevent highlighting of block-parameter named "as"
          begin: /\w+/
        }
      ]
    }, g = {
      contains: [
        t.NUMBER_MODE,
        t.QUOTE_STRING_MODE,
        t.APOS_STRING_MODE,
        y,
        b,
        m,
        v
      ],
      returnEnd: !0
      // the property "end" is defined through inheritance when the mode is used. If depends
      // on the surrounding mode, but "endsWithParent" does not work here (i.e. it includes the
      // end-token of the surrounding mode)
    }, E = t.inherit(h, {
      className: "name",
      keywords: r,
      starts: t.inherit(g, { end: /\)/ })
    });
    v.contains = [E];
    const S = t.inherit(h, {
      keywords: r,
      className: "name",
      starts: t.inherit(g, { end: /\}\}/ })
    }), C = t.inherit(h, {
      keywords: r,
      className: "name"
    }), T = t.inherit(h, {
      className: "name",
      keywords: r,
      starts: t.inherit(g, { end: /\}\}/ })
    });
    return {
      name: "Handlebars",
      aliases: [
        "hbs",
        "html.hbs",
        "html.handlebars",
        "htmlbars"
      ],
      case_insensitive: !0,
      subLanguage: "xml",
      contains: [
        {
          begin: /\\\{\{/,
          skip: !0
        },
        {
          begin: /\\\\(?=\{\{)/,
          skip: !0
        },
        t.COMMENT(/\{\{!--/, /--\}\}/),
        t.COMMENT(/\{\{!/, /\}\}/),
        {
          // open raw block "{{{{raw}}}} content not evaluated {{{{/raw}}}}"
          className: "template-tag",
          begin: /\{\{\{\{(?!\/)/,
          end: /\}\}\}\}/,
          contains: [S],
          starts: {
            end: /\{\{\{\{\//,
            returnEnd: !0,
            subLanguage: "xml"
          }
        },
        {
          // close raw block
          className: "template-tag",
          begin: /\{\{\{\{\//,
          end: /\}\}\}\}/,
          contains: [C]
        },
        {
          // open block statement
          className: "template-tag",
          begin: /\{\{#/,
          end: /\}\}/,
          contains: [S]
        },
        {
          className: "template-tag",
          begin: /\{\{(?=else\}\})/,
          end: /\}\}/,
          keywords: "else"
        },
        {
          className: "template-tag",
          begin: /\{\{(?=else if)/,
          end: /\}\}/,
          keywords: "else if"
        },
        {
          // closing block statement
          className: "template-tag",
          begin: /\{\{\//,
          end: /\}\}/,
          contains: [C]
        },
        {
          // template variable or helper-call that is NOT html-escaped
          className: "template-variable",
          begin: /\{\{\{/,
          end: /\}\}\}/,
          contains: [T]
        },
        {
          // template variable or helper-call that is html-escaped
          className: "template-variable",
          begin: /\{\{/,
          end: /\}\}/,
          contains: [T]
        }
      ]
    };
  }
  return $E = e, $E;
}
var UE, WD;
function tJ() {
  if (WD) return UE;
  WD = 1;
  function e(t) {
    const n = "([0-9]_*)+", r = "([0-9a-fA-F]_*)+", i = "([01]_*)+", a = "([0-7]_*)+", u = "([!#$%&*+.\\/<=>?@\\\\^~-]|(?!([(),;\\[\\]`|{}]|[_:\"']))(\\p{S}|\\p{P}))", c = { variants: [
      // Double dash forms a valid comment only if it's not part of legal lexeme.
      // See: Haskell 98 report: https://www.haskell.org/onlinereport/lexemes.html
      //
      // The commented code does the job, but we can't use negative lookbehind,
      // due to poor support by Safari browser.
      // > hljs.COMMENT(`(?<!${symbol})--+(?!${symbol})`, '$'),
      // So instead, we'll add a no-markup rule before the COMMENT rule in the rules list
      // to match the problematic infix operators that contain double dash.
      t.COMMENT("--+", "$"),
      t.COMMENT(
        /\{-/,
        /-\}/,
        { contains: ["self"] }
      )
    ] }, d = {
      className: "meta",
      begin: /\{-#/,
      end: /#-\}/
    }, f = {
      className: "meta",
      begin: "^#",
      end: "$"
    }, h = {
      className: "type",
      begin: "\\b[A-Z][\\w']*",
      // TODO: other constructors (build-in, infix).
      relevance: 0
    }, m = {
      begin: "\\(",
      end: "\\)",
      illegal: '"',
      contains: [
        d,
        f,
        {
          className: "type",
          begin: "\\b[A-Z][\\w]*(\\((\\.\\.|,|\\w+)\\))?"
        },
        t.inherit(t.TITLE_MODE, { begin: "[_a-z][\\w']*" }),
        c
      ]
    }, v = {
      begin: /\{/,
      end: /\}/,
      contains: m.contains
    }, b = {
      className: "number",
      relevance: 0,
      variants: [
        // decimal floating-point-literal (subsumes decimal-literal)
        { match: `\\b(${n})(\\.(${n}))?([eE][+-]?(${n}))?\\b` },
        // hexadecimal floating-point-literal (subsumes hexadecimal-literal)
        { match: `\\b0[xX]_*(${r})(\\.(${r}))?([pP][+-]?(${n}))?\\b` },
        // octal-literal
        { match: `\\b0[oO](${a})\\b` },
        // binary-literal
        { match: `\\b0[bB](${i})\\b` }
      ]
    };
    return {
      name: "Haskell",
      aliases: ["hs"],
      keywords: "let in if then else case of where do module import hiding qualified type data newtype deriving class instance as default infix infixl infixr foreign export ccall stdcall cplusplus jvm dotnet safe unsafe family forall mdo proc rec",
      unicodeRegex: !0,
      contains: [
        // Top-level constructions.
        {
          beginKeywords: "module",
          end: "where",
          keywords: "module where",
          contains: [
            m,
            c
          ],
          illegal: "\\W\\.|;"
        },
        {
          begin: "\\bimport\\b",
          end: "$",
          keywords: "import qualified as hiding",
          contains: [
            m,
            c
          ],
          illegal: "\\W\\.|;"
        },
        {
          className: "class",
          begin: "^(\\s*)?(class|instance)\\b",
          end: "where",
          keywords: "class family instance where",
          contains: [
            h,
            m,
            c
          ]
        },
        {
          className: "class",
          begin: "\\b(data|(new)?type)\\b",
          end: "$",
          keywords: "data family type newtype deriving",
          contains: [
            d,
            h,
            m,
            v,
            c
          ]
        },
        {
          beginKeywords: "default",
          end: "$",
          contains: [
            h,
            m,
            c
          ]
        },
        {
          beginKeywords: "infix infixl infixr",
          end: "$",
          contains: [
            t.C_NUMBER_MODE,
            c
          ]
        },
        {
          begin: "\\bforeign\\b",
          end: "$",
          keywords: "foreign import export ccall stdcall cplusplus jvm dotnet safe unsafe",
          contains: [
            h,
            t.QUOTE_STRING_MODE,
            c
          ]
        },
        {
          className: "meta",
          begin: "#!\\/usr\\/bin\\/env runhaskell",
          end: "$"
        },
        // "Whitespaces".
        d,
        f,
        // Literals and names.
        // Single characters.
        {
          scope: "string",
          begin: /'(?=\\?.')/,
          end: /'/,
          contains: [
            {
              scope: "char.escape",
              match: /\\./
            }
          ]
        },
        t.QUOTE_STRING_MODE,
        b,
        h,
        t.inherit(t.TITLE_MODE, { begin: "^[_a-z][\\w']*" }),
        // No markup, prevents infix operators from being recognized as comments.
        { begin: `(?!-)${u}--+|--+(?!-)${u}` },
        c,
        {
          // No markup, relevance booster
          begin: "->|<-"
        }
      ]
    };
  }
  return UE = e, UE;
}
var qE, KD;
function nJ() {
  if (KD) return qE;
  KD = 1;
  function e(t) {
    const n = "[a-zA-Z_$][a-zA-Z0-9_$]*", r = /(-?)(\b0[xX][a-fA-F0-9_]+|(\b\d+(\.[\d_]*)?|\.[\d_]+)(([eE][-+]?\d+)|i32|u32|i64|f64)?)/;
    return {
      name: "Haxe",
      aliases: ["hx"],
      keywords: {
        keyword: "abstract break case cast catch continue default do dynamic else enum extern final for function here if import in inline is macro never new override package private get set public return static super switch this throw trace try typedef untyped using var while " + "Int Float String Bool Dynamic Void Array ",
        built_in: "trace this",
        literal: "true false null _"
      },
      contains: [
        {
          className: "string",
          // interpolate-able strings
          begin: "'",
          end: "'",
          contains: [
            t.BACKSLASH_ESCAPE,
            {
              className: "subst",
              // interpolation
              begin: /\$\{/,
              end: /\}/
            },
            {
              className: "subst",
              // interpolation
              begin: /\$/,
              end: /\W\}/
            }
          ]
        },
        t.QUOTE_STRING_MODE,
        t.C_LINE_COMMENT_MODE,
        t.C_BLOCK_COMMENT_MODE,
        {
          className: "number",
          begin: r,
          relevance: 0
        },
        {
          className: "variable",
          begin: "\\$" + n
        },
        {
          className: "meta",
          // compiler meta
          begin: /@:?/,
          end: /\(|$/,
          excludeEnd: !0
        },
        {
          className: "meta",
          // compiler conditionals
          begin: "#",
          end: "$",
          keywords: { keyword: "if else elseif end error" }
        },
        {
          className: "type",
          // function types
          begin: /:[ \t]*/,
          end: /[^A-Za-z0-9_ \t\->]/,
          excludeBegin: !0,
          excludeEnd: !0,
          relevance: 0
        },
        {
          className: "type",
          // types
          begin: /:[ \t]*/,
          end: /\W/,
          excludeBegin: !0,
          excludeEnd: !0
        },
        {
          className: "type",
          // instantiation
          begin: /new */,
          end: /\W/,
          excludeBegin: !0,
          excludeEnd: !0
        },
        {
          className: "title.class",
          // enums
          beginKeywords: "enum",
          end: /\{/,
          contains: [t.TITLE_MODE]
        },
        {
          className: "title.class",
          // abstracts
          begin: "\\babstract\\b(?=\\s*" + t.IDENT_RE + "\\s*\\()",
          end: /[\{$]/,
          contains: [
            {
              className: "type",
              begin: /\(/,
              end: /\)/,
              excludeBegin: !0,
              excludeEnd: !0
            },
            {
              className: "type",
              begin: /from +/,
              end: /\W/,
              excludeBegin: !0,
              excludeEnd: !0
            },
            {
              className: "type",
              begin: /to +/,
              end: /\W/,
              excludeBegin: !0,
              excludeEnd: !0
            },
            t.TITLE_MODE
          ],
          keywords: { keyword: "abstract from to" }
        },
        {
          className: "title.class",
          // classes
          begin: /\b(class|interface) +/,
          end: /[\{$]/,
          excludeEnd: !0,
          keywords: "class interface",
          contains: [
            {
              className: "keyword",
              begin: /\b(extends|implements) +/,
              keywords: "extends implements",
              contains: [
                {
                  className: "type",
                  begin: t.IDENT_RE,
                  relevance: 0
                }
              ]
            },
            t.TITLE_MODE
          ]
        },
        {
          className: "title.function",
          beginKeywords: "function",
          end: /\(/,
          excludeEnd: !0,
          illegal: /\S/,
          contains: [t.TITLE_MODE]
        }
      ],
      illegal: /<\//
    };
  }
  return qE = e, qE;
}
var GE, jD;
function rJ() {
  if (jD) return GE;
  jD = 1;
  function e(t) {
    return {
      name: "HSP",
      case_insensitive: !0,
      keywords: {
        $pattern: /[\w._]+/,
        keyword: "goto gosub return break repeat loop continue wait await dim sdim foreach dimtype dup dupptr end stop newmod delmod mref run exgoto on mcall assert logmes newlab resume yield onexit onerror onkey onclick oncmd exist delete mkdir chdir dirlist bload bsave bcopy memfile if else poke wpoke lpoke getstr chdpm memexpand memcpy memset notesel noteadd notedel noteload notesave randomize noteunsel noteget split strrep setease button chgdisp exec dialog mmload mmplay mmstop mci pset pget syscolor mes print title pos circle cls font sysfont objsize picload color palcolor palette redraw width gsel gcopy gzoom gmode bmpsave hsvcolor getkey listbox chkbox combox input mesbox buffer screen bgscr mouse objsel groll line clrobj boxf objprm objmode stick grect grotate gsquare gradf objimage objskip objenable celload celdiv celput newcom querycom delcom cnvstow comres axobj winobj sendmsg comevent comevarg sarrayconv callfunc cnvwtos comevdisp libptr system hspstat hspver stat cnt err strsize looplev sublev iparam wparam lparam refstr refdval int rnd strlen length length2 length3 length4 vartype gettime peek wpeek lpeek varptr varuse noteinfo instr abs limit getease str strmid strf getpath strtrim sin cos tan atan sqrt double absf expf logf limitf powf geteasef mousex mousey mousew hwnd hinstance hdc ginfo objinfo dirinfo sysinfo thismod __hspver__ __hsp30__ __date__ __time__ __line__ __file__ _debug __hspdef__ and or xor not screen_normal screen_palette screen_hide screen_fixedsize screen_tool screen_frame gmode_gdi gmode_mem gmode_rgb0 gmode_alpha gmode_rgb0alpha gmode_add gmode_sub gmode_pixela ginfo_mx ginfo_my ginfo_act ginfo_sel ginfo_wx1 ginfo_wy1 ginfo_wx2 ginfo_wy2 ginfo_vx ginfo_vy ginfo_sizex ginfo_sizey ginfo_winx ginfo_winy ginfo_mesx ginfo_mesy ginfo_r ginfo_g ginfo_b ginfo_paluse ginfo_dispx ginfo_dispy ginfo_cx ginfo_cy ginfo_intid ginfo_newid ginfo_sx ginfo_sy objinfo_mode objinfo_bmscr objinfo_hwnd notemax notesize dir_cur dir_exe dir_win dir_sys dir_cmdline dir_desktop dir_mydoc dir_tv font_normal font_bold font_italic font_underline font_strikeout font_antialias objmode_normal objmode_guifont objmode_usefont gsquare_grad msgothic msmincho do until while wend for next _break _continue switch case default swbreak swend ddim ldim alloc m_pi rad2deg deg2rad ease_linear ease_quad_in ease_quad_out ease_quad_inout ease_cubic_in ease_cubic_out ease_cubic_inout ease_quartic_in ease_quartic_out ease_quartic_inout ease_bounce_in ease_bounce_out ease_bounce_inout ease_shake_in ease_shake_out ease_shake_inout ease_loop"
      },
      contains: [
        t.C_LINE_COMMENT_MODE,
        t.C_BLOCK_COMMENT_MODE,
        t.QUOTE_STRING_MODE,
        t.APOS_STRING_MODE,
        {
          // multi-line string
          className: "string",
          begin: /\{"/,
          end: /"\}/,
          contains: [t.BACKSLASH_ESCAPE]
        },
        t.COMMENT(";", "$", { relevance: 0 }),
        {
          // pre-processor
          className: "meta",
          begin: "#",
          end: "$",
          keywords: { keyword: "addion cfunc cmd cmpopt comfunc const defcfunc deffunc define else endif enum epack func global if ifdef ifndef include modcfunc modfunc modinit modterm module pack packopt regcmd runtime undef usecom uselib" },
          contains: [
            t.inherit(t.QUOTE_STRING_MODE, { className: "string" }),
            t.NUMBER_MODE,
            t.C_NUMBER_MODE,
            t.C_LINE_COMMENT_MODE,
            t.C_BLOCK_COMMENT_MODE
          ]
        },
        {
          // label
          className: "symbol",
          begin: "^\\*(\\w+|@)"
        },
        t.NUMBER_MODE,
        t.C_NUMBER_MODE
      ]
    };
  }
  return GE = e, GE;
}
var YE, QD;
function iJ() {
  if (QD) return YE;
  QD = 1;
  function e(t) {
    const n = t.regex, r = "HTTP/([32]|1\\.[01])", i = /[A-Za-z][A-Za-z0-9-]*/, a = {
      className: "attribute",
      begin: n.concat("^", i, "(?=\\:\\s)"),
      starts: { contains: [
        {
          className: "punctuation",
          begin: /: /,
          relevance: 0,
          starts: {
            end: "$",
            relevance: 0
          }
        }
      ] }
    }, o = [
      a,
      {
        begin: "\\n\\n",
        starts: {
          subLanguage: [],
          endsWithParent: !0
        }
      }
    ];
    return {
      name: "HTTP",
      aliases: ["https"],
      illegal: /\S/,
      contains: [
        // response
        {
          begin: "^(?=" + r + " \\d{3})",
          end: /$/,
          contains: [
            {
              className: "meta",
              begin: r
            },
            {
              className: "number",
              begin: "\\b\\d{3}\\b"
            }
          ],
          starts: {
            end: /\b\B/,
            illegal: /\S/,
            contains: o
          }
        },
        // request
        {
          begin: "(?=^[A-Z]+ (.*?) " + r + "$)",
          end: /$/,
          contains: [
            {
              className: "string",
              begin: " ",
              end: " ",
              excludeBegin: !0,
              excludeEnd: !0
            },
            {
              className: "meta",
              begin: r
            },
            {
              className: "keyword",
              begin: "[A-Z]+"
            }
          ],
          starts: {
            end: /\b\B/,
            illegal: /\S/,
            contains: o
          }
        },
        // to allow headers to work even without a preamble
        t.inherit(a, { relevance: 0 })
      ]
    };
  }
  return YE = e, YE;
}
var HE, XD;
function aJ() {
  if (XD) return HE;
  XD = 1;
  function e(t) {
    const n = "a-zA-Z_\\-!.?+*=<>&#'", r = "[" + n + "][" + n + "0-9/;:]*", i = {
      $pattern: r,
      built_in: (
        // keywords
        "!= % %= & &= * ** **= *= *map + += , --build-class-- --import-- -= . / // //= /= < << <<= <= = > >= >> >>= @ @= ^ ^= abs accumulate all and any ap-compose ap-dotimes ap-each ap-each-while ap-filter ap-first ap-if ap-last ap-map ap-map-when ap-pipe ap-reduce ap-reject apply as-> ascii assert assoc bin break butlast callable calling-module-name car case cdr chain chr coll? combinations compile compress cond cons cons? continue count curry cut cycle dec def default-method defclass defmacro defmacro-alias defmacro/g! defmain defmethod defmulti defn defn-alias defnc defnr defreader defseq del delattr delete-route dict-comp dir disassemble dispatch-reader-macro distinct divmod do doto drop drop-last drop-while empty? end-sequence eval eval-and-compile eval-when-compile even? every? except exec filter first flatten float? fn fnc fnr for for* format fraction genexpr gensym get getattr global globals group-by hasattr hash hex id identity if if* if-not if-python2 import in inc input instance? integer integer-char? integer? interleave interpose is is-coll is-cons is-empty is-even is-every is-float is-instance is-integer is-integer-char is-iterable is-iterator is-keyword is-neg is-none is-not is-numeric is-odd is-pos is-string is-symbol is-zero isinstance islice issubclass iter iterable? iterate iterator? keyword keyword? lambda last len let lif lif-not list* list-comp locals loop macro-error macroexpand macroexpand-1 macroexpand-all map max merge-with method-decorator min multi-decorator multicombinations name neg? next none? nonlocal not not-in not? nth numeric? oct odd? open or ord partition permutations pos? post-route postwalk pow prewalk print product profile/calls profile/cpu put-route quasiquote quote raise range read read-str recursive-replace reduce remove repeat repeatedly repr require rest round route route-with-methods rwm second seq set-comp setattr setv some sorted string string? sum switch symbol? take take-nth take-while tee try unless unquote unquote-splicing vars walk when while with with* with-decorator with-gensyms xi xor yield yield-from zero? zip zip-longest | |= ~"
      )
    }, a = "[-+]?\\d+(\\.\\d+)?", o = {
      begin: r,
      relevance: 0
    }, s = {
      className: "number",
      begin: a,
      relevance: 0
    }, l = t.inherit(t.QUOTE_STRING_MODE, { illegal: null }), u = t.COMMENT(
      ";",
      "$",
      { relevance: 0 }
    ), c = {
      className: "literal",
      begin: /\b([Tt]rue|[Ff]alse|nil|None)\b/
    }, d = {
      begin: "[\\[\\{]",
      end: "[\\]\\}]",
      relevance: 0
    }, f = {
      className: "comment",
      begin: "\\^" + r
    }, h = t.COMMENT("\\^\\{", "\\}"), m = {
      className: "symbol",
      begin: "[:]{1,2}" + r
    }, v = {
      begin: "\\(",
      end: "\\)"
    }, b = {
      endsWithParent: !0,
      relevance: 0
    }, y = {
      className: "name",
      relevance: 0,
      keywords: i,
      begin: r,
      starts: b
    }, g = [
      v,
      l,
      f,
      h,
      u,
      m,
      d,
      s,
      c,
      o
    ];
    return v.contains = [
      t.COMMENT("comment", ""),
      y,
      b
    ], b.contains = g, d.contains = g, {
      name: "Hy",
      aliases: ["hylang"],
      illegal: /\S/,
      contains: [
        t.SHEBANG(),
        v,
        l,
        f,
        h,
        u,
        m,
        d,
        s,
        c
      ]
    };
  }
  return HE = e, HE;
}
var zE, ZD;
function oJ() {
  if (ZD) return zE;
  ZD = 1;
  function e(t) {
    const n = "\\[", r = "\\]";
    return {
      name: "Inform 7",
      aliases: ["i7"],
      case_insensitive: !0,
      keywords: {
        // Some keywords more or less unique to I7, for relevance.
        keyword: (
          // kind:
          "thing room person man woman animal container supporter backdrop door scenery open closed locked inside gender is are say understand kind of rule"
        )
      },
      contains: [
        {
          className: "string",
          begin: '"',
          end: '"',
          relevance: 0,
          contains: [
            {
              className: "subst",
              begin: n,
              end: r
            }
          ]
        },
        {
          className: "section",
          begin: /^(Volume|Book|Part|Chapter|Section|Table)\b/,
          end: "$"
        },
        {
          // Rule definition
          // This is here for relevance.
          begin: /^(Check|Carry out|Report|Instead of|To|Rule|When|Before|After)\b/,
          end: ":",
          contains: [
            {
              // Rule name
              begin: "\\(This",
              end: "\\)"
            }
          ]
        },
        {
          className: "comment",
          begin: n,
          end: r,
          contains: ["self"]
        }
      ]
    };
  }
  return zE = e, zE;
}
var VE, JD;
function sJ() {
  if (JD) return VE;
  JD = 1;
  function e(t) {
    const n = t.regex, r = {
      className: "number",
      relevance: 0,
      variants: [
        { begin: /([+-]+)?[\d]+_[\d_]+/ },
        { begin: t.NUMBER_RE }
      ]
    }, i = t.COMMENT();
    i.variants = [
      {
        begin: /;/,
        end: /$/
      },
      {
        begin: /#/,
        end: /$/
      }
    ];
    const a = {
      className: "variable",
      variants: [
        { begin: /\$[\w\d"][\w\d_]*/ },
        { begin: /\$\{(.*?)\}/ }
      ]
    }, o = {
      className: "literal",
      begin: /\bon|off|true|false|yes|no\b/
    }, s = {
      className: "string",
      contains: [t.BACKSLASH_ESCAPE],
      variants: [
        {
          begin: "'''",
          end: "'''",
          relevance: 10
        },
        {
          begin: '"""',
          end: '"""',
          relevance: 10
        },
        {
          begin: '"',
          end: '"'
        },
        {
          begin: "'",
          end: "'"
        }
      ]
    }, l = {
      begin: /\[/,
      end: /\]/,
      contains: [
        i,
        o,
        a,
        s,
        r,
        "self"
      ],
      relevance: 0
    }, u = /[A-Za-z0-9_-]+/, c = /"(\\"|[^"])*"/, d = /'[^']*'/, f = n.either(
      u,
      c,
      d
    ), h = n.concat(
      f,
      "(\\s*\\.\\s*",
      f,
      ")*",
      n.lookahead(/\s*=\s*[^#\s]/)
    );
    return {
      name: "TOML, also INI",
      aliases: ["toml"],
      case_insensitive: !0,
      illegal: /\S/,
      contains: [
        i,
        {
          className: "section",
          begin: /\[+/,
          end: /\]+/
        },
        {
          begin: h,
          className: "attr",
          starts: {
            end: /$/,
            contains: [
              i,
              l,
              o,
              a,
              s,
              r
            ]
          }
        }
      ]
    };
  }
  return VE = e, VE;
}
var WE, eI;
function lJ() {
  if (eI) return WE;
  eI = 1;
  function e(t) {
    const n = t.regex, r = {
      className: "params",
      begin: "\\(",
      end: "\\)"
    }, i = /(_[a-z_\d]+)?/, a = /([de][+-]?\d+)?/, o = {
      className: "number",
      variants: [
        { begin: n.concat(/\b\d+/, /\.(\d*)/, a, i) },
        { begin: n.concat(/\b\d+/, a, i) },
        { begin: n.concat(/\.\d+/, a, i) }
      ],
      relevance: 0
    };
    return {
      name: "IRPF90",
      case_insensitive: !0,
      keywords: {
        literal: ".False. .True.",
        keyword: "kind do while private call intrinsic where elsewhere type endtype endmodule endselect endinterface end enddo endif if forall endforall only contains default return stop then public subroutine|10 function program .and. .or. .not. .le. .eq. .ge. .gt. .lt. goto save else use module select case access blank direct exist file fmt form formatted iostat name named nextrec number opened rec recl sequential status unformatted unit continue format pause cycle exit c_null_char c_alert c_backspace c_form_feed flush wait decimal round iomsg synchronous nopass non_overridable pass protected volatile abstract extends import non_intrinsic value deferred generic final enumerator class associate bind enum c_int c_short c_long c_long_long c_signed_char c_size_t c_int8_t c_int16_t c_int32_t c_int64_t c_int_least8_t c_int_least16_t c_int_least32_t c_int_least64_t c_int_fast8_t c_int_fast16_t c_int_fast32_t c_int_fast64_t c_intmax_t C_intptr_t c_float c_double c_long_double c_float_complex c_double_complex c_long_double_complex c_bool c_char c_null_ptr c_null_funptr c_new_line c_carriage_return c_horizontal_tab c_vertical_tab iso_c_binding c_loc c_funloc c_associated  c_f_pointer c_ptr c_funptr iso_fortran_env character_storage_size error_unit file_storage_size input_unit iostat_end iostat_eor numeric_storage_size output_unit c_f_procpointer ieee_arithmetic ieee_support_underflow_control ieee_get_underflow_mode ieee_set_underflow_mode newunit contiguous recursive pad position action delim readwrite eor advance nml interface procedure namelist include sequence elemental pure integer real character complex logical dimension allocatable|10 parameter external implicit|10 none double precision assign intent optional pointer target in out common equivalence data begin_provider &begin_provider end_provider begin_shell end_shell begin_template end_template subst assert touch soft_touch provide no_dep free irp_if irp_else irp_endif irp_write irp_read",
        built_in: "alog alog10 amax0 amax1 amin0 amin1 amod cabs ccos cexp clog csin csqrt dabs dacos dasin datan datan2 dcos dcosh ddim dexp dint dlog dlog10 dmax1 dmin1 dmod dnint dsign dsin dsinh dsqrt dtan dtanh float iabs idim idint idnint ifix isign max0 max1 min0 min1 sngl algama cdabs cdcos cdexp cdlog cdsin cdsqrt cqabs cqcos cqexp cqlog cqsin cqsqrt dcmplx dconjg derf derfc dfloat dgamma dimag dlgama iqint qabs qacos qasin qatan qatan2 qcmplx qconjg qcos qcosh qdim qerf qerfc qexp qgamma qimag qlgama qlog qlog10 qmax1 qmin1 qmod qnint qsign qsin qsinh qsqrt qtan qtanh abs acos aimag aint anint asin atan atan2 char cmplx conjg cos cosh exp ichar index int log log10 max min nint sign sin sinh sqrt tan tanh print write dim lge lgt lle llt mod nullify allocate deallocate adjustl adjustr all allocated any associated bit_size btest ceiling count cshift date_and_time digits dot_product eoshift epsilon exponent floor fraction huge iand ibclr ibits ibset ieor ior ishft ishftc lbound len_trim matmul maxexponent maxloc maxval merge minexponent minloc minval modulo mvbits nearest pack present product radix random_number random_seed range repeat reshape rrspacing scale scan selected_int_kind selected_real_kind set_exponent shape size spacing spread sum system_clock tiny transpose trim ubound unpack verify achar iachar transfer dble entry dprod cpu_time command_argument_count get_command get_command_argument get_environment_variable is_iostat_end ieee_arithmetic ieee_support_underflow_control ieee_get_underflow_mode ieee_set_underflow_mode is_iostat_eor move_alloc new_line selected_char_kind same_type_as extends_type_of acosh asinh atanh bessel_j0 bessel_j1 bessel_jn bessel_y0 bessel_y1 bessel_yn erf erfc erfc_scaled gamma log_gamma hypot norm2 atomic_define atomic_ref execute_command_line leadz trailz storage_size merge_bits bge bgt ble blt dshiftl dshiftr findloc iall iany iparity image_index lcobound ucobound maskl maskr num_images parity popcnt poppar shifta shiftl shiftr this_image IRP_ALIGN irp_here"
      },
      illegal: /\/\*/,
      contains: [
        t.inherit(t.APOS_STRING_MODE, {
          className: "string",
          relevance: 0
        }),
        t.inherit(t.QUOTE_STRING_MODE, {
          className: "string",
          relevance: 0
        }),
        {
          className: "function",
          beginKeywords: "subroutine function program",
          illegal: "[${=\\n]",
          contains: [
            t.UNDERSCORE_TITLE_MODE,
            r
          ]
        },
        t.COMMENT("!", "$", { relevance: 0 }),
        t.COMMENT("begin_doc", "end_doc", { relevance: 10 }),
        o
      ]
    };
  }
  return WE = e, WE;
}
var KE, tI;
function uJ() {
  if (tI) return KE;
  tI = 1;
  function e(t) {
    const n = "[A-Za-zА-Яа-яёЁ_!][A-Za-zА-Яа-яёЁ_0-9]*", r = "[A-Za-zА-Яа-яёЁ_][A-Za-zА-Яа-яёЁ_0-9]*", i = "and и else иначе endexcept endfinally endforeach конецвсе endif конецесли endwhile конецпока except exitfor finally foreach все if если in в not не or или try while пока ", oe = "SYSRES_CONST_ACCES_RIGHT_TYPE_EDIT SYSRES_CONST_ACCES_RIGHT_TYPE_FULL SYSRES_CONST_ACCES_RIGHT_TYPE_VIEW SYSRES_CONST_ACCESS_MODE_REQUISITE_CODE SYSRES_CONST_ACCESS_NO_ACCESS_VIEW SYSRES_CONST_ACCESS_NO_ACCESS_VIEW_CODE SYSRES_CONST_ACCESS_RIGHTS_ADD_REQUISITE_CODE SYSRES_CONST_ACCESS_RIGHTS_ADD_REQUISITE_YES_CODE SYSRES_CONST_ACCESS_RIGHTS_CHANGE_REQUISITE_CODE SYSRES_CONST_ACCESS_RIGHTS_CHANGE_REQUISITE_YES_CODE SYSRES_CONST_ACCESS_RIGHTS_DELETE_REQUISITE_CODE SYSRES_CONST_ACCESS_RIGHTS_DELETE_REQUISITE_YES_CODE SYSRES_CONST_ACCESS_RIGHTS_EXECUTE_REQUISITE_CODE SYSRES_CONST_ACCESS_RIGHTS_EXECUTE_REQUISITE_YES_CODE SYSRES_CONST_ACCESS_RIGHTS_NO_ACCESS_REQUISITE_CODE SYSRES_CONST_ACCESS_RIGHTS_NO_ACCESS_REQUISITE_YES_CODE SYSRES_CONST_ACCESS_RIGHTS_RATIFY_REQUISITE_CODE SYSRES_CONST_ACCESS_RIGHTS_RATIFY_REQUISITE_YES_CODE SYSRES_CONST_ACCESS_RIGHTS_REQUISITE_CODE SYSRES_CONST_ACCESS_RIGHTS_VIEW SYSRES_CONST_ACCESS_RIGHTS_VIEW_CODE SYSRES_CONST_ACCESS_RIGHTS_VIEW_REQUISITE_CODE SYSRES_CONST_ACCESS_RIGHTS_VIEW_REQUISITE_YES_CODE SYSRES_CONST_ACCESS_TYPE_CHANGE SYSRES_CONST_ACCESS_TYPE_CHANGE_CODE SYSRES_CONST_ACCESS_TYPE_EXISTS SYSRES_CONST_ACCESS_TYPE_EXISTS_CODE SYSRES_CONST_ACCESS_TYPE_FULL SYSRES_CONST_ACCESS_TYPE_FULL_CODE SYSRES_CONST_ACCESS_TYPE_VIEW SYSRES_CONST_ACCESS_TYPE_VIEW_CODE SYSRES_CONST_ACTION_TYPE_ABORT SYSRES_CONST_ACTION_TYPE_ACCEPT SYSRES_CONST_ACTION_TYPE_ACCESS_RIGHTS SYSRES_CONST_ACTION_TYPE_ADD_ATTACHMENT SYSRES_CONST_ACTION_TYPE_CHANGE_CARD SYSRES_CONST_ACTION_TYPE_CHANGE_KIND SYSRES_CONST_ACTION_TYPE_CHANGE_STORAGE SYSRES_CONST_ACTION_TYPE_CONTINUE SYSRES_CONST_ACTION_TYPE_COPY SYSRES_CONST_ACTION_TYPE_CREATE SYSRES_CONST_ACTION_TYPE_CREATE_VERSION SYSRES_CONST_ACTION_TYPE_DELETE SYSRES_CONST_ACTION_TYPE_DELETE_ATTACHMENT SYSRES_CONST_ACTION_TYPE_DELETE_VERSION SYSRES_CONST_ACTION_TYPE_DISABLE_DELEGATE_ACCESS_RIGHTS SYSRES_CONST_ACTION_TYPE_ENABLE_DELEGATE_ACCESS_RIGHTS SYSRES_CONST_ACTION_TYPE_ENCRYPTION_BY_CERTIFICATE SYSRES_CONST_ACTION_TYPE_ENCRYPTION_BY_CERTIFICATE_AND_PASSWORD SYSRES_CONST_ACTION_TYPE_ENCRYPTION_BY_PASSWORD SYSRES_CONST_ACTION_TYPE_EXPORT_WITH_LOCK SYSRES_CONST_ACTION_TYPE_EXPORT_WITHOUT_LOCK SYSRES_CONST_ACTION_TYPE_IMPORT_WITH_UNLOCK SYSRES_CONST_ACTION_TYPE_IMPORT_WITHOUT_UNLOCK SYSRES_CONST_ACTION_TYPE_LIFE_CYCLE_STAGE SYSRES_CONST_ACTION_TYPE_LOCK SYSRES_CONST_ACTION_TYPE_LOCK_FOR_SERVER SYSRES_CONST_ACTION_TYPE_LOCK_MODIFY SYSRES_CONST_ACTION_TYPE_MARK_AS_READED SYSRES_CONST_ACTION_TYPE_MARK_AS_UNREADED SYSRES_CONST_ACTION_TYPE_MODIFY SYSRES_CONST_ACTION_TYPE_MODIFY_CARD SYSRES_CONST_ACTION_TYPE_MOVE_TO_ARCHIVE SYSRES_CONST_ACTION_TYPE_OFF_ENCRYPTION SYSRES_CONST_ACTION_TYPE_PASSWORD_CHANGE SYSRES_CONST_ACTION_TYPE_PERFORM SYSRES_CONST_ACTION_TYPE_RECOVER_FROM_LOCAL_COPY SYSRES_CONST_ACTION_TYPE_RESTART SYSRES_CONST_ACTION_TYPE_RESTORE_FROM_ARCHIVE SYSRES_CONST_ACTION_TYPE_REVISION SYSRES_CONST_ACTION_TYPE_SEND_BY_MAIL SYSRES_CONST_ACTION_TYPE_SIGN SYSRES_CONST_ACTION_TYPE_START SYSRES_CONST_ACTION_TYPE_UNLOCK SYSRES_CONST_ACTION_TYPE_UNLOCK_FROM_SERVER SYSRES_CONST_ACTION_TYPE_VERSION_STATE SYSRES_CONST_ACTION_TYPE_VERSION_VISIBILITY SYSRES_CONST_ACTION_TYPE_VIEW SYSRES_CONST_ACTION_TYPE_VIEW_SHADOW_COPY SYSRES_CONST_ACTION_TYPE_WORKFLOW_DESCRIPTION_MODIFY SYSRES_CONST_ACTION_TYPE_WRITE_HISTORY SYSRES_CONST_ACTIVE_VERSION_STATE_PICK_VALUE SYSRES_CONST_ADD_REFERENCE_MODE_NAME SYSRES_CONST_ADDITION_REQUISITE_CODE SYSRES_CONST_ADDITIONAL_PARAMS_REQUISITE_CODE SYSRES_CONST_ADITIONAL_JOB_END_DATE_REQUISITE_NAME SYSRES_CONST_ADITIONAL_JOB_READ_REQUISITE_NAME SYSRES_CONST_ADITIONAL_JOB_START_DATE_REQUISITE_NAME SYSRES_CONST_ADITIONAL_JOB_STATE_REQUISITE_NAME SYSRES_CONST_ADMINISTRATION_HISTORY_ADDING_USER_TO_GROUP_ACTION SYSRES_CONST_ADMINISTRATION_HISTORY_ADDING_USER_TO_GROUP_ACTION_CODE SYSRES_CONST_ADMINISTRATION_HISTORY_CREATION_COMP_ACTION SYSRES_CONST_ADMINISTRATION_HISTORY_CREATION_COMP_ACTION_CODE SYSRES_CONST_ADMINISTRATION_HISTORY_CREATION_GROUP_ACTION SYSRES_CONST_ADMINISTRATION_HISTORY_CREATION_GROUP_ACTION_CODE SYSRES_CONST_ADMINISTRATION_HISTORY_CREATION_USER_ACTION SYSRES_CONST_ADMINISTRATION_HISTORY_CREATION_USER_ACTION_CODE SYSRES_CONST_ADMINISTRATION_HISTORY_DATABASE_USER_CREATION SYSRES_CONST_ADMINISTRATION_HISTORY_DATABASE_USER_CREATION_ACTION SYSRES_CONST_ADMINISTRATION_HISTORY_DATABASE_USER_DELETION SYSRES_CONST_ADMINISTRATION_HISTORY_DATABASE_USER_DELETION_ACTION SYSRES_CONST_ADMINISTRATION_HISTORY_DELETION_COMP_ACTION SYSRES_CONST_ADMINISTRATION_HISTORY_DELETION_COMP_ACTION_CODE SYSRES_CONST_ADMINISTRATION_HISTORY_DELETION_GROUP_ACTION SYSRES_CONST_ADMINISTRATION_HISTORY_DELETION_GROUP_ACTION_CODE SYSRES_CONST_ADMINISTRATION_HISTORY_DELETION_USER_ACTION SYSRES_CONST_ADMINISTRATION_HISTORY_DELETION_USER_ACTION_CODE SYSRES_CONST_ADMINISTRATION_HISTORY_DELETION_USER_FROM_GROUP_ACTION SYSRES_CONST_ADMINISTRATION_HISTORY_DELETION_USER_FROM_GROUP_ACTION_CODE SYSRES_CONST_ADMINISTRATION_HISTORY_GRANTING_FILTERER_ACTION SYSRES_CONST_ADMINISTRATION_HISTORY_GRANTING_FILTERER_ACTION_CODE SYSRES_CONST_ADMINISTRATION_HISTORY_GRANTING_FILTERER_RESTRICTION_ACTION SYSRES_CONST_ADMINISTRATION_HISTORY_GRANTING_FILTERER_RESTRICTION_ACTION_CODE SYSRES_CONST_ADMINISTRATION_HISTORY_GRANTING_PRIVILEGE_ACTION SYSRES_CONST_ADMINISTRATION_HISTORY_GRANTING_PRIVILEGE_ACTION_CODE SYSRES_CONST_ADMINISTRATION_HISTORY_GRANTING_RIGHTS_ACTION SYSRES_CONST_ADMINISTRATION_HISTORY_GRANTING_RIGHTS_ACTION_CODE SYSRES_CONST_ADMINISTRATION_HISTORY_IS_MAIN_SERVER_CHANGED_ACTION SYSRES_CONST_ADMINISTRATION_HISTORY_IS_MAIN_SERVER_CHANGED_ACTION_CODE SYSRES_CONST_ADMINISTRATION_HISTORY_IS_PUBLIC_CHANGED_ACTION SYSRES_CONST_ADMINISTRATION_HISTORY_IS_PUBLIC_CHANGED_ACTION_CODE SYSRES_CONST_ADMINISTRATION_HISTORY_REMOVING_FILTERER_ACTION SYSRES_CONST_ADMINISTRATION_HISTORY_REMOVING_FILTERER_ACTION_CODE SYSRES_CONST_ADMINISTRATION_HISTORY_REMOVING_FILTERER_RESTRICTION_ACTION SYSRES_CONST_ADMINISTRATION_HISTORY_REMOVING_FILTERER_RESTRICTION_ACTION_CODE SYSRES_CONST_ADMINISTRATION_HISTORY_REMOVING_PRIVILEGE_ACTION SYSRES_CONST_ADMINISTRATION_HISTORY_REMOVING_PRIVILEGE_ACTION_CODE SYSRES_CONST_ADMINISTRATION_HISTORY_REMOVING_RIGHTS_ACTION SYSRES_CONST_ADMINISTRATION_HISTORY_REMOVING_RIGHTS_ACTION_CODE SYSRES_CONST_ADMINISTRATION_HISTORY_SERVER_LOGIN_CREATION SYSRES_CONST_ADMINISTRATION_HISTORY_SERVER_LOGIN_CREATION_ACTION SYSRES_CONST_ADMINISTRATION_HISTORY_SERVER_LOGIN_DELETION SYSRES_CONST_ADMINISTRATION_HISTORY_SERVER_LOGIN_DELETION_ACTION SYSRES_CONST_ADMINISTRATION_HISTORY_UPDATING_CATEGORY_ACTION SYSRES_CONST_ADMINISTRATION_HISTORY_UPDATING_CATEGORY_ACTION_CODE SYSRES_CONST_ADMINISTRATION_HISTORY_UPDATING_COMP_TITLE_ACTION SYSRES_CONST_ADMINISTRATION_HISTORY_UPDATING_COMP_TITLE_ACTION_CODE SYSRES_CONST_ADMINISTRATION_HISTORY_UPDATING_FULL_NAME_ACTION SYSRES_CONST_ADMINISTRATION_HISTORY_UPDATING_FULL_NAME_ACTION_CODE SYSRES_CONST_ADMINISTRATION_HISTORY_UPDATING_GROUP_ACTION SYSRES_CONST_ADMINISTRATION_HISTORY_UPDATING_GROUP_ACTION_CODE SYSRES_CONST_ADMINISTRATION_HISTORY_UPDATING_PARENT_GROUP_ACTION SYSRES_CONST_ADMINISTRATION_HISTORY_UPDATING_PARENT_GROUP_ACTION_CODE SYSRES_CONST_ADMINISTRATION_HISTORY_UPDATING_USER_AUTH_TYPE_ACTION SYSRES_CONST_ADMINISTRATION_HISTORY_UPDATING_USER_AUTH_TYPE_ACTION_CODE SYSRES_CONST_ADMINISTRATION_HISTORY_UPDATING_USER_LOGIN_ACTION SYSRES_CONST_ADMINISTRATION_HISTORY_UPDATING_USER_LOGIN_ACTION_CODE SYSRES_CONST_ADMINISTRATION_HISTORY_UPDATING_USER_STATUS_ACTION SYSRES_CONST_ADMINISTRATION_HISTORY_UPDATING_USER_STATUS_ACTION_CODE SYSRES_CONST_ADMINISTRATION_HISTORY_USER_PASSWORD_CHANGE SYSRES_CONST_ADMINISTRATION_HISTORY_USER_PASSWORD_CHANGE_ACTION SYSRES_CONST_ALL_ACCEPT_CONDITION_RUS SYSRES_CONST_ALL_USERS_GROUP SYSRES_CONST_ALL_USERS_GROUP_NAME SYSRES_CONST_ALL_USERS_SERVER_GROUP_NAME SYSRES_CONST_ALLOWED_ACCESS_TYPE_CODE SYSRES_CONST_ALLOWED_ACCESS_TYPE_NAME SYSRES_CONST_APP_VIEWER_TYPE_REQUISITE_CODE SYSRES_CONST_APPROVING_SIGNATURE_NAME SYSRES_CONST_APPROVING_SIGNATURE_REQUISITE_CODE SYSRES_CONST_ASSISTANT_SUBSTITUE_TYPE SYSRES_CONST_ASSISTANT_SUBSTITUE_TYPE_CODE SYSRES_CONST_ATTACH_TYPE_COMPONENT_TOKEN SYSRES_CONST_ATTACH_TYPE_DOC SYSRES_CONST_ATTACH_TYPE_EDOC SYSRES_CONST_ATTACH_TYPE_FOLDER SYSRES_CONST_ATTACH_TYPE_JOB SYSRES_CONST_ATTACH_TYPE_REFERENCE SYSRES_CONST_ATTACH_TYPE_TASK SYSRES_CONST_AUTH_ENCODED_PASSWORD SYSRES_CONST_AUTH_ENCODED_PASSWORD_CODE SYSRES_CONST_AUTH_NOVELL SYSRES_CONST_AUTH_PASSWORD SYSRES_CONST_AUTH_PASSWORD_CODE SYSRES_CONST_AUTH_WINDOWS SYSRES_CONST_AUTHENTICATING_SIGNATURE_NAME SYSRES_CONST_AUTHENTICATING_SIGNATURE_REQUISITE_CODE SYSRES_CONST_AUTO_ENUM_METHOD_FLAG SYSRES_CONST_AUTO_NUMERATION_CODE SYSRES_CONST_AUTO_STRONG_ENUM_METHOD_FLAG SYSRES_CONST_AUTOTEXT_NAME_REQUISITE_CODE SYSRES_CONST_AUTOTEXT_TEXT_REQUISITE_CODE SYSRES_CONST_AUTOTEXT_USAGE_ALL SYSRES_CONST_AUTOTEXT_USAGE_ALL_CODE SYSRES_CONST_AUTOTEXT_USAGE_SIGN SYSRES_CONST_AUTOTEXT_USAGE_SIGN_CODE SYSRES_CONST_AUTOTEXT_USAGE_WORK SYSRES_CONST_AUTOTEXT_USAGE_WORK_CODE SYSRES_CONST_AUTOTEXT_USE_ANYWHERE_CODE SYSRES_CONST_AUTOTEXT_USE_ON_SIGNING_CODE SYSRES_CONST_AUTOTEXT_USE_ON_WORK_CODE SYSRES_CONST_BEGIN_DATE_REQUISITE_CODE SYSRES_CONST_BLACK_LIFE_CYCLE_STAGE_FONT_COLOR SYSRES_CONST_BLUE_LIFE_CYCLE_STAGE_FONT_COLOR SYSRES_CONST_BTN_PART SYSRES_CONST_CALCULATED_ROLE_TYPE_CODE SYSRES_CONST_CALL_TYPE_VARIABLE_BUTTON_VALUE SYSRES_CONST_CALL_TYPE_VARIABLE_PROGRAM_VALUE SYSRES_CONST_CANCEL_MESSAGE_FUNCTION_RESULT SYSRES_CONST_CARD_PART SYSRES_CONST_CARD_REFERENCE_MODE_NAME SYSRES_CONST_CERTIFICATE_TYPE_REQUISITE_ENCRYPT_VALUE SYSRES_CONST_CERTIFICATE_TYPE_REQUISITE_SIGN_AND_ENCRYPT_VALUE SYSRES_CONST_CERTIFICATE_TYPE_REQUISITE_SIGN_VALUE SYSRES_CONST_CHECK_PARAM_VALUE_DATE_PARAM_TYPE SYSRES_CONST_CHECK_PARAM_VALUE_FLOAT_PARAM_TYPE SYSRES_CONST_CHECK_PARAM_VALUE_INTEGER_PARAM_TYPE SYSRES_CONST_CHECK_PARAM_VALUE_PICK_PARAM_TYPE SYSRES_CONST_CHECK_PARAM_VALUE_REEFRENCE_PARAM_TYPE SYSRES_CONST_CLOSED_RECORD_FLAG_VALUE_FEMININE SYSRES_CONST_CLOSED_RECORD_FLAG_VALUE_MASCULINE SYSRES_CONST_CODE_COMPONENT_TYPE_ADMIN SYSRES_CONST_CODE_COMPONENT_TYPE_DEVELOPER SYSRES_CONST_CODE_COMPONENT_TYPE_DOCS SYSRES_CONST_CODE_COMPONENT_TYPE_EDOC_CARDS SYSRES_CONST_CODE_COMPONENT_TYPE_EXTERNAL_EXECUTABLE SYSRES_CONST_CODE_COMPONENT_TYPE_OTHER SYSRES_CONST_CODE_COMPONENT_TYPE_REFERENCE SYSRES_CONST_CODE_COMPONENT_TYPE_REPORT SYSRES_CONST_CODE_COMPONENT_TYPE_SCRIPT SYSRES_CONST_CODE_COMPONENT_TYPE_URL SYSRES_CONST_CODE_REQUISITE_ACCESS SYSRES_CONST_CODE_REQUISITE_CODE SYSRES_CONST_CODE_REQUISITE_COMPONENT SYSRES_CONST_CODE_REQUISITE_DESCRIPTION SYSRES_CONST_CODE_REQUISITE_EXCLUDE_COMPONENT SYSRES_CONST_CODE_REQUISITE_RECORD SYSRES_CONST_COMMENT_REQ_CODE SYSRES_CONST_COMMON_SETTINGS_REQUISITE_CODE SYSRES_CONST_COMP_CODE_GRD SYSRES_CONST_COMPONENT_GROUP_TYPE_REQUISITE_CODE SYSRES_CONST_COMPONENT_TYPE_ADMIN_COMPONENTS SYSRES_CONST_COMPONENT_TYPE_DEVELOPER_COMPONENTS SYSRES_CONST_COMPONENT_TYPE_DOCS SYSRES_CONST_COMPONENT_TYPE_EDOC_CARDS SYSRES_CONST_COMPONENT_TYPE_EDOCS SYSRES_CONST_COMPONENT_TYPE_EXTERNAL_EXECUTABLE SYSRES_CONST_COMPONENT_TYPE_OTHER SYSRES_CONST_COMPONENT_TYPE_REFERENCE_TYPES SYSRES_CONST_COMPONENT_TYPE_REFERENCES SYSRES_CONST_COMPONENT_TYPE_REPORTS SYSRES_CONST_COMPONENT_TYPE_SCRIPTS SYSRES_CONST_COMPONENT_TYPE_URL SYSRES_CONST_COMPONENTS_REMOTE_SERVERS_VIEW_CODE SYSRES_CONST_CONDITION_BLOCK_DESCRIPTION SYSRES_CONST_CONST_FIRM_STATUS_COMMON SYSRES_CONST_CONST_FIRM_STATUS_INDIVIDUAL SYSRES_CONST_CONST_NEGATIVE_VALUE SYSRES_CONST_CONST_POSITIVE_VALUE SYSRES_CONST_CONST_SERVER_STATUS_DONT_REPLICATE SYSRES_CONST_CONST_SERVER_STATUS_REPLICATE SYSRES_CONST_CONTENTS_REQUISITE_CODE SYSRES_CONST_DATA_TYPE_BOOLEAN SYSRES_CONST_DATA_TYPE_DATE SYSRES_CONST_DATA_TYPE_FLOAT SYSRES_CONST_DATA_TYPE_INTEGER SYSRES_CONST_DATA_TYPE_PICK SYSRES_CONST_DATA_TYPE_REFERENCE SYSRES_CONST_DATA_TYPE_STRING SYSRES_CONST_DATA_TYPE_TEXT SYSRES_CONST_DATA_TYPE_VARIANT SYSRES_CONST_DATE_CLOSE_REQ_CODE SYSRES_CONST_DATE_FORMAT_DATE_ONLY_CHAR SYSRES_CONST_DATE_OPEN_REQ_CODE SYSRES_CONST_DATE_REQUISITE SYSRES_CONST_DATE_REQUISITE_CODE SYSRES_CONST_DATE_REQUISITE_NAME SYSRES_CONST_DATE_REQUISITE_TYPE SYSRES_CONST_DATE_TYPE_CHAR SYSRES_CONST_DATETIME_FORMAT_VALUE SYSRES_CONST_DEA_ACCESS_RIGHTS_ACTION_CODE SYSRES_CONST_DESCRIPTION_LOCALIZE_ID_REQUISITE_CODE SYSRES_CONST_DESCRIPTION_REQUISITE_CODE SYSRES_CONST_DET1_PART SYSRES_CONST_DET2_PART SYSRES_CONST_DET3_PART SYSRES_CONST_DET4_PART SYSRES_CONST_DET5_PART SYSRES_CONST_DET6_PART SYSRES_CONST_DETAIL_DATASET_KEY_REQUISITE_CODE SYSRES_CONST_DETAIL_PICK_REQUISITE_CODE SYSRES_CONST_DETAIL_REQ_CODE SYSRES_CONST_DO_NOT_USE_ACCESS_TYPE_CODE SYSRES_CONST_DO_NOT_USE_ACCESS_TYPE_NAME SYSRES_CONST_DO_NOT_USE_ON_VIEW_ACCESS_TYPE_CODE SYSRES_CONST_DO_NOT_USE_ON_VIEW_ACCESS_TYPE_NAME SYSRES_CONST_DOCUMENT_STORAGES_CODE SYSRES_CONST_DOCUMENT_TEMPLATES_TYPE_NAME SYSRES_CONST_DOUBLE_REQUISITE_CODE SYSRES_CONST_EDITOR_CLOSE_FILE_OBSERV_TYPE_CODE SYSRES_CONST_EDITOR_CLOSE_PROCESS_OBSERV_TYPE_CODE SYSRES_CONST_EDITOR_TYPE_REQUISITE_CODE SYSRES_CONST_EDITORS_APPLICATION_NAME_REQUISITE_CODE SYSRES_CONST_EDITORS_CREATE_SEVERAL_PROCESSES_REQUISITE_CODE SYSRES_CONST_EDITORS_EXTENSION_REQUISITE_CODE SYSRES_CONST_EDITORS_OBSERVER_BY_PROCESS_TYPE SYSRES_CONST_EDITORS_REFERENCE_CODE SYSRES_CONST_EDITORS_REPLACE_SPEC_CHARS_REQUISITE_CODE SYSRES_CONST_EDITORS_USE_PLUGINS_REQUISITE_CODE SYSRES_CONST_EDITORS_VIEW_DOCUMENT_OPENED_TO_EDIT_CODE SYSRES_CONST_EDOC_CARD_TYPE_REQUISITE_CODE SYSRES_CONST_EDOC_CARD_TYPES_LINK_REQUISITE_CODE SYSRES_CONST_EDOC_CERTIFICATE_AND_PASSWORD_ENCODE_CODE SYSRES_CONST_EDOC_CERTIFICATE_ENCODE_CODE SYSRES_CONST_EDOC_DATE_REQUISITE_CODE SYSRES_CONST_EDOC_KIND_REFERENCE_CODE SYSRES_CONST_EDOC_KINDS_BY_TEMPLATE_ACTION_CODE SYSRES_CONST_EDOC_MANAGE_ACCESS_CODE SYSRES_CONST_EDOC_NONE_ENCODE_CODE SYSRES_CONST_EDOC_NUMBER_REQUISITE_CODE SYSRES_CONST_EDOC_PASSWORD_ENCODE_CODE SYSRES_CONST_EDOC_READONLY_ACCESS_CODE SYSRES_CONST_EDOC_SHELL_LIFE_TYPE_VIEW_VALUE SYSRES_CONST_EDOC_SIZE_RESTRICTION_PRIORITY_REQUISITE_CODE SYSRES_CONST_EDOC_STORAGE_CHECK_ACCESS_RIGHTS_REQUISITE_CODE SYSRES_CONST_EDOC_STORAGE_COMPUTER_NAME_REQUISITE_CODE SYSRES_CONST_EDOC_STORAGE_DATABASE_NAME_REQUISITE_CODE SYSRES_CONST_EDOC_STORAGE_EDIT_IN_STORAGE_REQUISITE_CODE SYSRES_CONST_EDOC_STORAGE_LOCAL_PATH_REQUISITE_CODE SYSRES_CONST_EDOC_STORAGE_SHARED_SOURCE_NAME_REQUISITE_CODE SYSRES_CONST_EDOC_TEMPLATE_REQUISITE_CODE SYSRES_CONST_EDOC_TYPES_REFERENCE_CODE SYSRES_CONST_EDOC_VERSION_ACTIVE_STAGE_CODE SYSRES_CONST_EDOC_VERSION_DESIGN_STAGE_CODE SYSRES_CONST_EDOC_VERSION_OBSOLETE_STAGE_CODE SYSRES_CONST_EDOC_WRITE_ACCES_CODE SYSRES_CONST_EDOCUMENT_CARD_REQUISITES_REFERENCE_CODE_SELECTED_REQUISITE SYSRES_CONST_ENCODE_CERTIFICATE_TYPE_CODE SYSRES_CONST_END_DATE_REQUISITE_CODE SYSRES_CONST_ENUMERATION_TYPE_REQUISITE_CODE SYSRES_CONST_EXECUTE_ACCESS_RIGHTS_TYPE_CODE SYSRES_CONST_EXECUTIVE_FILE_STORAGE_TYPE SYSRES_CONST_EXIST_CONST SYSRES_CONST_EXIST_VALUE SYSRES_CONST_EXPORT_LOCK_TYPE_ASK SYSRES_CONST_EXPORT_LOCK_TYPE_WITH_LOCK SYSRES_CONST_EXPORT_LOCK_TYPE_WITHOUT_LOCK SYSRES_CONST_EXPORT_VERSION_TYPE_ASK SYSRES_CONST_EXPORT_VERSION_TYPE_LAST SYSRES_CONST_EXPORT_VERSION_TYPE_LAST_ACTIVE SYSRES_CONST_EXTENSION_REQUISITE_CODE SYSRES_CONST_FILTER_NAME_REQUISITE_CODE SYSRES_CONST_FILTER_REQUISITE_CODE SYSRES_CONST_FILTER_TYPE_COMMON_CODE SYSRES_CONST_FILTER_TYPE_COMMON_NAME SYSRES_CONST_FILTER_TYPE_USER_CODE SYSRES_CONST_FILTER_TYPE_USER_NAME SYSRES_CONST_FILTER_VALUE_REQUISITE_NAME SYSRES_CONST_FLOAT_NUMBER_FORMAT_CHAR SYSRES_CONST_FLOAT_REQUISITE_TYPE SYSRES_CONST_FOLDER_AUTHOR_VALUE SYSRES_CONST_FOLDER_KIND_ANY_OBJECTS SYSRES_CONST_FOLDER_KIND_COMPONENTS SYSRES_CONST_FOLDER_KIND_EDOCS SYSRES_CONST_FOLDER_KIND_JOBS SYSRES_CONST_FOLDER_KIND_TASKS SYSRES_CONST_FOLDER_TYPE_COMMON SYSRES_CONST_FOLDER_TYPE_COMPONENT SYSRES_CONST_FOLDER_TYPE_FAVORITES SYSRES_CONST_FOLDER_TYPE_INBOX SYSRES_CONST_FOLDER_TYPE_OUTBOX SYSRES_CONST_FOLDER_TYPE_QUICK_LAUNCH SYSRES_CONST_FOLDER_TYPE_SEARCH SYSRES_CONST_FOLDER_TYPE_SHORTCUTS SYSRES_CONST_FOLDER_TYPE_USER SYSRES_CONST_FROM_DICTIONARY_ENUM_METHOD_FLAG SYSRES_CONST_FULL_SUBSTITUTE_TYPE SYSRES_CONST_FULL_SUBSTITUTE_TYPE_CODE SYSRES_CONST_FUNCTION_CANCEL_RESULT SYSRES_CONST_FUNCTION_CATEGORY_SYSTEM SYSRES_CONST_FUNCTION_CATEGORY_USER SYSRES_CONST_FUNCTION_FAILURE_RESULT SYSRES_CONST_FUNCTION_SAVE_RESULT SYSRES_CONST_GENERATED_REQUISITE SYSRES_CONST_GREEN_LIFE_CYCLE_STAGE_FONT_COLOR SYSRES_CONST_GROUP_ACCOUNT_TYPE_VALUE_CODE SYSRES_CONST_GROUP_CATEGORY_NORMAL_CODE SYSRES_CONST_GROUP_CATEGORY_NORMAL_NAME SYSRES_CONST_GROUP_CATEGORY_SERVICE_CODE SYSRES_CONST_GROUP_CATEGORY_SERVICE_NAME SYSRES_CONST_GROUP_COMMON_CATEGORY_FIELD_VALUE SYSRES_CONST_GROUP_FULL_NAME_REQUISITE_CODE SYSRES_CONST_GROUP_NAME_REQUISITE_CODE SYSRES_CONST_GROUP_RIGHTS_T_REQUISITE_CODE SYSRES_CONST_GROUP_SERVER_CODES_REQUISITE_CODE SYSRES_CONST_GROUP_SERVER_NAME_REQUISITE_CODE SYSRES_CONST_GROUP_SERVICE_CATEGORY_FIELD_VALUE SYSRES_CONST_GROUP_USER_REQUISITE_CODE SYSRES_CONST_GROUPS_REFERENCE_CODE SYSRES_CONST_GROUPS_REQUISITE_CODE SYSRES_CONST_HIDDEN_MODE_NAME SYSRES_CONST_HIGH_LVL_REQUISITE_CODE SYSRES_CONST_HISTORY_ACTION_CREATE_CODE SYSRES_CONST_HISTORY_ACTION_DELETE_CODE SYSRES_CONST_HISTORY_ACTION_EDIT_CODE SYSRES_CONST_HOUR_CHAR SYSRES_CONST_ID_REQUISITE_CODE SYSRES_CONST_IDSPS_REQUISITE_CODE SYSRES_CONST_IMAGE_MODE_COLOR SYSRES_CONST_IMAGE_MODE_GREYSCALE SYSRES_CONST_IMAGE_MODE_MONOCHROME SYSRES_CONST_IMPORTANCE_HIGH SYSRES_CONST_IMPORTANCE_LOW SYSRES_CONST_IMPORTANCE_NORMAL SYSRES_CONST_IN_DESIGN_VERSION_STATE_PICK_VALUE SYSRES_CONST_INCOMING_WORK_RULE_TYPE_CODE SYSRES_CONST_INT_REQUISITE SYSRES_CONST_INT_REQUISITE_TYPE SYSRES_CONST_INTEGER_NUMBER_FORMAT_CHAR SYSRES_CONST_INTEGER_TYPE_CHAR SYSRES_CONST_IS_GENERATED_REQUISITE_NEGATIVE_VALUE SYSRES_CONST_IS_PUBLIC_ROLE_REQUISITE_CODE SYSRES_CONST_IS_REMOTE_USER_NEGATIVE_VALUE SYSRES_CONST_IS_REMOTE_USER_POSITIVE_VALUE SYSRES_CONST_IS_STORED_REQUISITE_NEGATIVE_VALUE SYSRES_CONST_IS_STORED_REQUISITE_STORED_VALUE SYSRES_CONST_ITALIC_LIFE_CYCLE_STAGE_DRAW_STYLE SYSRES_CONST_JOB_BLOCK_DESCRIPTION SYSRES_CONST_JOB_KIND_CONTROL_JOB SYSRES_CONST_JOB_KIND_JOB SYSRES_CONST_JOB_KIND_NOTICE SYSRES_CONST_JOB_STATE_ABORTED SYSRES_CONST_JOB_STATE_COMPLETE SYSRES_CONST_JOB_STATE_WORKING SYSRES_CONST_KIND_REQUISITE_CODE SYSRES_CONST_KIND_REQUISITE_NAME SYSRES_CONST_KINDS_CREATE_SHADOW_COPIES_REQUISITE_CODE SYSRES_CONST_KINDS_DEFAULT_EDOC_LIFE_STAGE_REQUISITE_CODE SYSRES_CONST_KINDS_EDOC_ALL_TEPLATES_ALLOWED_REQUISITE_CODE SYSRES_CONST_KINDS_EDOC_ALLOW_LIFE_CYCLE_STAGE_CHANGING_REQUISITE_CODE SYSRES_CONST_KINDS_EDOC_ALLOW_MULTIPLE_ACTIVE_VERSIONS_REQUISITE_CODE SYSRES_CONST_KINDS_EDOC_SHARE_ACCES_RIGHTS_BY_DEFAULT_CODE SYSRES_CONST_KINDS_EDOC_TEMPLATE_REQUISITE_CODE SYSRES_CONST_KINDS_EDOC_TYPE_REQUISITE_CODE SYSRES_CONST_KINDS_SIGNERS_REQUISITES_CODE SYSRES_CONST_KOD_INPUT_TYPE SYSRES_CONST_LAST_UPDATE_DATE_REQUISITE_CODE SYSRES_CONST_LIFE_CYCLE_START_STAGE_REQUISITE_CODE SYSRES_CONST_LILAC_LIFE_CYCLE_STAGE_FONT_COLOR SYSRES_CONST_LINK_OBJECT_KIND_COMPONENT SYSRES_CONST_LINK_OBJECT_KIND_DOCUMENT SYSRES_CONST_LINK_OBJECT_KIND_EDOC SYSRES_CONST_LINK_OBJECT_KIND_FOLDER SYSRES_CONST_LINK_OBJECT_KIND_JOB SYSRES_CONST_LINK_OBJECT_KIND_REFERENCE SYSRES_CONST_LINK_OBJECT_KIND_TASK SYSRES_CONST_LINK_REF_TYPE_REQUISITE_CODE SYSRES_CONST_LIST_REFERENCE_MODE_NAME SYSRES_CONST_LOCALIZATION_DICTIONARY_MAIN_VIEW_CODE SYSRES_CONST_MAIN_VIEW_CODE SYSRES_CONST_MANUAL_ENUM_METHOD_FLAG SYSRES_CONST_MASTER_COMP_TYPE_REQUISITE_CODE SYSRES_CONST_MASTER_TABLE_REC_ID_REQUISITE_CODE SYSRES_CONST_MAXIMIZED_MODE_NAME SYSRES_CONST_ME_VALUE SYSRES_CONST_MESSAGE_ATTENTION_CAPTION SYSRES_CONST_MESSAGE_CONFIRMATION_CAPTION SYSRES_CONST_MESSAGE_ERROR_CAPTION SYSRES_CONST_MESSAGE_INFORMATION_CAPTION SYSRES_CONST_MINIMIZED_MODE_NAME SYSRES_CONST_MINUTE_CHAR SYSRES_CONST_MODULE_REQUISITE_CODE SYSRES_CONST_MONITORING_BLOCK_DESCRIPTION SYSRES_CONST_MONTH_FORMAT_VALUE SYSRES_CONST_NAME_LOCALIZE_ID_REQUISITE_CODE SYSRES_CONST_NAME_REQUISITE_CODE SYSRES_CONST_NAME_SINGULAR_REQUISITE_CODE SYSRES_CONST_NAMEAN_INPUT_TYPE SYSRES_CONST_NEGATIVE_PICK_VALUE SYSRES_CONST_NEGATIVE_VALUE SYSRES_CONST_NO SYSRES_CONST_NO_PICK_VALUE SYSRES_CONST_NO_SIGNATURE_REQUISITE_CODE SYSRES_CONST_NO_VALUE SYSRES_CONST_NONE_ACCESS_RIGHTS_TYPE_CODE SYSRES_CONST_NONOPERATING_RECORD_FLAG_VALUE SYSRES_CONST_NONOPERATING_RECORD_FLAG_VALUE_MASCULINE SYSRES_CONST_NORMAL_ACCESS_RIGHTS_TYPE_CODE SYSRES_CONST_NORMAL_LIFE_CYCLE_STAGE_DRAW_STYLE SYSRES_CONST_NORMAL_MODE_NAME SYSRES_CONST_NOT_ALLOWED_ACCESS_TYPE_CODE SYSRES_CONST_NOT_ALLOWED_ACCESS_TYPE_NAME SYSRES_CONST_NOTE_REQUISITE_CODE SYSRES_CONST_NOTICE_BLOCK_DESCRIPTION SYSRES_CONST_NUM_REQUISITE SYSRES_CONST_NUM_STR_REQUISITE_CODE SYSRES_CONST_NUMERATION_AUTO_NOT_STRONG SYSRES_CONST_NUMERATION_AUTO_STRONG SYSRES_CONST_NUMERATION_FROM_DICTONARY SYSRES_CONST_NUMERATION_MANUAL SYSRES_CONST_NUMERIC_TYPE_CHAR SYSRES_CONST_NUMREQ_REQUISITE_CODE SYSRES_CONST_OBSOLETE_VERSION_STATE_PICK_VALUE SYSRES_CONST_OPERATING_RECORD_FLAG_VALUE SYSRES_CONST_OPERATING_RECORD_FLAG_VALUE_CODE SYSRES_CONST_OPERATING_RECORD_FLAG_VALUE_FEMININE SYSRES_CONST_OPERATING_RECORD_FLAG_VALUE_MASCULINE SYSRES_CONST_OPTIONAL_FORM_COMP_REQCODE_PREFIX SYSRES_CONST_ORANGE_LIFE_CYCLE_STAGE_FONT_COLOR SYSRES_CONST_ORIGINALREF_REQUISITE_CODE SYSRES_CONST_OURFIRM_REF_CODE SYSRES_CONST_OURFIRM_REQUISITE_CODE SYSRES_CONST_OURFIRM_VAR SYSRES_CONST_OUTGOING_WORK_RULE_TYPE_CODE SYSRES_CONST_PICK_NEGATIVE_RESULT SYSRES_CONST_PICK_POSITIVE_RESULT SYSRES_CONST_PICK_REQUISITE SYSRES_CONST_PICK_REQUISITE_TYPE SYSRES_CONST_PICK_TYPE_CHAR SYSRES_CONST_PLAN_STATUS_REQUISITE_CODE SYSRES_CONST_PLATFORM_VERSION_COMMENT SYSRES_CONST_PLUGINS_SETTINGS_DESCRIPTION_REQUISITE_CODE SYSRES_CONST_POSITIVE_PICK_VALUE SYSRES_CONST_POWER_TO_CREATE_ACTION_CODE SYSRES_CONST_POWER_TO_SIGN_ACTION_CODE SYSRES_CONST_PRIORITY_REQUISITE_CODE SYSRES_CONST_QUALIFIED_TASK_TYPE SYSRES_CONST_QUALIFIED_TASK_TYPE_CODE SYSRES_CONST_RECSTAT_REQUISITE_CODE SYSRES_CONST_RED_LIFE_CYCLE_STAGE_FONT_COLOR SYSRES_CONST_REF_ID_T_REF_TYPE_REQUISITE_CODE SYSRES_CONST_REF_REQUISITE SYSRES_CONST_REF_REQUISITE_TYPE SYSRES_CONST_REF_REQUISITES_REFERENCE_CODE_SELECTED_REQUISITE SYSRES_CONST_REFERENCE_RECORD_HISTORY_CREATE_ACTION_CODE SYSRES_CONST_REFERENCE_RECORD_HISTORY_DELETE_ACTION_CODE SYSRES_CONST_REFERENCE_RECORD_HISTORY_MODIFY_ACTION_CODE SYSRES_CONST_REFERENCE_TYPE_CHAR SYSRES_CONST_REFERENCE_TYPE_REQUISITE_NAME SYSRES_CONST_REFERENCES_ADD_PARAMS_REQUISITE_CODE SYSRES_CONST_REFERENCES_DISPLAY_REQUISITE_REQUISITE_CODE SYSRES_CONST_REMOTE_SERVER_STATUS_WORKING SYSRES_CONST_REMOTE_SERVER_TYPE_MAIN SYSRES_CONST_REMOTE_SERVER_TYPE_SECONDARY SYSRES_CONST_REMOTE_USER_FLAG_VALUE_CODE SYSRES_CONST_REPORT_APP_EDITOR_INTERNAL SYSRES_CONST_REPORT_BASE_REPORT_ID_REQUISITE_CODE SYSRES_CONST_REPORT_BASE_REPORT_REQUISITE_CODE SYSRES_CONST_REPORT_SCRIPT_REQUISITE_CODE SYSRES_CONST_REPORT_TEMPLATE_REQUISITE_CODE SYSRES_CONST_REPORT_VIEWER_CODE_REQUISITE_CODE SYSRES_CONST_REQ_ALLOW_COMPONENT_DEFAULT_VALUE SYSRES_CONST_REQ_ALLOW_RECORD_DEFAULT_VALUE SYSRES_CONST_REQ_ALLOW_SERVER_COMPONENT_DEFAULT_VALUE SYSRES_CONST_REQ_MODE_AVAILABLE_CODE SYSRES_CONST_REQ_MODE_EDIT_CODE SYSRES_CONST_REQ_MODE_HIDDEN_CODE SYSRES_CONST_REQ_MODE_NOT_AVAILABLE_CODE SYSRES_CONST_REQ_MODE_VIEW_CODE SYSRES_CONST_REQ_NUMBER_REQUISITE_CODE SYSRES_CONST_REQ_SECTION_VALUE SYSRES_CONST_REQ_TYPE_VALUE SYSRES_CONST_REQUISITE_FORMAT_BY_UNIT SYSRES_CONST_REQUISITE_FORMAT_DATE_FULL SYSRES_CONST_REQUISITE_FORMAT_DATE_TIME SYSRES_CONST_REQUISITE_FORMAT_LEFT SYSRES_CONST_REQUISITE_FORMAT_RIGHT SYSRES_CONST_REQUISITE_FORMAT_WITHOUT_UNIT SYSRES_CONST_REQUISITE_NUMBER_REQUISITE_CODE SYSRES_CONST_REQUISITE_SECTION_ACTIONS SYSRES_CONST_REQUISITE_SECTION_BUTTON SYSRES_CONST_REQUISITE_SECTION_BUTTONS SYSRES_CONST_REQUISITE_SECTION_CARD SYSRES_CONST_REQUISITE_SECTION_TABLE SYSRES_CONST_REQUISITE_SECTION_TABLE10 SYSRES_CONST_REQUISITE_SECTION_TABLE11 SYSRES_CONST_REQUISITE_SECTION_TABLE12 SYSRES_CONST_REQUISITE_SECTION_TABLE13 SYSRES_CONST_REQUISITE_SECTION_TABLE14 SYSRES_CONST_REQUISITE_SECTION_TABLE15 SYSRES_CONST_REQUISITE_SECTION_TABLE16 SYSRES_CONST_REQUISITE_SECTION_TABLE17 SYSRES_CONST_REQUISITE_SECTION_TABLE18 SYSRES_CONST_REQUISITE_SECTION_TABLE19 SYSRES_CONST_REQUISITE_SECTION_TABLE2 SYSRES_CONST_REQUISITE_SECTION_TABLE20 SYSRES_CONST_REQUISITE_SECTION_TABLE21 SYSRES_CONST_REQUISITE_SECTION_TABLE22 SYSRES_CONST_REQUISITE_SECTION_TABLE23 SYSRES_CONST_REQUISITE_SECTION_TABLE24 SYSRES_CONST_REQUISITE_SECTION_TABLE3 SYSRES_CONST_REQUISITE_SECTION_TABLE4 SYSRES_CONST_REQUISITE_SECTION_TABLE5 SYSRES_CONST_REQUISITE_SECTION_TABLE6 SYSRES_CONST_REQUISITE_SECTION_TABLE7 SYSRES_CONST_REQUISITE_SECTION_TABLE8 SYSRES_CONST_REQUISITE_SECTION_TABLE9 SYSRES_CONST_REQUISITES_PSEUDOREFERENCE_REQUISITE_NUMBER_REQUISITE_CODE SYSRES_CONST_RIGHT_ALIGNMENT_CODE SYSRES_CONST_ROLES_REFERENCE_CODE SYSRES_CONST_ROUTE_STEP_AFTER_RUS SYSRES_CONST_ROUTE_STEP_AND_CONDITION_RUS SYSRES_CONST_ROUTE_STEP_OR_CONDITION_RUS SYSRES_CONST_ROUTE_TYPE_COMPLEX SYSRES_CONST_ROUTE_TYPE_PARALLEL SYSRES_CONST_ROUTE_TYPE_SERIAL SYSRES_CONST_SBDATASETDESC_NEGATIVE_VALUE SYSRES_CONST_SBDATASETDESC_POSITIVE_VALUE SYSRES_CONST_SBVIEWSDESC_POSITIVE_VALUE SYSRES_CONST_SCRIPT_BLOCK_DESCRIPTION SYSRES_CONST_SEARCH_BY_TEXT_REQUISITE_CODE SYSRES_CONST_SEARCHES_COMPONENT_CONTENT SYSRES_CONST_SEARCHES_CRITERIA_ACTION_NAME SYSRES_CONST_SEARCHES_EDOC_CONTENT SYSRES_CONST_SEARCHES_FOLDER_CONTENT SYSRES_CONST_SEARCHES_JOB_CONTENT SYSRES_CONST_SEARCHES_REFERENCE_CODE SYSRES_CONST_SEARCHES_TASK_CONTENT SYSRES_CONST_SECOND_CHAR SYSRES_CONST_SECTION_REQUISITE_ACTIONS_VALUE SYSRES_CONST_SECTION_REQUISITE_CARD_VALUE SYSRES_CONST_SECTION_REQUISITE_CODE SYSRES_CONST_SECTION_REQUISITE_DETAIL_1_VALUE SYSRES_CONST_SECTION_REQUISITE_DETAIL_2_VALUE SYSRES_CONST_SECTION_REQUISITE_DETAIL_3_VALUE SYSRES_CONST_SECTION_REQUISITE_DETAIL_4_VALUE SYSRES_CONST_SECTION_REQUISITE_DETAIL_5_VALUE SYSRES_CONST_SECTION_REQUISITE_DETAIL_6_VALUE SYSRES_CONST_SELECT_REFERENCE_MODE_NAME SYSRES_CONST_SELECT_TYPE_SELECTABLE SYSRES_CONST_SELECT_TYPE_SELECTABLE_ONLY_CHILD SYSRES_CONST_SELECT_TYPE_SELECTABLE_WITH_CHILD SYSRES_CONST_SELECT_TYPE_UNSLECTABLE SYSRES_CONST_SERVER_TYPE_MAIN SYSRES_CONST_SERVICE_USER_CATEGORY_FIELD_VALUE SYSRES_CONST_SETTINGS_USER_REQUISITE_CODE SYSRES_CONST_SIGNATURE_AND_ENCODE_CERTIFICATE_TYPE_CODE SYSRES_CONST_SIGNATURE_CERTIFICATE_TYPE_CODE SYSRES_CONST_SINGULAR_TITLE_REQUISITE_CODE SYSRES_CONST_SQL_SERVER_AUTHENTIFICATION_FLAG_VALUE_CODE SYSRES_CONST_SQL_SERVER_ENCODE_AUTHENTIFICATION_FLAG_VALUE_CODE SYSRES_CONST_STANDART_ROUTE_REFERENCE_CODE SYSRES_CONST_STANDART_ROUTE_REFERENCE_COMMENT_REQUISITE_CODE SYSRES_CONST_STANDART_ROUTES_GROUPS_REFERENCE_CODE SYSRES_CONST_STATE_REQ_NAME SYSRES_CONST_STATE_REQUISITE_ACTIVE_VALUE SYSRES_CONST_STATE_REQUISITE_CLOSED_VALUE SYSRES_CONST_STATE_REQUISITE_CODE SYSRES_CONST_STATIC_ROLE_TYPE_CODE SYSRES_CONST_STATUS_PLAN_DEFAULT_VALUE SYSRES_CONST_STATUS_VALUE_AUTOCLEANING SYSRES_CONST_STATUS_VALUE_BLUE_SQUARE SYSRES_CONST_STATUS_VALUE_COMPLETE SYSRES_CONST_STATUS_VALUE_GREEN_SQUARE SYSRES_CONST_STATUS_VALUE_ORANGE_SQUARE SYSRES_CONST_STATUS_VALUE_PURPLE_SQUARE SYSRES_CONST_STATUS_VALUE_RED_SQUARE SYSRES_CONST_STATUS_VALUE_SUSPEND SYSRES_CONST_STATUS_VALUE_YELLOW_SQUARE SYSRES_CONST_STDROUTE_SHOW_TO_USERS_REQUISITE_CODE SYSRES_CONST_STORAGE_TYPE_FILE SYSRES_CONST_STORAGE_TYPE_SQL_SERVER SYSRES_CONST_STR_REQUISITE SYSRES_CONST_STRIKEOUT_LIFE_CYCLE_STAGE_DRAW_STYLE SYSRES_CONST_STRING_FORMAT_LEFT_ALIGN_CHAR SYSRES_CONST_STRING_FORMAT_RIGHT_ALIGN_CHAR SYSRES_CONST_STRING_REQUISITE_CODE SYSRES_CONST_STRING_REQUISITE_TYPE SYSRES_CONST_STRING_TYPE_CHAR SYSRES_CONST_SUBSTITUTES_PSEUDOREFERENCE_CODE SYSRES_CONST_SUBTASK_BLOCK_DESCRIPTION SYSRES_CONST_SYSTEM_SETTING_CURRENT_USER_PARAM_VALUE SYSRES_CONST_SYSTEM_SETTING_EMPTY_VALUE_PARAM_VALUE SYSRES_CONST_SYSTEM_VERSION_COMMENT SYSRES_CONST_TASK_ACCESS_TYPE_ALL SYSRES_CONST_TASK_ACCESS_TYPE_ALL_MEMBERS SYSRES_CONST_TASK_ACCESS_TYPE_MANUAL SYSRES_CONST_TASK_ENCODE_TYPE_CERTIFICATION SYSRES_CONST_TASK_ENCODE_TYPE_CERTIFICATION_AND_PASSWORD SYSRES_CONST_TASK_ENCODE_TYPE_NONE SYSRES_CONST_TASK_ENCODE_TYPE_PASSWORD SYSRES_CONST_TASK_ROUTE_ALL_CONDITION SYSRES_CONST_TASK_ROUTE_AND_CONDITION SYSRES_CONST_TASK_ROUTE_OR_CONDITION SYSRES_CONST_TASK_STATE_ABORTED SYSRES_CONST_TASK_STATE_COMPLETE SYSRES_CONST_TASK_STATE_CONTINUED SYSRES_CONST_TASK_STATE_CONTROL SYSRES_CONST_TASK_STATE_INIT SYSRES_CONST_TASK_STATE_WORKING SYSRES_CONST_TASK_TITLE SYSRES_CONST_TASK_TYPES_GROUPS_REFERENCE_CODE SYSRES_CONST_TASK_TYPES_REFERENCE_CODE SYSRES_CONST_TEMPLATES_REFERENCE_CODE SYSRES_CONST_TEST_DATE_REQUISITE_NAME SYSRES_CONST_TEST_DEV_DATABASE_NAME SYSRES_CONST_TEST_DEV_SYSTEM_CODE SYSRES_CONST_TEST_EDMS_DATABASE_NAME SYSRES_CONST_TEST_EDMS_MAIN_CODE SYSRES_CONST_TEST_EDMS_MAIN_DB_NAME SYSRES_CONST_TEST_EDMS_SECOND_CODE SYSRES_CONST_TEST_EDMS_SECOND_DB_NAME SYSRES_CONST_TEST_EDMS_SYSTEM_CODE SYSRES_CONST_TEST_NUMERIC_REQUISITE_NAME SYSRES_CONST_TEXT_REQUISITE SYSRES_CONST_TEXT_REQUISITE_CODE SYSRES_CONST_TEXT_REQUISITE_TYPE SYSRES_CONST_TEXT_TYPE_CHAR SYSRES_CONST_TYPE_CODE_REQUISITE_CODE SYSRES_CONST_TYPE_REQUISITE_CODE SYSRES_CONST_UNDEFINED_LIFE_CYCLE_STAGE_FONT_COLOR SYSRES_CONST_UNITS_SECTION_ID_REQUISITE_CODE SYSRES_CONST_UNITS_SECTION_REQUISITE_CODE SYSRES_CONST_UNOPERATING_RECORD_FLAG_VALUE_CODE SYSRES_CONST_UNSTORED_DATA_REQUISITE_CODE SYSRES_CONST_UNSTORED_DATA_REQUISITE_NAME SYSRES_CONST_USE_ACCESS_TYPE_CODE SYSRES_CONST_USE_ACCESS_TYPE_NAME SYSRES_CONST_USER_ACCOUNT_TYPE_VALUE_CODE SYSRES_CONST_USER_ADDITIONAL_INFORMATION_REQUISITE_CODE SYSRES_CONST_USER_AND_GROUP_ID_FROM_PSEUDOREFERENCE_REQUISITE_CODE SYSRES_CONST_USER_CATEGORY_NORMAL SYSRES_CONST_USER_CERTIFICATE_REQUISITE_CODE SYSRES_CONST_USER_CERTIFICATE_STATE_REQUISITE_CODE SYSRES_CONST_USER_CERTIFICATE_SUBJECT_NAME_REQUISITE_CODE SYSRES_CONST_USER_CERTIFICATE_THUMBPRINT_REQUISITE_CODE SYSRES_CONST_USER_COMMON_CATEGORY SYSRES_CONST_USER_COMMON_CATEGORY_CODE SYSRES_CONST_USER_FULL_NAME_REQUISITE_CODE SYSRES_CONST_USER_GROUP_TYPE_REQUISITE_CODE SYSRES_CONST_USER_LOGIN_REQUISITE_CODE SYSRES_CONST_USER_REMOTE_CONTROLLER_REQUISITE_CODE SYSRES_CONST_USER_REMOTE_SYSTEM_REQUISITE_CODE SYSRES_CONST_USER_RIGHTS_T_REQUISITE_CODE SYSRES_CONST_USER_SERVER_NAME_REQUISITE_CODE SYSRES_CONST_USER_SERVICE_CATEGORY SYSRES_CONST_USER_SERVICE_CATEGORY_CODE SYSRES_CONST_USER_STATUS_ADMINISTRATOR_CODE SYSRES_CONST_USER_STATUS_ADMINISTRATOR_NAME SYSRES_CONST_USER_STATUS_DEVELOPER_CODE SYSRES_CONST_USER_STATUS_DEVELOPER_NAME SYSRES_CONST_USER_STATUS_DISABLED_CODE SYSRES_CONST_USER_STATUS_DISABLED_NAME SYSRES_CONST_USER_STATUS_SYSTEM_DEVELOPER_CODE SYSRES_CONST_USER_STATUS_USER_CODE SYSRES_CONST_USER_STATUS_USER_NAME SYSRES_CONST_USER_STATUS_USER_NAME_DEPRECATED SYSRES_CONST_USER_TYPE_FIELD_VALUE_USER SYSRES_CONST_USER_TYPE_REQUISITE_CODE SYSRES_CONST_USERS_CONTROLLER_REQUISITE_CODE SYSRES_CONST_USERS_IS_MAIN_SERVER_REQUISITE_CODE SYSRES_CONST_USERS_REFERENCE_CODE SYSRES_CONST_USERS_REGISTRATION_CERTIFICATES_ACTION_NAME SYSRES_CONST_USERS_REQUISITE_CODE SYSRES_CONST_USERS_SYSTEM_REQUISITE_CODE SYSRES_CONST_USERS_USER_ACCESS_RIGHTS_TYPR_REQUISITE_CODE SYSRES_CONST_USERS_USER_AUTHENTICATION_REQUISITE_CODE SYSRES_CONST_USERS_USER_COMPONENT_REQUISITE_CODE SYSRES_CONST_USERS_USER_GROUP_REQUISITE_CODE SYSRES_CONST_USERS_VIEW_CERTIFICATES_ACTION_NAME SYSRES_CONST_VIEW_DEFAULT_CODE SYSRES_CONST_VIEW_DEFAULT_NAME SYSRES_CONST_VIEWER_REQUISITE_CODE SYSRES_CONST_WAITING_BLOCK_DESCRIPTION SYSRES_CONST_WIZARD_FORM_LABEL_TEST_STRING  SYSRES_CONST_WIZARD_QUERY_PARAM_HEIGHT_ETALON_STRING SYSRES_CONST_WIZARD_REFERENCE_COMMENT_REQUISITE_CODE SYSRES_CONST_WORK_RULES_DESCRIPTION_REQUISITE_CODE SYSRES_CONST_WORK_TIME_CALENDAR_REFERENCE_CODE SYSRES_CONST_WORK_WORKFLOW_HARD_ROUTE_TYPE_VALUE SYSRES_CONST_WORK_WORKFLOW_HARD_ROUTE_TYPE_VALUE_CODE SYSRES_CONST_WORK_WORKFLOW_HARD_ROUTE_TYPE_VALUE_CODE_RUS SYSRES_CONST_WORK_WORKFLOW_SOFT_ROUTE_TYPE_VALUE_CODE_RUS SYSRES_CONST_WORKFLOW_ROUTE_TYPR_HARD SYSRES_CONST_WORKFLOW_ROUTE_TYPR_SOFT SYSRES_CONST_XML_ENCODING SYSRES_CONST_XREC_STAT_REQUISITE_CODE SYSRES_CONST_XRECID_FIELD_NAME SYSRES_CONST_YES SYSRES_CONST_YES_NO_2_REQUISITE_CODE SYSRES_CONST_YES_NO_REQUISITE_CODE SYSRES_CONST_YES_NO_T_REF_TYPE_REQUISITE_CODE SYSRES_CONST_YES_PICK_VALUE SYSRES_CONST_YES_VALUE " + "CR FALSE nil NO_VALUE NULL TAB TRUE YES_VALUE " + "ADMINISTRATORS_GROUP_NAME CUSTOMIZERS_GROUP_NAME DEVELOPERS_GROUP_NAME SERVICE_USERS_GROUP_NAME " + "DECISION_BLOCK_FIRST_OPERAND_PROPERTY DECISION_BLOCK_NAME_PROPERTY DECISION_BLOCK_OPERATION_PROPERTY DECISION_BLOCK_RESULT_TYPE_PROPERTY DECISION_BLOCK_SECOND_OPERAND_PROPERTY " + "ANY_FILE_EXTENTION COMPRESSED_DOCUMENT_EXTENSION EXTENDED_DOCUMENT_EXTENSION SHORT_COMPRESSED_DOCUMENT_EXTENSION SHORT_EXTENDED_DOCUMENT_EXTENSION " + "JOB_BLOCK_ABORT_DEADLINE_PROPERTY JOB_BLOCK_AFTER_FINISH_EVENT JOB_BLOCK_AFTER_QUERY_PARAMETERS_EVENT JOB_BLOCK_ATTACHMENT_PROPERTY JOB_BLOCK_ATTACHMENTS_RIGHTS_GROUP_PROPERTY JOB_BLOCK_ATTACHMENTS_RIGHTS_TYPE_PROPERTY JOB_BLOCK_BEFORE_QUERY_PARAMETERS_EVENT JOB_BLOCK_BEFORE_START_EVENT JOB_BLOCK_CREATED_JOBS_PROPERTY JOB_BLOCK_DEADLINE_PROPERTY JOB_BLOCK_EXECUTION_RESULTS_PROPERTY JOB_BLOCK_IS_PARALLEL_PROPERTY JOB_BLOCK_IS_RELATIVE_ABORT_DEADLINE_PROPERTY JOB_BLOCK_IS_RELATIVE_DEADLINE_PROPERTY JOB_BLOCK_JOB_TEXT_PROPERTY JOB_BLOCK_NAME_PROPERTY JOB_BLOCK_NEED_SIGN_ON_PERFORM_PROPERTY JOB_BLOCK_PERFORMER_PROPERTY JOB_BLOCK_RELATIVE_ABORT_DEADLINE_TYPE_PROPERTY JOB_BLOCK_RELATIVE_DEADLINE_TYPE_PROPERTY JOB_BLOCK_SUBJECT_PROPERTY " + "ENGLISH_LANGUAGE_CODE RUSSIAN_LANGUAGE_CODE " + "smHidden smMaximized smMinimized smNormal wmNo wmYes " + "COMPONENT_TOKEN_LINK_KIND DOCUMENT_LINK_KIND EDOCUMENT_LINK_KIND FOLDER_LINK_KIND JOB_LINK_KIND REFERENCE_LINK_KIND TASK_LINK_KIND " + "COMPONENT_TOKEN_LOCK_TYPE EDOCUMENT_VERSION_LOCK_TYPE " + "MONITOR_BLOCK_AFTER_FINISH_EVENT MONITOR_BLOCK_BEFORE_START_EVENT MONITOR_BLOCK_DEADLINE_PROPERTY MONITOR_BLOCK_INTERVAL_PROPERTY MONITOR_BLOCK_INTERVAL_TYPE_PROPERTY MONITOR_BLOCK_IS_RELATIVE_DEADLINE_PROPERTY MONITOR_BLOCK_NAME_PROPERTY MONITOR_BLOCK_RELATIVE_DEADLINE_TYPE_PROPERTY MONITOR_BLOCK_SEARCH_SCRIPT_PROPERTY " + "NOTICE_BLOCK_AFTER_FINISH_EVENT NOTICE_BLOCK_ATTACHMENT_PROPERTY NOTICE_BLOCK_ATTACHMENTS_RIGHTS_GROUP_PROPERTY NOTICE_BLOCK_ATTACHMENTS_RIGHTS_TYPE_PROPERTY NOTICE_BLOCK_BEFORE_START_EVENT NOTICE_BLOCK_CREATED_NOTICES_PROPERTY NOTICE_BLOCK_DEADLINE_PROPERTY NOTICE_BLOCK_IS_RELATIVE_DEADLINE_PROPERTY NOTICE_BLOCK_NAME_PROPERTY NOTICE_BLOCK_NOTICE_TEXT_PROPERTY NOTICE_BLOCK_PERFORMER_PROPERTY NOTICE_BLOCK_RELATIVE_DEADLINE_TYPE_PROPERTY NOTICE_BLOCK_SUBJECT_PROPERTY " + "dseAfterCancel dseAfterClose dseAfterDelete dseAfterDeleteOutOfTransaction dseAfterInsert dseAfterOpen dseAfterScroll dseAfterUpdate dseAfterUpdateOutOfTransaction dseBeforeCancel dseBeforeClose dseBeforeDelete dseBeforeDetailUpdate dseBeforeInsert dseBeforeOpen dseBeforeUpdate dseOnAnyRequisiteChange dseOnCloseRecord dseOnDeleteError dseOnOpenRecord dseOnPrepareUpdate dseOnUpdateError dseOnUpdateRatifiedRecord dseOnValidDelete dseOnValidUpdate reOnChange reOnChangeValues SELECTION_BEGIN_ROUTE_EVENT SELECTION_END_ROUTE_EVENT " + "CURRENT_PERIOD_IS_REQUIRED PREVIOUS_CARD_TYPE_NAME SHOW_RECORD_PROPERTIES_FORM " + "ACCESS_RIGHTS_SETTING_DIALOG_CODE ADMINISTRATOR_USER_CODE ANALYTIC_REPORT_TYPE asrtHideLocal asrtHideRemote CALCULATED_ROLE_TYPE_CODE COMPONENTS_REFERENCE_DEVELOPER_VIEW_CODE DCTS_TEST_PROTOCOLS_FOLDER_PATH E_EDOC_VERSION_ALREADY_APPROVINGLY_SIGNED E_EDOC_VERSION_ALREADY_APPROVINGLY_SIGNED_BY_USER E_EDOC_VERSION_ALREDY_SIGNED E_EDOC_VERSION_ALREDY_SIGNED_BY_USER EDOC_TYPES_CODE_REQUISITE_FIELD_NAME EDOCUMENTS_ALIAS_NAME FILES_FOLDER_PATH FILTER_OPERANDS_DELIMITER FILTER_OPERATIONS_DELIMITER FORMCARD_NAME FORMLIST_NAME GET_EXTENDED_DOCUMENT_EXTENSION_CREATION_MODE GET_EXTENDED_DOCUMENT_EXTENSION_IMPORT_MODE INTEGRATED_REPORT_TYPE IS_BUILDER_APPLICATION_ROLE IS_BUILDER_APPLICATION_ROLE2 IS_BUILDER_USERS ISBSYSDEV LOG_FOLDER_PATH mbCancel mbNo mbNoToAll mbOK mbYes mbYesToAll MEMORY_DATASET_DESRIPTIONS_FILENAME mrNo mrNoToAll mrYes mrYesToAll MULTIPLE_SELECT_DIALOG_CODE NONOPERATING_RECORD_FLAG_FEMININE NONOPERATING_RECORD_FLAG_MASCULINE OPERATING_RECORD_FLAG_FEMININE OPERATING_RECORD_FLAG_MASCULINE PROFILING_SETTINGS_COMMON_SETTINGS_CODE_VALUE PROGRAM_INITIATED_LOOKUP_ACTION ratDelete ratEdit ratInsert REPORT_TYPE REQUIRED_PICK_VALUES_VARIABLE rmCard rmList SBRTE_PROGID_DEV SBRTE_PROGID_RELEASE STATIC_ROLE_TYPE_CODE SUPPRESS_EMPTY_TEMPLATE_CREATION SYSTEM_USER_CODE UPDATE_DIALOG_DATASET USED_IN_OBJECT_HINT_PARAM USER_INITIATED_LOOKUP_ACTION USER_NAME_FORMAT USER_SELECTION_RESTRICTIONS WORKFLOW_TEST_PROTOCOLS_FOLDER_PATH ELS_SUBTYPE_CONTROL_NAME ELS_FOLDER_KIND_CONTROL_NAME REPEAT_PROCESS_CURRENT_OBJECT_EXCEPTION_NAME " + "PRIVILEGE_COMPONENT_FULL_ACCESS PRIVILEGE_DEVELOPMENT_EXPORT PRIVILEGE_DEVELOPMENT_IMPORT PRIVILEGE_DOCUMENT_DELETE PRIVILEGE_ESD PRIVILEGE_FOLDER_DELETE PRIVILEGE_MANAGE_ACCESS_RIGHTS PRIVILEGE_MANAGE_REPLICATION PRIVILEGE_MANAGE_SESSION_SERVER PRIVILEGE_OBJECT_FULL_ACCESS PRIVILEGE_OBJECT_VIEW PRIVILEGE_RESERVE_LICENSE PRIVILEGE_SYSTEM_CUSTOMIZE PRIVILEGE_SYSTEM_DEVELOP PRIVILEGE_SYSTEM_INSTALL PRIVILEGE_TASK_DELETE PRIVILEGE_USER_PLUGIN_SETTINGS_CUSTOMIZE PRIVILEGES_PSEUDOREFERENCE_CODE " + "ACCESS_TYPES_PSEUDOREFERENCE_CODE ALL_AVAILABLE_COMPONENTS_PSEUDOREFERENCE_CODE ALL_AVAILABLE_PRIVILEGES_PSEUDOREFERENCE_CODE ALL_REPLICATE_COMPONENTS_PSEUDOREFERENCE_CODE AVAILABLE_DEVELOPERS_COMPONENTS_PSEUDOREFERENCE_CODE COMPONENTS_PSEUDOREFERENCE_CODE FILTRATER_SETTINGS_CONFLICTS_PSEUDOREFERENCE_CODE GROUPS_PSEUDOREFERENCE_CODE RECEIVE_PROTOCOL_PSEUDOREFERENCE_CODE REFERENCE_REQUISITE_PSEUDOREFERENCE_CODE REFERENCE_REQUISITES_PSEUDOREFERENCE_CODE REFTYPES_PSEUDOREFERENCE_CODE REPLICATION_SEANCES_DIARY_PSEUDOREFERENCE_CODE SEND_PROTOCOL_PSEUDOREFERENCE_CODE SUBSTITUTES_PSEUDOREFERENCE_CODE SYSTEM_SETTINGS_PSEUDOREFERENCE_CODE UNITS_PSEUDOREFERENCE_CODE USERS_PSEUDOREFERENCE_CODE VIEWERS_PSEUDOREFERENCE_CODE " + "CERTIFICATE_TYPE_ENCRYPT CERTIFICATE_TYPE_SIGN CERTIFICATE_TYPE_SIGN_AND_ENCRYPT " + "STORAGE_TYPE_FILE STORAGE_TYPE_NAS_CIFS STORAGE_TYPE_SAPERION STORAGE_TYPE_SQL_SERVER " + "COMPTYPE2_REQUISITE_DOCUMENTS_VALUE COMPTYPE2_REQUISITE_TASKS_VALUE COMPTYPE2_REQUISITE_FOLDERS_VALUE COMPTYPE2_REQUISITE_REFERENCES_VALUE " + "SYSREQ_CODE SYSREQ_COMPTYPE2 SYSREQ_CONST_AVAILABLE_FOR_WEB SYSREQ_CONST_COMMON_CODE SYSREQ_CONST_COMMON_VALUE SYSREQ_CONST_FIRM_CODE SYSREQ_CONST_FIRM_STATUS SYSREQ_CONST_FIRM_VALUE SYSREQ_CONST_SERVER_STATUS SYSREQ_CONTENTS SYSREQ_DATE_OPEN SYSREQ_DATE_CLOSE SYSREQ_DESCRIPTION SYSREQ_DESCRIPTION_LOCALIZE_ID SYSREQ_DOUBLE SYSREQ_EDOC_ACCESS_TYPE SYSREQ_EDOC_AUTHOR SYSREQ_EDOC_CREATED SYSREQ_EDOC_DELEGATE_RIGHTS_REQUISITE_CODE SYSREQ_EDOC_EDITOR SYSREQ_EDOC_ENCODE_TYPE SYSREQ_EDOC_ENCRYPTION_PLUGIN_NAME SYSREQ_EDOC_ENCRYPTION_PLUGIN_VERSION SYSREQ_EDOC_EXPORT_DATE SYSREQ_EDOC_EXPORTER SYSREQ_EDOC_KIND SYSREQ_EDOC_LIFE_STAGE_NAME SYSREQ_EDOC_LOCKED_FOR_SERVER_CODE SYSREQ_EDOC_MODIFIED SYSREQ_EDOC_NAME SYSREQ_EDOC_NOTE SYSREQ_EDOC_QUALIFIED_ID SYSREQ_EDOC_SESSION_KEY SYSREQ_EDOC_SESSION_KEY_ENCRYPTION_PLUGIN_NAME SYSREQ_EDOC_SESSION_KEY_ENCRYPTION_PLUGIN_VERSION SYSREQ_EDOC_SIGNATURE_TYPE SYSREQ_EDOC_SIGNED SYSREQ_EDOC_STORAGE SYSREQ_EDOC_STORAGES_ARCHIVE_STORAGE SYSREQ_EDOC_STORAGES_CHECK_RIGHTS SYSREQ_EDOC_STORAGES_COMPUTER_NAME SYSREQ_EDOC_STORAGES_EDIT_IN_STORAGE SYSREQ_EDOC_STORAGES_EXECUTIVE_STORAGE SYSREQ_EDOC_STORAGES_FUNCTION SYSREQ_EDOC_STORAGES_INITIALIZED SYSREQ_EDOC_STORAGES_LOCAL_PATH SYSREQ_EDOC_STORAGES_SAPERION_DATABASE_NAME SYSREQ_EDOC_STORAGES_SEARCH_BY_TEXT SYSREQ_EDOC_STORAGES_SERVER_NAME SYSREQ_EDOC_STORAGES_SHARED_SOURCE_NAME SYSREQ_EDOC_STORAGES_TYPE SYSREQ_EDOC_TEXT_MODIFIED SYSREQ_EDOC_TYPE_ACT_CODE SYSREQ_EDOC_TYPE_ACT_DESCRIPTION SYSREQ_EDOC_TYPE_ACT_DESCRIPTION_LOCALIZE_ID SYSREQ_EDOC_TYPE_ACT_ON_EXECUTE SYSREQ_EDOC_TYPE_ACT_ON_EXECUTE_EXISTS SYSREQ_EDOC_TYPE_ACT_SECTION SYSREQ_EDOC_TYPE_ADD_PARAMS SYSREQ_EDOC_TYPE_COMMENT SYSREQ_EDOC_TYPE_EVENT_TEXT SYSREQ_EDOC_TYPE_NAME_IN_SINGULAR SYSREQ_EDOC_TYPE_NAME_IN_SINGULAR_LOCALIZE_ID SYSREQ_EDOC_TYPE_NAME_LOCALIZE_ID SYSREQ_EDOC_TYPE_NUMERATION_METHOD SYSREQ_EDOC_TYPE_PSEUDO_REQUISITE_CODE SYSREQ_EDOC_TYPE_REQ_CODE SYSREQ_EDOC_TYPE_REQ_DESCRIPTION SYSREQ_EDOC_TYPE_REQ_DESCRIPTION_LOCALIZE_ID SYSREQ_EDOC_TYPE_REQ_IS_LEADING SYSREQ_EDOC_TYPE_REQ_IS_REQUIRED SYSREQ_EDOC_TYPE_REQ_NUMBER SYSREQ_EDOC_TYPE_REQ_ON_CHANGE SYSREQ_EDOC_TYPE_REQ_ON_CHANGE_EXISTS SYSREQ_EDOC_TYPE_REQ_ON_SELECT SYSREQ_EDOC_TYPE_REQ_ON_SELECT_KIND SYSREQ_EDOC_TYPE_REQ_SECTION SYSREQ_EDOC_TYPE_VIEW_CARD SYSREQ_EDOC_TYPE_VIEW_CODE SYSREQ_EDOC_TYPE_VIEW_COMMENT SYSREQ_EDOC_TYPE_VIEW_IS_MAIN SYSREQ_EDOC_TYPE_VIEW_NAME SYSREQ_EDOC_TYPE_VIEW_NAME_LOCALIZE_ID SYSREQ_EDOC_VERSION_AUTHOR SYSREQ_EDOC_VERSION_CRC SYSREQ_EDOC_VERSION_DATA SYSREQ_EDOC_VERSION_EDITOR SYSREQ_EDOC_VERSION_EXPORT_DATE SYSREQ_EDOC_VERSION_EXPORTER SYSREQ_EDOC_VERSION_HIDDEN SYSREQ_EDOC_VERSION_LIFE_STAGE SYSREQ_EDOC_VERSION_MODIFIED SYSREQ_EDOC_VERSION_NOTE SYSREQ_EDOC_VERSION_SIGNATURE_TYPE SYSREQ_EDOC_VERSION_SIGNED SYSREQ_EDOC_VERSION_SIZE SYSREQ_EDOC_VERSION_SOURCE SYSREQ_EDOC_VERSION_TEXT_MODIFIED SYSREQ_EDOCKIND_DEFAULT_VERSION_STATE_CODE SYSREQ_FOLDER_KIND SYSREQ_FUNC_CATEGORY SYSREQ_FUNC_COMMENT SYSREQ_FUNC_GROUP SYSREQ_FUNC_GROUP_COMMENT SYSREQ_FUNC_GROUP_NUMBER SYSREQ_FUNC_HELP SYSREQ_FUNC_PARAM_DEF_VALUE SYSREQ_FUNC_PARAM_IDENT SYSREQ_FUNC_PARAM_NUMBER SYSREQ_FUNC_PARAM_TYPE SYSREQ_FUNC_TEXT SYSREQ_GROUP_CATEGORY SYSREQ_ID SYSREQ_LAST_UPDATE SYSREQ_LEADER_REFERENCE SYSREQ_LINE_NUMBER SYSREQ_MAIN_RECORD_ID SYSREQ_NAME SYSREQ_NAME_LOCALIZE_ID SYSREQ_NOTE SYSREQ_ORIGINAL_RECORD SYSREQ_OUR_FIRM SYSREQ_PROFILING_SETTINGS_BATCH_LOGING SYSREQ_PROFILING_SETTINGS_BATCH_SIZE SYSREQ_PROFILING_SETTINGS_PROFILING_ENABLED SYSREQ_PROFILING_SETTINGS_SQL_PROFILING_ENABLED SYSREQ_PROFILING_SETTINGS_START_LOGGED SYSREQ_RECORD_STATUS SYSREQ_REF_REQ_FIELD_NAME SYSREQ_REF_REQ_FORMAT SYSREQ_REF_REQ_GENERATED SYSREQ_REF_REQ_LENGTH SYSREQ_REF_REQ_PRECISION SYSREQ_REF_REQ_REFERENCE SYSREQ_REF_REQ_SECTION SYSREQ_REF_REQ_STORED SYSREQ_REF_REQ_TOKENS SYSREQ_REF_REQ_TYPE SYSREQ_REF_REQ_VIEW SYSREQ_REF_TYPE_ACT_CODE SYSREQ_REF_TYPE_ACT_DESCRIPTION SYSREQ_REF_TYPE_ACT_DESCRIPTION_LOCALIZE_ID SYSREQ_REF_TYPE_ACT_ON_EXECUTE SYSREQ_REF_TYPE_ACT_ON_EXECUTE_EXISTS SYSREQ_REF_TYPE_ACT_SECTION SYSREQ_REF_TYPE_ADD_PARAMS SYSREQ_REF_TYPE_COMMENT SYSREQ_REF_TYPE_COMMON_SETTINGS SYSREQ_REF_TYPE_DISPLAY_REQUISITE_NAME SYSREQ_REF_TYPE_EVENT_TEXT SYSREQ_REF_TYPE_MAIN_LEADING_REF SYSREQ_REF_TYPE_NAME_IN_SINGULAR SYSREQ_REF_TYPE_NAME_IN_SINGULAR_LOCALIZE_ID SYSREQ_REF_TYPE_NAME_LOCALIZE_ID SYSREQ_REF_TYPE_NUMERATION_METHOD SYSREQ_REF_TYPE_REQ_CODE SYSREQ_REF_TYPE_REQ_DESCRIPTION SYSREQ_REF_TYPE_REQ_DESCRIPTION_LOCALIZE_ID SYSREQ_REF_TYPE_REQ_IS_CONTROL SYSREQ_REF_TYPE_REQ_IS_FILTER SYSREQ_REF_TYPE_REQ_IS_LEADING SYSREQ_REF_TYPE_REQ_IS_REQUIRED SYSREQ_REF_TYPE_REQ_NUMBER SYSREQ_REF_TYPE_REQ_ON_CHANGE SYSREQ_REF_TYPE_REQ_ON_CHANGE_EXISTS SYSREQ_REF_TYPE_REQ_ON_SELECT SYSREQ_REF_TYPE_REQ_ON_SELECT_KIND SYSREQ_REF_TYPE_REQ_SECTION SYSREQ_REF_TYPE_VIEW_CARD SYSREQ_REF_TYPE_VIEW_CODE SYSREQ_REF_TYPE_VIEW_COMMENT SYSREQ_REF_TYPE_VIEW_IS_MAIN SYSREQ_REF_TYPE_VIEW_NAME SYSREQ_REF_TYPE_VIEW_NAME_LOCALIZE_ID SYSREQ_REFERENCE_TYPE_ID SYSREQ_STATE SYSREQ_STATЕ SYSREQ_SYSTEM_SETTINGS_VALUE SYSREQ_TYPE SYSREQ_UNIT SYSREQ_UNIT_ID SYSREQ_USER_GROUPS_GROUP_FULL_NAME SYSREQ_USER_GROUPS_GROUP_NAME SYSREQ_USER_GROUPS_GROUP_SERVER_NAME SYSREQ_USERS_ACCESS_RIGHTS SYSREQ_USERS_AUTHENTICATION SYSREQ_USERS_CATEGORY SYSREQ_USERS_COMPONENT SYSREQ_USERS_COMPONENT_USER_IS_PUBLIC SYSREQ_USERS_DOMAIN SYSREQ_USERS_FULL_USER_NAME SYSREQ_USERS_GROUP SYSREQ_USERS_IS_MAIN_SERVER SYSREQ_USERS_LOGIN SYSREQ_USERS_REFERENCE_USER_IS_PUBLIC SYSREQ_USERS_STATUS SYSREQ_USERS_USER_CERTIFICATE SYSREQ_USERS_USER_CERTIFICATE_INFO SYSREQ_USERS_USER_CERTIFICATE_PLUGIN_NAME SYSREQ_USERS_USER_CERTIFICATE_PLUGIN_VERSION SYSREQ_USERS_USER_CERTIFICATE_STATE SYSREQ_USERS_USER_CERTIFICATE_SUBJECT_NAME SYSREQ_USERS_USER_CERTIFICATE_THUMBPRINT SYSREQ_USERS_USER_DEFAULT_CERTIFICATE SYSREQ_USERS_USER_DESCRIPTION SYSREQ_USERS_USER_GLOBAL_NAME SYSREQ_USERS_USER_LOGIN SYSREQ_USERS_USER_MAIN_SERVER SYSREQ_USERS_USER_TYPE SYSREQ_WORK_RULES_FOLDER_ID " + "RESULT_VAR_NAME RESULT_VAR_NAME_ENG " + "AUTO_NUMERATION_RULE_ID CANT_CHANGE_ID_REQUISITE_RULE_ID CANT_CHANGE_OURFIRM_REQUISITE_RULE_ID CHECK_CHANGING_REFERENCE_RECORD_USE_RULE_ID CHECK_CODE_REQUISITE_RULE_ID CHECK_DELETING_REFERENCE_RECORD_USE_RULE_ID CHECK_FILTRATER_CHANGES_RULE_ID CHECK_RECORD_INTERVAL_RULE_ID CHECK_REFERENCE_INTERVAL_RULE_ID CHECK_REQUIRED_DATA_FULLNESS_RULE_ID CHECK_REQUIRED_REQUISITES_FULLNESS_RULE_ID MAKE_RECORD_UNRATIFIED_RULE_ID RESTORE_AUTO_NUMERATION_RULE_ID SET_FIRM_CONTEXT_FROM_RECORD_RULE_ID SET_FIRST_RECORD_IN_LIST_FORM_RULE_ID SET_IDSPS_VALUE_RULE_ID SET_NEXT_CODE_VALUE_RULE_ID SET_OURFIRM_BOUNDS_RULE_ID SET_OURFIRM_REQUISITE_RULE_ID " + "SCRIPT_BLOCK_AFTER_FINISH_EVENT SCRIPT_BLOCK_BEFORE_START_EVENT SCRIPT_BLOCK_EXECUTION_RESULTS_PROPERTY SCRIPT_BLOCK_NAME_PROPERTY SCRIPT_BLOCK_SCRIPT_PROPERTY " + "SUBTASK_BLOCK_ABORT_DEADLINE_PROPERTY SUBTASK_BLOCK_AFTER_FINISH_EVENT SUBTASK_BLOCK_ASSIGN_PARAMS_EVENT SUBTASK_BLOCK_ATTACHMENTS_PROPERTY SUBTASK_BLOCK_ATTACHMENTS_RIGHTS_GROUP_PROPERTY SUBTASK_BLOCK_ATTACHMENTS_RIGHTS_TYPE_PROPERTY SUBTASK_BLOCK_BEFORE_START_EVENT SUBTASK_BLOCK_CREATED_TASK_PROPERTY SUBTASK_BLOCK_CREATION_EVENT SUBTASK_BLOCK_DEADLINE_PROPERTY SUBTASK_BLOCK_IMPORTANCE_PROPERTY SUBTASK_BLOCK_INITIATOR_PROPERTY SUBTASK_BLOCK_IS_RELATIVE_ABORT_DEADLINE_PROPERTY SUBTASK_BLOCK_IS_RELATIVE_DEADLINE_PROPERTY SUBTASK_BLOCK_JOBS_TYPE_PROPERTY SUBTASK_BLOCK_NAME_PROPERTY SUBTASK_BLOCK_PARALLEL_ROUTE_PROPERTY SUBTASK_BLOCK_PERFORMERS_PROPERTY SUBTASK_BLOCK_RELATIVE_ABORT_DEADLINE_TYPE_PROPERTY SUBTASK_BLOCK_RELATIVE_DEADLINE_TYPE_PROPERTY SUBTASK_BLOCK_REQUIRE_SIGN_PROPERTY SUBTASK_BLOCK_STANDARD_ROUTE_PROPERTY SUBTASK_BLOCK_START_EVENT SUBTASK_BLOCK_STEP_CONTROL_PROPERTY SUBTASK_BLOCK_SUBJECT_PROPERTY SUBTASK_BLOCK_TASK_CONTROL_PROPERTY SUBTASK_BLOCK_TEXT_PROPERTY SUBTASK_BLOCK_UNLOCK_ATTACHMENTS_ON_STOP_PROPERTY SUBTASK_BLOCK_USE_STANDARD_ROUTE_PROPERTY SUBTASK_BLOCK_WAIT_FOR_TASK_COMPLETE_PROPERTY " + "SYSCOMP_CONTROL_JOBS SYSCOMP_FOLDERS SYSCOMP_JOBS SYSCOMP_NOTICES SYSCOMP_TASKS " + "SYSDLG_CREATE_EDOCUMENT SYSDLG_CREATE_EDOCUMENT_VERSION SYSDLG_CURRENT_PERIOD SYSDLG_EDIT_FUNCTION_HELP SYSDLG_EDOCUMENT_KINDS_FOR_TEMPLATE SYSDLG_EXPORT_MULTIPLE_EDOCUMENTS SYSDLG_EXPORT_SINGLE_EDOCUMENT SYSDLG_IMPORT_EDOCUMENT SYSDLG_MULTIPLE_SELECT SYSDLG_SETUP_ACCESS_RIGHTS SYSDLG_SETUP_DEFAULT_RIGHTS SYSDLG_SETUP_FILTER_CONDITION SYSDLG_SETUP_SIGN_RIGHTS SYSDLG_SETUP_TASK_OBSERVERS SYSDLG_SETUP_TASK_ROUTE SYSDLG_SETUP_USERS_LIST SYSDLG_SIGN_EDOCUMENT SYSDLG_SIGN_MULTIPLE_EDOCUMENTS " + "SYSREF_ACCESS_RIGHTS_TYPES SYSREF_ADMINISTRATION_HISTORY SYSREF_ALL_AVAILABLE_COMPONENTS SYSREF_ALL_AVAILABLE_PRIVILEGES SYSREF_ALL_REPLICATING_COMPONENTS SYSREF_AVAILABLE_DEVELOPERS_COMPONENTS SYSREF_CALENDAR_EVENTS SYSREF_COMPONENT_TOKEN_HISTORY SYSREF_COMPONENT_TOKENS SYSREF_COMPONENTS SYSREF_CONSTANTS SYSREF_DATA_RECEIVE_PROTOCOL SYSREF_DATA_SEND_PROTOCOL SYSREF_DIALOGS SYSREF_DIALOGS_REQUISITES SYSREF_EDITORS SYSREF_EDOC_CARDS SYSREF_EDOC_TYPES SYSREF_EDOCUMENT_CARD_REQUISITES SYSREF_EDOCUMENT_CARD_TYPES SYSREF_EDOCUMENT_CARD_TYPES_REFERENCE SYSREF_EDOCUMENT_CARDS SYSREF_EDOCUMENT_HISTORY SYSREF_EDOCUMENT_KINDS SYSREF_EDOCUMENT_REQUISITES SYSREF_EDOCUMENT_SIGNATURES SYSREF_EDOCUMENT_TEMPLATES SYSREF_EDOCUMENT_TEXT_STORAGES SYSREF_EDOCUMENT_VIEWS SYSREF_FILTERER_SETUP_CONFLICTS SYSREF_FILTRATER_SETTING_CONFLICTS SYSREF_FOLDER_HISTORY SYSREF_FOLDERS SYSREF_FUNCTION_GROUPS SYSREF_FUNCTION_PARAMS SYSREF_FUNCTIONS SYSREF_JOB_HISTORY SYSREF_LINKS SYSREF_LOCALIZATION_DICTIONARY SYSREF_LOCALIZATION_LANGUAGES SYSREF_MODULES SYSREF_PRIVILEGES SYSREF_RECORD_HISTORY SYSREF_REFERENCE_REQUISITES SYSREF_REFERENCE_TYPE_VIEWS SYSREF_REFERENCE_TYPES SYSREF_REFERENCES SYSREF_REFERENCES_REQUISITES SYSREF_REMOTE_SERVERS SYSREF_REPLICATION_SESSIONS_LOG SYSREF_REPLICATION_SESSIONS_PROTOCOL SYSREF_REPORTS SYSREF_ROLES SYSREF_ROUTE_BLOCK_GROUPS SYSREF_ROUTE_BLOCKS SYSREF_SCRIPTS SYSREF_SEARCHES SYSREF_SERVER_EVENTS SYSREF_SERVER_EVENTS_HISTORY SYSREF_STANDARD_ROUTE_GROUPS SYSREF_STANDARD_ROUTES SYSREF_STATUSES SYSREF_SYSTEM_SETTINGS SYSREF_TASK_HISTORY SYSREF_TASK_KIND_GROUPS SYSREF_TASK_KINDS SYSREF_TASK_RIGHTS SYSREF_TASK_SIGNATURES SYSREF_TASKS SYSREF_UNITS SYSREF_USER_GROUPS SYSREF_USER_GROUPS_REFERENCE SYSREF_USER_SUBSTITUTION SYSREF_USERS SYSREF_USERS_REFERENCE SYSREF_VIEWERS SYSREF_WORKING_TIME_CALENDARS " + "ACCESS_RIGHTS_TABLE_NAME EDMS_ACCESS_TABLE_NAME EDOC_TYPES_TABLE_NAME " + "TEST_DEV_DB_NAME TEST_DEV_SYSTEM_CODE TEST_EDMS_DB_NAME TEST_EDMS_MAIN_CODE TEST_EDMS_MAIN_DB_NAME TEST_EDMS_SECOND_CODE TEST_EDMS_SECOND_DB_NAME TEST_EDMS_SYSTEM_CODE TEST_ISB5_MAIN_CODE TEST_ISB5_SECOND_CODE TEST_SQL_SERVER_2005_NAME TEST_SQL_SERVER_NAME " + "ATTENTION_CAPTION cbsCommandLinks cbsDefault CONFIRMATION_CAPTION ERROR_CAPTION INFORMATION_CAPTION mrCancel mrOk " + "EDOC_VERSION_ACTIVE_STAGE_CODE EDOC_VERSION_DESIGN_STAGE_CODE EDOC_VERSION_OBSOLETE_STAGE_CODE " + "cpDataEnciphermentEnabled cpDigitalSignatureEnabled cpID cpIssuer cpPluginVersion cpSerial cpSubjectName cpSubjSimpleName cpValidFromDate cpValidToDate " + "ISBL_SYNTAX NO_SYNTAX XML_SYNTAX " + "WAIT_BLOCK_AFTER_FINISH_EVENT WAIT_BLOCK_BEFORE_START_EVENT WAIT_BLOCK_DEADLINE_PROPERTY WAIT_BLOCK_IS_RELATIVE_DEADLINE_PROPERTY WAIT_BLOCK_NAME_PROPERTY WAIT_BLOCK_RELATIVE_DEADLINE_TYPE_PROPERTY " + "SYSRES_COMMON SYSRES_CONST SYSRES_MBFUNC SYSRES_SBDATA SYSRES_SBGUI SYSRES_SBINTF SYSRES_SBREFDSC SYSRES_SQLERRORS SYSRES_SYSCOMP ", sc = "atUser atGroup atRole " + "aemEnabledAlways aemDisabledAlways aemEnabledOnBrowse aemEnabledOnEdit aemDisabledOnBrowseEmpty " + "apBegin apEnd " + "alLeft alRight " + "asmNever asmNoButCustomize asmAsLastTime asmYesButCustomize asmAlways " + "cirCommon cirRevoked " + "ctSignature ctEncode ctSignatureEncode " + "clbUnchecked clbChecked clbGrayed " + "ceISB ceAlways ceNever " + "ctDocument ctReference ctScript ctUnknown ctReport ctDialog ctFunction ctFolder ctEDocument ctTask ctJob ctNotice ctControlJob " + "cfInternal cfDisplay " + "ciUnspecified ciWrite ciRead " + "ckFolder ckEDocument ckTask ckJob ckComponentToken ckAny ckReference ckScript ckReport ckDialog " + "ctISBLEditor ctBevel ctButton ctCheckListBox ctComboBox ctComboEdit ctGrid ctDBCheckBox ctDBComboBox ctDBEdit ctDBEllipsis ctDBMemo ctDBNavigator ctDBRadioGroup ctDBStatusLabel ctEdit ctGroupBox ctInplaceHint ctMemo ctPanel ctListBox ctRadioButton ctRichEdit ctTabSheet ctWebBrowser ctImage ctHyperLink ctLabel ctDBMultiEllipsis ctRibbon ctRichView ctInnerPanel ctPanelGroup ctBitButton " + "cctDate cctInteger cctNumeric cctPick cctReference cctString cctText " + "cltInternal cltPrimary cltGUI " + "dseBeforeOpen dseAfterOpen dseBeforeClose dseAfterClose dseOnValidDelete dseBeforeDelete dseAfterDelete dseAfterDeleteOutOfTransaction dseOnDeleteError dseBeforeInsert dseAfterInsert dseOnValidUpdate dseBeforeUpdate dseOnUpdateRatifiedRecord dseAfterUpdate dseAfterUpdateOutOfTransaction dseOnUpdateError dseAfterScroll dseOnOpenRecord dseOnCloseRecord dseBeforeCancel dseAfterCancel dseOnUpdateDeadlockError dseBeforeDetailUpdate dseOnPrepareUpdate dseOnAnyRequisiteChange " + "dssEdit dssInsert dssBrowse dssInActive " + "dftDate dftShortDate dftDateTime dftTimeStamp " + "dotDays dotHours dotMinutes dotSeconds " + "dtkndLocal dtkndUTC " + "arNone arView arEdit arFull " + "ddaView ddaEdit " + "emLock emEdit emSign emExportWithLock emImportWithUnlock emChangeVersionNote emOpenForModify emChangeLifeStage emDelete emCreateVersion emImport emUnlockExportedWithLock emStart emAbort emReInit emMarkAsReaded emMarkAsUnreaded emPerform emAccept emResume emChangeRights emEditRoute emEditObserver emRecoveryFromLocalCopy emChangeWorkAccessType emChangeEncodeTypeToCertificate emChangeEncodeTypeToPassword emChangeEncodeTypeToNone emChangeEncodeTypeToCertificatePassword emChangeStandardRoute emGetText emOpenForView emMoveToStorage emCreateObject emChangeVersionHidden emDeleteVersion emChangeLifeCycleStage emApprovingSign emExport emContinue emLockFromEdit emUnLockForEdit emLockForServer emUnlockFromServer emDelegateAccessRights emReEncode " + "ecotFile ecotProcess " + "eaGet eaCopy eaCreate eaCreateStandardRoute " + "edltAll edltNothing edltQuery " + "essmText essmCard " + "esvtLast esvtLastActive esvtSpecified " + "edsfExecutive edsfArchive " + "edstSQLServer edstFile " + "edvstNone edvstEDocumentVersionCopy edvstFile edvstTemplate edvstScannedFile " + "vsDefault vsDesign vsActive vsObsolete " + "etNone etCertificate etPassword etCertificatePassword " + "ecException ecWarning ecInformation " + "estAll estApprovingOnly " + "evtLast evtLastActive evtQuery " + "fdtString fdtNumeric fdtInteger fdtDate fdtText fdtUnknown fdtWideString fdtLargeInteger " + "ftInbox ftOutbox ftFavorites ftCommonFolder ftUserFolder ftComponents ftQuickLaunch ftShortcuts ftSearch " + "grhAuto grhX1 grhX2 grhX3 " + "hltText hltRTF hltHTML " + "iffBMP iffJPEG iffMultiPageTIFF iffSinglePageTIFF iffTIFF iffPNG " + "im8bGrayscale im24bRGB im1bMonochrome " + "itBMP itJPEG itWMF itPNG " + "ikhInformation ikhWarning ikhError ikhNoIcon " + "icUnknown icScript icFunction icIntegratedReport icAnalyticReport icDataSetEventHandler icActionHandler icFormEventHandler icLookUpEventHandler icRequisiteChangeEventHandler icBeforeSearchEventHandler icRoleCalculation icSelectRouteEventHandler icBlockPropertyCalculation icBlockQueryParamsEventHandler icChangeSearchResultEventHandler icBlockEventHandler icSubTaskInitEventHandler icEDocDataSetEventHandler icEDocLookUpEventHandler icEDocActionHandler icEDocFormEventHandler icEDocRequisiteChangeEventHandler icStructuredConversionRule icStructuredConversionEventBefore icStructuredConversionEventAfter icWizardEventHandler icWizardFinishEventHandler icWizardStepEventHandler icWizardStepFinishEventHandler icWizardActionEnableEventHandler icWizardActionExecuteEventHandler icCreateJobsHandler icCreateNoticesHandler icBeforeLookUpEventHandler icAfterLookUpEventHandler icTaskAbortEventHandler icWorkflowBlockActionHandler icDialogDataSetEventHandler icDialogActionHandler icDialogLookUpEventHandler icDialogRequisiteChangeEventHandler icDialogFormEventHandler icDialogValidCloseEventHandler icBlockFormEventHandler icTaskFormEventHandler icReferenceMethod icEDocMethod icDialogMethod icProcessMessageHandler " + "isShow isHide isByUserSettings " + "jkJob jkNotice jkControlJob " + "jtInner jtLeft jtRight jtFull jtCross " + "lbpAbove lbpBelow lbpLeft lbpRight " + "eltPerConnection eltPerUser " + "sfcUndefined sfcBlack sfcGreen sfcRed sfcBlue sfcOrange sfcLilac " + "sfsItalic sfsStrikeout sfsNormal " + "ldctStandardRoute ldctWizard ldctScript ldctFunction ldctRouteBlock ldctIntegratedReport ldctAnalyticReport ldctReferenceType ldctEDocumentType ldctDialog ldctServerEvents " + "mrcrtNone mrcrtUser mrcrtMaximal mrcrtCustom " + "vtEqual vtGreaterOrEqual vtLessOrEqual vtRange " + "rdYesterday rdToday rdTomorrow rdThisWeek rdThisMonth rdThisYear rdNextMonth rdNextWeek rdLastWeek rdLastMonth " + "rdWindow rdFile rdPrinter " + "rdtString rdtNumeric rdtInteger rdtDate rdtReference rdtAccount rdtText rdtPick rdtUnknown rdtLargeInteger rdtDocument " + "reOnChange reOnChangeValues " + "ttGlobal ttLocal ttUser ttSystem " + "ssmBrowse ssmSelect ssmMultiSelect ssmBrowseModal " + "smSelect smLike smCard " + "stNone stAuthenticating stApproving " + "sctString sctStream " + "sstAnsiSort sstNaturalSort " + "svtEqual svtContain " + "soatString soatNumeric soatInteger soatDatetime soatReferenceRecord soatText soatPick soatBoolean soatEDocument soatAccount soatIntegerCollection soatNumericCollection soatStringCollection soatPickCollection soatDatetimeCollection soatBooleanCollection soatReferenceRecordCollection soatEDocumentCollection soatAccountCollection soatContents soatUnknown " + "tarAbortByUser tarAbortByWorkflowException " + "tvtAllWords tvtExactPhrase tvtAnyWord " + "usNone usCompleted usRedSquare usBlueSquare usYellowSquare usGreenSquare usOrangeSquare usPurpleSquare usFollowUp " + "utUnknown utUser utDeveloper utAdministrator utSystemDeveloper utDisconnected " + "btAnd btDetailAnd btOr btNotOr btOnly " + "vmView vmSelect vmNavigation " + "vsmSingle vsmMultiple vsmMultipleCheck vsmNoSelection " + "wfatPrevious wfatNext wfatCancel wfatFinish " + "wfepUndefined wfepText3 wfepText6 wfepText9 wfepSpinEdit wfepDropDown wfepRadioGroup wfepFlag wfepText12 wfepText15 wfepText18 wfepText21 wfepText24 wfepText27 wfepText30 wfepRadioGroupColumn1 wfepRadioGroupColumn2 wfepRadioGroupColumn3 " + "wfetQueryParameter wfetText wfetDelimiter wfetLabel " + "wptString wptInteger wptNumeric wptBoolean wptDateTime wptPick wptText wptUser wptUserList wptEDocumentInfo wptEDocumentInfoList wptReferenceRecordInfo wptReferenceRecordInfoList wptFolderInfo wptTaskInfo wptContents wptFileName wptDate " + "wsrComplete wsrGoNext wsrGoPrevious wsrCustom wsrCancel wsrGoFinal " + "wstForm wstEDocument wstTaskCard wstReferenceRecordCard wstFinal " + "waAll waPerformers waManual " + "wsbStart wsbFinish wsbNotice wsbStep wsbDecision wsbWait wsbMonitor wsbScript wsbConnector wsbSubTask wsbLifeCycleStage wsbPause " + "wdtInteger wdtFloat wdtString wdtPick wdtDateTime wdtBoolean wdtTask wdtJob wdtFolder wdtEDocument wdtReferenceRecord wdtUser wdtGroup wdtRole wdtIntegerCollection wdtFloatCollection wdtStringCollection wdtPickCollection wdtDateTimeCollection wdtBooleanCollection wdtTaskCollection wdtJobCollection wdtFolderCollection wdtEDocumentCollection wdtReferenceRecordCollection wdtUserCollection wdtGroupCollection wdtRoleCollection wdtContents wdtUserList wdtSearchDescription wdtDeadLine wdtPickSet wdtAccountCollection " + "wiLow wiNormal wiHigh " + "wrtSoft wrtHard " + "wsInit wsRunning wsDone wsControlled wsAborted wsContinued " + "wtmFull wtmFromCurrent wtmOnlyCurrent ", Xl = "AddSubString AdjustLineBreaks AmountInWords Analysis ArrayDimCount ArrayHighBound ArrayLowBound ArrayOf ArrayReDim Assert Assigned BeginOfMonth BeginOfPeriod BuildProfilingOperationAnalysis CallProcedure CanReadFile CArrayElement CDataSetRequisite ChangeDate ChangeReferenceDataset Char CharPos CheckParam CheckParamValue CompareStrings ConstantExists ControlState ConvertDateStr Copy CopyFile CreateArray CreateCachedReference CreateConnection CreateDialog CreateDualListDialog CreateEditor CreateException CreateFile CreateFolderDialog CreateInputDialog CreateLinkFile CreateList CreateLock CreateMemoryDataSet CreateObject CreateOpenDialog CreateProgress CreateQuery CreateReference CreateReport CreateSaveDialog CreateScript CreateSQLPivotFunction CreateStringList CreateTreeListSelectDialog CSelectSQL CSQL CSubString CurrentUserID CurrentUserName CurrentVersion DataSetLocateEx DateDiff DateTimeDiff DateToStr DayOfWeek DeleteFile DirectoryExists DisableCheckAccessRights DisableCheckFullShowingRestriction DisableMassTaskSendingRestrictions DropTable DupeString EditText EnableCheckAccessRights EnableCheckFullShowingRestriction EnableMassTaskSendingRestrictions EndOfMonth EndOfPeriod ExceptionExists ExceptionsOff ExceptionsOn Execute ExecuteProcess Exit ExpandEnvironmentVariables ExtractFileDrive ExtractFileExt ExtractFileName ExtractFilePath ExtractParams FileExists FileSize FindFile FindSubString FirmContext ForceDirectories Format FormatDate FormatNumeric FormatSQLDate FormatString FreeException GetComponent GetComponentLaunchParam GetConstant GetLastException GetReferenceRecord GetRefTypeByRefID GetTableID GetTempFolder IfThen In IndexOf InputDialog InputDialogEx InteractiveMode IsFileLocked IsGraphicFile IsNumeric Length LoadString LoadStringFmt LocalTimeToUTC LowerCase Max MessageBox MessageBoxEx MimeDecodeBinary MimeDecodeString MimeEncodeBinary MimeEncodeString Min MoneyInWords MoveFile NewID Now OpenFile Ord Precision Raise ReadCertificateFromFile ReadFile ReferenceCodeByID ReferenceNumber ReferenceRequisiteMode ReferenceRequisiteValue RegionDateSettings RegionNumberSettings RegionTimeSettings RegRead RegWrite RenameFile Replace Round SelectServerCode SelectSQL ServerDateTime SetConstant SetManagedFolderFieldsState ShowConstantsInputDialog ShowMessage Sleep Split SQL SQL2XLSTAB SQLProfilingSendReport StrToDate SubString SubStringCount SystemSetting Time TimeDiff Today Transliterate Trim UpperCase UserStatus UTCToLocalTime ValidateXML VarIsClear VarIsEmpty VarIsNull WorkTimeDiff WriteFile WriteFileEx WriteObjectHistory Анализ БазаДанных БлокЕсть БлокЕстьРасш БлокИнфо БлокСнять БлокСнятьРасш БлокУстановить Ввод ВводМеню ВедС ВедСпр ВерхняяГраницаМассива ВнешПрогр Восст ВременнаяПапка Время ВыборSQL ВыбратьЗапись ВыделитьСтр Вызвать Выполнить ВыпПрогр ГрафическийФайл ГруппаДополнительно ДатаВремяСерв ДеньНедели ДиалогДаНет ДлинаСтр ДобПодстр ЕПусто ЕслиТо ЕЧисло ЗамПодстр ЗаписьСправочника ЗначПоляСпр ИДТипСпр ИзвлечьДиск ИзвлечьИмяФайла ИзвлечьПуть ИзвлечьРасширение ИзмДат ИзменитьРазмерМассива ИзмеренийМассива ИмяОрг ИмяПоляСпр Индекс ИндикаторЗакрыть ИндикаторОткрыть ИндикаторШаг ИнтерактивныйРежим ИтогТблСпр КодВидВедСпр КодВидСпрПоИД КодПоAnalit КодСимвола КодСпр КолПодстр КолПроп КонМес Конст КонстЕсть КонстЗнач КонТран КопироватьФайл КопияСтр КПериод КСтрТблСпр Макс МаксСтрТблСпр Массив Меню МенюРасш Мин НаборДанныхНайтиРасш НаимВидСпр НаимПоAnalit НаимСпр НастроитьПереводыСтрок НачМес НачТран НижняяГраницаМассива НомерСпр НПериод Окно Окр Окружение ОтлИнфДобавить ОтлИнфУдалить Отчет ОтчетАнал ОтчетИнт ПапкаСуществует Пауза ПВыборSQL ПереименоватьФайл Переменные ПереместитьФайл Подстр ПоискПодстр ПоискСтр ПолучитьИДТаблицы ПользовательДополнительно ПользовательИД ПользовательИмя ПользовательСтатус Прервать ПроверитьПараметр ПроверитьПараметрЗнач ПроверитьУсловие РазбСтр РазнВремя РазнДат РазнДатаВремя РазнРабВремя РегУстВрем РегУстДат РегУстЧсл РедТекст РеестрЗапись РеестрСписокИменПарам РеестрЧтение РеквСпр РеквСпрПр Сегодня Сейчас Сервер СерверПроцессИД СертификатФайлСчитать СжПроб Символ СистемаДиректумКод СистемаИнформация СистемаКод Содержит СоединениеЗакрыть СоединениеОткрыть СоздатьДиалог СоздатьДиалогВыбораИзДвухСписков СоздатьДиалогВыбораПапки СоздатьДиалогОткрытияФайла СоздатьДиалогСохраненияФайла СоздатьЗапрос СоздатьИндикатор СоздатьИсключение СоздатьКэшированныйСправочник СоздатьМассив СоздатьНаборДанных СоздатьОбъект СоздатьОтчет СоздатьПапку СоздатьРедактор СоздатьСоединение СоздатьСписок СоздатьСписокСтрок СоздатьСправочник СоздатьСценарий СоздСпр СостСпр Сохр СохрСпр СписокСистем Спр Справочник СпрБлокЕсть СпрБлокСнять СпрБлокСнятьРасш СпрБлокУстановить СпрИзмНабДан СпрКод СпрНомер СпрОбновить СпрОткрыть СпрОтменить СпрПарам СпрПолеЗнач СпрПолеИмя СпрРекв СпрРеквВведЗн СпрРеквНовые СпрРеквПр СпрРеквПредЗн СпрРеквРежим СпрРеквТипТекст СпрСоздать СпрСост СпрСохранить СпрТблИтог СпрТблСтр СпрТблСтрКол СпрТблСтрМакс СпрТблСтрМин СпрТблСтрПред СпрТблСтрСлед СпрТблСтрСозд СпрТблСтрУд СпрТекПредст СпрУдалить СравнитьСтр СтрВерхРегистр СтрНижнРегистр СтрТблСпр СумПроп Сценарий СценарийПарам ТекВерсия ТекОрг Точн Тран Транслитерация УдалитьТаблицу УдалитьФайл УдСпр УдСтрТблСпр Уст УстановкиКонстант ФайлАтрибутСчитать ФайлАтрибутУстановить ФайлВремя ФайлВремяУстановить ФайлВыбрать ФайлЗанят ФайлЗаписать ФайлИскать ФайлКопировать ФайлМожноЧитать ФайлОткрыть ФайлПереименовать ФайлПерекодировать ФайлПереместить ФайлПросмотреть ФайлРазмер ФайлСоздать ФайлСсылкаСоздать ФайлСуществует ФайлСчитать ФайлУдалить ФмтSQLДат ФмтДат ФмтСтр ФмтЧсл Формат ЦМассивЭлемент ЦНаборДанныхРеквизит ЦПодстр ", Zl = "AltState Application CallType ComponentTokens CreatedJobs CreatedNotices ControlState DialogResult Dialogs EDocuments EDocumentVersionSource Folders GlobalIDs Job Jobs InputValue LookUpReference LookUpRequisiteNames LookUpSearch Object ParentComponent Processes References Requisite ReportName Reports Result Scripts Searches SelectedAttachments SelectedItems SelectMode Sender ServerEvents ServiceFactory ShiftState SubTask SystemDialogs Tasks Wizard Wizards Work ВызовСпособ ИмяОтчета РеквЗнач ", Jl = "IApplication IAccessRights IAccountRepository IAccountSelectionRestrictions IAction IActionList IAdministrationHistoryDescription IAnchors IApplication IArchiveInfo IAttachment IAttachmentList ICheckListBox ICheckPointedList IColumn IComponent IComponentDescription IComponentToken IComponentTokenFactory IComponentTokenInfo ICompRecordInfo IConnection IContents IControl IControlJob IControlJobInfo IControlList ICrypto ICrypto2 ICustomJob ICustomJobInfo ICustomListBox ICustomObjectWizardStep ICustomWork ICustomWorkInfo IDataSet IDataSetAccessInfo IDataSigner IDateCriterion IDateRequisite IDateRequisiteDescription IDateValue IDeaAccessRights IDeaObjectInfo IDevelopmentComponentLock IDialog IDialogFactory IDialogPickRequisiteItems IDialogsFactory IDICSFactory IDocRequisite IDocumentInfo IDualListDialog IECertificate IECertificateInfo IECertificates IEditControl IEditorForm IEdmsExplorer IEdmsObject IEdmsObjectDescription IEdmsObjectFactory IEdmsObjectInfo IEDocument IEDocumentAccessRights IEDocumentDescription IEDocumentEditor IEDocumentFactory IEDocumentInfo IEDocumentStorage IEDocumentVersion IEDocumentVersionListDialog IEDocumentVersionSource IEDocumentWizardStep IEDocVerSignature IEDocVersionState IEnabledMode IEncodeProvider IEncrypter IEvent IEventList IException IExternalEvents IExternalHandler IFactory IField IFileDialog IFolder IFolderDescription IFolderDialog IFolderFactory IFolderInfo IForEach IForm IFormTitle IFormWizardStep IGlobalIDFactory IGlobalIDInfo IGrid IHasher IHistoryDescription IHyperLinkControl IImageButton IImageControl IInnerPanel IInplaceHint IIntegerCriterion IIntegerList IIntegerRequisite IIntegerValue IISBLEditorForm IJob IJobDescription IJobFactory IJobForm IJobInfo ILabelControl ILargeIntegerCriterion ILargeIntegerRequisite ILargeIntegerValue ILicenseInfo ILifeCycleStage IList IListBox ILocalIDInfo ILocalization ILock IMemoryDataSet IMessagingFactory IMetadataRepository INotice INoticeInfo INumericCriterion INumericRequisite INumericValue IObject IObjectDescription IObjectImporter IObjectInfo IObserver IPanelGroup IPickCriterion IPickProperty IPickRequisite IPickRequisiteDescription IPickRequisiteItem IPickRequisiteItems IPickValue IPrivilege IPrivilegeList IProcess IProcessFactory IProcessMessage IProgress IProperty IPropertyChangeEvent IQuery IReference IReferenceCriterion IReferenceEnabledMode IReferenceFactory IReferenceHistoryDescription IReferenceInfo IReferenceRecordCardWizardStep IReferenceRequisiteDescription IReferencesFactory IReferenceValue IRefRequisite IReport IReportFactory IRequisite IRequisiteDescription IRequisiteDescriptionList IRequisiteFactory IRichEdit IRouteStep IRule IRuleList ISchemeBlock IScript IScriptFactory ISearchCriteria ISearchCriterion ISearchDescription ISearchFactory ISearchFolderInfo ISearchForObjectDescription ISearchResultRestrictions ISecuredContext ISelectDialog IServerEvent IServerEventFactory IServiceDialog IServiceFactory ISignature ISignProvider ISignProvider2 ISignProvider3 ISimpleCriterion IStringCriterion IStringList IStringRequisite IStringRequisiteDescription IStringValue ISystemDialogsFactory ISystemInfo ITabSheet ITask ITaskAbortReasonInfo ITaskCardWizardStep ITaskDescription ITaskFactory ITaskInfo ITaskRoute ITextCriterion ITextRequisite ITextValue ITreeListSelectDialog IUser IUserList IValue IView IWebBrowserControl IWizard IWizardAction IWizardFactory IWizardFormElement IWizardParam IWizardPickParam IWizardReferenceParam IWizardStep IWorkAccessRights IWorkDescription IWorkflowAskableParam IWorkflowAskableParams IWorkflowBlock IWorkflowBlockResult IWorkflowEnabledMode IWorkflowParam IWorkflowPickParam IWorkflowReferenceParam IWorkState IWorkTreeCustomNode IWorkTreeJobNode IWorkTreeTaskNode IXMLEditorForm SBCrypto ", Do = oe + sc, lc = Zl, uc = "null true false nil ", eu = {
      className: "number",
      begin: t.NUMBER_RE,
      relevance: 0
    }, nl = {
      className: "string",
      variants: [
        {
          begin: '"',
          end: '"'
        },
        {
          begin: "'",
          end: "'"
        }
      ]
    }, rl = {
      className: "doctag",
      begin: "\\b(?:TODO|DONE|BEGIN|END|STUB|CHG|FIXME|NOTE|BUG|XXX)\\b",
      relevance: 0
    }, tu = {
      className: "comment",
      begin: "//",
      end: "$",
      relevance: 0,
      contains: [
        t.PHRASAL_WORDS_MODE,
        rl
      ]
    }, nu = {
      className: "comment",
      begin: "/\\*",
      end: "\\*/",
      relevance: 0,
      contains: [
        t.PHRASAL_WORDS_MODE,
        rl
      ]
    }, cc = { variants: [
      tu,
      nu
    ] }, il = {
      $pattern: n,
      keyword: i,
      built_in: Do,
      class: lc,
      literal: uc
    }, ru = {
      begin: "\\.\\s*" + t.UNDERSCORE_IDENT_RE,
      keywords: il,
      relevance: 0
    }, iu = {
      className: "type",
      begin: ":[ \\t]*(" + Jl.trim().replace(/\s/g, "|") + ")",
      end: "[ \\t]*=",
      excludeEnd: !0
    }, al = {
      className: "variable",
      keywords: il,
      begin: n,
      relevance: 0,
      contains: [
        iu,
        ru
      ]
    }, dc = r + "\\(";
    return {
      name: "ISBL",
      case_insensitive: !0,
      keywords: il,
      illegal: "\\$|\\?|%|,|;$|~|#|@|</",
      contains: [
        {
          className: "function",
          begin: dc,
          end: "\\)$",
          returnBegin: !0,
          keywords: il,
          illegal: "[\\[\\]\\|\\$\\?%,~#@]",
          contains: [
            {
              className: "title",
              keywords: {
                $pattern: n,
                built_in: Xl
              },
              begin: dc,
              end: "\\(",
              returnBegin: !0,
              excludeEnd: !0
            },
            ru,
            al,
            nl,
            eu,
            cc
          ]
        },
        iu,
        ru,
        al,
        nl,
        eu,
        cc
      ]
    };
  }
  return KE = e, KE;
}
var jE, nI;
function cJ() {
  if (nI) return jE;
  nI = 1;
  var e = "[0-9](_*[0-9])*", t = `\\.(${e})`, n = "[0-9a-fA-F](_*[0-9a-fA-F])*", r = {
    className: "number",
    variants: [
      // DecimalFloatingPointLiteral
      // including ExponentPart
      { begin: `(\\b(${e})((${t})|\\.)?|(${t}))[eE][+-]?(${e})[fFdD]?\\b` },
      // excluding ExponentPart
      { begin: `\\b(${e})((${t})[fFdD]?\\b|\\.([fFdD]\\b)?)` },
      { begin: `(${t})[fFdD]?\\b` },
      { begin: `\\b(${e})[fFdD]\\b` },
      // HexadecimalFloatingPointLiteral
      { begin: `\\b0[xX]((${n})\\.?|(${n})?\\.(${n}))[pP][+-]?(${e})[fFdD]?\\b` },
      // DecimalIntegerLiteral
      { begin: "\\b(0|[1-9](_*[0-9])*)[lL]?\\b" },
      // HexIntegerLiteral
      { begin: `\\b0[xX](${n})[lL]?\\b` },
      // OctalIntegerLiteral
      { begin: "\\b0(_*[0-7])*[lL]?\\b" },
      // BinaryIntegerLiteral
      { begin: "\\b0[bB][01](_*[01])*[lL]?\\b" }
    ],
    relevance: 0
  };
  function i(o, s, l) {
    return l === -1 ? "" : o.replace(s, (u) => i(o, s, l - 1));
  }
  function a(o) {
    const s = o.regex, l = "[À-ʸa-zA-Z_$][À-ʸa-zA-Z_$0-9]*", u = l + i("(?:<" + l + "~~~(?:\\s*,\\s*" + l + "~~~)*>)?", /~~~/g, 2), m = {
      keyword: [
        "synchronized",
        "abstract",
        "private",
        "var",
        "static",
        "if",
        "const ",
        "for",
        "while",
        "strictfp",
        "finally",
        "protected",
        "import",
        "native",
        "final",
        "void",
        "enum",
        "else",
        "break",
        "transient",
        "catch",
        "instanceof",
        "volatile",
        "case",
        "assert",
        "package",
        "default",
        "public",
        "try",
        "switch",
        "continue",
        "throws",
        "protected",
        "public",
        "private",
        "module",
        "requires",
        "exports",
        "do",
        "sealed",
        "yield",
        "permits"
      ],
      literal: [
        "false",
        "true",
        "null"
      ],
      type: [
        "char",
        "boolean",
        "long",
        "float",
        "int",
        "byte",
        "short",
        "double"
      ],
      built_in: [
        "super",
        "this"
      ]
    }, v = {
      className: "meta",
      begin: "@" + l,
      contains: [
        {
          begin: /\(/,
          end: /\)/,
          contains: ["self"]
          // allow nested () inside our annotation
        }
      ]
    }, b = {
      className: "params",
      begin: /\(/,
      end: /\)/,
      keywords: m,
      relevance: 0,
      contains: [o.C_BLOCK_COMMENT_MODE],
      endsParent: !0
    };
    return {
      name: "Java",
      aliases: ["jsp"],
      keywords: m,
      illegal: /<\/|#/,
      contains: [
        o.COMMENT(
          "/\\*\\*",
          "\\*/",
          {
            relevance: 0,
            contains: [
              {
                // eat up @'s in emails to prevent them to be recognized as doctags
                begin: /\w+@/,
                relevance: 0
              },
              {
                className: "doctag",
                begin: "@[A-Za-z]+"
              }
            ]
          }
        ),
        // relevance boost
        {
          begin: /import java\.[a-z]+\./,
          keywords: "import",
          relevance: 2
        },
        o.C_LINE_COMMENT_MODE,
        o.C_BLOCK_COMMENT_MODE,
        {
          begin: /"""/,
          end: /"""/,
          className: "string",
          contains: [o.BACKSLASH_ESCAPE]
        },
        o.APOS_STRING_MODE,
        o.QUOTE_STRING_MODE,
        {
          match: [
            /\b(?:class|interface|enum|extends|implements|new)/,
            /\s+/,
            l
          ],
          className: {
            1: "keyword",
            3: "title.class"
          }
        },
        {
          // Exceptions for hyphenated keywords
          match: /non-sealed/,
          scope: "keyword"
        },
        {
          begin: [
            s.concat(/(?!else)/, l),
            /\s+/,
            l,
            /\s+/,
            /=(?!=)/
          ],
          className: {
            1: "type",
            3: "variable",
            5: "operator"
          }
        },
        {
          begin: [
            /record/,
            /\s+/,
            l
          ],
          className: {
            1: "keyword",
            3: "title.class"
          },
          contains: [
            b,
            o.C_LINE_COMMENT_MODE,
            o.C_BLOCK_COMMENT_MODE
          ]
        },
        {
          // Expression keywords prevent 'keyword Name(...)' from being
          // recognized as a function definition
          beginKeywords: "new throw return else",
          relevance: 0
        },
        {
          begin: [
            "(?:" + u + "\\s+)",
            o.UNDERSCORE_IDENT_RE,
            /\s*(?=\()/
          ],
          className: { 2: "title.function" },
          keywords: m,
          contains: [
            {
              className: "params",
              begin: /\(/,
              end: /\)/,
              keywords: m,
              relevance: 0,
              contains: [
                v,
                o.APOS_STRING_MODE,
                o.QUOTE_STRING_MODE,
                r,
                o.C_BLOCK_COMMENT_MODE
              ]
            },
            o.C_LINE_COMMENT_MODE,
            o.C_BLOCK_COMMENT_MODE
          ]
        },
        r,
        v
      ]
    };
  }
  return jE = a, jE;
}
var QE, rI;
function dJ() {
  if (rI) return QE;
  rI = 1;
  const e = "[A-Za-z$_][0-9A-Za-z$_]*", t = [
    "as",
    // for exports
    "in",
    "of",
    "if",
    "for",
    "while",
    "finally",
    "var",
    "new",
    "function",
    "do",
    "return",
    "void",
    "else",
    "break",
    "catch",
    "instanceof",
    "with",
    "throw",
    "case",
    "default",
    "try",
    "switch",
    "continue",
    "typeof",
    "delete",
    "let",
    "yield",
    "const",
    "class",
    // JS handles these with a special rule
    // "get",
    // "set",
    "debugger",
    "async",
    "await",
    "static",
    "import",
    "from",
    "export",
    "extends"
  ], n = [
    "true",
    "false",
    "null",
    "undefined",
    "NaN",
    "Infinity"
  ], r = [
    // Fundamental objects
    "Object",
    "Function",
    "Boolean",
    "Symbol",
    // numbers and dates
    "Math",
    "Date",
    "Number",
    "BigInt",
    // text
    "String",
    "RegExp",
    // Indexed collections
    "Array",
    "Float32Array",
    "Float64Array",
    "Int8Array",
    "Uint8Array",
    "Uint8ClampedArray",
    "Int16Array",
    "Int32Array",
    "Uint16Array",
    "Uint32Array",
    "BigInt64Array",
    "BigUint64Array",
    // Keyed collections
    "Set",
    "Map",
    "WeakSet",
    "WeakMap",
    // Structured data
    "ArrayBuffer",
    "SharedArrayBuffer",
    "Atomics",
    "DataView",
    "JSON",
    // Control abstraction objects
    "Promise",
    "Generator",
    "GeneratorFunction",
    "AsyncFunction",
    // Reflection
    "Reflect",
    "Proxy",
    // Internationalization
    "Intl",
    // WebAssembly
    "WebAssembly"
  ], i = [
    "Error",
    "EvalError",
    "InternalError",
    "RangeError",
    "ReferenceError",
    "SyntaxError",
    "TypeError",
    "URIError"
  ], a = [
    "setInterval",
    "setTimeout",
    "clearInterval",
    "clearTimeout",
    "require",
    "exports",
    "eval",
    "isFinite",
    "isNaN",
    "parseFloat",
    "parseInt",
    "decodeURI",
    "decodeURIComponent",
    "encodeURI",
    "encodeURIComponent",
    "escape",
    "unescape"
  ], o = [
    "arguments",
    "this",
    "super",
    "console",
    "window",
    "document",
    "localStorage",
    "sessionStorage",
    "module",
    "global"
    // Node.js
  ], s = [].concat(
    a,
    r,
    i
  );
  function l(u) {
    const c = u.regex, d = (pe, { after: Se }) => {
      const Re = "</" + pe[0].slice(1);
      return pe.input.indexOf(Re, Se) !== -1;
    }, f = e, h = {
      begin: "<>",
      end: "</>"
    }, m = /<[A-Za-z0-9\\._:-]+\s*\/>/, v = {
      begin: /<[A-Za-z0-9\\._:-]+/,
      end: /\/[A-Za-z0-9\\._:-]+>|\/>/,
      /**
       * @param {RegExpMatchArray} match
       * @param {CallbackResponse} response
       */
      isTrulyOpeningTag: (pe, Se) => {
        const Re = pe[0].length + pe.index, Ye = pe.input[Re];
        if (
          // HTML should not include another raw `<` inside a tag
          // nested type?
          // `<Array<Array<number>>`, etc.
          Ye === "<" || // the , gives away that this is not HTML
          // `<T, A extends keyof T, V>`
          Ye === ","
        ) {
          Se.ignoreMatch();
          return;
        }
        Ye === ">" && (d(pe, { after: Re }) || Se.ignoreMatch());
        let nt;
        const ut = pe.input.substring(Re);
        if (nt = ut.match(/^\s*=/)) {
          Se.ignoreMatch();
          return;
        }
        if ((nt = ut.match(/^\s+extends\s+/)) && nt.index === 0) {
          Se.ignoreMatch();
          return;
        }
      }
    }, b = {
      $pattern: e,
      keyword: t,
      literal: n,
      built_in: s,
      "variable.language": o
    }, y = "[0-9](_?[0-9])*", g = `\\.(${y})`, E = "0|[1-9](_?[0-9])*|0[0-7]*[89][0-9]*", S = {
      className: "number",
      variants: [
        // DecimalLiteral
        { begin: `(\\b(${E})((${g})|\\.)?|(${g}))[eE][+-]?(${y})\\b` },
        { begin: `\\b(${E})\\b((${g})\\b|\\.)?|(${g})\\b` },
        // DecimalBigIntegerLiteral
        { begin: "\\b(0|[1-9](_?[0-9])*)n\\b" },
        // NonDecimalIntegerLiteral
        { begin: "\\b0[xX][0-9a-fA-F](_?[0-9a-fA-F])*n?\\b" },
        { begin: "\\b0[bB][0-1](_?[0-1])*n?\\b" },
        { begin: "\\b0[oO][0-7](_?[0-7])*n?\\b" },
        // LegacyOctalIntegerLiteral (does not include underscore separators)
        // https://tc39.es/ecma262/#sec-additional-syntax-numeric-literals
        { begin: "\\b0[0-7]+n?\\b" }
      ],
      relevance: 0
    }, C = {
      className: "subst",
      begin: "\\$\\{",
      end: "\\}",
      keywords: b,
      contains: []
      // defined later
    }, T = {
      begin: "html`",
      end: "",
      starts: {
        end: "`",
        returnEnd: !1,
        contains: [
          u.BACKSLASH_ESCAPE,
          C
        ],
        subLanguage: "xml"
      }
    }, O = {
      begin: "css`",
      end: "",
      starts: {
        end: "`",
        returnEnd: !1,
        contains: [
          u.BACKSLASH_ESCAPE,
          C
        ],
        subLanguage: "css"
      }
    }, R = {
      begin: "gql`",
      end: "",
      starts: {
        end: "`",
        returnEnd: !1,
        contains: [
          u.BACKSLASH_ESCAPE,
          C
        ],
        subLanguage: "graphql"
      }
    }, D = {
      className: "string",
      begin: "`",
      end: "`",
      contains: [
        u.BACKSLASH_ESCAPE,
        C
      ]
    }, $ = {
      className: "comment",
      variants: [
        u.COMMENT(
          /\/\*\*(?!\/)/,
          "\\*/",
          {
            relevance: 0,
            contains: [
              {
                begin: "(?=@[A-Za-z]+)",
                relevance: 0,
                contains: [
                  {
                    className: "doctag",
                    begin: "@[A-Za-z]+"
                  },
                  {
                    className: "type",
                    begin: "\\{",
                    end: "\\}",
                    excludeEnd: !0,
                    excludeBegin: !0,
                    relevance: 0
                  },
                  {
                    className: "variable",
                    begin: f + "(?=\\s*(-)|$)",
                    endsParent: !0,
                    relevance: 0
                  },
                  // eat spaces (not newlines) so we can find
                  // types or variables
                  {
                    begin: /(?=[^\n])\s/,
                    relevance: 0
                  }
                ]
              }
            ]
          }
        ),
        u.C_BLOCK_COMMENT_MODE,
        u.C_LINE_COMMENT_MODE
      ]
    }, P = [
      u.APOS_STRING_MODE,
      u.QUOTE_STRING_MODE,
      T,
      O,
      R,
      D,
      // Skip numbers when they are part of a variable name
      { match: /\$\d+/ },
      S
      // This is intentional:
      // See https://github.com/highlightjs/highlight.js/issues/3288
      // hljs.REGEXP_MODE
    ];
    C.contains = P.concat({
      // we need to pair up {} inside our subst to prevent
      // it from ending too early by matching another }
      begin: /\{/,
      end: /\}/,
      keywords: b,
      contains: [
        "self"
      ].concat(P)
    });
    const Y = [].concat($, C.contains), L = Y.concat([
      // eat recursive parens in sub expressions
      {
        begin: /\(/,
        end: /\)/,
        keywords: b,
        contains: ["self"].concat(Y)
      }
    ]), x = {
      className: "params",
      begin: /\(/,
      end: /\)/,
      excludeBegin: !0,
      excludeEnd: !0,
      keywords: b,
      contains: L
    }, I = {
      variants: [
        // class Car extends vehicle
        {
          match: [
            /class/,
            /\s+/,
            f,
            /\s+/,
            /extends/,
            /\s+/,
            c.concat(f, "(", c.concat(/\./, f), ")*")
          ],
          scope: {
            1: "keyword",
            3: "title.class",
            5: "keyword",
            7: "title.class.inherited"
          }
        },
        // class Car
        {
          match: [
            /class/,
            /\s+/,
            f
          ],
          scope: {
            1: "keyword",
            3: "title.class"
          }
        }
      ]
    }, k = {
      relevance: 0,
      match: c.either(
        // Hard coded exceptions
        /\bJSON/,
        // Float32Array, OutT
        /\b[A-Z][a-z]+([A-Z][a-z]*|\d)*/,
        // CSSFactory, CSSFactoryT
        /\b[A-Z]{2,}([A-Z][a-z]+|\d)+([A-Z][a-z]*)*/,
        // FPs, FPsT
        /\b[A-Z]{2,}[a-z]+([A-Z][a-z]+|\d)*([A-Z][a-z]*)*/
        // P
        // single letters are not highlighted
        // BLAH
        // this will be flagged as a UPPER_CASE_CONSTANT instead
      ),
      className: "title.class",
      keywords: {
        _: [
          // se we still get relevance credit for JS library classes
          ...r,
          ...i
        ]
      }
    }, B = {
      label: "use_strict",
      className: "meta",
      relevance: 10,
      begin: /^\s*['"]use (strict|asm)['"]/
    }, W = {
      variants: [
        {
          match: [
            /function/,
            /\s+/,
            f,
            /(?=\s*\()/
          ]
        },
        // anonymous function
        {
          match: [
            /function/,
            /\s*(?=\()/
          ]
        }
      ],
      className: {
        1: "keyword",
        3: "title.function"
      },
      label: "func.def",
      contains: [x],
      illegal: /%/
    }, Z = {
      relevance: 0,
      match: /\b[A-Z][A-Z_0-9]+\b/,
      className: "variable.constant"
    };
    function V(pe) {
      return c.concat("(?!", pe.join("|"), ")");
    }
    const K = {
      match: c.concat(
        /\b/,
        V([
          ...a,
          "super",
          "import"
        ]),
        f,
        c.lookahead(/\(/)
      ),
      className: "title.function",
      relevance: 0
    }, ne = {
      begin: c.concat(/\./, c.lookahead(
        c.concat(f, /(?![0-9A-Za-z$_(])/)
      )),
      end: f,
      excludeBegin: !0,
      keywords: "prototype",
      className: "property",
      relevance: 0
    }, Ee = {
      match: [
        /get|set/,
        /\s+/,
        f,
        /(?=\()/
      ],
      className: {
        1: "keyword",
        3: "title.function"
      },
      contains: [
        {
          // eat to avoid empty params
          begin: /\(\)/
        },
        x
      ]
    }, oe = "(\\([^()]*(\\([^()]*(\\([^()]*\\)[^()]*)*\\)[^()]*)*\\)|" + u.UNDERSCORE_IDENT_RE + ")\\s*=>", ae = {
      match: [
        /const|var|let/,
        /\s+/,
        f,
        /\s*/,
        /=\s*/,
        /(async\s*)?/,
        // async is optional
        c.lookahead(oe)
      ],
      keywords: "async",
      className: {
        1: "keyword",
        3: "title.function"
      },
      contains: [
        x
      ]
    };
    return {
      name: "JavaScript",
      aliases: ["js", "jsx", "mjs", "cjs"],
      keywords: b,
      // this will be extended by TypeScript
      exports: { PARAMS_CONTAINS: L, CLASS_REFERENCE: k },
      illegal: /#(?![$_A-z])/,
      contains: [
        u.SHEBANG({
          label: "shebang",
          binary: "node",
          relevance: 5
        }),
        B,
        u.APOS_STRING_MODE,
        u.QUOTE_STRING_MODE,
        T,
        O,
        R,
        D,
        $,
        // Skip numbers when they are part of a variable name
        { match: /\$\d+/ },
        S,
        k,
        {
          className: "attr",
          begin: f + c.lookahead(":"),
          relevance: 0
        },
        ae,
        {
          // "value" container
          begin: "(" + u.RE_STARTERS_RE + "|\\b(case|return|throw)\\b)\\s*",
          keywords: "return throw case",
          relevance: 0,
          contains: [
            $,
            u.REGEXP_MODE,
            {
              className: "function",
              // we have to count the parens to make sure we actually have the
              // correct bounding ( ) before the =>.  There could be any number of
              // sub-expressions inside also surrounded by parens.
              begin: oe,
              returnBegin: !0,
              end: "\\s*=>",
              contains: [
                {
                  className: "params",
                  variants: [
                    {
                      begin: u.UNDERSCORE_IDENT_RE,
                      relevance: 0
                    },
                    {
                      className: null,
                      begin: /\(\s*\)/,
                      skip: !0
                    },
                    {
                      begin: /\(/,
                      end: /\)/,
                      excludeBegin: !0,
                      excludeEnd: !0,
                      keywords: b,
                      contains: L
                    }
                  ]
                }
              ]
            },
            {
              // could be a comma delimited list of params to a function call
              begin: /,/,
              relevance: 0
            },
            {
              match: /\s+/,
              relevance: 0
            },
            {
              // JSX
              variants: [
                { begin: h.begin, end: h.end },
                { match: m },
                {
                  begin: v.begin,
                  // we carefully check the opening tag to see if it truly
                  // is a tag and not a false positive
                  "on:begin": v.isTrulyOpeningTag,
                  end: v.end
                }
              ],
              subLanguage: "xml",
              contains: [
                {
                  begin: v.begin,
                  end: v.end,
                  skip: !0,
                  contains: ["self"]
                }
              ]
            }
          ]
        },
        W,
        {
          // prevent this from getting swallowed up by function
          // since they appear "function like"
          beginKeywords: "while if switch catch for"
        },
        {
          // we have to count the parens to make sure we actually have the correct
          // bounding ( ).  There could be any number of sub-expressions inside
          // also surrounded by parens.
          begin: "\\b(?!function)" + u.UNDERSCORE_IDENT_RE + "\\([^()]*(\\([^()]*(\\([^()]*\\)[^()]*)*\\)[^()]*)*\\)\\s*\\{",
          // end parens
          returnBegin: !0,
          label: "func.def",
          contains: [
            x,
            u.inherit(u.TITLE_MODE, { begin: f, className: "title.function" })
          ]
        },
        // catch ... so it won't trigger the property rule below
        {
          match: /\.\.\./,
          relevance: 0
        },
        ne,
        // hack: prevents detection of keywords in some circumstances
        // .keyword()
        // $keyword = x
        {
          match: "\\$" + f,
          relevance: 0
        },
        {
          match: [/\bconstructor(?=\s*\()/],
          className: { 1: "title.function" },
          contains: [x]
        },
        K,
        Z,
        I,
        Ee,
        {
          match: /\$[(.]/
          // relevance booster for a pattern common to JS libs: `$(something)` and `$.something`
        }
      ]
    };
  }
  return QE = l, QE;
}
var XE, iI;
function fJ() {
  if (iI) return XE;
  iI = 1;
  function e(t) {
    const r = {
      className: "params",
      begin: /\(/,
      end: /\)/,
      contains: [{
        begin: /[\w-]+ *=/,
        returnBegin: !0,
        relevance: 0,
        contains: [
          {
            className: "attr",
            begin: /[\w-]+/
          }
        ]
      }],
      relevance: 0
    }, i = {
      className: "function",
      begin: /:[\w\-.]+/,
      relevance: 0
    }, a = {
      className: "string",
      begin: /\B([\/.])[\w\-.\/=]+/
    }, o = {
      className: "params",
      begin: /--[\w\-=\/]+/
    };
    return {
      name: "JBoss CLI",
      aliases: ["wildfly-cli"],
      keywords: {
        $pattern: "[a-z-]+",
        keyword: "alias batch cd clear command connect connection-factory connection-info data-source deploy deployment-info deployment-overlay echo echo-dmr help history if jdbc-driver-info jms-queue|20 jms-topic|20 ls patch pwd quit read-attribute read-operation reload rollout-plan run-batch set shutdown try unalias undeploy unset version xa-data-source",
        // module
        literal: "true false"
      },
      contains: [
        t.HASH_COMMENT_MODE,
        t.QUOTE_STRING_MODE,
        o,
        i,
        a,
        r
      ]
    };
  }
  return XE = e, XE;
}
var ZE, aI;
function pJ() {
  if (aI) return ZE;
  aI = 1;
  function e(t) {
    const n = {
      className: "attr",
      begin: /"(\\.|[^\\"\r\n])*"(?=\s*:)/,
      relevance: 1.01
    }, r = {
      match: /[{}[\],:]/,
      className: "punctuation",
      relevance: 0
    }, i = [
      "true",
      "false",
      "null"
    ], a = {
      scope: "literal",
      beginKeywords: i.join(" ")
    };
    return {
      name: "JSON",
      keywords: {
        literal: i
      },
      contains: [
        n,
        r,
        t.QUOTE_STRING_MODE,
        a,
        t.C_NUMBER_MODE,
        t.C_LINE_COMMENT_MODE,
        t.C_BLOCK_COMMENT_MODE
      ],
      illegal: "\\S"
    };
  }
  return ZE = e, ZE;
}
var JE, oI;
function mJ() {
  if (oI) return JE;
  oI = 1;
  function e(t) {
    const n = "[A-Za-z_\\u00A1-\\uFFFF][A-Za-z_0-9\\u00A1-\\uFFFF]*", o = {
      $pattern: n,
      keyword: [
        "baremodule",
        "begin",
        "break",
        "catch",
        "ccall",
        "const",
        "continue",
        "do",
        "else",
        "elseif",
        "end",
        "export",
        "false",
        "finally",
        "for",
        "function",
        "global",
        "if",
        "import",
        "in",
        "isa",
        "let",
        "local",
        "macro",
        "module",
        "quote",
        "return",
        "true",
        "try",
        "using",
        "where",
        "while"
      ],
      literal: [
        "ARGS",
        "C_NULL",
        "DEPOT_PATH",
        "ENDIAN_BOM",
        "ENV",
        "Inf",
        "Inf16",
        "Inf32",
        "Inf64",
        "InsertionSort",
        "LOAD_PATH",
        "MergeSort",
        "NaN",
        "NaN16",
        "NaN32",
        "NaN64",
        "PROGRAM_FILE",
        "QuickSort",
        "RoundDown",
        "RoundFromZero",
        "RoundNearest",
        "RoundNearestTiesAway",
        "RoundNearestTiesUp",
        "RoundToZero",
        "RoundUp",
        "VERSION|0",
        "devnull",
        "false",
        "im",
        "missing",
        "nothing",
        "pi",
        "stderr",
        "stdin",
        "stdout",
        "true",
        "undef",
        "π",
        "ℯ"
      ],
      built_in: [
        "AbstractArray",
        "AbstractChannel",
        "AbstractChar",
        "AbstractDict",
        "AbstractDisplay",
        "AbstractFloat",
        "AbstractIrrational",
        "AbstractMatrix",
        "AbstractRange",
        "AbstractSet",
        "AbstractString",
        "AbstractUnitRange",
        "AbstractVecOrMat",
        "AbstractVector",
        "Any",
        "ArgumentError",
        "Array",
        "AssertionError",
        "BigFloat",
        "BigInt",
        "BitArray",
        "BitMatrix",
        "BitSet",
        "BitVector",
        "Bool",
        "BoundsError",
        "CapturedException",
        "CartesianIndex",
        "CartesianIndices",
        "Cchar",
        "Cdouble",
        "Cfloat",
        "Channel",
        "Char",
        "Cint",
        "Cintmax_t",
        "Clong",
        "Clonglong",
        "Cmd",
        "Colon",
        "Complex",
        "ComplexF16",
        "ComplexF32",
        "ComplexF64",
        "CompositeException",
        "Condition",
        "Cptrdiff_t",
        "Cshort",
        "Csize_t",
        "Cssize_t",
        "Cstring",
        "Cuchar",
        "Cuint",
        "Cuintmax_t",
        "Culong",
        "Culonglong",
        "Cushort",
        "Cvoid",
        "Cwchar_t",
        "Cwstring",
        "DataType",
        "DenseArray",
        "DenseMatrix",
        "DenseVecOrMat",
        "DenseVector",
        "Dict",
        "DimensionMismatch",
        "Dims",
        "DivideError",
        "DomainError",
        "EOFError",
        "Enum",
        "ErrorException",
        "Exception",
        "ExponentialBackOff",
        "Expr",
        "Float16",
        "Float32",
        "Float64",
        "Function",
        "GlobalRef",
        "HTML",
        "IO",
        "IOBuffer",
        "IOContext",
        "IOStream",
        "IdDict",
        "IndexCartesian",
        "IndexLinear",
        "IndexStyle",
        "InexactError",
        "InitError",
        "Int",
        "Int128",
        "Int16",
        "Int32",
        "Int64",
        "Int8",
        "Integer",
        "InterruptException",
        "InvalidStateException",
        "Irrational",
        "KeyError",
        "LinRange",
        "LineNumberNode",
        "LinearIndices",
        "LoadError",
        "MIME",
        "Matrix",
        "Method",
        "MethodError",
        "Missing",
        "MissingException",
        "Module",
        "NTuple",
        "NamedTuple",
        "Nothing",
        "Number",
        "OrdinalRange",
        "OutOfMemoryError",
        "OverflowError",
        "Pair",
        "PartialQuickSort",
        "PermutedDimsArray",
        "Pipe",
        "ProcessFailedException",
        "Ptr",
        "QuoteNode",
        "Rational",
        "RawFD",
        "ReadOnlyMemoryError",
        "Real",
        "ReentrantLock",
        "Ref",
        "Regex",
        "RegexMatch",
        "RoundingMode",
        "SegmentationFault",
        "Set",
        "Signed",
        "Some",
        "StackOverflowError",
        "StepRange",
        "StepRangeLen",
        "StridedArray",
        "StridedMatrix",
        "StridedVecOrMat",
        "StridedVector",
        "String",
        "StringIndexError",
        "SubArray",
        "SubString",
        "SubstitutionString",
        "Symbol",
        "SystemError",
        "Task",
        "TaskFailedException",
        "Text",
        "TextDisplay",
        "Timer",
        "Tuple",
        "Type",
        "TypeError",
        "TypeVar",
        "UInt",
        "UInt128",
        "UInt16",
        "UInt32",
        "UInt64",
        "UInt8",
        "UndefInitializer",
        "UndefKeywordError",
        "UndefRefError",
        "UndefVarError",
        "Union",
        "UnionAll",
        "UnitRange",
        "Unsigned",
        "Val",
        "Vararg",
        "VecElement",
        "VecOrMat",
        "Vector",
        "VersionNumber",
        "WeakKeyDict",
        "WeakRef"
      ]
    }, s = {
      keywords: o,
      illegal: /<\//
    }, l = {
      className: "number",
      // supported numeric literals:
      //  * binary literal (e.g. 0x10)
      //  * octal literal (e.g. 0o76543210)
      //  * hexadecimal literal (e.g. 0xfedcba876543210)
      //  * hexadecimal floating point literal (e.g. 0x1p0, 0x1.2p2)
      //  * decimal literal (e.g. 9876543210, 100_000_000)
      //  * floating pointe literal (e.g. 1.2, 1.2f, .2, 1., 1.2e10, 1.2e-10)
      begin: /(\b0x[\d_]*(\.[\d_]*)?|0x\.\d[\d_]*)p[-+]?\d+|\b0[box][a-fA-F0-9][a-fA-F0-9_]*|(\b\d[\d_]*(\.[\d_]*)?|\.\d[\d_]*)([eEfF][-+]?\d+)?/,
      relevance: 0
    }, u = {
      className: "string",
      begin: /'(.|\\[xXuU][a-zA-Z0-9]+)'/
    }, c = {
      className: "subst",
      begin: /\$\(/,
      end: /\)/,
      keywords: o
    }, d = {
      className: "variable",
      begin: "\\$" + n
    }, f = {
      className: "string",
      contains: [
        t.BACKSLASH_ESCAPE,
        c,
        d
      ],
      variants: [
        {
          begin: /\w*"""/,
          end: /"""\w*/,
          relevance: 10
        },
        {
          begin: /\w*"/,
          end: /"\w*/
        }
      ]
    }, h = {
      className: "string",
      contains: [
        t.BACKSLASH_ESCAPE,
        c,
        d
      ],
      begin: "`",
      end: "`"
    }, m = {
      className: "meta",
      begin: "@" + n
    }, v = {
      className: "comment",
      variants: [
        {
          begin: "#=",
          end: "=#",
          relevance: 10
        },
        {
          begin: "#",
          end: "$"
        }
      ]
    };
    return s.name = "Julia", s.contains = [
      l,
      u,
      f,
      h,
      m,
      v,
      t.HASH_COMMENT_MODE,
      {
        className: "keyword",
        begin: "\\b(((abstract|primitive)\\s+)type|(mutable\\s+)?struct)\\b"
      },
      { begin: /<:/ }
      // relevance booster
    ], c.contains = s.contains, s;
  }
  return JE = e, JE;
}
var eS, sI;
function hJ() {
  if (sI) return eS;
  sI = 1;
  function e(t) {
    return {
      name: "Julia REPL",
      contains: [
        {
          className: "meta.prompt",
          begin: /^julia>/,
          relevance: 10,
          starts: {
            // end the highlighting if we are on a new line and the line does not have at
            // least six spaces in the beginning
            end: /^(?![ ]{6})/,
            subLanguage: "julia"
          }
        }
      ],
      // jldoctest Markdown blocks are used in the Julia manual and package docs indicate
      // code snippets that should be verified when the documentation is built. They can be
      // either REPL-like or script-like, but are usually REPL-like and therefore we apply
      // julia-repl highlighting to them. More information can be found in Documenter's
      // manual: https://juliadocs.github.io/Documenter.jl/latest/man/doctests.html
      aliases: ["jldoctest"]
    };
  }
  return eS = e, eS;
}
var tS, lI;
function gJ() {
  if (lI) return tS;
  lI = 1;
  var e = "[0-9](_*[0-9])*", t = `\\.(${e})`, n = "[0-9a-fA-F](_*[0-9a-fA-F])*", r = {
    className: "number",
    variants: [
      // DecimalFloatingPointLiteral
      // including ExponentPart
      { begin: `(\\b(${e})((${t})|\\.)?|(${t}))[eE][+-]?(${e})[fFdD]?\\b` },
      // excluding ExponentPart
      { begin: `\\b(${e})((${t})[fFdD]?\\b|\\.([fFdD]\\b)?)` },
      { begin: `(${t})[fFdD]?\\b` },
      { begin: `\\b(${e})[fFdD]\\b` },
      // HexadecimalFloatingPointLiteral
      { begin: `\\b0[xX]((${n})\\.?|(${n})?\\.(${n}))[pP][+-]?(${e})[fFdD]?\\b` },
      // DecimalIntegerLiteral
      { begin: "\\b(0|[1-9](_*[0-9])*)[lL]?\\b" },
      // HexIntegerLiteral
      { begin: `\\b0[xX](${n})[lL]?\\b` },
      // OctalIntegerLiteral
      { begin: "\\b0(_*[0-7])*[lL]?\\b" },
      // BinaryIntegerLiteral
      { begin: "\\b0[bB][01](_*[01])*[lL]?\\b" }
    ],
    relevance: 0
  };
  function i(a) {
    const o = {
      keyword: "abstract as val var vararg get set class object open private protected public noinline crossinline dynamic final enum if else do while for when throw try catch finally import package is in fun override companion reified inline lateinit init interface annotation data sealed internal infix operator out by constructor super tailrec where const inner suspend typealias external expect actual",
      built_in: "Byte Short Char Int Long Boolean Float Double Void Unit Nothing",
      literal: "true false null"
    }, s = {
      className: "keyword",
      begin: /\b(break|continue|return|this)\b/,
      starts: { contains: [
        {
          className: "symbol",
          begin: /@\w+/
        }
      ] }
    }, l = {
      className: "symbol",
      begin: a.UNDERSCORE_IDENT_RE + "@"
    }, u = {
      className: "subst",
      begin: /\$\{/,
      end: /\}/,
      contains: [a.C_NUMBER_MODE]
    }, c = {
      className: "variable",
      begin: "\\$" + a.UNDERSCORE_IDENT_RE
    }, d = {
      className: "string",
      variants: [
        {
          begin: '"""',
          end: '"""(?=[^"])',
          contains: [
            c,
            u
          ]
        },
        // Can't use built-in modes easily, as we want to use STRING in the meta
        // context as 'meta-string' and there's no syntax to remove explicitly set
        // classNames in built-in modes.
        {
          begin: "'",
          end: "'",
          illegal: /\n/,
          contains: [a.BACKSLASH_ESCAPE]
        },
        {
          begin: '"',
          end: '"',
          illegal: /\n/,
          contains: [
            a.BACKSLASH_ESCAPE,
            c,
            u
          ]
        }
      ]
    };
    u.contains.push(d);
    const f = {
      className: "meta",
      begin: "@(?:file|property|field|get|set|receiver|param|setparam|delegate)\\s*:(?:\\s*" + a.UNDERSCORE_IDENT_RE + ")?"
    }, h = {
      className: "meta",
      begin: "@" + a.UNDERSCORE_IDENT_RE,
      contains: [
        {
          begin: /\(/,
          end: /\)/,
          contains: [
            a.inherit(d, { className: "string" }),
            "self"
          ]
        }
      ]
    }, m = r, v = a.COMMENT(
      "/\\*",
      "\\*/",
      { contains: [a.C_BLOCK_COMMENT_MODE] }
    ), b = { variants: [
      {
        className: "type",
        begin: a.UNDERSCORE_IDENT_RE
      },
      {
        begin: /\(/,
        end: /\)/,
        contains: []
        // defined later
      }
    ] }, y = b;
    return y.variants[1].contains = [b], b.variants[1].contains = [y], {
      name: "Kotlin",
      aliases: [
        "kt",
        "kts"
      ],
      keywords: o,
      contains: [
        a.COMMENT(
          "/\\*\\*",
          "\\*/",
          {
            relevance: 0,
            contains: [
              {
                className: "doctag",
                begin: "@[A-Za-z]+"
              }
            ]
          }
        ),
        a.C_LINE_COMMENT_MODE,
        v,
        s,
        l,
        f,
        h,
        {
          className: "function",
          beginKeywords: "fun",
          end: "[(]|$",
          returnBegin: !0,
          excludeEnd: !0,
          keywords: o,
          relevance: 5,
          contains: [
            {
              begin: a.UNDERSCORE_IDENT_RE + "\\s*\\(",
              returnBegin: !0,
              relevance: 0,
              contains: [a.UNDERSCORE_TITLE_MODE]
            },
            {
              className: "type",
              begin: /</,
              end: />/,
              keywords: "reified",
              relevance: 0
            },
            {
              className: "params",
              begin: /\(/,
              end: /\)/,
              endsParent: !0,
              keywords: o,
              relevance: 0,
              contains: [
                {
                  begin: /:/,
                  end: /[=,\/]/,
                  endsWithParent: !0,
                  contains: [
                    b,
                    a.C_LINE_COMMENT_MODE,
                    v
                  ],
                  relevance: 0
                },
                a.C_LINE_COMMENT_MODE,
                v,
                f,
                h,
                d,
                a.C_NUMBER_MODE
              ]
            },
            v
          ]
        },
        {
          begin: [
            /class|interface|trait/,
            /\s+/,
            a.UNDERSCORE_IDENT_RE
          ],
          beginScope: {
            3: "title.class"
          },
          keywords: "class interface trait",
          end: /[:\{(]|$/,
          excludeEnd: !0,
          illegal: "extends implements",
          contains: [
            { beginKeywords: "public protected internal private constructor" },
            a.UNDERSCORE_TITLE_MODE,
            {
              className: "type",
              begin: /</,
              end: />/,
              excludeBegin: !0,
              excludeEnd: !0,
              relevance: 0
            },
            {
              className: "type",
              begin: /[,:]\s*/,
              end: /[<\(,){\s]|$/,
              excludeBegin: !0,
              returnEnd: !0
            },
            f,
            h
          ]
        },
        d,
        {
          className: "meta",
          begin: "^#!/usr/bin/env",
          end: "$",
          illegal: `
`
        },
        m
      ]
    };
  }
  return tS = i, tS;
}
var nS, uI;
function _J() {
  if (uI) return nS;
  uI = 1;
  function e(t) {
    const n = "[a-zA-Z_][\\w.]*", r = "<\\?(lasso(script)?|=)", i = "\\]|\\?>", a = {
      $pattern: n + "|&[lg]t;",
      literal: "true false none minimal full all void and or not bw nbw ew new cn ncn lt lte gt gte eq neq rx nrx ft",
      built_in: "array date decimal duration integer map pair string tag xml null boolean bytes keyword list locale queue set stack staticarray local var variable global data self inherited currentcapture givenblock",
      keyword: "cache database_names database_schemanames database_tablenames define_tag define_type email_batch encode_set html_comment handle handle_error header if inline iterate ljax_target link link_currentaction link_currentgroup link_currentrecord link_detail link_firstgroup link_firstrecord link_lastgroup link_lastrecord link_nextgroup link_nextrecord link_prevgroup link_prevrecord log loop namespace_using output_none portal private protect records referer referrer repeating resultset rows search_args search_arguments select sort_args sort_arguments thread_atomic value_list while abort case else fail_if fail_ifnot fail if_empty if_false if_null if_true loop_abort loop_continue loop_count params params_up return return_value run_children soap_definetag soap_lastrequest soap_lastresponse tag_name ascending average by define descending do equals frozen group handle_failure import in into join let match max min on order parent protected provide public require returnhome skip split_thread sum take thread to trait type where with yield yieldhome"
    }, o = t.COMMENT(
      "<!--",
      "-->",
      { relevance: 0 }
    ), s = {
      className: "meta",
      begin: "\\[noprocess\\]",
      starts: {
        end: "\\[/noprocess\\]",
        returnEnd: !0,
        contains: [o]
      }
    }, l = {
      className: "meta",
      begin: "\\[/noprocess|" + r
    }, u = {
      className: "symbol",
      begin: "'" + n + "'"
    }, c = [
      t.C_LINE_COMMENT_MODE,
      t.C_BLOCK_COMMENT_MODE,
      t.inherit(t.C_NUMBER_MODE, { begin: t.C_NUMBER_RE + "|(-?infinity|NaN)\\b" }),
      t.inherit(t.APOS_STRING_MODE, { illegal: null }),
      t.inherit(t.QUOTE_STRING_MODE, { illegal: null }),
      {
        className: "string",
        begin: "`",
        end: "`"
      },
      {
        // variables
        variants: [
          { begin: "[#$]" + n },
          {
            begin: "#",
            end: "\\d+",
            illegal: "\\W"
          }
        ]
      },
      {
        className: "type",
        begin: "::\\s*",
        end: n,
        illegal: "\\W"
      },
      {
        className: "params",
        variants: [
          {
            begin: "-(?!infinity)" + n,
            relevance: 0
          },
          { begin: "(\\.\\.\\.)" }
        ]
      },
      {
        begin: /(->|\.)\s*/,
        relevance: 0,
        contains: [u]
      },
      {
        className: "class",
        beginKeywords: "define",
        returnEnd: !0,
        end: "\\(|=>",
        contains: [t.inherit(t.TITLE_MODE, { begin: n + "(=(?!>))?|[-+*/%](?!>)" })]
      }
    ];
    return {
      name: "Lasso",
      aliases: [
        "ls",
        "lassoscript"
      ],
      case_insensitive: !0,
      keywords: a,
      contains: [
        {
          className: "meta",
          begin: i,
          relevance: 0,
          starts: {
            // markup
            end: "\\[|" + r,
            returnEnd: !0,
            relevance: 0,
            contains: [o]
          }
        },
        s,
        l,
        {
          className: "meta",
          begin: "\\[no_square_brackets",
          starts: {
            end: "\\[/no_square_brackets\\]",
            // not implemented in the language
            keywords: a,
            contains: [
              {
                className: "meta",
                begin: i,
                relevance: 0,
                starts: {
                  end: "\\[noprocess\\]|" + r,
                  returnEnd: !0,
                  contains: [o]
                }
              },
              s,
              l
            ].concat(c)
          }
        },
        {
          className: "meta",
          begin: "\\[",
          relevance: 0
        },
        {
          className: "meta",
          begin: "^#!",
          end: "lasso9$",
          relevance: 10
        }
      ].concat(c)
    };
  }
  return nS = e, nS;
}
var rS, cI;
function vJ() {
  if (cI) return rS;
  cI = 1;
  function e(t) {
    const r = t.regex.either(...[
      "(?:NeedsTeXFormat|RequirePackage|GetIdInfo)",
      "Provides(?:Expl)?(?:Package|Class|File)",
      "(?:DeclareOption|ProcessOptions)",
      "(?:documentclass|usepackage|input|include)",
      "makeat(?:letter|other)",
      "ExplSyntax(?:On|Off)",
      "(?:new|renew|provide)?command",
      "(?:re)newenvironment",
      "(?:New|Renew|Provide|Declare)(?:Expandable)?DocumentCommand",
      "(?:New|Renew|Provide|Declare)DocumentEnvironment",
      "(?:(?:e|g|x)?def|let)",
      "(?:begin|end)",
      "(?:part|chapter|(?:sub){0,2}section|(?:sub)?paragraph)",
      "caption",
      "(?:label|(?:eq|page|name)?ref|(?:paren|foot|super)?cite)",
      "(?:alpha|beta|[Gg]amma|[Dd]elta|(?:var)?epsilon|zeta|eta|[Tt]heta|vartheta)",
      "(?:iota|(?:var)?kappa|[Ll]ambda|mu|nu|[Xx]i|[Pp]i|varpi|(?:var)rho)",
      "(?:[Ss]igma|varsigma|tau|[Uu]psilon|[Pp]hi|varphi|chi|[Pp]si|[Oo]mega)",
      "(?:frac|sum|prod|lim|infty|times|sqrt|leq|geq|left|right|middle|[bB]igg?)",
      "(?:[lr]angle|q?quad|[lcvdi]?dots|d?dot|hat|tilde|bar)"
    ].map(($) => $ + "(?![a-zA-Z@:_])")), i = new RegExp([
      // A function \module_function_name:signature or \__module_function_name:signature,
      // where both module and function_name need at least two characters and
      // function_name may contain single underscores.
      "(?:__)?[a-zA-Z]{2,}_[a-zA-Z](?:_?[a-zA-Z])+:[a-zA-Z]*",
      // A variable \scope_module_and_name_type or \scope__module_ane_name_type,
      // where scope is one of l, g or c, type needs at least two characters
      // and module_and_name may contain single underscores.
      "[lgc]__?[a-zA-Z](?:_?[a-zA-Z])*_[a-zA-Z]{2,}",
      // A quark \q_the_name or \q__the_name or
      // scan mark \s_the_name or \s__vthe_name,
      // where variable_name needs at least two characters and
      // may contain single underscores.
      "[qs]__?[a-zA-Z](?:_?[a-zA-Z])+",
      // Other LaTeX3 macro names that are not covered by the three rules above.
      "use(?:_i)?:[a-zA-Z]*",
      "(?:else|fi|or):",
      "(?:if|cs|exp):w",
      "(?:hbox|vbox):n",
      "::[a-zA-Z]_unbraced",
      "::[a-zA-Z:]"
    ].map(($) => $ + "(?![a-zA-Z:_])").join("|")), a = [
      { begin: /[a-zA-Z@]+/ },
      // control word
      { begin: /[^a-zA-Z@]?/ }
      // control symbol
    ], o = [
      { begin: /\^{6}[0-9a-f]{6}/ },
      { begin: /\^{5}[0-9a-f]{5}/ },
      { begin: /\^{4}[0-9a-f]{4}/ },
      { begin: /\^{3}[0-9a-f]{3}/ },
      { begin: /\^{2}[0-9a-f]{2}/ },
      { begin: /\^{2}[\u0000-\u007f]/ }
    ], s = {
      className: "keyword",
      begin: /\\/,
      relevance: 0,
      contains: [
        {
          endsParent: !0,
          begin: r
        },
        {
          endsParent: !0,
          begin: i
        },
        {
          endsParent: !0,
          variants: o
        },
        {
          endsParent: !0,
          relevance: 0,
          variants: a
        }
      ]
    }, l = {
      className: "params",
      relevance: 0,
      begin: /#+\d?/
    }, u = {
      // relevance: 1
      variants: o
    }, c = {
      className: "built_in",
      relevance: 0,
      begin: /[$&^_]/
    }, d = {
      className: "meta",
      begin: /% ?!(T[eE]X|tex|BIB|bib)/,
      end: "$",
      relevance: 10
    }, f = t.COMMENT(
      "%",
      "$",
      { relevance: 0 }
    ), h = [
      s,
      l,
      u,
      c,
      d,
      f
    ], m = {
      begin: /\{/,
      end: /\}/,
      relevance: 0,
      contains: [
        "self",
        ...h
      ]
    }, v = t.inherit(
      m,
      {
        relevance: 0,
        endsParent: !0,
        contains: [
          m,
          ...h
        ]
      }
    ), b = {
      begin: /\[/,
      end: /\]/,
      endsParent: !0,
      relevance: 0,
      contains: [
        m,
        ...h
      ]
    }, y = {
      begin: /\s+/,
      relevance: 0
    }, g = [v], E = [b], S = function($, P) {
      return {
        contains: [y],
        starts: {
          relevance: 0,
          contains: $,
          starts: P
        }
      };
    }, C = function($, P) {
      return {
        begin: "\\\\" + $ + "(?![a-zA-Z@:_])",
        keywords: {
          $pattern: /\\[a-zA-Z]+/,
          keyword: "\\" + $
        },
        relevance: 0,
        contains: [y],
        starts: P
      };
    }, T = function($, P) {
      return t.inherit(
        {
          begin: "\\\\begin(?=[ 	]*(\\r?\\n[ 	]*)?\\{" + $ + "\\})",
          keywords: {
            $pattern: /\\[a-zA-Z]+/,
            keyword: "\\begin"
          },
          relevance: 0
        },
        S(g, P)
      );
    }, O = ($ = "string") => t.END_SAME_AS_BEGIN({
      className: $,
      begin: /(.|\r?\n)/,
      end: /(.|\r?\n)/,
      excludeBegin: !0,
      excludeEnd: !0,
      endsParent: !0
    }), R = function($) {
      return {
        className: "string",
        end: "(?=\\\\end\\{" + $ + "\\})"
      };
    }, D = ($ = "string") => ({
      relevance: 0,
      begin: /\{/,
      starts: {
        endsParent: !0,
        contains: [
          {
            className: $,
            end: /(?=\})/,
            endsParent: !0,
            contains: [
              {
                begin: /\{/,
                end: /\}/,
                relevance: 0,
                contains: ["self"]
              }
            ]
          }
        ]
      }
    }), q = [
      ...[
        "verb",
        "lstinline"
      ].map(($) => C($, { contains: [O()] })),
      C("mint", S(g, { contains: [O()] })),
      C("mintinline", S(g, { contains: [
        D(),
        O()
      ] })),
      C("url", { contains: [
        D("link"),
        D("link")
      ] }),
      C("hyperref", { contains: [D("link")] }),
      C("href", S(E, { contains: [D("link")] })),
      ...[].concat(...[
        "",
        "\\*"
      ].map(($) => [
        T("verbatim" + $, R("verbatim" + $)),
        T("filecontents" + $, S(g, R("filecontents" + $))),
        ...[
          "",
          "B",
          "L"
        ].map(
          (P) => T(P + "Verbatim" + $, S(E, R(P + "Verbatim" + $)))
        )
      ])),
      T("minted", S(E, S(g, R("minted"))))
    ];
    return {
      name: "LaTeX",
      aliases: ["tex"],
      contains: [
        ...q,
        ...h
      ]
    };
  }
  return rS = e, rS;
}
var iS, dI;
function bJ() {
  if (dI) return iS;
  dI = 1;
  function e(t) {
    return {
      name: "LDIF",
      contains: [
        {
          className: "attribute",
          match: "^dn(?=:)",
          relevance: 10
        },
        {
          className: "attribute",
          match: "^\\w+(?=:)"
        },
        {
          className: "literal",
          match: "^-"
        },
        t.HASH_COMMENT_MODE
      ]
    };
  }
  return iS = e, iS;
}
var aS, fI;
function EJ() {
  if (fI) return aS;
  fI = 1;
  function e(t) {
    const n = /([A-Za-z_][A-Za-z_0-9]*)?/, i = {
      scope: "params",
      begin: /\(/,
      end: /\)(?=\:?)/,
      endsParent: !0,
      relevance: 7,
      contains: [
        {
          scope: "string",
          begin: '"',
          end: '"'
        },
        {
          scope: "keyword",
          match: [
            "true",
            "false",
            "in"
          ].join("|")
        },
        {
          scope: "variable",
          match: /[A-Za-z_][A-Za-z_0-9]*/
        },
        {
          scope: "operator",
          match: /\+|\-|\*|\/|\%|\=\=|\=|\!|\>|\<|\&\&|\|\|/
        }
      ]
    }, a = {
      match: [
        n,
        /(?=\()/
      ],
      scope: {
        1: "keyword"
      },
      contains: [i]
    };
    return i.contains.unshift(a), {
      name: "Leaf",
      contains: [
        // #ident():
        {
          match: [
            /#+/,
            n,
            /(?=\()/
          ],
          scope: {
            1: "punctuation",
            2: "keyword"
          },
          // will start up after the ending `)` match from line ~44
          // just to grab the trailing `:` if we can match it
          starts: {
            contains: [
              {
                match: /\:/,
                scope: "punctuation"
              }
            ]
          },
          contains: [
            i
          ]
        },
        // #ident or #ident:
        {
          match: [
            /#+/,
            n,
            /:?/
          ],
          scope: {
            1: "punctuation",
            2: "keyword",
            3: "punctuation"
          }
        }
      ]
    };
  }
  return aS = e, aS;
}
var oS, pI;
function SJ() {
  if (pI) return oS;
  pI = 1;
  const e = (l) => ({
    IMPORTANT: {
      scope: "meta",
      begin: "!important"
    },
    BLOCK_COMMENT: l.C_BLOCK_COMMENT_MODE,
    HEXCOLOR: {
      scope: "number",
      begin: /#(([0-9a-fA-F]{3,4})|(([0-9a-fA-F]{2}){3,4}))\b/
    },
    FUNCTION_DISPATCH: {
      className: "built_in",
      begin: /[\w-]+(?=\()/
    },
    ATTRIBUTE_SELECTOR_MODE: {
      scope: "selector-attr",
      begin: /\[/,
      end: /\]/,
      illegal: "$",
      contains: [
        l.APOS_STRING_MODE,
        l.QUOTE_STRING_MODE
      ]
    },
    CSS_NUMBER_MODE: {
      scope: "number",
      begin: l.NUMBER_RE + "(%|em|ex|ch|rem|vw|vh|vmin|vmax|cm|mm|in|pt|pc|px|deg|grad|rad|turn|s|ms|Hz|kHz|dpi|dpcm|dppx)?",
      relevance: 0
    },
    CSS_VARIABLE: {
      className: "attr",
      begin: /--[A-Za-z_][A-Za-z0-9_-]*/
    }
  }), t = [
    "a",
    "abbr",
    "address",
    "article",
    "aside",
    "audio",
    "b",
    "blockquote",
    "body",
    "button",
    "canvas",
    "caption",
    "cite",
    "code",
    "dd",
    "del",
    "details",
    "dfn",
    "div",
    "dl",
    "dt",
    "em",
    "fieldset",
    "figcaption",
    "figure",
    "footer",
    "form",
    "h1",
    "h2",
    "h3",
    "h4",
    "h5",
    "h6",
    "header",
    "hgroup",
    "html",
    "i",
    "iframe",
    "img",
    "input",
    "ins",
    "kbd",
    "label",
    "legend",
    "li",
    "main",
    "mark",
    "menu",
    "nav",
    "object",
    "ol",
    "p",
    "q",
    "quote",
    "samp",
    "section",
    "span",
    "strong",
    "summary",
    "sup",
    "table",
    "tbody",
    "td",
    "textarea",
    "tfoot",
    "th",
    "thead",
    "time",
    "tr",
    "ul",
    "var",
    "video"
  ], n = [
    "any-hover",
    "any-pointer",
    "aspect-ratio",
    "color",
    "color-gamut",
    "color-index",
    "device-aspect-ratio",
    "device-height",
    "device-width",
    "display-mode",
    "forced-colors",
    "grid",
    "height",
    "hover",
    "inverted-colors",
    "monochrome",
    "orientation",
    "overflow-block",
    "overflow-inline",
    "pointer",
    "prefers-color-scheme",
    "prefers-contrast",
    "prefers-reduced-motion",
    "prefers-reduced-transparency",
    "resolution",
    "scan",
    "scripting",
    "update",
    "width",
    // TODO: find a better solution?
    "min-width",
    "max-width",
    "min-height",
    "max-height"
  ], r = [
    "active",
    "any-link",
    "blank",
    "checked",
    "current",
    "default",
    "defined",
    "dir",
    // dir()
    "disabled",
    "drop",
    "empty",
    "enabled",
    "first",
    "first-child",
    "first-of-type",
    "fullscreen",
    "future",
    "focus",
    "focus-visible",
    "focus-within",
    "has",
    // has()
    "host",
    // host or host()
    "host-context",
    // host-context()
    "hover",
    "indeterminate",
    "in-range",
    "invalid",
    "is",
    // is()
    "lang",
    // lang()
    "last-child",
    "last-of-type",
    "left",
    "link",
    "local-link",
    "not",
    // not()
    "nth-child",
    // nth-child()
    "nth-col",
    // nth-col()
    "nth-last-child",
    // nth-last-child()
    "nth-last-col",
    // nth-last-col()
    "nth-last-of-type",
    //nth-last-of-type()
    "nth-of-type",
    //nth-of-type()
    "only-child",
    "only-of-type",
    "optional",
    "out-of-range",
    "past",
    "placeholder-shown",
    "read-only",
    "read-write",
    "required",
    "right",
    "root",
    "scope",
    "target",
    "target-within",
    "user-invalid",
    "valid",
    "visited",
    "where"
    // where()
  ], i = [
    "after",
    "backdrop",
    "before",
    "cue",
    "cue-region",
    "first-letter",
    "first-line",
    "grammar-error",
    "marker",
    "part",
    "placeholder",
    "selection",
    "slotted",
    "spelling-error"
  ], a = [
    "align-content",
    "align-items",
    "align-self",
    "all",
    "animation",
    "animation-delay",
    "animation-direction",
    "animation-duration",
    "animation-fill-mode",
    "animation-iteration-count",
    "animation-name",
    "animation-play-state",
    "animation-timing-function",
    "backface-visibility",
    "background",
    "background-attachment",
    "background-blend-mode",
    "background-clip",
    "background-color",
    "background-image",
    "background-origin",
    "background-position",
    "background-repeat",
    "background-size",
    "block-size",
    "border",
    "border-block",
    "border-block-color",
    "border-block-end",
    "border-block-end-color",
    "border-block-end-style",
    "border-block-end-width",
    "border-block-start",
    "border-block-start-color",
    "border-block-start-style",
    "border-block-start-width",
    "border-block-style",
    "border-block-width",
    "border-bottom",
    "border-bottom-color",
    "border-bottom-left-radius",
    "border-bottom-right-radius",
    "border-bottom-style",
    "border-bottom-width",
    "border-collapse",
    "border-color",
    "border-image",
    "border-image-outset",
    "border-image-repeat",
    "border-image-slice",
    "border-image-source",
    "border-image-width",
    "border-inline",
    "border-inline-color",
    "border-inline-end",
    "border-inline-end-color",
    "border-inline-end-style",
    "border-inline-end-width",
    "border-inline-start",
    "border-inline-start-color",
    "border-inline-start-style",
    "border-inline-start-width",
    "border-inline-style",
    "border-inline-width",
    "border-left",
    "border-left-color",
    "border-left-style",
    "border-left-width",
    "border-radius",
    "border-right",
    "border-right-color",
    "border-right-style",
    "border-right-width",
    "border-spacing",
    "border-style",
    "border-top",
    "border-top-color",
    "border-top-left-radius",
    "border-top-right-radius",
    "border-top-style",
    "border-top-width",
    "border-width",
    "bottom",
    "box-decoration-break",
    "box-shadow",
    "box-sizing",
    "break-after",
    "break-before",
    "break-inside",
    "caption-side",
    "caret-color",
    "clear",
    "clip",
    "clip-path",
    "clip-rule",
    "color",
    "column-count",
    "column-fill",
    "column-gap",
    "column-rule",
    "column-rule-color",
    "column-rule-style",
    "column-rule-width",
    "column-span",
    "column-width",
    "columns",
    "contain",
    "content",
    "content-visibility",
    "counter-increment",
    "counter-reset",
    "cue",
    "cue-after",
    "cue-before",
    "cursor",
    "direction",
    "display",
    "empty-cells",
    "filter",
    "flex",
    "flex-basis",
    "flex-direction",
    "flex-flow",
    "flex-grow",
    "flex-shrink",
    "flex-wrap",
    "float",
    "flow",
    "font",
    "font-display",
    "font-family",
    "font-feature-settings",
    "font-kerning",
    "font-language-override",
    "font-size",
    "font-size-adjust",
    "font-smoothing",
    "font-stretch",
    "font-style",
    "font-synthesis",
    "font-variant",
    "font-variant-caps",
    "font-variant-east-asian",
    "font-variant-ligatures",
    "font-variant-numeric",
    "font-variant-position",
    "font-variation-settings",
    "font-weight",
    "gap",
    "glyph-orientation-vertical",
    "grid",
    "grid-area",
    "grid-auto-columns",
    "grid-auto-flow",
    "grid-auto-rows",
    "grid-column",
    "grid-column-end",
    "grid-column-start",
    "grid-gap",
    "grid-row",
    "grid-row-end",
    "grid-row-start",
    "grid-template",
    "grid-template-areas",
    "grid-template-columns",
    "grid-template-rows",
    "hanging-punctuation",
    "height",
    "hyphens",
    "icon",
    "image-orientation",
    "image-rendering",
    "image-resolution",
    "ime-mode",
    "inline-size",
    "isolation",
    "justify-content",
    "left",
    "letter-spacing",
    "line-break",
    "line-height",
    "list-style",
    "list-style-image",
    "list-style-position",
    "list-style-type",
    "margin",
    "margin-block",
    "margin-block-end",
    "margin-block-start",
    "margin-bottom",
    "margin-inline",
    "margin-inline-end",
    "margin-inline-start",
    "margin-left",
    "margin-right",
    "margin-top",
    "marks",
    "mask",
    "mask-border",
    "mask-border-mode",
    "mask-border-outset",
    "mask-border-repeat",
    "mask-border-slice",
    "mask-border-source",
    "mask-border-width",
    "mask-clip",
    "mask-composite",
    "mask-image",
    "mask-mode",
    "mask-origin",
    "mask-position",
    "mask-repeat",
    "mask-size",
    "mask-type",
    "max-block-size",
    "max-height",
    "max-inline-size",
    "max-width",
    "min-block-size",
    "min-height",
    "min-inline-size",
    "min-width",
    "mix-blend-mode",
    "nav-down",
    "nav-index",
    "nav-left",
    "nav-right",
    "nav-up",
    "none",
    "normal",
    "object-fit",
    "object-position",
    "opacity",
    "order",
    "orphans",
    "outline",
    "outline-color",
    "outline-offset",
    "outline-style",
    "outline-width",
    "overflow",
    "overflow-wrap",
    "overflow-x",
    "overflow-y",
    "padding",
    "padding-block",
    "padding-block-end",
    "padding-block-start",
    "padding-bottom",
    "padding-inline",
    "padding-inline-end",
    "padding-inline-start",
    "padding-left",
    "padding-right",
    "padding-top",
    "page-break-after",
    "page-break-before",
    "page-break-inside",
    "pause",
    "pause-after",
    "pause-before",
    "perspective",
    "perspective-origin",
    "pointer-events",
    "position",
    "quotes",
    "resize",
    "rest",
    "rest-after",
    "rest-before",
    "right",
    "row-gap",
    "scroll-margin",
    "scroll-margin-block",
    "scroll-margin-block-end",
    "scroll-margin-block-start",
    "scroll-margin-bottom",
    "scroll-margin-inline",
    "scroll-margin-inline-end",
    "scroll-margin-inline-start",
    "scroll-margin-left",
    "scroll-margin-right",
    "scroll-margin-top",
    "scroll-padding",
    "scroll-padding-block",
    "scroll-padding-block-end",
    "scroll-padding-block-start",
    "scroll-padding-bottom",
    "scroll-padding-inline",
    "scroll-padding-inline-end",
    "scroll-padding-inline-start",
    "scroll-padding-left",
    "scroll-padding-right",
    "scroll-padding-top",
    "scroll-snap-align",
    "scroll-snap-stop",
    "scroll-snap-type",
    "scrollbar-color",
    "scrollbar-gutter",
    "scrollbar-width",
    "shape-image-threshold",
    "shape-margin",
    "shape-outside",
    "speak",
    "speak-as",
    "src",
    // @font-face
    "tab-size",
    "table-layout",
    "text-align",
    "text-align-all",
    "text-align-last",
    "text-combine-upright",
    "text-decoration",
    "text-decoration-color",
    "text-decoration-line",
    "text-decoration-style",
    "text-emphasis",
    "text-emphasis-color",
    "text-emphasis-position",
    "text-emphasis-style",
    "text-indent",
    "text-justify",
    "text-orientation",
    "text-overflow",
    "text-rendering",
    "text-shadow",
    "text-transform",
    "text-underline-position",
    "top",
    "transform",
    "transform-box",
    "transform-origin",
    "transform-style",
    "transition",
    "transition-delay",
    "transition-duration",
    "transition-property",
    "transition-timing-function",
    "unicode-bidi",
    "vertical-align",
    "visibility",
    "voice-balance",
    "voice-duration",
    "voice-family",
    "voice-pitch",
    "voice-range",
    "voice-rate",
    "voice-stress",
    "voice-volume",
    "white-space",
    "widows",
    "width",
    "will-change",
    "word-break",
    "word-spacing",
    "word-wrap",
    "writing-mode",
    "z-index"
    // reverse makes sure longer attributes `font-weight` are matched fully
    // instead of getting false positives on say `font`
  ].reverse(), o = r.concat(i);
  function s(l) {
    const u = e(l), c = o, d = "and or not only", f = "[\\w-]+", h = "(" + f + "|@\\{" + f + "\\})", m = [], v = [], b = function($) {
      return {
        // Less strings are not multiline (also include '~' for more consistent coloring of "escaped" strings)
        className: "string",
        begin: "~?" + $ + ".*?" + $
      };
    }, y = function($, P, Y) {
      return {
        className: $,
        begin: P,
        relevance: Y
      };
    }, g = {
      $pattern: /[a-z-]+/,
      keyword: d,
      attribute: n.join(" ")
    }, E = {
      // used only to properly balance nested parens inside mixin call, def. arg list
      begin: "\\(",
      end: "\\)",
      contains: v,
      keywords: g,
      relevance: 0
    };
    v.push(
      l.C_LINE_COMMENT_MODE,
      l.C_BLOCK_COMMENT_MODE,
      b("'"),
      b('"'),
      u.CSS_NUMBER_MODE,
      // fixme: it does not include dot for numbers like .5em :(
      {
        begin: "(url|data-uri)\\(",
        starts: {
          className: "string",
          end: "[\\)\\n]",
          excludeEnd: !0
        }
      },
      u.HEXCOLOR,
      E,
      y("variable", "@@?" + f, 10),
      y("variable", "@\\{" + f + "\\}"),
      y("built_in", "~?`[^`]*?`"),
      // inline javascript (or whatever host language) *multiline* string
      {
        // @media features (it’s here to not duplicate things in AT_RULE_MODE with extra PARENS_MODE overriding):
        className: "attribute",
        begin: f + "\\s*:",
        end: ":",
        returnBegin: !0,
        excludeEnd: !0
      },
      u.IMPORTANT,
      { beginKeywords: "and not" },
      u.FUNCTION_DISPATCH
    );
    const S = v.concat({
      begin: /\{/,
      end: /\}/,
      contains: m
    }), C = {
      beginKeywords: "when",
      endsWithParent: !0,
      contains: [{ beginKeywords: "and not" }].concat(v)
      // using this form to override VALUE’s 'function' match
    }, T = {
      begin: h + "\\s*:",
      returnBegin: !0,
      end: /[;}]/,
      relevance: 0,
      contains: [
        { begin: /-(webkit|moz|ms|o)-/ },
        u.CSS_VARIABLE,
        {
          className: "attribute",
          begin: "\\b(" + a.join("|") + ")\\b",
          end: /(?=:)/,
          starts: {
            endsWithParent: !0,
            illegal: "[<=$]",
            relevance: 0,
            contains: v
          }
        }
      ]
    }, O = {
      className: "keyword",
      begin: "@(import|media|charset|font-face|(-[a-z]+-)?keyframes|supports|document|namespace|page|viewport|host)\\b",
      starts: {
        end: "[;{}]",
        keywords: g,
        returnEnd: !0,
        contains: v,
        relevance: 0
      }
    }, R = {
      className: "variable",
      variants: [
        // using more strict pattern for higher relevance to increase chances of Less detection.
        // this is *the only* Less specific statement used in most of the sources, so...
        // (we’ll still often loose to the css-parser unless there's '//' comment,
        // simply because 1 variable just can't beat 99 properties :)
        {
          begin: "@" + f + "\\s*:",
          relevance: 15
        },
        { begin: "@" + f }
      ],
      starts: {
        end: "[;}]",
        returnEnd: !0,
        contains: S
      }
    }, D = {
      // first parse unambiguous selectors (i.e. those not starting with tag)
      // then fall into the scary lookahead-discriminator variant.
      // this mode also handles mixin definitions and calls
      variants: [
        {
          begin: "[\\.#:&\\[>]",
          end: "[;{}]"
          // mixin calls end with ';'
        },
        {
          begin: h,
          end: /\{/
        }
      ],
      returnBegin: !0,
      returnEnd: !0,
      illegal: `[<='$"]`,
      relevance: 0,
      contains: [
        l.C_LINE_COMMENT_MODE,
        l.C_BLOCK_COMMENT_MODE,
        C,
        y("keyword", "all\\b"),
        y("variable", "@\\{" + f + "\\}"),
        // otherwise it’s identified as tag
        {
          begin: "\\b(" + t.join("|") + ")\\b",
          className: "selector-tag"
        },
        u.CSS_NUMBER_MODE,
        y("selector-tag", h, 0),
        y("selector-id", "#" + h),
        y("selector-class", "\\." + h, 0),
        y("selector-tag", "&", 0),
        u.ATTRIBUTE_SELECTOR_MODE,
        {
          className: "selector-pseudo",
          begin: ":(" + r.join("|") + ")"
        },
        {
          className: "selector-pseudo",
          begin: ":(:)?(" + i.join("|") + ")"
        },
        {
          begin: /\(/,
          end: /\)/,
          relevance: 0,
          contains: S
        },
        // argument list of parametric mixins
        { begin: "!important" },
        // eat !important after mixin call or it will be colored as tag
        u.FUNCTION_DISPATCH
      ]
    }, q = {
      begin: f + `:(:)?(${c.join("|")})`,
      returnBegin: !0,
      contains: [D]
    };
    return m.push(
      l.C_LINE_COMMENT_MODE,
      l.C_BLOCK_COMMENT_MODE,
      O,
      R,
      q,
      T,
      D,
      C,
      u.FUNCTION_DISPATCH
    ), {
      name: "Less",
      case_insensitive: !0,
      illegal: `[=>'/<($"]`,
      contains: m
    };
  }
  return oS = s, oS;
}
var sS, mI;
function yJ() {
  if (mI) return sS;
  mI = 1;
  function e(t) {
    const n = "[a-zA-Z_\\-+\\*\\/<=>&#][a-zA-Z0-9_\\-+*\\/<=>&#!]*", r = "\\|[^]*?\\|", i = "(-|\\+)?\\d+(\\.\\d+|\\/\\d+)?((d|e|f|l|s|D|E|F|L|S)(\\+|-)?\\d+)?", a = {
      className: "literal",
      begin: "\\b(t{1}|nil)\\b"
    }, o = {
      className: "number",
      variants: [
        {
          begin: i,
          relevance: 0
        },
        { begin: "#(b|B)[0-1]+(/[0-1]+)?" },
        { begin: "#(o|O)[0-7]+(/[0-7]+)?" },
        { begin: "#(x|X)[0-9a-fA-F]+(/[0-9a-fA-F]+)?" },
        {
          begin: "#(c|C)\\(" + i + " +" + i,
          end: "\\)"
        }
      ]
    }, s = t.inherit(t.QUOTE_STRING_MODE, { illegal: null }), l = t.COMMENT(
      ";",
      "$",
      { relevance: 0 }
    ), u = {
      begin: "\\*",
      end: "\\*"
    }, c = {
      className: "symbol",
      begin: "[:&]" + n
    }, d = {
      begin: n,
      relevance: 0
    }, f = { begin: r }, m = {
      contains: [
        o,
        s,
        u,
        c,
        {
          begin: "\\(",
          end: "\\)",
          contains: [
            "self",
            a,
            s,
            o,
            d
          ]
        },
        d
      ],
      variants: [
        {
          begin: "['`]\\(",
          end: "\\)"
        },
        {
          begin: "\\(quote ",
          end: "\\)",
          keywords: { name: "quote" }
        },
        { begin: "'" + r }
      ]
    }, v = { variants: [
      { begin: "'" + n },
      { begin: "#'" + n + "(::" + n + ")*" }
    ] }, b = {
      begin: "\\(\\s*",
      end: "\\)"
    }, y = {
      endsWithParent: !0,
      relevance: 0
    };
    return b.contains = [
      {
        className: "name",
        variants: [
          {
            begin: n,
            relevance: 0
          },
          { begin: r }
        ]
      },
      y
    ], y.contains = [
      m,
      v,
      b,
      a,
      o,
      s,
      l,
      u,
      c,
      f,
      d
    ], {
      name: "Lisp",
      illegal: /\S/,
      contains: [
        o,
        t.SHEBANG(),
        a,
        s,
        l,
        m,
        v,
        b,
        d
      ]
    };
  }
  return sS = e, sS;
}
var lS, hI;
function TJ() {
  if (hI) return lS;
  hI = 1;
  function e(t) {
    const n = {
      className: "variable",
      variants: [
        { begin: "\\b([gtps][A-Z]{1}[a-zA-Z0-9]*)(\\[.+\\])?(?:\\s*?)" },
        { begin: "\\$_[A-Z]+" }
      ],
      relevance: 0
    }, r = [
      t.C_BLOCK_COMMENT_MODE,
      t.HASH_COMMENT_MODE,
      t.COMMENT("--", "$"),
      t.COMMENT("[^:]//", "$")
    ], i = t.inherit(t.TITLE_MODE, { variants: [
      { begin: "\\b_*rig[A-Z][A-Za-z0-9_\\-]*" },
      { begin: "\\b_[a-z0-9\\-]+" }
    ] }), a = t.inherit(t.TITLE_MODE, { begin: "\\b([A-Za-z0-9_\\-]+)\\b" });
    return {
      name: "LiveCode",
      case_insensitive: !1,
      keywords: {
        keyword: "$_COOKIE $_FILES $_GET $_GET_BINARY $_GET_RAW $_POST $_POST_BINARY $_POST_RAW $_SESSION $_SERVER codepoint codepoints segment segments codeunit codeunits sentence sentences trueWord trueWords paragraph after byte bytes english the until http forever descending using line real8 with seventh for stdout finally element word words fourth before black ninth sixth characters chars stderr uInt1 uInt1s uInt2 uInt2s stdin string lines relative rel any fifth items from middle mid at else of catch then third it file milliseconds seconds second secs sec int1 int1s int4 int4s internet int2 int2s normal text item last long detailed effective uInt4 uInt4s repeat end repeat URL in try into switch to words https token binfile each tenth as ticks tick system real4 by dateItems without char character ascending eighth whole dateTime numeric short first ftp integer abbreviated abbr abbrev private case while if div mod wrap and or bitAnd bitNot bitOr bitXor among not in a an within contains ends with begins the keys of keys",
        literal: "SIX TEN FORMFEED NINE ZERO NONE SPACE FOUR FALSE COLON CRLF PI COMMA ENDOFFILE EOF EIGHT FIVE QUOTE EMPTY ONE TRUE RETURN CR LINEFEED RIGHT BACKSLASH NULL SEVEN TAB THREE TWO six ten formfeed nine zero none space four false colon crlf pi comma endoffile eof eight five quote empty one true return cr linefeed right backslash null seven tab three two RIVERSION RISTATE FILE_READ_MODE FILE_WRITE_MODE FILE_WRITE_MODE DIR_WRITE_MODE FILE_READ_UMASK FILE_WRITE_UMASK DIR_READ_UMASK DIR_WRITE_UMASK",
        built_in: "put abs acos aliasReference annuity arrayDecode arrayEncode asin atan atan2 average avg avgDev base64Decode base64Encode baseConvert binaryDecode binaryEncode byteOffset byteToNum cachedURL cachedURLs charToNum cipherNames codepointOffset codepointProperty codepointToNum codeunitOffset commandNames compound compress constantNames cos date dateFormat decompress difference directories diskSpace DNSServers exp exp1 exp2 exp10 extents files flushEvents folders format functionNames geometricMean global globals hasMemory harmonicMean hostAddress hostAddressToName hostName hostNameToAddress isNumber ISOToMac itemOffset keys len length libURLErrorData libUrlFormData libURLftpCommand libURLLastHTTPHeaders libURLLastRHHeaders libUrlMultipartFormAddPart libUrlMultipartFormData libURLVersion lineOffset ln ln1 localNames log log2 log10 longFilePath lower macToISO matchChunk matchText matrixMultiply max md5Digest median merge messageAuthenticationCode messageDigest millisec millisecs millisecond milliseconds min monthNames nativeCharToNum normalizeText num number numToByte numToChar numToCodepoint numToNativeChar offset open openfiles openProcesses openProcessIDs openSockets paragraphOffset paramCount param params peerAddress pendingMessages platform popStdDev populationStandardDeviation populationVariance popVariance processID random randomBytes replaceText result revCreateXMLTree revCreateXMLTreeFromFile revCurrentRecord revCurrentRecordIsFirst revCurrentRecordIsLast revDatabaseColumnCount revDatabaseColumnIsNull revDatabaseColumnLengths revDatabaseColumnNames revDatabaseColumnNamed revDatabaseColumnNumbered revDatabaseColumnTypes revDatabaseConnectResult revDatabaseCursors revDatabaseID revDatabaseTableNames revDatabaseType revDataFromQuery revdb_closeCursor revdb_columnbynumber revdb_columncount revdb_columnisnull revdb_columnlengths revdb_columnnames revdb_columntypes revdb_commit revdb_connect revdb_connections revdb_connectionerr revdb_currentrecord revdb_cursorconnection revdb_cursorerr revdb_cursors revdb_dbtype revdb_disconnect revdb_execute revdb_iseof revdb_isbof revdb_movefirst revdb_movelast revdb_movenext revdb_moveprev revdb_query revdb_querylist revdb_recordcount revdb_rollback revdb_tablenames revGetDatabaseDriverPath revNumberOfRecords revOpenDatabase revOpenDatabases revQueryDatabase revQueryDatabaseBlob revQueryResult revQueryIsAtStart revQueryIsAtEnd revUnixFromMacPath revXMLAttribute revXMLAttributes revXMLAttributeValues revXMLChildContents revXMLChildNames revXMLCreateTreeFromFileWithNamespaces revXMLCreateTreeWithNamespaces revXMLDataFromXPathQuery revXMLEvaluateXPath revXMLFirstChild revXMLMatchingNode revXMLNextSibling revXMLNodeContents revXMLNumberOfChildren revXMLParent revXMLPreviousSibling revXMLRootNode revXMLRPC_CreateRequest revXMLRPC_Documents revXMLRPC_Error revXMLRPC_GetHost revXMLRPC_GetMethod revXMLRPC_GetParam revXMLText revXMLRPC_Execute revXMLRPC_GetParamCount revXMLRPC_GetParamNode revXMLRPC_GetParamType revXMLRPC_GetPath revXMLRPC_GetPort revXMLRPC_GetProtocol revXMLRPC_GetRequest revXMLRPC_GetResponse revXMLRPC_GetSocket revXMLTree revXMLTrees revXMLValidateDTD revZipDescribeItem revZipEnumerateItems revZipOpenArchives round sampVariance sec secs seconds sentenceOffset sha1Digest shell shortFilePath sin specialFolderPath sqrt standardDeviation statRound stdDev sum sysError systemVersion tan tempName textDecode textEncode tick ticks time to tokenOffset toLower toUpper transpose truewordOffset trunc uniDecode uniEncode upper URLDecode URLEncode URLStatus uuid value variableNames variance version waitDepth weekdayNames wordOffset xsltApplyStylesheet xsltApplyStylesheetFromFile xsltLoadStylesheet xsltLoadStylesheetFromFile add breakpoint cancel clear local variable file word line folder directory URL close socket process combine constant convert create new alias folder directory decrypt delete variable word line folder directory URL dispatch divide do encrypt filter get include intersect kill libURLDownloadToFile libURLFollowHttpRedirects libURLftpUpload libURLftpUploadFile libURLresetAll libUrlSetAuthCallback libURLSetDriver libURLSetCustomHTTPHeaders libUrlSetExpect100 libURLSetFTPListCommand libURLSetFTPMode libURLSetFTPStopTime libURLSetStatusCallback load extension loadedExtensions multiply socket prepare process post seek rel relative read from process rename replace require resetAll resolve revAddXMLNode revAppendXML revCloseCursor revCloseDatabase revCommitDatabase revCopyFile revCopyFolder revCopyXMLNode revDeleteFolder revDeleteXMLNode revDeleteAllXMLTrees revDeleteXMLTree revExecuteSQL revGoURL revInsertXMLNode revMoveFolder revMoveToFirstRecord revMoveToLastRecord revMoveToNextRecord revMoveToPreviousRecord revMoveToRecord revMoveXMLNode revPutIntoXMLNode revRollBackDatabase revSetDatabaseDriverPath revSetXMLAttribute revXMLRPC_AddParam revXMLRPC_DeleteAllDocuments revXMLAddDTD revXMLRPC_Free revXMLRPC_FreeAll revXMLRPC_DeleteDocument revXMLRPC_DeleteParam revXMLRPC_SetHost revXMLRPC_SetMethod revXMLRPC_SetPort revXMLRPC_SetProtocol revXMLRPC_SetSocket revZipAddItemWithData revZipAddItemWithFile revZipAddUncompressedItemWithData revZipAddUncompressedItemWithFile revZipCancel revZipCloseArchive revZipDeleteItem revZipExtractItemToFile revZipExtractItemToVariable revZipSetProgressCallback revZipRenameItem revZipReplaceItemWithData revZipReplaceItemWithFile revZipOpenArchive send set sort split start stop subtract symmetric union unload vectorDotProduct wait write"
      },
      contains: [
        n,
        {
          className: "keyword",
          begin: "\\bend\\sif\\b"
        },
        {
          className: "function",
          beginKeywords: "function",
          end: "$",
          contains: [
            n,
            a,
            t.APOS_STRING_MODE,
            t.QUOTE_STRING_MODE,
            t.BINARY_NUMBER_MODE,
            t.C_NUMBER_MODE,
            i
          ]
        },
        {
          className: "function",
          begin: "\\bend\\s+",
          end: "$",
          keywords: "end",
          contains: [
            a,
            i
          ],
          relevance: 0
        },
        {
          beginKeywords: "command on",
          end: "$",
          contains: [
            n,
            a,
            t.APOS_STRING_MODE,
            t.QUOTE_STRING_MODE,
            t.BINARY_NUMBER_MODE,
            t.C_NUMBER_MODE,
            i
          ]
        },
        {
          className: "meta",
          variants: [
            {
              begin: "<\\?(rev|lc|livecode)",
              relevance: 10
            },
            { begin: "<\\?" },
            { begin: "\\?>" }
          ]
        },
        t.APOS_STRING_MODE,
        t.QUOTE_STRING_MODE,
        t.BINARY_NUMBER_MODE,
        t.C_NUMBER_MODE,
        i
      ].concat(r),
      illegal: ";$|^\\[|^=|&|\\{"
    };
  }
  return lS = e, lS;
}
var uS, gI;
function CJ() {
  if (gI) return uS;
  gI = 1;
  const e = [
    "as",
    // for exports
    "in",
    "of",
    "if",
    "for",
    "while",
    "finally",
    "var",
    "new",
    "function",
    "do",
    "return",
    "void",
    "else",
    "break",
    "catch",
    "instanceof",
    "with",
    "throw",
    "case",
    "default",
    "try",
    "switch",
    "continue",
    "typeof",
    "delete",
    "let",
    "yield",
    "const",
    "class",
    // JS handles these with a special rule
    // "get",
    // "set",
    "debugger",
    "async",
    "await",
    "static",
    "import",
    "from",
    "export",
    "extends"
  ], t = [
    "true",
    "false",
    "null",
    "undefined",
    "NaN",
    "Infinity"
  ], n = [
    // Fundamental objects
    "Object",
    "Function",
    "Boolean",
    "Symbol",
    // numbers and dates
    "Math",
    "Date",
    "Number",
    "BigInt",
    // text
    "String",
    "RegExp",
    // Indexed collections
    "Array",
    "Float32Array",
    "Float64Array",
    "Int8Array",
    "Uint8Array",
    "Uint8ClampedArray",
    "Int16Array",
    "Int32Array",
    "Uint16Array",
    "Uint32Array",
    "BigInt64Array",
    "BigUint64Array",
    // Keyed collections
    "Set",
    "Map",
    "WeakSet",
    "WeakMap",
    // Structured data
    "ArrayBuffer",
    "SharedArrayBuffer",
    "Atomics",
    "DataView",
    "JSON",
    // Control abstraction objects
    "Promise",
    "Generator",
    "GeneratorFunction",
    "AsyncFunction",
    // Reflection
    "Reflect",
    "Proxy",
    // Internationalization
    "Intl",
    // WebAssembly
    "WebAssembly"
  ], r = [
    "Error",
    "EvalError",
    "InternalError",
    "RangeError",
    "ReferenceError",
    "SyntaxError",
    "TypeError",
    "URIError"
  ], i = [
    "setInterval",
    "setTimeout",
    "clearInterval",
    "clearTimeout",
    "require",
    "exports",
    "eval",
    "isFinite",
    "isNaN",
    "parseFloat",
    "parseInt",
    "decodeURI",
    "decodeURIComponent",
    "encodeURI",
    "encodeURIComponent",
    "escape",
    "unescape"
  ], a = [].concat(
    i,
    n,
    r
  );
  function o(s) {
    const l = [
      "npm",
      "print"
    ], u = [
      "yes",
      "no",
      "on",
      "off",
      "it",
      "that",
      "void"
    ], c = [
      "then",
      "unless",
      "until",
      "loop",
      "of",
      "by",
      "when",
      "and",
      "or",
      "is",
      "isnt",
      "not",
      "it",
      "that",
      "otherwise",
      "from",
      "to",
      "til",
      "fallthrough",
      "case",
      "enum",
      "native",
      "list",
      "map",
      "__hasProp",
      "__extends",
      "__slice",
      "__bind",
      "__indexOf"
    ], d = {
      keyword: e.concat(c),
      literal: t.concat(u),
      built_in: a.concat(l)
    }, f = "[A-Za-z$_](?:-[0-9A-Za-z$_]|[0-9A-Za-z$_])*", h = s.inherit(s.TITLE_MODE, { begin: f }), m = {
      className: "subst",
      begin: /#\{/,
      end: /\}/,
      keywords: d
    }, v = {
      className: "subst",
      begin: /#[A-Za-z$_]/,
      end: /(?:-[0-9A-Za-z$_]|[0-9A-Za-z$_])*/,
      keywords: d
    }, b = [
      s.BINARY_NUMBER_MODE,
      {
        className: "number",
        begin: "(\\b0[xX][a-fA-F0-9_]+)|(\\b\\d(\\d|_\\d)*(\\.(\\d(\\d|_\\d)*)?)?(_*[eE]([-+]\\d(_\\d|\\d)*)?)?[_a-z]*)",
        relevance: 0,
        starts: {
          end: "(\\s*/)?",
          relevance: 0
        }
        // a number tries to eat the following slash to prevent treating it as a regexp
      },
      {
        className: "string",
        variants: [
          {
            begin: /'''/,
            end: /'''/,
            contains: [s.BACKSLASH_ESCAPE]
          },
          {
            begin: /'/,
            end: /'/,
            contains: [s.BACKSLASH_ESCAPE]
          },
          {
            begin: /"""/,
            end: /"""/,
            contains: [
              s.BACKSLASH_ESCAPE,
              m,
              v
            ]
          },
          {
            begin: /"/,
            end: /"/,
            contains: [
              s.BACKSLASH_ESCAPE,
              m,
              v
            ]
          },
          {
            begin: /\\/,
            end: /(\s|$)/,
            excludeEnd: !0
          }
        ]
      },
      {
        className: "regexp",
        variants: [
          {
            begin: "//",
            end: "//[gim]*",
            contains: [
              m,
              s.HASH_COMMENT_MODE
            ]
          },
          {
            // regex can't start with space to parse x / 2 / 3 as two divisions
            // regex can't start with *, and it supports an "illegal" in the main mode
            begin: /\/(?![ *])(\\.|[^\\\n])*?\/[gim]*(?=\W)/
          }
        ]
      },
      { begin: "@" + f },
      {
        begin: "``",
        end: "``",
        excludeBegin: !0,
        excludeEnd: !0,
        subLanguage: "javascript"
      }
    ];
    m.contains = b;
    const y = {
      className: "params",
      begin: "\\(",
      returnBegin: !0,
      /* We need another contained nameless mode to not have every nested
      pair of parens to be called "params" */
      contains: [
        {
          begin: /\(/,
          end: /\)/,
          keywords: d,
          contains: ["self"].concat(b)
        }
      ]
    }, g = { begin: "(#=>|=>|\\|>>|-?->|!->)" }, E = {
      variants: [
        { match: [
          /class\s+/,
          f,
          /\s+extends\s+/,
          f
        ] },
        { match: [
          /class\s+/,
          f
        ] }
      ],
      scope: {
        2: "title.class",
        4: "title.class.inherited"
      },
      keywords: d
    };
    return {
      name: "LiveScript",
      aliases: ["ls"],
      keywords: d,
      illegal: /\/\*/,
      contains: b.concat([
        s.COMMENT("\\/\\*", "\\*\\/"),
        s.HASH_COMMENT_MODE,
        g,
        // relevance booster
        {
          className: "function",
          contains: [
            h,
            y
          ],
          returnBegin: !0,
          variants: [
            {
              begin: "(" + f + "\\s*(?:=|:=)\\s*)?(\\(.*\\)\\s*)?\\B->\\*?",
              end: "->\\*?"
            },
            {
              begin: "(" + f + "\\s*(?:=|:=)\\s*)?!?(\\(.*\\)\\s*)?\\B[-~]{1,2}>\\*?",
              end: "[-~]{1,2}>\\*?"
            },
            {
              begin: "(" + f + "\\s*(?:=|:=)\\s*)?(\\(.*\\)\\s*)?\\B!?[-~]{1,2}>\\*?",
              end: "!?[-~]{1,2}>\\*?"
            }
          ]
        },
        E,
        {
          begin: f + ":",
          end: ":",
          returnBegin: !0,
          returnEnd: !0,
          relevance: 0
        }
      ])
    };
  }
  return uS = o, uS;
}
var cS, _I;
function AJ() {
  if (_I) return cS;
  _I = 1;
  function e(t) {
    const n = t.regex, r = /([-a-zA-Z$._][\w$.-]*)/, i = {
      className: "type",
      begin: /\bi\d+(?=\s|\b)/
    }, a = {
      className: "operator",
      relevance: 0,
      begin: /=/
    }, o = {
      className: "punctuation",
      relevance: 0,
      begin: /,/
    }, s = {
      className: "number",
      variants: [
        { begin: /[su]?0[xX][KMLHR]?[a-fA-F0-9]+/ },
        { begin: /[-+]?\d+(?:[.]\d+)?(?:[eE][-+]?\d+(?:[.]\d+)?)?/ }
      ],
      relevance: 0
    }, l = {
      className: "symbol",
      variants: [
        { begin: /^\s*[a-z]+:/ }
        // labels
      ],
      relevance: 0
    }, u = {
      className: "variable",
      variants: [
        { begin: n.concat(/%/, r) },
        { begin: /%\d+/ },
        { begin: /#\d+/ }
      ]
    }, c = {
      className: "title",
      variants: [
        { begin: n.concat(/@/, r) },
        { begin: /@\d+/ },
        { begin: n.concat(/!/, r) },
        { begin: n.concat(/!\d+/, r) },
        // https://llvm.org/docs/LangRef.html#namedmetadatastructure
        // obviously a single digit can also be used in this fashion
        { begin: /!\d+/ }
      ]
    };
    return {
      name: "LLVM IR",
      // TODO: split into different categories of keywords
      keywords: "begin end true false declare define global constant private linker_private internal available_externally linkonce linkonce_odr weak weak_odr appending dllimport dllexport common default hidden protected extern_weak external thread_local zeroinitializer undef null to tail target triple datalayout volatile nuw nsw nnan ninf nsz arcp fast exact inbounds align addrspace section alias module asm sideeffect gc dbg linker_private_weak attributes blockaddress initialexec localdynamic localexec prefix unnamed_addr ccc fastcc coldcc x86_stdcallcc x86_fastcallcc arm_apcscc arm_aapcscc arm_aapcs_vfpcc ptx_device ptx_kernel intel_ocl_bicc msp430_intrcc spir_func spir_kernel x86_64_sysvcc x86_64_win64cc x86_thiscallcc cc c signext zeroext inreg sret nounwind noreturn noalias nocapture byval nest readnone readonly inlinehint noinline alwaysinline optsize ssp sspreq noredzone noimplicitfloat naked builtin cold nobuiltin noduplicate nonlazybind optnone returns_twice sanitize_address sanitize_memory sanitize_thread sspstrong uwtable returned type opaque eq ne slt sgt sle sge ult ugt ule uge oeq one olt ogt ole oge ord uno ueq une x acq_rel acquire alignstack atomic catch cleanup filter inteldialect max min monotonic nand personality release seq_cst singlethread umax umin unordered xchg add fadd sub fsub mul fmul udiv sdiv fdiv urem srem frem shl lshr ashr and or xor icmp fcmp phi call trunc zext sext fptrunc fpext uitofp sitofp fptoui fptosi inttoptr ptrtoint bitcast addrspacecast select va_arg ret br switch invoke unwind unreachable indirectbr landingpad resume malloc alloca free load store getelementptr extractelement insertelement shufflevector getresult extractvalue insertvalue atomicrmw cmpxchg fence argmemonly double",
      contains: [
        i,
        // this matches "empty comments"...
        // ...because it's far more likely this is a statement terminator in
        // another language than an actual comment
        t.COMMENT(/;\s*$/, null, { relevance: 0 }),
        t.COMMENT(/;/, /$/),
        {
          className: "string",
          begin: /"/,
          end: /"/,
          contains: [
            {
              className: "char.escape",
              match: /\\\d\d/
            }
          ]
        },
        c,
        o,
        a,
        u,
        l,
        s
      ]
    };
  }
  return cS = e, cS;
}
var dS, vI;
function OJ() {
  if (vI) return dS;
  vI = 1;
  function e(t) {
    const r = {
      className: "string",
      begin: '"',
      end: '"',
      contains: [{
        className: "subst",
        begin: /\\[tn"\\]/
      }]
    }, i = {
      className: "number",
      relevance: 0,
      begin: t.C_NUMBER_RE
    }, a = {
      className: "literal",
      variants: [
        { begin: "\\b(PI|TWO_PI|PI_BY_TWO|DEG_TO_RAD|RAD_TO_DEG|SQRT2)\\b" },
        { begin: "\\b(XP_ERROR_(EXPERIENCES_DISABLED|EXPERIENCE_(DISABLED|SUSPENDED)|INVALID_(EXPERIENCE|PARAMETERS)|KEY_NOT_FOUND|MATURITY_EXCEEDED|NONE|NOT_(FOUND|PERMITTED(_LAND)?)|NO_EXPERIENCE|QUOTA_EXCEEDED|RETRY_UPDATE|STORAGE_EXCEPTION|STORE_DISABLED|THROTTLED|UNKNOWN_ERROR)|JSON_APPEND|STATUS_(PHYSICS|ROTATE_[XYZ]|PHANTOM|SANDBOX|BLOCK_GRAB(_OBJECT)?|(DIE|RETURN)_AT_EDGE|CAST_SHADOWS|OK|MALFORMED_PARAMS|TYPE_MISMATCH|BOUNDS_ERROR|NOT_(FOUND|SUPPORTED)|INTERNAL_ERROR|WHITELIST_FAILED)|AGENT(_(BY_(LEGACY_|USER)NAME|FLYING|ATTACHMENTS|SCRIPTED|MOUSELOOK|SITTING|ON_OBJECT|AWAY|WALKING|IN_AIR|TYPING|CROUCHING|BUSY|ALWAYS_RUN|AUTOPILOT|LIST_(PARCEL(_OWNER)?|REGION)))?|CAMERA_(PITCH|DISTANCE|BEHINDNESS_(ANGLE|LAG)|(FOCUS|POSITION)(_(THRESHOLD|LOCKED|LAG))?|FOCUS_OFFSET|ACTIVE)|ANIM_ON|LOOP|REVERSE|PING_PONG|SMOOTH|ROTATE|SCALE|ALL_SIDES|LINK_(ROOT|SET|ALL_(OTHERS|CHILDREN)|THIS)|ACTIVE|PASS(IVE|_(ALWAYS|IF_NOT_HANDLED|NEVER))|SCRIPTED|CONTROL_(FWD|BACK|(ROT_)?(LEFT|RIGHT)|UP|DOWN|(ML_)?LBUTTON)|PERMISSION_(RETURN_OBJECTS|DEBIT|OVERRIDE_ANIMATIONS|SILENT_ESTATE_MANAGEMENT|TAKE_CONTROLS|TRIGGER_ANIMATION|ATTACH|CHANGE_LINKS|(CONTROL|TRACK)_CAMERA|TELEPORT)|INVENTORY_(TEXTURE|SOUND|OBJECT|SCRIPT|LANDMARK|CLOTHING|NOTECARD|BODYPART|ANIMATION|GESTURE|ALL|NONE)|CHANGED_(INVENTORY|COLOR|SHAPE|SCALE|TEXTURE|LINK|ALLOWED_DROP|OWNER|REGION(_START)?|TELEPORT|MEDIA)|OBJECT_(CLICK_ACTION|HOVER_HEIGHT|LAST_OWNER_ID|(PHYSICS|SERVER|STREAMING)_COST|UNKNOWN_DETAIL|CHARACTER_TIME|PHANTOM|PHYSICS|TEMP_(ATTACHED|ON_REZ)|NAME|DESC|POS|PRIM_(COUNT|EQUIVALENCE)|RETURN_(PARCEL(_OWNER)?|REGION)|REZZER_KEY|ROO?T|VELOCITY|OMEGA|OWNER|GROUP(_TAG)?|CREATOR|ATTACHED_(POINT|SLOTS_AVAILABLE)|RENDER_WEIGHT|(BODY_SHAPE|PATHFINDING)_TYPE|(RUNNING|TOTAL)_SCRIPT_COUNT|TOTAL_INVENTORY_COUNT|SCRIPT_(MEMORY|TIME))|TYPE_(INTEGER|FLOAT|STRING|KEY|VECTOR|ROTATION|INVALID)|(DEBUG|PUBLIC)_CHANNEL|ATTACH_(AVATAR_CENTER|CHEST|HEAD|BACK|PELVIS|MOUTH|CHIN|NECK|NOSE|BELLY|[LR](SHOULDER|HAND|FOOT|EAR|EYE|[UL](ARM|LEG)|HIP)|(LEFT|RIGHT)_PEC|HUD_(CENTER_[12]|TOP_(RIGHT|CENTER|LEFT)|BOTTOM(_(RIGHT|LEFT))?)|[LR]HAND_RING1|TAIL_(BASE|TIP)|[LR]WING|FACE_(JAW|[LR]EAR|[LR]EYE|TOUNGE)|GROIN|HIND_[LR]FOOT)|LAND_(LEVEL|RAISE|LOWER|SMOOTH|NOISE|REVERT)|DATA_(ONLINE|NAME|BORN|SIM_(POS|STATUS|RATING)|PAYINFO)|PAYMENT_INFO_(ON_FILE|USED)|REMOTE_DATA_(CHANNEL|REQUEST|REPLY)|PSYS_(PART_(BF_(ZERO|ONE(_MINUS_(DEST_COLOR|SOURCE_(ALPHA|COLOR)))?|DEST_COLOR|SOURCE_(ALPHA|COLOR))|BLEND_FUNC_(DEST|SOURCE)|FLAGS|(START|END)_(COLOR|ALPHA|SCALE|GLOW)|MAX_AGE|(RIBBON|WIND|INTERP_(COLOR|SCALE)|BOUNCE|FOLLOW_(SRC|VELOCITY)|TARGET_(POS|LINEAR)|EMISSIVE)_MASK)|SRC_(MAX_AGE|PATTERN|ANGLE_(BEGIN|END)|BURST_(RATE|PART_COUNT|RADIUS|SPEED_(MIN|MAX))|ACCEL|TEXTURE|TARGET_KEY|OMEGA|PATTERN_(DROP|EXPLODE|ANGLE(_CONE(_EMPTY)?)?)))|VEHICLE_(REFERENCE_FRAME|TYPE_(NONE|SLED|CAR|BOAT|AIRPLANE|BALLOON)|(LINEAR|ANGULAR)_(FRICTION_TIMESCALE|MOTOR_DIRECTION)|LINEAR_MOTOR_OFFSET|HOVER_(HEIGHT|EFFICIENCY|TIMESCALE)|BUOYANCY|(LINEAR|ANGULAR)_(DEFLECTION_(EFFICIENCY|TIMESCALE)|MOTOR_(DECAY_)?TIMESCALE)|VERTICAL_ATTRACTION_(EFFICIENCY|TIMESCALE)|BANKING_(EFFICIENCY|MIX|TIMESCALE)|FLAG_(NO_DEFLECTION_UP|LIMIT_(ROLL_ONLY|MOTOR_UP)|HOVER_((WATER|TERRAIN|UP)_ONLY|GLOBAL_HEIGHT)|MOUSELOOK_(STEER|BANK)|CAMERA_DECOUPLED))|PRIM_(ALLOW_UNSIT|ALPHA_MODE(_(BLEND|EMISSIVE|MASK|NONE))?|NORMAL|SPECULAR|TYPE(_(BOX|CYLINDER|PRISM|SPHERE|TORUS|TUBE|RING|SCULPT))?|HOLE_(DEFAULT|CIRCLE|SQUARE|TRIANGLE)|MATERIAL(_(STONE|METAL|GLASS|WOOD|FLESH|PLASTIC|RUBBER))?|SHINY_(NONE|LOW|MEDIUM|HIGH)|BUMP_(NONE|BRIGHT|DARK|WOOD|BARK|BRICKS|CHECKER|CONCRETE|TILE|STONE|DISKS|GRAVEL|BLOBS|SIDING|LARGETILE|STUCCO|SUCTION|WEAVE)|TEXGEN_(DEFAULT|PLANAR)|SCRIPTED_SIT_ONLY|SCULPT_(TYPE_(SPHERE|TORUS|PLANE|CYLINDER|MASK)|FLAG_(MIRROR|INVERT))|PHYSICS(_(SHAPE_(CONVEX|NONE|PRIM|TYPE)))?|(POS|ROT)_LOCAL|SLICE|TEXT|FLEXIBLE|POINT_LIGHT|TEMP_ON_REZ|PHANTOM|POSITION|SIT_TARGET|SIZE|ROTATION|TEXTURE|NAME|OMEGA|DESC|LINK_TARGET|COLOR|BUMP_SHINY|FULLBRIGHT|TEXGEN|GLOW|MEDIA_(ALT_IMAGE_ENABLE|CONTROLS|(CURRENT|HOME)_URL|AUTO_(LOOP|PLAY|SCALE|ZOOM)|FIRST_CLICK_INTERACT|(WIDTH|HEIGHT)_PIXELS|WHITELIST(_ENABLE)?|PERMS_(INTERACT|CONTROL)|PARAM_MAX|CONTROLS_(STANDARD|MINI)|PERM_(NONE|OWNER|GROUP|ANYONE)|MAX_(URL_LENGTH|WHITELIST_(SIZE|COUNT)|(WIDTH|HEIGHT)_PIXELS)))|MASK_(BASE|OWNER|GROUP|EVERYONE|NEXT)|PERM_(TRANSFER|MODIFY|COPY|MOVE|ALL)|PARCEL_(MEDIA_COMMAND_(STOP|PAUSE|PLAY|LOOP|TEXTURE|URL|TIME|AGENT|UNLOAD|AUTO_ALIGN|TYPE|SIZE|DESC|LOOP_SET)|FLAG_(ALLOW_(FLY|(GROUP_)?SCRIPTS|LANDMARK|TERRAFORM|DAMAGE|CREATE_(GROUP_)?OBJECTS)|USE_(ACCESS_(GROUP|LIST)|BAN_LIST|LAND_PASS_LIST)|LOCAL_SOUND_ONLY|RESTRICT_PUSHOBJECT|ALLOW_(GROUP|ALL)_OBJECT_ENTRY)|COUNT_(TOTAL|OWNER|GROUP|OTHER|SELECTED|TEMP)|DETAILS_(NAME|DESC|OWNER|GROUP|AREA|ID|SEE_AVATARS))|LIST_STAT_(MAX|MIN|MEAN|MEDIAN|STD_DEV|SUM(_SQUARES)?|NUM_COUNT|GEOMETRIC_MEAN|RANGE)|PAY_(HIDE|DEFAULT)|REGION_FLAG_(ALLOW_DAMAGE|FIXED_SUN|BLOCK_TERRAFORM|SANDBOX|DISABLE_(COLLISIONS|PHYSICS)|BLOCK_FLY|ALLOW_DIRECT_TELEPORT|RESTRICT_PUSHOBJECT)|HTTP_(METHOD|MIMETYPE|BODY_(MAXLENGTH|TRUNCATED)|CUSTOM_HEADER|PRAGMA_NO_CACHE|VERBOSE_THROTTLE|VERIFY_CERT)|SIT_(INVALID_(AGENT|LINK_OBJECT)|NO(T_EXPERIENCE|_(ACCESS|EXPERIENCE_PERMISSION|SIT_TARGET)))|STRING_(TRIM(_(HEAD|TAIL))?)|CLICK_ACTION_(NONE|TOUCH|SIT|BUY|PAY|OPEN(_MEDIA)?|PLAY|ZOOM)|TOUCH_INVALID_FACE|PROFILE_(NONE|SCRIPT_MEMORY)|RC_(DATA_FLAGS|DETECT_PHANTOM|GET_(LINK_NUM|NORMAL|ROOT_KEY)|MAX_HITS|REJECT_(TYPES|AGENTS|(NON)?PHYSICAL|LAND))|RCERR_(CAST_TIME_EXCEEDED|SIM_PERF_LOW|UNKNOWN)|ESTATE_ACCESS_(ALLOWED_(AGENT|GROUP)_(ADD|REMOVE)|BANNED_AGENT_(ADD|REMOVE))|DENSITY|FRICTION|RESTITUTION|GRAVITY_MULTIPLIER|KFM_(COMMAND|CMD_(PLAY|STOP|PAUSE)|MODE|FORWARD|LOOP|PING_PONG|REVERSE|DATA|ROTATION|TRANSLATION)|ERR_(GENERIC|PARCEL_PERMISSIONS|MALFORMED_PARAMS|RUNTIME_PERMISSIONS|THROTTLED)|CHARACTER_(CMD_((SMOOTH_)?STOP|JUMP)|DESIRED_(TURN_)?SPEED|RADIUS|STAY_WITHIN_PARCEL|LENGTH|ORIENTATION|ACCOUNT_FOR_SKIPPED_FRAMES|AVOIDANCE_MODE|TYPE(_([ABCD]|NONE))?|MAX_(DECEL|TURN_RADIUS|(ACCEL|SPEED)))|PURSUIT_(OFFSET|FUZZ_FACTOR|GOAL_TOLERANCE|INTERCEPT)|REQUIRE_LINE_OF_SIGHT|FORCE_DIRECT_PATH|VERTICAL|HORIZONTAL|AVOID_(CHARACTERS|DYNAMIC_OBSTACLES|NONE)|PU_(EVADE_(HIDDEN|SPOTTED)|FAILURE_(DYNAMIC_PATHFINDING_DISABLED|INVALID_(GOAL|START)|NO_(NAVMESH|VALID_DESTINATION)|OTHER|TARGET_GONE|(PARCEL_)?UNREACHABLE)|(GOAL|SLOWDOWN_DISTANCE)_REACHED)|TRAVERSAL_TYPE(_(FAST|NONE|SLOW))?|CONTENT_TYPE_(ATOM|FORM|HTML|JSON|LLSD|RSS|TEXT|XHTML|XML)|GCNP_(RADIUS|STATIC)|(PATROL|WANDER)_PAUSE_AT_WAYPOINTS|OPT_(AVATAR|CHARACTER|EXCLUSION_VOLUME|LEGACY_LINKSET|MATERIAL_VOLUME|OTHER|STATIC_OBSTACLE|WALKABLE)|SIM_STAT_PCT_CHARS_STEPPED)\\b" },
        { begin: "\\b(FALSE|TRUE)\\b" },
        { begin: "\\b(ZERO_ROTATION)\\b" },
        { begin: "\\b(EOF|JSON_(ARRAY|DELETE|FALSE|INVALID|NULL|NUMBER|OBJECT|STRING|TRUE)|NULL_KEY|TEXTURE_(BLANK|DEFAULT|MEDIA|PLYWOOD|TRANSPARENT)|URL_REQUEST_(GRANTED|DENIED))\\b" },
        { begin: "\\b(ZERO_VECTOR|TOUCH_INVALID_(TEXCOORD|VECTOR))\\b" }
      ]
    }, o = {
      className: "built_in",
      begin: "\\b(ll(AgentInExperience|(Create|DataSize|Delete|KeyCount|Keys|Read|Update)KeyValue|GetExperience(Details|ErrorMessage)|ReturnObjectsBy(ID|Owner)|Json(2List|[GS]etValue|ValueType)|Sin|Cos|Tan|Atan2|Sqrt|Pow|Abs|Fabs|Frand|Floor|Ceil|Round|Vec(Mag|Norm|Dist)|Rot(Between|2(Euler|Fwd|Left|Up))|(Euler|Axes)2Rot|Whisper|(Region|Owner)?Say|Shout|Listen(Control|Remove)?|Sensor(Repeat|Remove)?|Detected(Name|Key|Owner|Type|Pos|Vel|Grab|Rot|Group|LinkNumber)|Die|Ground|Wind|([GS]et)(AnimationOverride|MemoryLimit|PrimMediaParams|ParcelMusicURL|Object(Desc|Name)|PhysicsMaterial|Status|Scale|Color|Alpha|Texture|Pos|Rot|Force|Torque)|ResetAnimationOverride|(Scale|Offset|Rotate)Texture|(Rot)?Target(Remove)?|(Stop)?MoveToTarget|Apply(Rotational)?Impulse|Set(KeyframedMotion|ContentType|RegionPos|(Angular)?Velocity|Buoyancy|HoverHeight|ForceAndTorque|TimerEvent|ScriptState|Damage|TextureAnim|Sound(Queueing|Radius)|Vehicle(Type|(Float|Vector|Rotation)Param)|(Touch|Sit)?Text|Camera(Eye|At)Offset|PrimitiveParams|ClickAction|Link(Alpha|Color|PrimitiveParams(Fast)?|Texture(Anim)?|Camera|Media)|RemoteScriptAccessPin|PayPrice|LocalRot)|ScaleByFactor|Get((Max|Min)ScaleFactor|ClosestNavPoint|StaticPath|SimStats|Env|PrimitiveParams|Link(PrimitiveParams|Number(OfSides)?|Key|Name|Media)|HTTPHeader|FreeURLs|Object(Details|PermMask|PrimCount)|Parcel(MaxPrims|Details|Prim(Count|Owners))|Attached(List)?|(SPMax|Free|Used)Memory|Region(Name|TimeDilation|FPS|Corner|AgentCount)|Root(Position|Rotation)|UnixTime|(Parcel|Region)Flags|(Wall|GMT)clock|SimulatorHostname|BoundingBox|GeometricCenter|Creator|NumberOf(Prims|NotecardLines|Sides)|Animation(List)?|(Camera|Local)(Pos|Rot)|Vel|Accel|Omega|Time(stamp|OfDay)|(Object|CenterOf)?Mass|MassMKS|Energy|Owner|(Owner)?Key|SunDirection|Texture(Offset|Scale|Rot)|Inventory(Number|Name|Key|Type|Creator|PermMask)|Permissions(Key)?|StartParameter|List(Length|EntryType)|Date|Agent(Size|Info|Language|List)|LandOwnerAt|NotecardLine|Script(Name|State))|(Get|Reset|GetAndReset)Time|PlaySound(Slave)?|LoopSound(Master|Slave)?|(Trigger|Stop|Preload)Sound|((Get|Delete)Sub|Insert)String|To(Upper|Lower)|Give(InventoryList|Money)|RezObject|(Stop)?LookAt|Sleep|CollisionFilter|(Take|Release)Controls|DetachFromAvatar|AttachToAvatar(Temp)?|InstantMessage|(GetNext)?Email|StopHover|MinEventDelay|RotLookAt|String(Length|Trim)|(Start|Stop)Animation|TargetOmega|Request(Experience)?Permissions|(Create|Break)Link|BreakAllLinks|(Give|Remove)Inventory|Water|PassTouches|Request(Agent|Inventory)Data|TeleportAgent(Home|GlobalCoords)?|ModifyLand|CollisionSound|ResetScript|MessageLinked|PushObject|PassCollisions|AxisAngle2Rot|Rot2(Axis|Angle)|A(cos|sin)|AngleBetween|AllowInventoryDrop|SubStringIndex|List2(CSV|Integer|Json|Float|String|Key|Vector|Rot|List(Strided)?)|DeleteSubList|List(Statistics|Sort|Randomize|(Insert|Find|Replace)List)|EdgeOfWorld|AdjustSoundVolume|Key2Name|TriggerSoundLimited|EjectFromLand|(CSV|ParseString)2List|OverMyLand|SameGroup|UnSit|Ground(Slope|Normal|Contour)|GroundRepel|(Set|Remove)VehicleFlags|SitOnLink|(AvatarOn)?(Link)?SitTarget|Script(Danger|Profiler)|Dialog|VolumeDetect|ResetOtherScript|RemoteLoadScriptPin|(Open|Close)RemoteDataChannel|SendRemoteData|RemoteDataReply|(Integer|String)ToBase64|XorBase64|Log(10)?|Base64To(String|Integer)|ParseStringKeepNulls|RezAtRoot|RequestSimulatorData|ForceMouselook|(Load|Release|(E|Une)scape)URL|ParcelMedia(CommandList|Query)|ModPow|MapDestination|(RemoveFrom|AddTo|Reset)Land(Pass|Ban)List|(Set|Clear)CameraParams|HTTP(Request|Response)|TextBox|DetectedTouch(UV|Face|Pos|(N|Bin)ormal|ST)|(MD5|SHA1|DumpList2)String|Request(Secure)?URL|Clear(Prim|Link)Media|(Link)?ParticleSystem|(Get|Request)(Username|DisplayName)|RegionSayTo|CastRay|GenerateKey|TransferLindenDollars|ManageEstateAccess|(Create|Delete)Character|ExecCharacterCmd|Evade|FleeFrom|NavigateTo|PatrolPoints|Pursue|UpdateCharacter|WanderWithin))\\b"
    };
    return {
      name: "LSL (Linden Scripting Language)",
      illegal: ":",
      contains: [
        r,
        {
          className: "comment",
          variants: [
            t.COMMENT("//", "$"),
            t.COMMENT("/\\*", "\\*/")
          ],
          relevance: 0
        },
        i,
        {
          className: "section",
          variants: [
            { begin: "\\b(state|default)\\b" },
            { begin: "\\b(state_(entry|exit)|touch(_(start|end))?|(land_)?collision(_(start|end))?|timer|listen|(no_)?sensor|control|(not_)?at_(rot_)?target|money|email|experience_permissions(_denied)?|run_time_permissions|changed|attach|dataserver|moving_(start|end)|link_message|(on|object)_rez|remote_data|http_re(sponse|quest)|path_update|transaction_result)\\b" }
          ]
        },
        o,
        a,
        {
          className: "type",
          begin: "\\b(integer|float|string|key|vector|quaternion|rotation|list)\\b"
        }
      ]
    };
  }
  return dS = e, dS;
}
var fS, bI;
function RJ() {
  if (bI) return fS;
  bI = 1;
  function e(t) {
    const n = "\\[=*\\[", r = "\\]=*\\]", i = {
      begin: n,
      end: r,
      contains: ["self"]
    }, a = [
      t.COMMENT("--(?!" + n + ")", "$"),
      t.COMMENT(
        "--" + n,
        r,
        {
          contains: [i],
          relevance: 10
        }
      )
    ];
    return {
      name: "Lua",
      keywords: {
        $pattern: t.UNDERSCORE_IDENT_RE,
        literal: "true false nil",
        keyword: "and break do else elseif end for goto if in local not or repeat return then until while",
        built_in: (
          // Metatags and globals:
          "_G _ENV _VERSION __index __newindex __mode __call __metatable __tostring __len __gc __add __sub __mul __div __mod __pow __concat __unm __eq __lt __le assert collectgarbage dofile error getfenv getmetatable ipairs load loadfile loadstring module next pairs pcall print rawequal rawget rawset require select setfenv setmetatable tonumber tostring type unpack xpcall arg self coroutine resume yield status wrap create running debug getupvalue debug sethook getmetatable gethook setmetatable setlocal traceback setfenv getinfo setupvalue getlocal getregistry getfenv io lines write close flush open output type read stderr stdin input stdout popen tmpfile math log max acos huge ldexp pi cos tanh pow deg tan cosh sinh random randomseed frexp ceil floor rad abs sqrt modf asin min mod fmod log10 atan2 exp sin atan os exit setlocale date getenv difftime remove time clock tmpname rename execute package preload loadlib loaded loaders cpath config path seeall string sub upper len gfind rep find match char dump gmatch reverse byte format gsub lower table setn insert getn foreachi maxn foreach concat sort remove"
        )
      },
      contains: a.concat([
        {
          className: "function",
          beginKeywords: "function",
          end: "\\)",
          contains: [
            t.inherit(t.TITLE_MODE, { begin: "([_a-zA-Z]\\w*\\.)*([_a-zA-Z]\\w*:)?[_a-zA-Z]\\w*" }),
            {
              className: "params",
              begin: "\\(",
              endsWithParent: !0,
              contains: a
            }
          ].concat(a)
        },
        t.C_NUMBER_MODE,
        t.APOS_STRING_MODE,
        t.QUOTE_STRING_MODE,
        {
          className: "string",
          begin: n,
          end: r,
          contains: [i],
          relevance: 5
        }
      ])
    };
  }
  return fS = e, fS;
}
var pS, EI;
function wJ() {
  if (EI) return pS;
  EI = 1;
  function e(t) {
    const n = {
      className: "variable",
      variants: [
        {
          begin: "\\$\\(" + t.UNDERSCORE_IDENT_RE + "\\)",
          contains: [t.BACKSLASH_ESCAPE]
        },
        { begin: /\$[@%<?\^\+\*]/ }
      ]
    }, r = {
      className: "string",
      begin: /"/,
      end: /"/,
      contains: [
        t.BACKSLASH_ESCAPE,
        n
      ]
    }, i = {
      className: "variable",
      begin: /\$\([\w-]+\s/,
      end: /\)/,
      keywords: { built_in: "subst patsubst strip findstring filter filter-out sort word wordlist firstword lastword dir notdir suffix basename addsuffix addprefix join wildcard realpath abspath error warning shell origin flavor foreach if or and call eval file value" },
      contains: [n]
    }, a = { begin: "^" + t.UNDERSCORE_IDENT_RE + "\\s*(?=[:+?]?=)" }, o = {
      className: "meta",
      begin: /^\.PHONY:/,
      end: /$/,
      keywords: {
        $pattern: /[\.\w]+/,
        keyword: ".PHONY"
      }
    }, s = {
      className: "section",
      begin: /^[^\s]+:/,
      end: /$/,
      contains: [n]
    };
    return {
      name: "Makefile",
      aliases: [
        "mk",
        "mak",
        "make"
      ],
      keywords: {
        $pattern: /[\w-]+/,
        keyword: "define endef undefine ifdef ifndef ifeq ifneq else endif include -include sinclude override export unexport private vpath"
      },
      contains: [
        t.HASH_COMMENT_MODE,
        n,
        r,
        i,
        a,
        o,
        s
      ]
    };
  }
  return pS = e, pS;
}
var mS, SI;
function xJ() {
  if (SI) return mS;
  SI = 1;
  const e = [
    "AASTriangle",
    "AbelianGroup",
    "Abort",
    "AbortKernels",
    "AbortProtect",
    "AbortScheduledTask",
    "Above",
    "Abs",
    "AbsArg",
    "AbsArgPlot",
    "Absolute",
    "AbsoluteCorrelation",
    "AbsoluteCorrelationFunction",
    "AbsoluteCurrentValue",
    "AbsoluteDashing",
    "AbsoluteFileName",
    "AbsoluteOptions",
    "AbsolutePointSize",
    "AbsoluteThickness",
    "AbsoluteTime",
    "AbsoluteTiming",
    "AcceptanceThreshold",
    "AccountingForm",
    "Accumulate",
    "Accuracy",
    "AccuracyGoal",
    "AcousticAbsorbingValue",
    "AcousticImpedanceValue",
    "AcousticNormalVelocityValue",
    "AcousticPDEComponent",
    "AcousticPressureCondition",
    "AcousticRadiationValue",
    "AcousticSoundHardValue",
    "AcousticSoundSoftCondition",
    "ActionDelay",
    "ActionMenu",
    "ActionMenuBox",
    "ActionMenuBoxOptions",
    "Activate",
    "Active",
    "ActiveClassification",
    "ActiveClassificationObject",
    "ActiveItem",
    "ActivePrediction",
    "ActivePredictionObject",
    "ActiveStyle",
    "AcyclicGraphQ",
    "AddOnHelpPath",
    "AddSides",
    "AddTo",
    "AddToSearchIndex",
    "AddUsers",
    "AdjacencyGraph",
    "AdjacencyList",
    "AdjacencyMatrix",
    "AdjacentMeshCells",
    "Adjugate",
    "AdjustmentBox",
    "AdjustmentBoxOptions",
    "AdjustTimeSeriesForecast",
    "AdministrativeDivisionData",
    "AffineHalfSpace",
    "AffineSpace",
    "AffineStateSpaceModel",
    "AffineTransform",
    "After",
    "AggregatedEntityClass",
    "AggregationLayer",
    "AircraftData",
    "AirportData",
    "AirPressureData",
    "AirSoundAttenuation",
    "AirTemperatureData",
    "AiryAi",
    "AiryAiPrime",
    "AiryAiZero",
    "AiryBi",
    "AiryBiPrime",
    "AiryBiZero",
    "AlgebraicIntegerQ",
    "AlgebraicNumber",
    "AlgebraicNumberDenominator",
    "AlgebraicNumberNorm",
    "AlgebraicNumberPolynomial",
    "AlgebraicNumberTrace",
    "AlgebraicRules",
    "AlgebraicRulesData",
    "Algebraics",
    "AlgebraicUnitQ",
    "Alignment",
    "AlignmentMarker",
    "AlignmentPoint",
    "All",
    "AllowAdultContent",
    "AllowChatServices",
    "AllowedCloudExtraParameters",
    "AllowedCloudParameterExtensions",
    "AllowedDimensions",
    "AllowedFrequencyRange",
    "AllowedHeads",
    "AllowGroupClose",
    "AllowIncomplete",
    "AllowInlineCells",
    "AllowKernelInitialization",
    "AllowLooseGrammar",
    "AllowReverseGroupClose",
    "AllowScriptLevelChange",
    "AllowVersionUpdate",
    "AllTrue",
    "Alphabet",
    "AlphabeticOrder",
    "AlphabeticSort",
    "AlphaChannel",
    "AlternateImage",
    "AlternatingFactorial",
    "AlternatingGroup",
    "AlternativeHypothesis",
    "Alternatives",
    "AltitudeMethod",
    "AmbientLight",
    "AmbiguityFunction",
    "AmbiguityList",
    "Analytic",
    "AnatomyData",
    "AnatomyForm",
    "AnatomyPlot3D",
    "AnatomySkinStyle",
    "AnatomyStyling",
    "AnchoredSearch",
    "And",
    "AndersonDarlingTest",
    "AngerJ",
    "AngleBisector",
    "AngleBracket",
    "AnglePath",
    "AnglePath3D",
    "AngleVector",
    "AngularGauge",
    "Animate",
    "AnimatedImage",
    "AnimationCycleOffset",
    "AnimationCycleRepetitions",
    "AnimationDirection",
    "AnimationDisplayTime",
    "AnimationRate",
    "AnimationRepetitions",
    "AnimationRunning",
    "AnimationRunTime",
    "AnimationTimeIndex",
    "AnimationVideo",
    "Animator",
    "AnimatorBox",
    "AnimatorBoxOptions",
    "AnimatorElements",
    "Annotate",
    "Annotation",
    "AnnotationDelete",
    "AnnotationKeys",
    "AnnotationRules",
    "AnnotationValue",
    "Annuity",
    "AnnuityDue",
    "Annulus",
    "AnomalyDetection",
    "AnomalyDetector",
    "AnomalyDetectorFunction",
    "Anonymous",
    "Antialiasing",
    "Antihermitian",
    "AntihermitianMatrixQ",
    "Antisymmetric",
    "AntisymmetricMatrixQ",
    "Antonyms",
    "AnyOrder",
    "AnySubset",
    "AnyTrue",
    "Apart",
    "ApartSquareFree",
    "APIFunction",
    "Appearance",
    "AppearanceElements",
    "AppearanceRules",
    "AppellF1",
    "Append",
    "AppendCheck",
    "AppendLayer",
    "AppendTo",
    "Application",
    "Apply",
    "ApplyReaction",
    "ApplySides",
    "ApplyTo",
    "ArcCos",
    "ArcCosh",
    "ArcCot",
    "ArcCoth",
    "ArcCsc",
    "ArcCsch",
    "ArcCurvature",
    "ARCHProcess",
    "ArcLength",
    "ArcSec",
    "ArcSech",
    "ArcSin",
    "ArcSinDistribution",
    "ArcSinh",
    "ArcTan",
    "ArcTanh",
    "Area",
    "Arg",
    "ArgMax",
    "ArgMin",
    "ArgumentCountQ",
    "ArgumentsOptions",
    "ARIMAProcess",
    "ArithmeticGeometricMean",
    "ARMAProcess",
    "Around",
    "AroundReplace",
    "ARProcess",
    "Array",
    "ArrayComponents",
    "ArrayDepth",
    "ArrayFilter",
    "ArrayFlatten",
    "ArrayMesh",
    "ArrayPad",
    "ArrayPlot",
    "ArrayPlot3D",
    "ArrayQ",
    "ArrayReduce",
    "ArrayResample",
    "ArrayReshape",
    "ArrayRules",
    "Arrays",
    "Arrow",
    "Arrow3DBox",
    "ArrowBox",
    "Arrowheads",
    "ASATriangle",
    "Ask",
    "AskAppend",
    "AskConfirm",
    "AskDisplay",
    "AskedQ",
    "AskedValue",
    "AskFunction",
    "AskState",
    "AskTemplateDisplay",
    "AspectRatio",
    "AspectRatioFixed",
    "Assert",
    "AssessmentFunction",
    "AssessmentResultObject",
    "AssociateTo",
    "Association",
    "AssociationFormat",
    "AssociationMap",
    "AssociationQ",
    "AssociationThread",
    "AssumeDeterministic",
    "Assuming",
    "Assumptions",
    "AstroAngularSeparation",
    "AstroBackground",
    "AstroCenter",
    "AstroDistance",
    "AstroGraphics",
    "AstroGridLines",
    "AstroGridLinesStyle",
    "AstronomicalData",
    "AstroPosition",
    "AstroProjection",
    "AstroRange",
    "AstroRangePadding",
    "AstroReferenceFrame",
    "AstroStyling",
    "AstroZoomLevel",
    "Asymptotic",
    "AsymptoticDSolveValue",
    "AsymptoticEqual",
    "AsymptoticEquivalent",
    "AsymptoticExpectation",
    "AsymptoticGreater",
    "AsymptoticGreaterEqual",
    "AsymptoticIntegrate",
    "AsymptoticLess",
    "AsymptoticLessEqual",
    "AsymptoticOutputTracker",
    "AsymptoticProbability",
    "AsymptoticProduct",
    "AsymptoticRSolveValue",
    "AsymptoticSolve",
    "AsymptoticSum",
    "Asynchronous",
    "AsynchronousTaskObject",
    "AsynchronousTasks",
    "Atom",
    "AtomCoordinates",
    "AtomCount",
    "AtomDiagramCoordinates",
    "AtomLabels",
    "AtomLabelStyle",
    "AtomList",
    "AtomQ",
    "AttachCell",
    "AttachedCell",
    "AttentionLayer",
    "Attributes",
    "Audio",
    "AudioAmplify",
    "AudioAnnotate",
    "AudioAnnotationLookup",
    "AudioBlockMap",
    "AudioCapture",
    "AudioChannelAssignment",
    "AudioChannelCombine",
    "AudioChannelMix",
    "AudioChannels",
    "AudioChannelSeparate",
    "AudioData",
    "AudioDelay",
    "AudioDelete",
    "AudioDevice",
    "AudioDistance",
    "AudioEncoding",
    "AudioFade",
    "AudioFrequencyShift",
    "AudioGenerator",
    "AudioIdentify",
    "AudioInputDevice",
    "AudioInsert",
    "AudioInstanceQ",
    "AudioIntervals",
    "AudioJoin",
    "AudioLabel",
    "AudioLength",
    "AudioLocalMeasurements",
    "AudioLooping",
    "AudioLoudness",
    "AudioMeasurements",
    "AudioNormalize",
    "AudioOutputDevice",
    "AudioOverlay",
    "AudioPad",
    "AudioPan",
    "AudioPartition",
    "AudioPause",
    "AudioPitchShift",
    "AudioPlay",
    "AudioPlot",
    "AudioQ",
    "AudioRecord",
    "AudioReplace",
    "AudioResample",
    "AudioReverb",
    "AudioReverse",
    "AudioSampleRate",
    "AudioSpectralMap",
    "AudioSpectralTransformation",
    "AudioSplit",
    "AudioStop",
    "AudioStream",
    "AudioStreams",
    "AudioTimeStretch",
    "AudioTrackApply",
    "AudioTrackSelection",
    "AudioTrim",
    "AudioType",
    "AugmentedPolyhedron",
    "AugmentedSymmetricPolynomial",
    "Authenticate",
    "Authentication",
    "AuthenticationDialog",
    "AutoAction",
    "Autocomplete",
    "AutocompletionFunction",
    "AutoCopy",
    "AutocorrelationTest",
    "AutoDelete",
    "AutoEvaluateEvents",
    "AutoGeneratedPackage",
    "AutoIndent",
    "AutoIndentSpacings",
    "AutoItalicWords",
    "AutoloadPath",
    "AutoMatch",
    "Automatic",
    "AutomaticImageSize",
    "AutoMultiplicationSymbol",
    "AutoNumberFormatting",
    "AutoOpenNotebooks",
    "AutoOpenPalettes",
    "AutoOperatorRenderings",
    "AutoQuoteCharacters",
    "AutoRefreshed",
    "AutoRemove",
    "AutorunSequencing",
    "AutoScaling",
    "AutoScroll",
    "AutoSpacing",
    "AutoStyleOptions",
    "AutoStyleWords",
    "AutoSubmitting",
    "Axes",
    "AxesEdge",
    "AxesLabel",
    "AxesOrigin",
    "AxesStyle",
    "AxiomaticTheory",
    "Axis",
    "Axis3DBox",
    "Axis3DBoxOptions",
    "AxisBox",
    "AxisBoxOptions",
    "AxisLabel",
    "AxisObject",
    "AxisStyle",
    "BabyMonsterGroupB",
    "Back",
    "BackFaceColor",
    "BackFaceGlowColor",
    "BackFaceOpacity",
    "BackFaceSpecularColor",
    "BackFaceSpecularExponent",
    "BackFaceSurfaceAppearance",
    "BackFaceTexture",
    "Background",
    "BackgroundAppearance",
    "BackgroundTasksSettings",
    "Backslash",
    "Backsubstitution",
    "Backward",
    "Ball",
    "Band",
    "BandpassFilter",
    "BandstopFilter",
    "BarabasiAlbertGraphDistribution",
    "BarChart",
    "BarChart3D",
    "BarcodeImage",
    "BarcodeRecognize",
    "BaringhausHenzeTest",
    "BarLegend",
    "BarlowProschanImportance",
    "BarnesG",
    "BarOrigin",
    "BarSpacing",
    "BartlettHannWindow",
    "BartlettWindow",
    "BaseDecode",
    "BaseEncode",
    "BaseForm",
    "Baseline",
    "BaselinePosition",
    "BaseStyle",
    "BasicRecurrentLayer",
    "BatchNormalizationLayer",
    "BatchSize",
    "BatesDistribution",
    "BattleLemarieWavelet",
    "BayesianMaximization",
    "BayesianMaximizationObject",
    "BayesianMinimization",
    "BayesianMinimizationObject",
    "Because",
    "BeckmannDistribution",
    "Beep",
    "Before",
    "Begin",
    "BeginDialogPacket",
    "BeginPackage",
    "BellB",
    "BellY",
    "Below",
    "BenfordDistribution",
    "BeniniDistribution",
    "BenktanderGibratDistribution",
    "BenktanderWeibullDistribution",
    "BernoulliB",
    "BernoulliDistribution",
    "BernoulliGraphDistribution",
    "BernoulliProcess",
    "BernsteinBasis",
    "BesagL",
    "BesselFilterModel",
    "BesselI",
    "BesselJ",
    "BesselJZero",
    "BesselK",
    "BesselY",
    "BesselYZero",
    "Beta",
    "BetaBinomialDistribution",
    "BetaDistribution",
    "BetaNegativeBinomialDistribution",
    "BetaPrimeDistribution",
    "BetaRegularized",
    "Between",
    "BetweennessCentrality",
    "Beveled",
    "BeveledPolyhedron",
    "BezierCurve",
    "BezierCurve3DBox",
    "BezierCurve3DBoxOptions",
    "BezierCurveBox",
    "BezierCurveBoxOptions",
    "BezierFunction",
    "BilateralFilter",
    "BilateralLaplaceTransform",
    "BilateralZTransform",
    "Binarize",
    "BinaryDeserialize",
    "BinaryDistance",
    "BinaryFormat",
    "BinaryImageQ",
    "BinaryRead",
    "BinaryReadList",
    "BinarySerialize",
    "BinaryWrite",
    "BinCounts",
    "BinLists",
    "BinnedVariogramList",
    "Binomial",
    "BinomialDistribution",
    "BinomialPointProcess",
    "BinomialProcess",
    "BinormalDistribution",
    "BiorthogonalSplineWavelet",
    "BioSequence",
    "BioSequenceBackTranslateList",
    "BioSequenceComplement",
    "BioSequenceInstances",
    "BioSequenceModify",
    "BioSequencePlot",
    "BioSequenceQ",
    "BioSequenceReverseComplement",
    "BioSequenceTranscribe",
    "BioSequenceTranslate",
    "BipartiteGraphQ",
    "BiquadraticFilterModel",
    "BirnbaumImportance",
    "BirnbaumSaundersDistribution",
    "BitAnd",
    "BitClear",
    "BitGet",
    "BitLength",
    "BitNot",
    "BitOr",
    "BitRate",
    "BitSet",
    "BitShiftLeft",
    "BitShiftRight",
    "BitXor",
    "BiweightLocation",
    "BiweightMidvariance",
    "Black",
    "BlackmanHarrisWindow",
    "BlackmanNuttallWindow",
    "BlackmanWindow",
    "Blank",
    "BlankForm",
    "BlankNullSequence",
    "BlankSequence",
    "Blend",
    "Block",
    "BlockchainAddressData",
    "BlockchainBase",
    "BlockchainBlockData",
    "BlockchainContractValue",
    "BlockchainData",
    "BlockchainGet",
    "BlockchainKeyEncode",
    "BlockchainPut",
    "BlockchainTokenData",
    "BlockchainTransaction",
    "BlockchainTransactionData",
    "BlockchainTransactionSign",
    "BlockchainTransactionSubmit",
    "BlockDiagonalMatrix",
    "BlockLowerTriangularMatrix",
    "BlockMap",
    "BlockRandom",
    "BlockUpperTriangularMatrix",
    "BlomqvistBeta",
    "BlomqvistBetaTest",
    "Blue",
    "Blur",
    "Blurring",
    "BodePlot",
    "BohmanWindow",
    "Bold",
    "Bond",
    "BondCount",
    "BondLabels",
    "BondLabelStyle",
    "BondList",
    "BondQ",
    "Bookmarks",
    "Boole",
    "BooleanConsecutiveFunction",
    "BooleanConvert",
    "BooleanCountingFunction",
    "BooleanFunction",
    "BooleanGraph",
    "BooleanMaxterms",
    "BooleanMinimize",
    "BooleanMinterms",
    "BooleanQ",
    "BooleanRegion",
    "Booleans",
    "BooleanStrings",
    "BooleanTable",
    "BooleanVariables",
    "BorderDimensions",
    "BorelTannerDistribution",
    "Bottom",
    "BottomHatTransform",
    "BoundaryDiscretizeGraphics",
    "BoundaryDiscretizeRegion",
    "BoundaryMesh",
    "BoundaryMeshRegion",
    "BoundaryMeshRegionQ",
    "BoundaryStyle",
    "BoundedRegionQ",
    "BoundingRegion",
    "Bounds",
    "Box",
    "BoxBaselineShift",
    "BoxData",
    "BoxDimensions",
    "Boxed",
    "Boxes",
    "BoxForm",
    "BoxFormFormatTypes",
    "BoxFrame",
    "BoxID",
    "BoxMargins",
    "BoxMatrix",
    "BoxObject",
    "BoxRatios",
    "BoxRotation",
    "BoxRotationPoint",
    "BoxStyle",
    "BoxWhiskerChart",
    "Bra",
    "BracketingBar",
    "BraKet",
    "BrayCurtisDistance",
    "BreadthFirstScan",
    "Break",
    "BridgeData",
    "BrightnessEqualize",
    "BroadcastStationData",
    "Brown",
    "BrownForsytheTest",
    "BrownianBridgeProcess",
    "BrowserCategory",
    "BSplineBasis",
    "BSplineCurve",
    "BSplineCurve3DBox",
    "BSplineCurve3DBoxOptions",
    "BSplineCurveBox",
    "BSplineCurveBoxOptions",
    "BSplineFunction",
    "BSplineSurface",
    "BSplineSurface3DBox",
    "BSplineSurface3DBoxOptions",
    "BubbleChart",
    "BubbleChart3D",
    "BubbleScale",
    "BubbleSizes",
    "BuckyballGraph",
    "BuildCompiledComponent",
    "BuildingData",
    "BulletGauge",
    "BusinessDayQ",
    "ButterflyGraph",
    "ButterworthFilterModel",
    "Button",
    "ButtonBar",
    "ButtonBox",
    "ButtonBoxOptions",
    "ButtonCell",
    "ButtonContents",
    "ButtonData",
    "ButtonEvaluator",
    "ButtonExpandable",
    "ButtonFrame",
    "ButtonFunction",
    "ButtonMargins",
    "ButtonMinHeight",
    "ButtonNote",
    "ButtonNotebook",
    "ButtonSource",
    "ButtonStyle",
    "ButtonStyleMenuListing",
    "Byte",
    "ByteArray",
    "ByteArrayFormat",
    "ByteArrayFormatQ",
    "ByteArrayQ",
    "ByteArrayToString",
    "ByteCount",
    "ByteOrdering",
    "C",
    "CachedValue",
    "CacheGraphics",
    "CachePersistence",
    "CalendarConvert",
    "CalendarData",
    "CalendarType",
    "Callout",
    "CalloutMarker",
    "CalloutStyle",
    "CallPacket",
    "CanberraDistance",
    "Cancel",
    "CancelButton",
    "CandlestickChart",
    "CanonicalGraph",
    "CanonicalizePolygon",
    "CanonicalizePolyhedron",
    "CanonicalizeRegion",
    "CanonicalName",
    "CanonicalWarpingCorrespondence",
    "CanonicalWarpingDistance",
    "CantorMesh",
    "CantorStaircase",
    "Canvas",
    "Cap",
    "CapForm",
    "CapitalDifferentialD",
    "Capitalize",
    "CapsuleShape",
    "CaptureRunning",
    "CaputoD",
    "CardinalBSplineBasis",
    "CarlemanLinearize",
    "CarlsonRC",
    "CarlsonRD",
    "CarlsonRE",
    "CarlsonRF",
    "CarlsonRG",
    "CarlsonRJ",
    "CarlsonRK",
    "CarlsonRM",
    "CarmichaelLambda",
    "CaseOrdering",
    "Cases",
    "CaseSensitive",
    "Cashflow",
    "Casoratian",
    "Cast",
    "Catalan",
    "CatalanNumber",
    "Catch",
    "CategoricalDistribution",
    "Catenate",
    "CatenateLayer",
    "CauchyDistribution",
    "CauchyMatrix",
    "CauchyPointProcess",
    "CauchyWindow",
    "CayleyGraph",
    "CDF",
    "CDFDeploy",
    "CDFInformation",
    "CDFWavelet",
    "Ceiling",
    "CelestialSystem",
    "Cell",
    "CellAutoOverwrite",
    "CellBaseline",
    "CellBoundingBox",
    "CellBracketOptions",
    "CellChangeTimes",
    "CellContents",
    "CellContext",
    "CellDingbat",
    "CellDingbatMargin",
    "CellDynamicExpression",
    "CellEditDuplicate",
    "CellElementsBoundingBox",
    "CellElementSpacings",
    "CellEpilog",
    "CellEvaluationDuplicate",
    "CellEvaluationFunction",
    "CellEvaluationLanguage",
    "CellEventActions",
    "CellFrame",
    "CellFrameColor",
    "CellFrameLabelMargins",
    "CellFrameLabels",
    "CellFrameMargins",
    "CellFrameStyle",
    "CellGroup",
    "CellGroupData",
    "CellGrouping",
    "CellGroupingRules",
    "CellHorizontalScrolling",
    "CellID",
    "CellInsertionPointCell",
    "CellLabel",
    "CellLabelAutoDelete",
    "CellLabelMargins",
    "CellLabelPositioning",
    "CellLabelStyle",
    "CellLabelTemplate",
    "CellMargins",
    "CellObject",
    "CellOpen",
    "CellPrint",
    "CellProlog",
    "Cells",
    "CellSize",
    "CellStyle",
    "CellTags",
    "CellTrayPosition",
    "CellTrayWidgets",
    "CellularAutomaton",
    "CensoredDistribution",
    "Censoring",
    "Center",
    "CenterArray",
    "CenterDot",
    "CenteredInterval",
    "CentralFeature",
    "CentralMoment",
    "CentralMomentGeneratingFunction",
    "Cepstrogram",
    "CepstrogramArray",
    "CepstrumArray",
    "CForm",
    "ChampernowneNumber",
    "ChangeOptions",
    "ChannelBase",
    "ChannelBrokerAction",
    "ChannelDatabin",
    "ChannelHistoryLength",
    "ChannelListen",
    "ChannelListener",
    "ChannelListeners",
    "ChannelListenerWait",
    "ChannelObject",
    "ChannelPreSendFunction",
    "ChannelReceiverFunction",
    "ChannelSend",
    "ChannelSubscribers",
    "ChanVeseBinarize",
    "Character",
    "CharacterCounts",
    "CharacterEncoding",
    "CharacterEncodingsPath",
    "CharacteristicFunction",
    "CharacteristicPolynomial",
    "CharacterName",
    "CharacterNormalize",
    "CharacterRange",
    "Characters",
    "ChartBaseStyle",
    "ChartElementData",
    "ChartElementDataFunction",
    "ChartElementFunction",
    "ChartElements",
    "ChartLabels",
    "ChartLayout",
    "ChartLegends",
    "ChartStyle",
    "Chebyshev1FilterModel",
    "Chebyshev2FilterModel",
    "ChebyshevDistance",
    "ChebyshevT",
    "ChebyshevU",
    "Check",
    "CheckAbort",
    "CheckAll",
    "CheckArguments",
    "Checkbox",
    "CheckboxBar",
    "CheckboxBox",
    "CheckboxBoxOptions",
    "ChemicalConvert",
    "ChemicalData",
    "ChemicalFormula",
    "ChemicalInstance",
    "ChemicalReaction",
    "ChessboardDistance",
    "ChiDistribution",
    "ChineseRemainder",
    "ChiSquareDistribution",
    "ChoiceButtons",
    "ChoiceDialog",
    "CholeskyDecomposition",
    "Chop",
    "ChromaticityPlot",
    "ChromaticityPlot3D",
    "ChromaticPolynomial",
    "Circle",
    "CircleBox",
    "CircleDot",
    "CircleMinus",
    "CirclePlus",
    "CirclePoints",
    "CircleThrough",
    "CircleTimes",
    "CirculantGraph",
    "CircularArcThrough",
    "CircularOrthogonalMatrixDistribution",
    "CircularQuaternionMatrixDistribution",
    "CircularRealMatrixDistribution",
    "CircularSymplecticMatrixDistribution",
    "CircularUnitaryMatrixDistribution",
    "Circumsphere",
    "CityData",
    "ClassifierFunction",
    "ClassifierInformation",
    "ClassifierMeasurements",
    "ClassifierMeasurementsObject",
    "Classify",
    "ClassPriors",
    "Clear",
    "ClearAll",
    "ClearAttributes",
    "ClearCookies",
    "ClearPermissions",
    "ClearSystemCache",
    "ClebschGordan",
    "ClickPane",
    "ClickToCopy",
    "ClickToCopyEnabled",
    "Clip",
    "ClipboardNotebook",
    "ClipFill",
    "ClippingStyle",
    "ClipPlanes",
    "ClipPlanesStyle",
    "ClipRange",
    "Clock",
    "ClockGauge",
    "ClockwiseContourIntegral",
    "Close",
    "Closed",
    "CloseKernels",
    "ClosenessCentrality",
    "Closing",
    "ClosingAutoSave",
    "ClosingEvent",
    "CloudAccountData",
    "CloudBase",
    "CloudConnect",
    "CloudConnections",
    "CloudDeploy",
    "CloudDirectory",
    "CloudDisconnect",
    "CloudEvaluate",
    "CloudExport",
    "CloudExpression",
    "CloudExpressions",
    "CloudFunction",
    "CloudGet",
    "CloudImport",
    "CloudLoggingData",
    "CloudObject",
    "CloudObjectInformation",
    "CloudObjectInformationData",
    "CloudObjectNameFormat",
    "CloudObjects",
    "CloudObjectURLType",
    "CloudPublish",
    "CloudPut",
    "CloudRenderingMethod",
    "CloudSave",
    "CloudShare",
    "CloudSubmit",
    "CloudSymbol",
    "CloudUnshare",
    "CloudUserID",
    "ClusterClassify",
    "ClusterDissimilarityFunction",
    "ClusteringComponents",
    "ClusteringMeasurements",
    "ClusteringTree",
    "CMYKColor",
    "Coarse",
    "CodeAssistOptions",
    "Coefficient",
    "CoefficientArrays",
    "CoefficientDomain",
    "CoefficientList",
    "CoefficientRules",
    "CoifletWavelet",
    "Collect",
    "CollinearPoints",
    "Colon",
    "ColonForm",
    "ColorBalance",
    "ColorCombine",
    "ColorConvert",
    "ColorCoverage",
    "ColorData",
    "ColorDataFunction",
    "ColorDetect",
    "ColorDistance",
    "ColorFunction",
    "ColorFunctionBinning",
    "ColorFunctionScaling",
    "Colorize",
    "ColorNegate",
    "ColorOutput",
    "ColorProfileData",
    "ColorQ",
    "ColorQuantize",
    "ColorReplace",
    "ColorRules",
    "ColorSelectorSettings",
    "ColorSeparate",
    "ColorSetter",
    "ColorSetterBox",
    "ColorSetterBoxOptions",
    "ColorSlider",
    "ColorsNear",
    "ColorSpace",
    "ColorToneMapping",
    "Column",
    "ColumnAlignments",
    "ColumnBackgrounds",
    "ColumnForm",
    "ColumnLines",
    "ColumnsEqual",
    "ColumnSpacings",
    "ColumnWidths",
    "CombinatorB",
    "CombinatorC",
    "CombinatorI",
    "CombinatorK",
    "CombinatorS",
    "CombinatorW",
    "CombinatorY",
    "CombinedEntityClass",
    "CombinerFunction",
    "CometData",
    "CommonDefaultFormatTypes",
    "Commonest",
    "CommonestFilter",
    "CommonName",
    "CommonUnits",
    "CommunityBoundaryStyle",
    "CommunityGraphPlot",
    "CommunityLabels",
    "CommunityRegionStyle",
    "CompanyData",
    "CompatibleUnitQ",
    "CompilationOptions",
    "CompilationTarget",
    "Compile",
    "Compiled",
    "CompiledCodeFunction",
    "CompiledComponent",
    "CompiledExpressionDeclaration",
    "CompiledFunction",
    "CompiledLayer",
    "CompilerCallback",
    "CompilerEnvironment",
    "CompilerEnvironmentAppend",
    "CompilerEnvironmentAppendTo",
    "CompilerEnvironmentObject",
    "CompilerOptions",
    "Complement",
    "ComplementedEntityClass",
    "CompleteGraph",
    "CompleteGraphQ",
    "CompleteIntegral",
    "CompleteKaryTree",
    "CompletionsListPacket",
    "Complex",
    "ComplexArrayPlot",
    "ComplexContourPlot",
    "Complexes",
    "ComplexExpand",
    "ComplexInfinity",
    "ComplexityFunction",
    "ComplexListPlot",
    "ComplexPlot",
    "ComplexPlot3D",
    "ComplexRegionPlot",
    "ComplexStreamPlot",
    "ComplexVectorPlot",
    "ComponentMeasurements",
    "ComponentwiseContextMenu",
    "Compose",
    "ComposeList",
    "ComposeSeries",
    "CompositeQ",
    "Composition",
    "CompoundElement",
    "CompoundExpression",
    "CompoundPoissonDistribution",
    "CompoundPoissonProcess",
    "CompoundRenewalProcess",
    "Compress",
    "CompressedData",
    "CompressionLevel",
    "ComputeUncertainty",
    "ConcaveHullMesh",
    "Condition",
    "ConditionalExpression",
    "Conditioned",
    "Cone",
    "ConeBox",
    "ConfidenceLevel",
    "ConfidenceRange",
    "ConfidenceTransform",
    "ConfigurationPath",
    "Confirm",
    "ConfirmAssert",
    "ConfirmBy",
    "ConfirmMatch",
    "ConfirmQuiet",
    "ConformationMethod",
    "ConformAudio",
    "ConformImages",
    "Congruent",
    "ConicGradientFilling",
    "ConicHullRegion",
    "ConicHullRegion3DBox",
    "ConicHullRegion3DBoxOptions",
    "ConicHullRegionBox",
    "ConicHullRegionBoxOptions",
    "ConicOptimization",
    "Conjugate",
    "ConjugateTranspose",
    "Conjunction",
    "Connect",
    "ConnectedComponents",
    "ConnectedGraphComponents",
    "ConnectedGraphQ",
    "ConnectedMeshComponents",
    "ConnectedMoleculeComponents",
    "ConnectedMoleculeQ",
    "ConnectionSettings",
    "ConnectLibraryCallbackFunction",
    "ConnectSystemModelComponents",
    "ConnectSystemModelController",
    "ConnesWindow",
    "ConoverTest",
    "ConservativeConvectionPDETerm",
    "ConsoleMessage",
    "Constant",
    "ConstantArray",
    "ConstantArrayLayer",
    "ConstantImage",
    "ConstantPlusLayer",
    "ConstantRegionQ",
    "Constants",
    "ConstantTimesLayer",
    "ConstellationData",
    "ConstrainedMax",
    "ConstrainedMin",
    "Construct",
    "Containing",
    "ContainsAll",
    "ContainsAny",
    "ContainsExactly",
    "ContainsNone",
    "ContainsOnly",
    "ContentDetectorFunction",
    "ContentFieldOptions",
    "ContentLocationFunction",
    "ContentObject",
    "ContentPadding",
    "ContentsBoundingBox",
    "ContentSelectable",
    "ContentSize",
    "Context",
    "ContextMenu",
    "Contexts",
    "ContextToFileName",
    "Continuation",
    "Continue",
    "ContinuedFraction",
    "ContinuedFractionK",
    "ContinuousAction",
    "ContinuousMarkovProcess",
    "ContinuousTask",
    "ContinuousTimeModelQ",
    "ContinuousWaveletData",
    "ContinuousWaveletTransform",
    "ContourDetect",
    "ContourGraphics",
    "ContourIntegral",
    "ContourLabels",
    "ContourLines",
    "ContourPlot",
    "ContourPlot3D",
    "Contours",
    "ContourShading",
    "ContourSmoothing",
    "ContourStyle",
    "ContraharmonicMean",
    "ContrastiveLossLayer",
    "Control",
    "ControlActive",
    "ControlAlignment",
    "ControlGroupContentsBox",
    "ControllabilityGramian",
    "ControllabilityMatrix",
    "ControllableDecomposition",
    "ControllableModelQ",
    "ControllerDuration",
    "ControllerInformation",
    "ControllerInformationData",
    "ControllerLinking",
    "ControllerManipulate",
    "ControllerMethod",
    "ControllerPath",
    "ControllerState",
    "ControlPlacement",
    "ControlsRendering",
    "ControlType",
    "ConvectionPDETerm",
    "Convergents",
    "ConversionOptions",
    "ConversionRules",
    "ConvertToPostScript",
    "ConvertToPostScriptPacket",
    "ConvexHullMesh",
    "ConvexHullRegion",
    "ConvexOptimization",
    "ConvexPolygonQ",
    "ConvexPolyhedronQ",
    "ConvexRegionQ",
    "ConvolutionLayer",
    "Convolve",
    "ConwayGroupCo1",
    "ConwayGroupCo2",
    "ConwayGroupCo3",
    "CookieFunction",
    "Cookies",
    "CoordinateBoundingBox",
    "CoordinateBoundingBoxArray",
    "CoordinateBounds",
    "CoordinateBoundsArray",
    "CoordinateChartData",
    "CoordinatesToolOptions",
    "CoordinateTransform",
    "CoordinateTransformData",
    "CoplanarPoints",
    "CoprimeQ",
    "Coproduct",
    "CopulaDistribution",
    "Copyable",
    "CopyDatabin",
    "CopyDirectory",
    "CopyFile",
    "CopyFunction",
    "CopyTag",
    "CopyToClipboard",
    "CoreNilpotentDecomposition",
    "CornerFilter",
    "CornerNeighbors",
    "Correlation",
    "CorrelationDistance",
    "CorrelationFunction",
    "CorrelationTest",
    "Cos",
    "Cosh",
    "CoshIntegral",
    "CosineDistance",
    "CosineWindow",
    "CosIntegral",
    "Cot",
    "Coth",
    "CoulombF",
    "CoulombG",
    "CoulombH1",
    "CoulombH2",
    "Count",
    "CountDistinct",
    "CountDistinctBy",
    "CounterAssignments",
    "CounterBox",
    "CounterBoxOptions",
    "CounterClockwiseContourIntegral",
    "CounterEvaluator",
    "CounterFunction",
    "CounterIncrements",
    "CounterStyle",
    "CounterStyleMenuListing",
    "CountRoots",
    "CountryData",
    "Counts",
    "CountsBy",
    "Covariance",
    "CovarianceEstimatorFunction",
    "CovarianceFunction",
    "CoxianDistribution",
    "CoxIngersollRossProcess",
    "CoxModel",
    "CoxModelFit",
    "CramerVonMisesTest",
    "CreateArchive",
    "CreateCellID",
    "CreateChannel",
    "CreateCloudExpression",
    "CreateCompilerEnvironment",
    "CreateDatabin",
    "CreateDataStructure",
    "CreateDataSystemModel",
    "CreateDialog",
    "CreateDirectory",
    "CreateDocument",
    "CreateFile",
    "CreateIntermediateDirectories",
    "CreateLicenseEntitlement",
    "CreateManagedLibraryExpression",
    "CreateNotebook",
    "CreatePacletArchive",
    "CreatePalette",
    "CreatePermissionsGroup",
    "CreateScheduledTask",
    "CreateSearchIndex",
    "CreateSystemModel",
    "CreateTemporary",
    "CreateTypeInstance",
    "CreateUUID",
    "CreateWindow",
    "CriterionFunction",
    "CriticalityFailureImportance",
    "CriticalitySuccessImportance",
    "CriticalSection",
    "Cross",
    "CrossEntropyLossLayer",
    "CrossingCount",
    "CrossingDetect",
    "CrossingPolygon",
    "CrossMatrix",
    "Csc",
    "Csch",
    "CSGRegion",
    "CSGRegionQ",
    "CSGRegionTree",
    "CTCLossLayer",
    "Cube",
    "CubeRoot",
    "Cubics",
    "Cuboid",
    "CuboidBox",
    "CuboidBoxOptions",
    "Cumulant",
    "CumulantGeneratingFunction",
    "CumulativeFeatureImpactPlot",
    "Cup",
    "CupCap",
    "Curl",
    "CurlyDoubleQuote",
    "CurlyQuote",
    "CurrencyConvert",
    "CurrentDate",
    "CurrentImage",
    "CurrentNotebookImage",
    "CurrentScreenImage",
    "CurrentValue",
    "Curry",
    "CurryApplied",
    "CurvatureFlowFilter",
    "CurveClosed",
    "Cyan",
    "CycleGraph",
    "CycleIndexPolynomial",
    "Cycles",
    "CyclicGroup",
    "Cyclotomic",
    "Cylinder",
    "CylinderBox",
    "CylinderBoxOptions",
    "CylindricalDecomposition",
    "CylindricalDecompositionFunction",
    "D",
    "DagumDistribution",
    "DamData",
    "DamerauLevenshteinDistance",
    "DampingFactor",
    "Darker",
    "Dashed",
    "Dashing",
    "DatabaseConnect",
    "DatabaseDisconnect",
    "DatabaseReference",
    "Databin",
    "DatabinAdd",
    "DatabinRemove",
    "Databins",
    "DatabinSubmit",
    "DatabinUpload",
    "DataCompression",
    "DataDistribution",
    "DataRange",
    "DataReversed",
    "Dataset",
    "DatasetDisplayPanel",
    "DatasetTheme",
    "DataStructure",
    "DataStructureQ",
    "Date",
    "DateBounds",
    "Dated",
    "DateDelimiters",
    "DateDifference",
    "DatedUnit",
    "DateFormat",
    "DateFunction",
    "DateGranularity",
    "DateHistogram",
    "DateInterval",
    "DateList",
    "DateListLogPlot",
    "DateListPlot",
    "DateListStepPlot",
    "DateObject",
    "DateObjectQ",
    "DateOverlapsQ",
    "DatePattern",
    "DatePlus",
    "DateRange",
    "DateReduction",
    "DateScale",
    "DateSelect",
    "DateString",
    "DateTicksFormat",
    "DateValue",
    "DateWithinQ",
    "DaubechiesWavelet",
    "DavisDistribution",
    "DawsonF",
    "DayCount",
    "DayCountConvention",
    "DayHemisphere",
    "DaylightQ",
    "DayMatchQ",
    "DayName",
    "DayNightTerminator",
    "DayPlus",
    "DayRange",
    "DayRound",
    "DeBruijnGraph",
    "DeBruijnSequence",
    "Debug",
    "DebugTag",
    "Decapitalize",
    "Decimal",
    "DecimalForm",
    "DeclareCompiledComponent",
    "DeclareKnownSymbols",
    "DeclarePackage",
    "Decompose",
    "DeconvolutionLayer",
    "Decrement",
    "Decrypt",
    "DecryptFile",
    "DedekindEta",
    "DeepSpaceProbeData",
    "Default",
    "Default2DTool",
    "Default3DTool",
    "DefaultAttachedCellStyle",
    "DefaultAxesStyle",
    "DefaultBaseStyle",
    "DefaultBoxStyle",
    "DefaultButton",
    "DefaultColor",
    "DefaultControlPlacement",
    "DefaultDockedCellStyle",
    "DefaultDuplicateCellStyle",
    "DefaultDuration",
    "DefaultElement",
    "DefaultFaceGridsStyle",
    "DefaultFieldHintStyle",
    "DefaultFont",
    "DefaultFontProperties",
    "DefaultFormatType",
    "DefaultFrameStyle",
    "DefaultFrameTicksStyle",
    "DefaultGridLinesStyle",
    "DefaultInlineFormatType",
    "DefaultInputFormatType",
    "DefaultLabelStyle",
    "DefaultMenuStyle",
    "DefaultNaturalLanguage",
    "DefaultNewCellStyle",
    "DefaultNewInlineCellStyle",
    "DefaultNotebook",
    "DefaultOptions",
    "DefaultOutputFormatType",
    "DefaultPrintPrecision",
    "DefaultStyle",
    "DefaultStyleDefinitions",
    "DefaultTextFormatType",
    "DefaultTextInlineFormatType",
    "DefaultTicksStyle",
    "DefaultTooltipStyle",
    "DefaultValue",
    "DefaultValues",
    "Defer",
    "DefineExternal",
    "DefineInputStreamMethod",
    "DefineOutputStreamMethod",
    "DefineResourceFunction",
    "Definition",
    "Degree",
    "DegreeCentrality",
    "DegreeGraphDistribution",
    "DegreeLexicographic",
    "DegreeReverseLexicographic",
    "DEigensystem",
    "DEigenvalues",
    "Deinitialization",
    "Del",
    "DelaunayMesh",
    "Delayed",
    "Deletable",
    "Delete",
    "DeleteAdjacentDuplicates",
    "DeleteAnomalies",
    "DeleteBorderComponents",
    "DeleteCases",
    "DeleteChannel",
    "DeleteCloudExpression",
    "DeleteContents",
    "DeleteDirectory",
    "DeleteDuplicates",
    "DeleteDuplicatesBy",
    "DeleteElements",
    "DeleteFile",
    "DeleteMissing",
    "DeleteObject",
    "DeletePermissionsKey",
    "DeleteSearchIndex",
    "DeleteSmallComponents",
    "DeleteStopwords",
    "DeleteWithContents",
    "DeletionWarning",
    "DelimitedArray",
    "DelimitedSequence",
    "Delimiter",
    "DelimiterAutoMatching",
    "DelimiterFlashTime",
    "DelimiterMatching",
    "Delimiters",
    "DeliveryFunction",
    "Dendrogram",
    "Denominator",
    "DensityGraphics",
    "DensityHistogram",
    "DensityPlot",
    "DensityPlot3D",
    "DependentVariables",
    "Deploy",
    "Deployed",
    "Depth",
    "DepthFirstScan",
    "Derivative",
    "DerivativeFilter",
    "DerivativePDETerm",
    "DerivedKey",
    "DescriptorStateSpace",
    "DesignMatrix",
    "DestroyAfterEvaluation",
    "Det",
    "DeviceClose",
    "DeviceConfigure",
    "DeviceExecute",
    "DeviceExecuteAsynchronous",
    "DeviceObject",
    "DeviceOpen",
    "DeviceOpenQ",
    "DeviceRead",
    "DeviceReadBuffer",
    "DeviceReadLatest",
    "DeviceReadList",
    "DeviceReadTimeSeries",
    "Devices",
    "DeviceStreams",
    "DeviceWrite",
    "DeviceWriteBuffer",
    "DGaussianWavelet",
    "DiacriticalPositioning",
    "Diagonal",
    "DiagonalizableMatrixQ",
    "DiagonalMatrix",
    "DiagonalMatrixQ",
    "Dialog",
    "DialogIndent",
    "DialogInput",
    "DialogLevel",
    "DialogNotebook",
    "DialogProlog",
    "DialogReturn",
    "DialogSymbols",
    "Diamond",
    "DiamondMatrix",
    "DiceDissimilarity",
    "DictionaryLookup",
    "DictionaryWordQ",
    "DifferenceDelta",
    "DifferenceOrder",
    "DifferenceQuotient",
    "DifferenceRoot",
    "DifferenceRootReduce",
    "Differences",
    "DifferentialD",
    "DifferentialRoot",
    "DifferentialRootReduce",
    "DifferentiatorFilter",
    "DiffusionPDETerm",
    "DiggleGatesPointProcess",
    "DiggleGrattonPointProcess",
    "DigitalSignature",
    "DigitBlock",
    "DigitBlockMinimum",
    "DigitCharacter",
    "DigitCount",
    "DigitQ",
    "DihedralAngle",
    "DihedralGroup",
    "Dilation",
    "DimensionalCombinations",
    "DimensionalMeshComponents",
    "DimensionReduce",
    "DimensionReducerFunction",
    "DimensionReduction",
    "Dimensions",
    "DiracComb",
    "DiracDelta",
    "DirectedEdge",
    "DirectedEdges",
    "DirectedGraph",
    "DirectedGraphQ",
    "DirectedInfinity",
    "Direction",
    "DirectionalLight",
    "Directive",
    "Directory",
    "DirectoryName",
    "DirectoryQ",
    "DirectoryStack",
    "DirichletBeta",
    "DirichletCharacter",
    "DirichletCondition",
    "DirichletConvolve",
    "DirichletDistribution",
    "DirichletEta",
    "DirichletL",
    "DirichletLambda",
    "DirichletTransform",
    "DirichletWindow",
    "DisableConsolePrintPacket",
    "DisableFormatting",
    "DiscreteAsymptotic",
    "DiscreteChirpZTransform",
    "DiscreteConvolve",
    "DiscreteDelta",
    "DiscreteHadamardTransform",
    "DiscreteIndicator",
    "DiscreteInputOutputModel",
    "DiscreteLimit",
    "DiscreteLQEstimatorGains",
    "DiscreteLQRegulatorGains",
    "DiscreteLyapunovSolve",
    "DiscreteMarkovProcess",
    "DiscreteMaxLimit",
    "DiscreteMinLimit",
    "DiscretePlot",
    "DiscretePlot3D",
    "DiscreteRatio",
    "DiscreteRiccatiSolve",
    "DiscreteShift",
    "DiscreteTimeModelQ",
    "DiscreteUniformDistribution",
    "DiscreteVariables",
    "DiscreteWaveletData",
    "DiscreteWaveletPacketTransform",
    "DiscreteWaveletTransform",
    "DiscretizeGraphics",
    "DiscretizeRegion",
    "Discriminant",
    "DisjointQ",
    "Disjunction",
    "Disk",
    "DiskBox",
    "DiskBoxOptions",
    "DiskMatrix",
    "DiskSegment",
    "Dispatch",
    "DispatchQ",
    "DispersionEstimatorFunction",
    "Display",
    "DisplayAllSteps",
    "DisplayEndPacket",
    "DisplayForm",
    "DisplayFunction",
    "DisplayPacket",
    "DisplayRules",
    "DisplayString",
    "DisplayTemporary",
    "DisplayWith",
    "DisplayWithRef",
    "DisplayWithVariable",
    "DistanceFunction",
    "DistanceMatrix",
    "DistanceTransform",
    "Distribute",
    "Distributed",
    "DistributedContexts",
    "DistributeDefinitions",
    "DistributionChart",
    "DistributionDomain",
    "DistributionFitTest",
    "DistributionParameterAssumptions",
    "DistributionParameterQ",
    "Dithering",
    "Div",
    "Divergence",
    "Divide",
    "DivideBy",
    "Dividers",
    "DivideSides",
    "Divisible",
    "Divisors",
    "DivisorSigma",
    "DivisorSum",
    "DMSList",
    "DMSString",
    "Do",
    "DockedCell",
    "DockedCells",
    "DocumentGenerator",
    "DocumentGeneratorInformation",
    "DocumentGeneratorInformationData",
    "DocumentGenerators",
    "DocumentNotebook",
    "DocumentWeightingRules",
    "Dodecahedron",
    "DomainRegistrationInformation",
    "DominantColors",
    "DominatorTreeGraph",
    "DominatorVertexList",
    "DOSTextFormat",
    "Dot",
    "DotDashed",
    "DotEqual",
    "DotLayer",
    "DotPlusLayer",
    "Dotted",
    "DoubleBracketingBar",
    "DoubleContourIntegral",
    "DoubleDownArrow",
    "DoubleLeftArrow",
    "DoubleLeftRightArrow",
    "DoubleLeftTee",
    "DoubleLongLeftArrow",
    "DoubleLongLeftRightArrow",
    "DoubleLongRightArrow",
    "DoubleRightArrow",
    "DoubleRightTee",
    "DoubleUpArrow",
    "DoubleUpDownArrow",
    "DoubleVerticalBar",
    "DoublyInfinite",
    "Down",
    "DownArrow",
    "DownArrowBar",
    "DownArrowUpArrow",
    "DownLeftRightVector",
    "DownLeftTeeVector",
    "DownLeftVector",
    "DownLeftVectorBar",
    "DownRightTeeVector",
    "DownRightVector",
    "DownRightVectorBar",
    "Downsample",
    "DownTee",
    "DownTeeArrow",
    "DownValues",
    "DownValuesFunction",
    "DragAndDrop",
    "DrawBackFaces",
    "DrawEdges",
    "DrawFrontFaces",
    "DrawHighlighted",
    "DrazinInverse",
    "Drop",
    "DropoutLayer",
    "DropShadowing",
    "DSolve",
    "DSolveChangeVariables",
    "DSolveValue",
    "Dt",
    "DualLinearProgramming",
    "DualPlanarGraph",
    "DualPolyhedron",
    "DualSystemsModel",
    "DumpGet",
    "DumpSave",
    "DuplicateFreeQ",
    "Duration",
    "Dynamic",
    "DynamicBox",
    "DynamicBoxOptions",
    "DynamicEvaluationTimeout",
    "DynamicGeoGraphics",
    "DynamicImage",
    "DynamicLocation",
    "DynamicModule",
    "DynamicModuleBox",
    "DynamicModuleBoxOptions",
    "DynamicModuleParent",
    "DynamicModuleValues",
    "DynamicName",
    "DynamicNamespace",
    "DynamicReference",
    "DynamicSetting",
    "DynamicUpdating",
    "DynamicWrapper",
    "DynamicWrapperBox",
    "DynamicWrapperBoxOptions",
    "E",
    "EarthImpactData",
    "EarthquakeData",
    "EccentricityCentrality",
    "Echo",
    "EchoEvaluation",
    "EchoFunction",
    "EchoLabel",
    "EchoTiming",
    "EclipseType",
    "EdgeAdd",
    "EdgeBetweennessCentrality",
    "EdgeCapacity",
    "EdgeCapForm",
    "EdgeChromaticNumber",
    "EdgeColor",
    "EdgeConnectivity",
    "EdgeContract",
    "EdgeCost",
    "EdgeCount",
    "EdgeCoverQ",
    "EdgeCycleMatrix",
    "EdgeDashing",
    "EdgeDelete",
    "EdgeDetect",
    "EdgeForm",
    "EdgeIndex",
    "EdgeJoinForm",
    "EdgeLabeling",
    "EdgeLabels",
    "EdgeLabelStyle",
    "EdgeList",
    "EdgeOpacity",
    "EdgeQ",
    "EdgeRenderingFunction",
    "EdgeRules",
    "EdgeShapeFunction",
    "EdgeStyle",
    "EdgeTaggedGraph",
    "EdgeTaggedGraphQ",
    "EdgeTags",
    "EdgeThickness",
    "EdgeTransitiveGraphQ",
    "EdgeValueRange",
    "EdgeValueSizes",
    "EdgeWeight",
    "EdgeWeightedGraphQ",
    "Editable",
    "EditButtonSettings",
    "EditCellTagsSettings",
    "EditDistance",
    "EffectiveInterest",
    "Eigensystem",
    "Eigenvalues",
    "EigenvectorCentrality",
    "Eigenvectors",
    "Element",
    "ElementData",
    "ElementwiseLayer",
    "ElidedForms",
    "Eliminate",
    "EliminationOrder",
    "Ellipsoid",
    "EllipticE",
    "EllipticExp",
    "EllipticExpPrime",
    "EllipticF",
    "EllipticFilterModel",
    "EllipticK",
    "EllipticLog",
    "EllipticNomeQ",
    "EllipticPi",
    "EllipticReducedHalfPeriods",
    "EllipticTheta",
    "EllipticThetaPrime",
    "EmbedCode",
    "EmbeddedHTML",
    "EmbeddedService",
    "EmbeddedSQLEntityClass",
    "EmbeddedSQLExpression",
    "EmbeddingLayer",
    "EmbeddingObject",
    "EmitSound",
    "EmphasizeSyntaxErrors",
    "EmpiricalDistribution",
    "Empty",
    "EmptyGraphQ",
    "EmptyRegion",
    "EmptySpaceF",
    "EnableConsolePrintPacket",
    "Enabled",
    "Enclose",
    "Encode",
    "Encrypt",
    "EncryptedObject",
    "EncryptFile",
    "End",
    "EndAdd",
    "EndDialogPacket",
    "EndOfBuffer",
    "EndOfFile",
    "EndOfLine",
    "EndOfString",
    "EndPackage",
    "EngineEnvironment",
    "EngineeringForm",
    "Enter",
    "EnterExpressionPacket",
    "EnterTextPacket",
    "Entity",
    "EntityClass",
    "EntityClassList",
    "EntityCopies",
    "EntityFunction",
    "EntityGroup",
    "EntityInstance",
    "EntityList",
    "EntityPrefetch",
    "EntityProperties",
    "EntityProperty",
    "EntityPropertyClass",
    "EntityRegister",
    "EntityStore",
    "EntityStores",
    "EntityTypeName",
    "EntityUnregister",
    "EntityValue",
    "Entropy",
    "EntropyFilter",
    "Environment",
    "Epilog",
    "EpilogFunction",
    "Equal",
    "EqualColumns",
    "EqualRows",
    "EqualTilde",
    "EqualTo",
    "EquatedTo",
    "Equilibrium",
    "EquirippleFilterKernel",
    "Equivalent",
    "Erf",
    "Erfc",
    "Erfi",
    "ErlangB",
    "ErlangC",
    "ErlangDistribution",
    "Erosion",
    "ErrorBox",
    "ErrorBoxOptions",
    "ErrorNorm",
    "ErrorPacket",
    "ErrorsDialogSettings",
    "EscapeRadius",
    "EstimatedBackground",
    "EstimatedDistribution",
    "EstimatedPointNormals",
    "EstimatedPointProcess",
    "EstimatedProcess",
    "EstimatedVariogramModel",
    "EstimatorGains",
    "EstimatorRegulator",
    "EuclideanDistance",
    "EulerAngles",
    "EulerCharacteristic",
    "EulerE",
    "EulerGamma",
    "EulerianGraphQ",
    "EulerMatrix",
    "EulerPhi",
    "Evaluatable",
    "Evaluate",
    "Evaluated",
    "EvaluatePacket",
    "EvaluateScheduledTask",
    "EvaluationBox",
    "EvaluationCell",
    "EvaluationCompletionAction",
    "EvaluationData",
    "EvaluationElements",
    "EvaluationEnvironment",
    "EvaluationMode",
    "EvaluationMonitor",
    "EvaluationNotebook",
    "EvaluationObject",
    "EvaluationOrder",
    "EvaluationPrivileges",
    "EvaluationRateLimit",
    "Evaluator",
    "EvaluatorNames",
    "EvenQ",
    "EventData",
    "EventEvaluator",
    "EventHandler",
    "EventHandlerTag",
    "EventLabels",
    "EventSeries",
    "ExactBlackmanWindow",
    "ExactNumberQ",
    "ExactRootIsolation",
    "ExampleData",
    "Except",
    "ExcludedContexts",
    "ExcludedForms",
    "ExcludedLines",
    "ExcludedPhysicalQuantities",
    "ExcludePods",
    "Exclusions",
    "ExclusionsStyle",
    "Exists",
    "Exit",
    "ExitDialog",
    "ExoplanetData",
    "Exp",
    "Expand",
    "ExpandAll",
    "ExpandDenominator",
    "ExpandFileName",
    "ExpandNumerator",
    "Expectation",
    "ExpectationE",
    "ExpectedValue",
    "ExpGammaDistribution",
    "ExpIntegralE",
    "ExpIntegralEi",
    "ExpirationDate",
    "Exponent",
    "ExponentFunction",
    "ExponentialDistribution",
    "ExponentialFamily",
    "ExponentialGeneratingFunction",
    "ExponentialMovingAverage",
    "ExponentialPowerDistribution",
    "ExponentPosition",
    "ExponentStep",
    "Export",
    "ExportAutoReplacements",
    "ExportByteArray",
    "ExportForm",
    "ExportPacket",
    "ExportString",
    "Expression",
    "ExpressionCell",
    "ExpressionGraph",
    "ExpressionPacket",
    "ExpressionTree",
    "ExpressionUUID",
    "ExpToTrig",
    "ExtendedEntityClass",
    "ExtendedGCD",
    "Extension",
    "ExtentElementFunction",
    "ExtentMarkers",
    "ExtentSize",
    "ExternalBundle",
    "ExternalCall",
    "ExternalDataCharacterEncoding",
    "ExternalEvaluate",
    "ExternalFunction",
    "ExternalFunctionName",
    "ExternalIdentifier",
    "ExternalObject",
    "ExternalOptions",
    "ExternalSessionObject",
    "ExternalSessions",
    "ExternalStorageBase",
    "ExternalStorageDownload",
    "ExternalStorageGet",
    "ExternalStorageObject",
    "ExternalStoragePut",
    "ExternalStorageUpload",
    "ExternalTypeSignature",
    "ExternalValue",
    "Extract",
    "ExtractArchive",
    "ExtractLayer",
    "ExtractPacletArchive",
    "ExtremeValueDistribution",
    "FaceAlign",
    "FaceForm",
    "FaceGrids",
    "FaceGridsStyle",
    "FaceRecognize",
    "FacialFeatures",
    "Factor",
    "FactorComplete",
    "Factorial",
    "Factorial2",
    "FactorialMoment",
    "FactorialMomentGeneratingFunction",
    "FactorialPower",
    "FactorInteger",
    "FactorList",
    "FactorSquareFree",
    "FactorSquareFreeList",
    "FactorTerms",
    "FactorTermsList",
    "Fail",
    "Failure",
    "FailureAction",
    "FailureDistribution",
    "FailureQ",
    "False",
    "FareySequence",
    "FARIMAProcess",
    "FeatureDistance",
    "FeatureExtract",
    "FeatureExtraction",
    "FeatureExtractor",
    "FeatureExtractorFunction",
    "FeatureImpactPlot",
    "FeatureNames",
    "FeatureNearest",
    "FeatureSpacePlot",
    "FeatureSpacePlot3D",
    "FeatureTypes",
    "FeatureValueDependencyPlot",
    "FeatureValueImpactPlot",
    "FEDisableConsolePrintPacket",
    "FeedbackLinearize",
    "FeedbackSector",
    "FeedbackSectorStyle",
    "FeedbackType",
    "FEEnableConsolePrintPacket",
    "FetalGrowthData",
    "Fibonacci",
    "Fibonorial",
    "FieldCompletionFunction",
    "FieldHint",
    "FieldHintStyle",
    "FieldMasked",
    "FieldSize",
    "File",
    "FileBaseName",
    "FileByteCount",
    "FileConvert",
    "FileDate",
    "FileExistsQ",
    "FileExtension",
    "FileFormat",
    "FileFormatProperties",
    "FileFormatQ",
    "FileHandler",
    "FileHash",
    "FileInformation",
    "FileName",
    "FileNameDepth",
    "FileNameDialogSettings",
    "FileNameDrop",
    "FileNameForms",
    "FileNameJoin",
    "FileNames",
    "FileNameSetter",
    "FileNameSplit",
    "FileNameTake",
    "FileNameToFormatList",
    "FilePrint",
    "FileSize",
    "FileSystemMap",
    "FileSystemScan",
    "FileSystemTree",
    "FileTemplate",
    "FileTemplateApply",
    "FileType",
    "FilledCurve",
    "FilledCurveBox",
    "FilledCurveBoxOptions",
    "FilledTorus",
    "FillForm",
    "Filling",
    "FillingStyle",
    "FillingTransform",
    "FilteredEntityClass",
    "FilterRules",
    "FinancialBond",
    "FinancialData",
    "FinancialDerivative",
    "FinancialIndicator",
    "Find",
    "FindAnomalies",
    "FindArgMax",
    "FindArgMin",
    "FindChannels",
    "FindClique",
    "FindClusters",
    "FindCookies",
    "FindCurvePath",
    "FindCycle",
    "FindDevices",
    "FindDistribution",
    "FindDistributionParameters",
    "FindDivisions",
    "FindEdgeColoring",
    "FindEdgeCover",
    "FindEdgeCut",
    "FindEdgeIndependentPaths",
    "FindEquationalProof",
    "FindEulerianCycle",
    "FindExternalEvaluators",
    "FindFaces",
    "FindFile",
    "FindFit",
    "FindFormula",
    "FindFundamentalCycles",
    "FindGeneratingFunction",
    "FindGeoLocation",
    "FindGeometricConjectures",
    "FindGeometricTransform",
    "FindGraphCommunities",
    "FindGraphIsomorphism",
    "FindGraphPartition",
    "FindHamiltonianCycle",
    "FindHamiltonianPath",
    "FindHiddenMarkovStates",
    "FindImageText",
    "FindIndependentEdgeSet",
    "FindIndependentVertexSet",
    "FindInstance",
    "FindIntegerNullVector",
    "FindIsomers",
    "FindIsomorphicSubgraph",
    "FindKClan",
    "FindKClique",
    "FindKClub",
    "FindKPlex",
    "FindLibrary",
    "FindLinearRecurrence",
    "FindList",
    "FindMatchingColor",
    "FindMaximum",
    "FindMaximumCut",
    "FindMaximumFlow",
    "FindMaxValue",
    "FindMeshDefects",
    "FindMinimum",
    "FindMinimumCostFlow",
    "FindMinimumCut",
    "FindMinValue",
    "FindMoleculeSubstructure",
    "FindPath",
    "FindPeaks",
    "FindPermutation",
    "FindPlanarColoring",
    "FindPointProcessParameters",
    "FindPostmanTour",
    "FindProcessParameters",
    "FindRegionTransform",
    "FindRepeat",
    "FindRoot",
    "FindSequenceFunction",
    "FindSettings",
    "FindShortestPath",
    "FindShortestTour",
    "FindSpanningTree",
    "FindSubgraphIsomorphism",
    "FindSystemModelEquilibrium",
    "FindTextualAnswer",
    "FindThreshold",
    "FindTransientRepeat",
    "FindVertexColoring",
    "FindVertexCover",
    "FindVertexCut",
    "FindVertexIndependentPaths",
    "Fine",
    "FinishDynamic",
    "FiniteAbelianGroupCount",
    "FiniteGroupCount",
    "FiniteGroupData",
    "First",
    "FirstCase",
    "FirstPassageTimeDistribution",
    "FirstPosition",
    "FischerGroupFi22",
    "FischerGroupFi23",
    "FischerGroupFi24Prime",
    "FisherHypergeometricDistribution",
    "FisherRatioTest",
    "FisherZDistribution",
    "Fit",
    "FitAll",
    "FitRegularization",
    "FittedModel",
    "FixedOrder",
    "FixedPoint",
    "FixedPointList",
    "FlashSelection",
    "Flat",
    "FlatShading",
    "Flatten",
    "FlattenAt",
    "FlattenLayer",
    "FlatTopWindow",
    "FlightData",
    "FlipView",
    "Floor",
    "FlowPolynomial",
    "Fold",
    "FoldList",
    "FoldPair",
    "FoldPairList",
    "FoldWhile",
    "FoldWhileList",
    "FollowRedirects",
    "Font",
    "FontColor",
    "FontFamily",
    "FontForm",
    "FontName",
    "FontOpacity",
    "FontPostScriptName",
    "FontProperties",
    "FontReencoding",
    "FontSize",
    "FontSlant",
    "FontSubstitutions",
    "FontTracking",
    "FontVariations",
    "FontWeight",
    "For",
    "ForAll",
    "ForAllType",
    "ForceVersionInstall",
    "Format",
    "FormatRules",
    "FormatType",
    "FormatTypeAutoConvert",
    "FormatValues",
    "FormBox",
    "FormBoxOptions",
    "FormControl",
    "FormFunction",
    "FormLayoutFunction",
    "FormObject",
    "FormPage",
    "FormProtectionMethod",
    "FormTheme",
    "FormulaData",
    "FormulaLookup",
    "FortranForm",
    "Forward",
    "ForwardBackward",
    "ForwardCloudCredentials",
    "Fourier",
    "FourierCoefficient",
    "FourierCosCoefficient",
    "FourierCosSeries",
    "FourierCosTransform",
    "FourierDCT",
    "FourierDCTFilter",
    "FourierDCTMatrix",
    "FourierDST",
    "FourierDSTMatrix",
    "FourierMatrix",
    "FourierParameters",
    "FourierSequenceTransform",
    "FourierSeries",
    "FourierSinCoefficient",
    "FourierSinSeries",
    "FourierSinTransform",
    "FourierTransform",
    "FourierTrigSeries",
    "FoxH",
    "FoxHReduce",
    "FractionalBrownianMotionProcess",
    "FractionalD",
    "FractionalGaussianNoiseProcess",
    "FractionalPart",
    "FractionBox",
    "FractionBoxOptions",
    "FractionLine",
    "Frame",
    "FrameBox",
    "FrameBoxOptions",
    "Framed",
    "FrameInset",
    "FrameLabel",
    "Frameless",
    "FrameListVideo",
    "FrameMargins",
    "FrameRate",
    "FrameStyle",
    "FrameTicks",
    "FrameTicksStyle",
    "FRatioDistribution",
    "FrechetDistribution",
    "FreeQ",
    "FrenetSerretSystem",
    "FrequencySamplingFilterKernel",
    "FresnelC",
    "FresnelF",
    "FresnelG",
    "FresnelS",
    "Friday",
    "FrobeniusNumber",
    "FrobeniusSolve",
    "FromAbsoluteTime",
    "FromCharacterCode",
    "FromCoefficientRules",
    "FromContinuedFraction",
    "FromDate",
    "FromDateString",
    "FromDigits",
    "FromDMS",
    "FromEntity",
    "FromJulianDate",
    "FromLetterNumber",
    "FromPolarCoordinates",
    "FromRawPointer",
    "FromRomanNumeral",
    "FromSphericalCoordinates",
    "FromUnixTime",
    "Front",
    "FrontEndDynamicExpression",
    "FrontEndEventActions",
    "FrontEndExecute",
    "FrontEndObject",
    "FrontEndResource",
    "FrontEndResourceString",
    "FrontEndStackSize",
    "FrontEndToken",
    "FrontEndTokenExecute",
    "FrontEndValueCache",
    "FrontEndVersion",
    "FrontFaceColor",
    "FrontFaceGlowColor",
    "FrontFaceOpacity",
    "FrontFaceSpecularColor",
    "FrontFaceSpecularExponent",
    "FrontFaceSurfaceAppearance",
    "FrontFaceTexture",
    "Full",
    "FullAxes",
    "FullDefinition",
    "FullForm",
    "FullGraphics",
    "FullInformationOutputRegulator",
    "FullOptions",
    "FullRegion",
    "FullSimplify",
    "Function",
    "FunctionAnalytic",
    "FunctionBijective",
    "FunctionCompile",
    "FunctionCompileExport",
    "FunctionCompileExportByteArray",
    "FunctionCompileExportLibrary",
    "FunctionCompileExportString",
    "FunctionContinuous",
    "FunctionConvexity",
    "FunctionDeclaration",
    "FunctionDiscontinuities",
    "FunctionDomain",
    "FunctionExpand",
    "FunctionInjective",
    "FunctionInterpolation",
    "FunctionLayer",
    "FunctionMeromorphic",
    "FunctionMonotonicity",
    "FunctionPeriod",
    "FunctionPoles",
    "FunctionRange",
    "FunctionSign",
    "FunctionSingularities",
    "FunctionSpace",
    "FunctionSurjective",
    "FussellVeselyImportance",
    "GaborFilter",
    "GaborMatrix",
    "GaborWavelet",
    "GainMargins",
    "GainPhaseMargins",
    "GalaxyData",
    "GalleryView",
    "Gamma",
    "GammaDistribution",
    "GammaRegularized",
    "GapPenalty",
    "GARCHProcess",
    "GatedRecurrentLayer",
    "Gather",
    "GatherBy",
    "GaugeFaceElementFunction",
    "GaugeFaceStyle",
    "GaugeFrameElementFunction",
    "GaugeFrameSize",
    "GaugeFrameStyle",
    "GaugeLabels",
    "GaugeMarkers",
    "GaugeStyle",
    "GaussianFilter",
    "GaussianIntegers",
    "GaussianMatrix",
    "GaussianOrthogonalMatrixDistribution",
    "GaussianSymplecticMatrixDistribution",
    "GaussianUnitaryMatrixDistribution",
    "GaussianWindow",
    "GCD",
    "GegenbauerC",
    "General",
    "GeneralizedLinearModelFit",
    "GenerateAsymmetricKeyPair",
    "GenerateConditions",
    "GeneratedAssetFormat",
    "GeneratedAssetLocation",
    "GeneratedCell",
    "GeneratedCellStyles",
    "GeneratedDocumentBinding",
    "GenerateDerivedKey",
    "GenerateDigitalSignature",
    "GenerateDocument",
    "GeneratedParameters",
    "GeneratedQuantityMagnitudes",
    "GenerateFileSignature",
    "GenerateHTTPResponse",
    "GenerateSecuredAuthenticationKey",
    "GenerateSymmetricKey",
    "GeneratingFunction",
    "GeneratorDescription",
    "GeneratorHistoryLength",
    "GeneratorOutputType",
    "Generic",
    "GenericCylindricalDecomposition",
    "GenomeData",
    "GenomeLookup",
    "GeoAntipode",
    "GeoArea",
    "GeoArraySize",
    "GeoBackground",
    "GeoBoundary",
    "GeoBoundingBox",
    "GeoBounds",
    "GeoBoundsRegion",
    "GeoBoundsRegionBoundary",
    "GeoBubbleChart",
    "GeoCenter",
    "GeoCircle",
    "GeoContourPlot",
    "GeoDensityPlot",
    "GeodesicClosing",
    "GeodesicDilation",
    "GeodesicErosion",
    "GeodesicOpening",
    "GeodesicPolyhedron",
    "GeoDestination",
    "GeodesyData",
    "GeoDirection",
    "GeoDisk",
    "GeoDisplacement",
    "GeoDistance",
    "GeoDistanceList",
    "GeoElevationData",
    "GeoEntities",
    "GeoGraphics",
    "GeoGraphPlot",
    "GeoGraphValuePlot",
    "GeogravityModelData",
    "GeoGridDirectionDifference",
    "GeoGridLines",
    "GeoGridLinesStyle",
    "GeoGridPosition",
    "GeoGridRange",
    "GeoGridRangePadding",
    "GeoGridUnitArea",
    "GeoGridUnitDistance",
    "GeoGridVector",
    "GeoGroup",
    "GeoHemisphere",
    "GeoHemisphereBoundary",
    "GeoHistogram",
    "GeoIdentify",
    "GeoImage",
    "GeoLabels",
    "GeoLength",
    "GeoListPlot",
    "GeoLocation",
    "GeologicalPeriodData",
    "GeomagneticModelData",
    "GeoMarker",
    "GeometricAssertion",
    "GeometricBrownianMotionProcess",
    "GeometricDistribution",
    "GeometricMean",
    "GeometricMeanFilter",
    "GeometricOptimization",
    "GeometricScene",
    "GeometricStep",
    "GeometricStylingRules",
    "GeometricTest",
    "GeometricTransformation",
    "GeometricTransformation3DBox",
    "GeometricTransformation3DBoxOptions",
    "GeometricTransformationBox",
    "GeometricTransformationBoxOptions",
    "GeoModel",
    "GeoNearest",
    "GeoOrientationData",
    "GeoPath",
    "GeoPolygon",
    "GeoPosition",
    "GeoPositionENU",
    "GeoPositionXYZ",
    "GeoProjection",
    "GeoProjectionData",
    "GeoRange",
    "GeoRangePadding",
    "GeoRegionValuePlot",
    "GeoResolution",
    "GeoScaleBar",
    "GeoServer",
    "GeoSmoothHistogram",
    "GeoStreamPlot",
    "GeoStyling",
    "GeoStylingImageFunction",
    "GeoVariant",
    "GeoVector",
    "GeoVectorENU",
    "GeoVectorPlot",
    "GeoVectorXYZ",
    "GeoVisibleRegion",
    "GeoVisibleRegionBoundary",
    "GeoWithinQ",
    "GeoZoomLevel",
    "GestureHandler",
    "GestureHandlerTag",
    "Get",
    "GetContext",
    "GetEnvironment",
    "GetFileName",
    "GetLinebreakInformationPacket",
    "GibbsPointProcess",
    "Glaisher",
    "GlobalClusteringCoefficient",
    "GlobalPreferences",
    "GlobalSession",
    "Glow",
    "GoldenAngle",
    "GoldenRatio",
    "GompertzMakehamDistribution",
    "GoochShading",
    "GoodmanKruskalGamma",
    "GoodmanKruskalGammaTest",
    "Goto",
    "GouraudShading",
    "Grad",
    "Gradient",
    "GradientFilter",
    "GradientFittedMesh",
    "GradientOrientationFilter",
    "GrammarApply",
    "GrammarRules",
    "GrammarToken",
    "Graph",
    "Graph3D",
    "GraphAssortativity",
    "GraphAutomorphismGroup",
    "GraphCenter",
    "GraphComplement",
    "GraphData",
    "GraphDensity",
    "GraphDiameter",
    "GraphDifference",
    "GraphDisjointUnion",
    "GraphDistance",
    "GraphDistanceMatrix",
    "GraphEmbedding",
    "GraphHighlight",
    "GraphHighlightStyle",
    "GraphHub",
    "Graphics",
    "Graphics3D",
    "Graphics3DBox",
    "Graphics3DBoxOptions",
    "GraphicsArray",
    "GraphicsBaseline",
    "GraphicsBox",
    "GraphicsBoxOptions",
    "GraphicsColor",
    "GraphicsColumn",
    "GraphicsComplex",
    "GraphicsComplex3DBox",
    "GraphicsComplex3DBoxOptions",
    "GraphicsComplexBox",
    "GraphicsComplexBoxOptions",
    "GraphicsContents",
    "GraphicsData",
    "GraphicsGrid",
    "GraphicsGridBox",
    "GraphicsGroup",
    "GraphicsGroup3DBox",
    "GraphicsGroup3DBoxOptions",
    "GraphicsGroupBox",
    "GraphicsGroupBoxOptions",
    "GraphicsGrouping",
    "GraphicsHighlightColor",
    "GraphicsRow",
    "GraphicsSpacing",
    "GraphicsStyle",
    "GraphIntersection",
    "GraphJoin",
    "GraphLayerLabels",
    "GraphLayers",
    "GraphLayerStyle",
    "GraphLayout",
    "GraphLinkEfficiency",
    "GraphPeriphery",
    "GraphPlot",
    "GraphPlot3D",
    "GraphPower",
    "GraphProduct",
    "GraphPropertyDistribution",
    "GraphQ",
    "GraphRadius",
    "GraphReciprocity",
    "GraphRoot",
    "GraphStyle",
    "GraphSum",
    "GraphTree",
    "GraphUnion",
    "Gray",
    "GrayLevel",
    "Greater",
    "GreaterEqual",
    "GreaterEqualLess",
    "GreaterEqualThan",
    "GreaterFullEqual",
    "GreaterGreater",
    "GreaterLess",
    "GreaterSlantEqual",
    "GreaterThan",
    "GreaterTilde",
    "GreekStyle",
    "Green",
    "GreenFunction",
    "Grid",
    "GridBaseline",
    "GridBox",
    "GridBoxAlignment",
    "GridBoxBackground",
    "GridBoxDividers",
    "GridBoxFrame",
    "GridBoxItemSize",
    "GridBoxItemStyle",
    "GridBoxOptions",
    "GridBoxSpacings",
    "GridCreationSettings",
    "GridDefaultElement",
    "GridElementStyleOptions",
    "GridFrame",
    "GridFrameMargins",
    "GridGraph",
    "GridLines",
    "GridLinesStyle",
    "GridVideo",
    "GroebnerBasis",
    "GroupActionBase",
    "GroupBy",
    "GroupCentralizer",
    "GroupElementFromWord",
    "GroupElementPosition",
    "GroupElementQ",
    "GroupElements",
    "GroupElementToWord",
    "GroupGenerators",
    "Groupings",
    "GroupMultiplicationTable",
    "GroupOpenerColor",
    "GroupOpenerInsideFrame",
    "GroupOrbits",
    "GroupOrder",
    "GroupPageBreakWithin",
    "GroupSetwiseStabilizer",
    "GroupStabilizer",
    "GroupStabilizerChain",
    "GroupTogetherGrouping",
    "GroupTogetherNestedGrouping",
    "GrowCutComponents",
    "Gudermannian",
    "GuidedFilter",
    "GumbelDistribution",
    "HaarWavelet",
    "HadamardMatrix",
    "HalfLine",
    "HalfNormalDistribution",
    "HalfPlane",
    "HalfSpace",
    "HalftoneShading",
    "HamiltonianGraphQ",
    "HammingDistance",
    "HammingWindow",
    "HandlerFunctions",
    "HandlerFunctionsKeys",
    "HankelH1",
    "HankelH2",
    "HankelMatrix",
    "HankelTransform",
    "HannPoissonWindow",
    "HannWindow",
    "HaradaNortonGroupHN",
    "HararyGraph",
    "HardcorePointProcess",
    "HarmonicMean",
    "HarmonicMeanFilter",
    "HarmonicNumber",
    "Hash",
    "HatchFilling",
    "HatchShading",
    "Haversine",
    "HazardFunction",
    "Head",
    "HeadCompose",
    "HeaderAlignment",
    "HeaderBackground",
    "HeaderDisplayFunction",
    "HeaderLines",
    "Headers",
    "HeaderSize",
    "HeaderStyle",
    "Heads",
    "HeatFluxValue",
    "HeatInsulationValue",
    "HeatOutflowValue",
    "HeatRadiationValue",
    "HeatSymmetryValue",
    "HeatTemperatureCondition",
    "HeatTransferPDEComponent",
    "HeatTransferValue",
    "HeavisideLambda",
    "HeavisidePi",
    "HeavisideTheta",
    "HeldGroupHe",
    "HeldPart",
    "HelmholtzPDEComponent",
    "HelpBrowserLookup",
    "HelpBrowserNotebook",
    "HelpBrowserSettings",
    "HelpViewerSettings",
    "Here",
    "HermiteDecomposition",
    "HermiteH",
    "Hermitian",
    "HermitianMatrixQ",
    "HessenbergDecomposition",
    "Hessian",
    "HeunB",
    "HeunBPrime",
    "HeunC",
    "HeunCPrime",
    "HeunD",
    "HeunDPrime",
    "HeunG",
    "HeunGPrime",
    "HeunT",
    "HeunTPrime",
    "HexadecimalCharacter",
    "Hexahedron",
    "HexahedronBox",
    "HexahedronBoxOptions",
    "HiddenItems",
    "HiddenMarkovProcess",
    "HiddenSurface",
    "Highlighted",
    "HighlightGraph",
    "HighlightImage",
    "HighlightMesh",
    "HighlightString",
    "HighpassFilter",
    "HigmanSimsGroupHS",
    "HilbertCurve",
    "HilbertFilter",
    "HilbertMatrix",
    "Histogram",
    "Histogram3D",
    "HistogramDistribution",
    "HistogramList",
    "HistogramPointDensity",
    "HistogramTransform",
    "HistogramTransformInterpolation",
    "HistoricalPeriodData",
    "HitMissTransform",
    "HITSCentrality",
    "HjorthDistribution",
    "HodgeDual",
    "HoeffdingD",
    "HoeffdingDTest",
    "Hold",
    "HoldAll",
    "HoldAllComplete",
    "HoldComplete",
    "HoldFirst",
    "HoldForm",
    "HoldPattern",
    "HoldRest",
    "HolidayCalendar",
    "HomeDirectory",
    "HomePage",
    "Horizontal",
    "HorizontalForm",
    "HorizontalGauge",
    "HorizontalScrollPosition",
    "HornerForm",
    "HostLookup",
    "HotellingTSquareDistribution",
    "HoytDistribution",
    "HTMLSave",
    "HTTPErrorResponse",
    "HTTPRedirect",
    "HTTPRequest",
    "HTTPRequestData",
    "HTTPResponse",
    "Hue",
    "HumanGrowthData",
    "HumpDownHump",
    "HumpEqual",
    "HurwitzLerchPhi",
    "HurwitzZeta",
    "HyperbolicDistribution",
    "HypercubeGraph",
    "HyperexponentialDistribution",
    "Hyperfactorial",
    "Hypergeometric0F1",
    "Hypergeometric0F1Regularized",
    "Hypergeometric1F1",
    "Hypergeometric1F1Regularized",
    "Hypergeometric2F1",
    "Hypergeometric2F1Regularized",
    "HypergeometricDistribution",
    "HypergeometricPFQ",
    "HypergeometricPFQRegularized",
    "HypergeometricU",
    "Hyperlink",
    "HyperlinkAction",
    "HyperlinkCreationSettings",
    "Hyperplane",
    "Hyphenation",
    "HyphenationOptions",
    "HypoexponentialDistribution",
    "HypothesisTestData",
    "I",
    "IconData",
    "Iconize",
    "IconizedObject",
    "IconRules",
    "Icosahedron",
    "Identity",
    "IdentityMatrix",
    "If",
    "IfCompiled",
    "IgnoreCase",
    "IgnoreDiacritics",
    "IgnoreIsotopes",
    "IgnorePunctuation",
    "IgnoreSpellCheck",
    "IgnoreStereochemistry",
    "IgnoringInactive",
    "Im",
    "Image",
    "Image3D",
    "Image3DProjection",
    "Image3DSlices",
    "ImageAccumulate",
    "ImageAdd",
    "ImageAdjust",
    "ImageAlign",
    "ImageApply",
    "ImageApplyIndexed",
    "ImageAspectRatio",
    "ImageAssemble",
    "ImageAugmentationLayer",
    "ImageBoundingBoxes",
    "ImageCache",
    "ImageCacheValid",
    "ImageCapture",
    "ImageCaptureFunction",
    "ImageCases",
    "ImageChannels",
    "ImageClip",
    "ImageCollage",
    "ImageColorSpace",
    "ImageCompose",
    "ImageContainsQ",
    "ImageContents",
    "ImageConvolve",
    "ImageCooccurrence",
    "ImageCorners",
    "ImageCorrelate",
    "ImageCorrespondingPoints",
    "ImageCrop",
    "ImageData",
    "ImageDeconvolve",
    "ImageDemosaic",
    "ImageDifference",
    "ImageDimensions",
    "ImageDisplacements",
    "ImageDistance",
    "ImageEditMode",
    "ImageEffect",
    "ImageExposureCombine",
    "ImageFeatureTrack",
    "ImageFileApply",
    "ImageFileFilter",
    "ImageFileScan",
    "ImageFilter",
    "ImageFocusCombine",
    "ImageForestingComponents",
    "ImageFormattingWidth",
    "ImageForwardTransformation",
    "ImageGraphics",
    "ImageHistogram",
    "ImageIdentify",
    "ImageInstanceQ",
    "ImageKeypoints",
    "ImageLabels",
    "ImageLegends",
    "ImageLevels",
    "ImageLines",
    "ImageMargins",
    "ImageMarker",
    "ImageMarkers",
    "ImageMeasurements",
    "ImageMesh",
    "ImageMultiply",
    "ImageOffset",
    "ImagePad",
    "ImagePadding",
    "ImagePartition",
    "ImagePeriodogram",
    "ImagePerspectiveTransformation",
    "ImagePosition",
    "ImagePreviewFunction",
    "ImagePyramid",
    "ImagePyramidApply",
    "ImageQ",
    "ImageRangeCache",
    "ImageRecolor",
    "ImageReflect",
    "ImageRegion",
    "ImageResize",
    "ImageResolution",
    "ImageRestyle",
    "ImageRotate",
    "ImageRotated",
    "ImageSaliencyFilter",
    "ImageScaled",
    "ImageScan",
    "ImageSize",
    "ImageSizeAction",
    "ImageSizeCache",
    "ImageSizeMultipliers",
    "ImageSizeRaw",
    "ImageStitch",
    "ImageSubtract",
    "ImageTake",
    "ImageTransformation",
    "ImageTrim",
    "ImageType",
    "ImageValue",
    "ImageValuePositions",
    "ImageVectorscopePlot",
    "ImageWaveformPlot",
    "ImagingDevice",
    "ImplicitD",
    "ImplicitRegion",
    "Implies",
    "Import",
    "ImportAutoReplacements",
    "ImportByteArray",
    "ImportedObject",
    "ImportOptions",
    "ImportString",
    "ImprovementImportance",
    "In",
    "Inactivate",
    "Inactive",
    "InactiveStyle",
    "IncidenceGraph",
    "IncidenceList",
    "IncidenceMatrix",
    "IncludeAromaticBonds",
    "IncludeConstantBasis",
    "IncludedContexts",
    "IncludeDefinitions",
    "IncludeDirectories",
    "IncludeFileExtension",
    "IncludeGeneratorTasks",
    "IncludeHydrogens",
    "IncludeInflections",
    "IncludeMetaInformation",
    "IncludePods",
    "IncludeQuantities",
    "IncludeRelatedTables",
    "IncludeSingularSolutions",
    "IncludeSingularTerm",
    "IncludeWindowTimes",
    "Increment",
    "IndefiniteMatrixQ",
    "Indent",
    "IndentingNewlineSpacings",
    "IndentMaxFraction",
    "IndependenceTest",
    "IndependentEdgeSetQ",
    "IndependentPhysicalQuantity",
    "IndependentUnit",
    "IndependentUnitDimension",
    "IndependentVertexSetQ",
    "Indeterminate",
    "IndeterminateThreshold",
    "IndexCreationOptions",
    "Indexed",
    "IndexEdgeTaggedGraph",
    "IndexGraph",
    "IndexTag",
    "Inequality",
    "InertEvaluate",
    "InertExpression",
    "InexactNumberQ",
    "InexactNumbers",
    "InfiniteFuture",
    "InfiniteLine",
    "InfiniteLineThrough",
    "InfinitePast",
    "InfinitePlane",
    "Infinity",
    "Infix",
    "InflationAdjust",
    "InflationMethod",
    "Information",
    "InformationData",
    "InformationDataGrid",
    "Inherited",
    "InheritScope",
    "InhomogeneousPoissonPointProcess",
    "InhomogeneousPoissonProcess",
    "InitialEvaluationHistory",
    "Initialization",
    "InitializationCell",
    "InitializationCellEvaluation",
    "InitializationCellWarning",
    "InitializationObject",
    "InitializationObjects",
    "InitializationValue",
    "Initialize",
    "InitialSeeding",
    "InlineCounterAssignments",
    "InlineCounterIncrements",
    "InlineRules",
    "Inner",
    "InnerPolygon",
    "InnerPolyhedron",
    "Inpaint",
    "Input",
    "InputAliases",
    "InputAssumptions",
    "InputAutoReplacements",
    "InputField",
    "InputFieldBox",
    "InputFieldBoxOptions",
    "InputForm",
    "InputGrouping",
    "InputNamePacket",
    "InputNotebook",
    "InputPacket",
    "InputPorts",
    "InputSettings",
    "InputStream",
    "InputString",
    "InputStringPacket",
    "InputToBoxFormPacket",
    "Insert",
    "InsertionFunction",
    "InsertionPointObject",
    "InsertLinebreaks",
    "InsertResults",
    "Inset",
    "Inset3DBox",
    "Inset3DBoxOptions",
    "InsetBox",
    "InsetBoxOptions",
    "Insphere",
    "Install",
    "InstallService",
    "InstanceNormalizationLayer",
    "InString",
    "Integer",
    "IntegerDigits",
    "IntegerExponent",
    "IntegerLength",
    "IntegerName",
    "IntegerPart",
    "IntegerPartitions",
    "IntegerQ",
    "IntegerReverse",
    "Integers",
    "IntegerString",
    "Integral",
    "Integrate",
    "IntegrateChangeVariables",
    "Interactive",
    "InteractiveTradingChart",
    "InterfaceSwitched",
    "Interlaced",
    "Interleaving",
    "InternallyBalancedDecomposition",
    "InterpolatingFunction",
    "InterpolatingPolynomial",
    "Interpolation",
    "InterpolationOrder",
    "InterpolationPoints",
    "InterpolationPrecision",
    "Interpretation",
    "InterpretationBox",
    "InterpretationBoxOptions",
    "InterpretationFunction",
    "Interpreter",
    "InterpretTemplate",
    "InterquartileRange",
    "Interrupt",
    "InterruptSettings",
    "IntersectedEntityClass",
    "IntersectingQ",
    "Intersection",
    "Interval",
    "IntervalIntersection",
    "IntervalMarkers",
    "IntervalMarkersStyle",
    "IntervalMemberQ",
    "IntervalSlider",
    "IntervalUnion",
    "Into",
    "Inverse",
    "InverseBetaRegularized",
    "InverseBilateralLaplaceTransform",
    "InverseBilateralZTransform",
    "InverseCDF",
    "InverseChiSquareDistribution",
    "InverseContinuousWaveletTransform",
    "InverseDistanceTransform",
    "InverseEllipticNomeQ",
    "InverseErf",
    "InverseErfc",
    "InverseFourier",
    "InverseFourierCosTransform",
    "InverseFourierSequenceTransform",
    "InverseFourierSinTransform",
    "InverseFourierTransform",
    "InverseFunction",
    "InverseFunctions",
    "InverseGammaDistribution",
    "InverseGammaRegularized",
    "InverseGaussianDistribution",
    "InverseGudermannian",
    "InverseHankelTransform",
    "InverseHaversine",
    "InverseImagePyramid",
    "InverseJacobiCD",
    "InverseJacobiCN",
    "InverseJacobiCS",
    "InverseJacobiDC",
    "InverseJacobiDN",
    "InverseJacobiDS",
    "InverseJacobiNC",
    "InverseJacobiND",
    "InverseJacobiNS",
    "InverseJacobiSC",
    "InverseJacobiSD",
    "InverseJacobiSN",
    "InverseLaplaceTransform",
    "InverseMellinTransform",
    "InversePermutation",
    "InverseRadon",
    "InverseRadonTransform",
    "InverseSeries",
    "InverseShortTimeFourier",
    "InverseSpectrogram",
    "InverseSurvivalFunction",
    "InverseTransformedRegion",
    "InverseWaveletTransform",
    "InverseWeierstrassP",
    "InverseWishartMatrixDistribution",
    "InverseZTransform",
    "Invisible",
    "InvisibleApplication",
    "InvisibleTimes",
    "IPAddress",
    "IrreduciblePolynomialQ",
    "IslandData",
    "IsolatingInterval",
    "IsomorphicGraphQ",
    "IsomorphicSubgraphQ",
    "IsotopeData",
    "Italic",
    "Item",
    "ItemAspectRatio",
    "ItemBox",
    "ItemBoxOptions",
    "ItemDisplayFunction",
    "ItemSize",
    "ItemStyle",
    "ItoProcess",
    "JaccardDissimilarity",
    "JacobiAmplitude",
    "Jacobian",
    "JacobiCD",
    "JacobiCN",
    "JacobiCS",
    "JacobiDC",
    "JacobiDN",
    "JacobiDS",
    "JacobiEpsilon",
    "JacobiNC",
    "JacobiND",
    "JacobiNS",
    "JacobiP",
    "JacobiSC",
    "JacobiSD",
    "JacobiSN",
    "JacobiSymbol",
    "JacobiZeta",
    "JacobiZN",
    "JankoGroupJ1",
    "JankoGroupJ2",
    "JankoGroupJ3",
    "JankoGroupJ4",
    "JarqueBeraALMTest",
    "JohnsonDistribution",
    "Join",
    "JoinAcross",
    "Joined",
    "JoinedCurve",
    "JoinedCurveBox",
    "JoinedCurveBoxOptions",
    "JoinForm",
    "JordanDecomposition",
    "JordanModelDecomposition",
    "JulianDate",
    "JuliaSetBoettcher",
    "JuliaSetIterationCount",
    "JuliaSetPlot",
    "JuliaSetPoints",
    "K",
    "KagiChart",
    "KaiserBesselWindow",
    "KaiserWindow",
    "KalmanEstimator",
    "KalmanFilter",
    "KarhunenLoeveDecomposition",
    "KaryTree",
    "KatzCentrality",
    "KCoreComponents",
    "KDistribution",
    "KEdgeConnectedComponents",
    "KEdgeConnectedGraphQ",
    "KeepExistingVersion",
    "KelvinBei",
    "KelvinBer",
    "KelvinKei",
    "KelvinKer",
    "KendallTau",
    "KendallTauTest",
    "KernelConfiguration",
    "KernelExecute",
    "KernelFunction",
    "KernelMixtureDistribution",
    "KernelObject",
    "Kernels",
    "Ket",
    "Key",
    "KeyCollisionFunction",
    "KeyComplement",
    "KeyDrop",
    "KeyDropFrom",
    "KeyExistsQ",
    "KeyFreeQ",
    "KeyIntersection",
    "KeyMap",
    "KeyMemberQ",
    "KeypointStrength",
    "Keys",
    "KeySelect",
    "KeySort",
    "KeySortBy",
    "KeyTake",
    "KeyUnion",
    "KeyValueMap",
    "KeyValuePattern",
    "Khinchin",
    "KillProcess",
    "KirchhoffGraph",
    "KirchhoffMatrix",
    "KleinInvariantJ",
    "KnapsackSolve",
    "KnightTourGraph",
    "KnotData",
    "KnownUnitQ",
    "KochCurve",
    "KolmogorovSmirnovTest",
    "KroneckerDelta",
    "KroneckerModelDecomposition",
    "KroneckerProduct",
    "KroneckerSymbol",
    "KuiperTest",
    "KumaraswamyDistribution",
    "Kurtosis",
    "KuwaharaFilter",
    "KVertexConnectedComponents",
    "KVertexConnectedGraphQ",
    "LABColor",
    "Label",
    "Labeled",
    "LabeledSlider",
    "LabelingFunction",
    "LabelingSize",
    "LabelStyle",
    "LabelVisibility",
    "LaguerreL",
    "LakeData",
    "LambdaComponents",
    "LambertW",
    "LameC",
    "LameCPrime",
    "LameEigenvalueA",
    "LameEigenvalueB",
    "LameS",
    "LameSPrime",
    "LaminaData",
    "LanczosWindow",
    "LandauDistribution",
    "Language",
    "LanguageCategory",
    "LanguageData",
    "LanguageIdentify",
    "LanguageOptions",
    "LaplaceDistribution",
    "LaplaceTransform",
    "Laplacian",
    "LaplacianFilter",
    "LaplacianGaussianFilter",
    "LaplacianPDETerm",
    "Large",
    "Larger",
    "Last",
    "Latitude",
    "LatitudeLongitude",
    "LatticeData",
    "LatticeReduce",
    "Launch",
    "LaunchKernels",
    "LayeredGraphPlot",
    "LayeredGraphPlot3D",
    "LayerSizeFunction",
    "LayoutInformation",
    "LCHColor",
    "LCM",
    "LeaderSize",
    "LeafCount",
    "LeapVariant",
    "LeapYearQ",
    "LearnDistribution",
    "LearnedDistribution",
    "LearningRate",
    "LearningRateMultipliers",
    "LeastSquares",
    "LeastSquaresFilterKernel",
    "Left",
    "LeftArrow",
    "LeftArrowBar",
    "LeftArrowRightArrow",
    "LeftDownTeeVector",
    "LeftDownVector",
    "LeftDownVectorBar",
    "LeftRightArrow",
    "LeftRightVector",
    "LeftTee",
    "LeftTeeArrow",
    "LeftTeeVector",
    "LeftTriangle",
    "LeftTriangleBar",
    "LeftTriangleEqual",
    "LeftUpDownVector",
    "LeftUpTeeVector",
    "LeftUpVector",
    "LeftUpVectorBar",
    "LeftVector",
    "LeftVectorBar",
    "LegendAppearance",
    "Legended",
    "LegendFunction",
    "LegendLabel",
    "LegendLayout",
    "LegendMargins",
    "LegendMarkers",
    "LegendMarkerSize",
    "LegendreP",
    "LegendreQ",
    "LegendreType",
    "Length",
    "LengthWhile",
    "LerchPhi",
    "Less",
    "LessEqual",
    "LessEqualGreater",
    "LessEqualThan",
    "LessFullEqual",
    "LessGreater",
    "LessLess",
    "LessSlantEqual",
    "LessThan",
    "LessTilde",
    "LetterCharacter",
    "LetterCounts",
    "LetterNumber",
    "LetterQ",
    "Level",
    "LeveneTest",
    "LeviCivitaTensor",
    "LevyDistribution",
    "Lexicographic",
    "LexicographicOrder",
    "LexicographicSort",
    "LibraryDataType",
    "LibraryFunction",
    "LibraryFunctionDeclaration",
    "LibraryFunctionError",
    "LibraryFunctionInformation",
    "LibraryFunctionLoad",
    "LibraryFunctionUnload",
    "LibraryLoad",
    "LibraryUnload",
    "LicenseEntitlementObject",
    "LicenseEntitlements",
    "LicenseID",
    "LicensingSettings",
    "LiftingFilterData",
    "LiftingWaveletTransform",
    "LightBlue",
    "LightBrown",
    "LightCyan",
    "Lighter",
    "LightGray",
    "LightGreen",
    "Lighting",
    "LightingAngle",
    "LightMagenta",
    "LightOrange",
    "LightPink",
    "LightPurple",
    "LightRed",
    "LightSources",
    "LightYellow",
    "Likelihood",
    "Limit",
    "LimitsPositioning",
    "LimitsPositioningTokens",
    "LindleyDistribution",
    "Line",
    "Line3DBox",
    "Line3DBoxOptions",
    "LinearFilter",
    "LinearFractionalOptimization",
    "LinearFractionalTransform",
    "LinearGradientFilling",
    "LinearGradientImage",
    "LinearizingTransformationData",
    "LinearLayer",
    "LinearModelFit",
    "LinearOffsetFunction",
    "LinearOptimization",
    "LinearProgramming",
    "LinearRecurrence",
    "LinearSolve",
    "LinearSolveFunction",
    "LineBox",
    "LineBoxOptions",
    "LineBreak",
    "LinebreakAdjustments",
    "LineBreakChart",
    "LinebreakSemicolonWeighting",
    "LineBreakWithin",
    "LineColor",
    "LineGraph",
    "LineIndent",
    "LineIndentMaxFraction",
    "LineIntegralConvolutionPlot",
    "LineIntegralConvolutionScale",
    "LineLegend",
    "LineOpacity",
    "LineSpacing",
    "LineWrapParts",
    "LinkActivate",
    "LinkClose",
    "LinkConnect",
    "LinkConnectedQ",
    "LinkCreate",
    "LinkError",
    "LinkFlush",
    "LinkFunction",
    "LinkHost",
    "LinkInterrupt",
    "LinkLaunch",
    "LinkMode",
    "LinkObject",
    "LinkOpen",
    "LinkOptions",
    "LinkPatterns",
    "LinkProtocol",
    "LinkRankCentrality",
    "LinkRead",
    "LinkReadHeld",
    "LinkReadyQ",
    "Links",
    "LinkService",
    "LinkWrite",
    "LinkWriteHeld",
    "LiouvilleLambda",
    "List",
    "Listable",
    "ListAnimate",
    "ListContourPlot",
    "ListContourPlot3D",
    "ListConvolve",
    "ListCorrelate",
    "ListCurvePathPlot",
    "ListDeconvolve",
    "ListDensityPlot",
    "ListDensityPlot3D",
    "Listen",
    "ListFormat",
    "ListFourierSequenceTransform",
    "ListInterpolation",
    "ListLineIntegralConvolutionPlot",
    "ListLinePlot",
    "ListLinePlot3D",
    "ListLogLinearPlot",
    "ListLogLogPlot",
    "ListLogPlot",
    "ListPicker",
    "ListPickerBox",
    "ListPickerBoxBackground",
    "ListPickerBoxOptions",
    "ListPlay",
    "ListPlot",
    "ListPlot3D",
    "ListPointPlot3D",
    "ListPolarPlot",
    "ListQ",
    "ListSliceContourPlot3D",
    "ListSliceDensityPlot3D",
    "ListSliceVectorPlot3D",
    "ListStepPlot",
    "ListStreamDensityPlot",
    "ListStreamPlot",
    "ListStreamPlot3D",
    "ListSurfacePlot3D",
    "ListVectorDensityPlot",
    "ListVectorDisplacementPlot",
    "ListVectorDisplacementPlot3D",
    "ListVectorPlot",
    "ListVectorPlot3D",
    "ListZTransform",
    "Literal",
    "LiteralSearch",
    "LiteralType",
    "LoadCompiledComponent",
    "LocalAdaptiveBinarize",
    "LocalCache",
    "LocalClusteringCoefficient",
    "LocalEvaluate",
    "LocalizeDefinitions",
    "LocalizeVariables",
    "LocalObject",
    "LocalObjects",
    "LocalResponseNormalizationLayer",
    "LocalSubmit",
    "LocalSymbol",
    "LocalTime",
    "LocalTimeZone",
    "LocationEquivalenceTest",
    "LocationTest",
    "Locator",
    "LocatorAutoCreate",
    "LocatorBox",
    "LocatorBoxOptions",
    "LocatorCentering",
    "LocatorPane",
    "LocatorPaneBox",
    "LocatorPaneBoxOptions",
    "LocatorRegion",
    "Locked",
    "Log",
    "Log10",
    "Log2",
    "LogBarnesG",
    "LogGamma",
    "LogGammaDistribution",
    "LogicalExpand",
    "LogIntegral",
    "LogisticDistribution",
    "LogisticSigmoid",
    "LogitModelFit",
    "LogLikelihood",
    "LogLinearPlot",
    "LogLogisticDistribution",
    "LogLogPlot",
    "LogMultinormalDistribution",
    "LogNormalDistribution",
    "LogPlot",
    "LogRankTest",
    "LogSeriesDistribution",
    "LongEqual",
    "Longest",
    "LongestCommonSequence",
    "LongestCommonSequencePositions",
    "LongestCommonSubsequence",
    "LongestCommonSubsequencePositions",
    "LongestMatch",
    "LongestOrderedSequence",
    "LongForm",
    "Longitude",
    "LongLeftArrow",
    "LongLeftRightArrow",
    "LongRightArrow",
    "LongShortTermMemoryLayer",
    "Lookup",
    "Loopback",
    "LoopFreeGraphQ",
    "Looping",
    "LossFunction",
    "LowerCaseQ",
    "LowerLeftArrow",
    "LowerRightArrow",
    "LowerTriangularize",
    "LowerTriangularMatrix",
    "LowerTriangularMatrixQ",
    "LowpassFilter",
    "LQEstimatorGains",
    "LQGRegulator",
    "LQOutputRegulatorGains",
    "LQRegulatorGains",
    "LUBackSubstitution",
    "LucasL",
    "LuccioSamiComponents",
    "LUDecomposition",
    "LunarEclipse",
    "LUVColor",
    "LyapunovSolve",
    "LyonsGroupLy",
    "MachineID",
    "MachineName",
    "MachineNumberQ",
    "MachinePrecision",
    "MacintoshSystemPageSetup",
    "Magenta",
    "Magnification",
    "Magnify",
    "MailAddressValidation",
    "MailExecute",
    "MailFolder",
    "MailItem",
    "MailReceiverFunction",
    "MailResponseFunction",
    "MailSearch",
    "MailServerConnect",
    "MailServerConnection",
    "MailSettings",
    "MainSolve",
    "MaintainDynamicCaches",
    "Majority",
    "MakeBoxes",
    "MakeExpression",
    "MakeRules",
    "ManagedLibraryExpressionID",
    "ManagedLibraryExpressionQ",
    "MandelbrotSetBoettcher",
    "MandelbrotSetDistance",
    "MandelbrotSetIterationCount",
    "MandelbrotSetMemberQ",
    "MandelbrotSetPlot",
    "MangoldtLambda",
    "ManhattanDistance",
    "Manipulate",
    "Manipulator",
    "MannedSpaceMissionData",
    "MannWhitneyTest",
    "MantissaExponent",
    "Manual",
    "Map",
    "MapAll",
    "MapApply",
    "MapAt",
    "MapIndexed",
    "MAProcess",
    "MapThread",
    "MarchenkoPasturDistribution",
    "MarcumQ",
    "MardiaCombinedTest",
    "MardiaKurtosisTest",
    "MardiaSkewnessTest",
    "MarginalDistribution",
    "MarkovProcessProperties",
    "Masking",
    "MassConcentrationCondition",
    "MassFluxValue",
    "MassImpermeableBoundaryValue",
    "MassOutflowValue",
    "MassSymmetryValue",
    "MassTransferValue",
    "MassTransportPDEComponent",
    "MatchingDissimilarity",
    "MatchLocalNameQ",
    "MatchLocalNames",
    "MatchQ",
    "Material",
    "MaterialShading",
    "MaternPointProcess",
    "MathematicalFunctionData",
    "MathematicaNotation",
    "MathieuC",
    "MathieuCharacteristicA",
    "MathieuCharacteristicB",
    "MathieuCharacteristicExponent",
    "MathieuCPrime",
    "MathieuGroupM11",
    "MathieuGroupM12",
    "MathieuGroupM22",
    "MathieuGroupM23",
    "MathieuGroupM24",
    "MathieuS",
    "MathieuSPrime",
    "MathMLForm",
    "MathMLText",
    "Matrices",
    "MatrixExp",
    "MatrixForm",
    "MatrixFunction",
    "MatrixLog",
    "MatrixNormalDistribution",
    "MatrixPlot",
    "MatrixPower",
    "MatrixPropertyDistribution",
    "MatrixQ",
    "MatrixRank",
    "MatrixTDistribution",
    "Max",
    "MaxBend",
    "MaxCellMeasure",
    "MaxColorDistance",
    "MaxDate",
    "MaxDetect",
    "MaxDisplayedChildren",
    "MaxDuration",
    "MaxExtraBandwidths",
    "MaxExtraConditions",
    "MaxFeatureDisplacement",
    "MaxFeatures",
    "MaxFilter",
    "MaximalBy",
    "Maximize",
    "MaxItems",
    "MaxIterations",
    "MaxLimit",
    "MaxMemoryUsed",
    "MaxMixtureKernels",
    "MaxOverlapFraction",
    "MaxPlotPoints",
    "MaxPoints",
    "MaxRecursion",
    "MaxStableDistribution",
    "MaxStepFraction",
    "MaxSteps",
    "MaxStepSize",
    "MaxTrainingRounds",
    "MaxValue",
    "MaxwellDistribution",
    "MaxWordGap",
    "McLaughlinGroupMcL",
    "Mean",
    "MeanAbsoluteLossLayer",
    "MeanAround",
    "MeanClusteringCoefficient",
    "MeanDegreeConnectivity",
    "MeanDeviation",
    "MeanFilter",
    "MeanGraphDistance",
    "MeanNeighborDegree",
    "MeanPointDensity",
    "MeanShift",
    "MeanShiftFilter",
    "MeanSquaredLossLayer",
    "Median",
    "MedianDeviation",
    "MedianFilter",
    "MedicalTestData",
    "Medium",
    "MeijerG",
    "MeijerGReduce",
    "MeixnerDistribution",
    "MellinConvolve",
    "MellinTransform",
    "MemberQ",
    "MemoryAvailable",
    "MemoryConstrained",
    "MemoryConstraint",
    "MemoryInUse",
    "MengerMesh",
    "Menu",
    "MenuAppearance",
    "MenuCommandKey",
    "MenuEvaluator",
    "MenuItem",
    "MenuList",
    "MenuPacket",
    "MenuSortingValue",
    "MenuStyle",
    "MenuView",
    "Merge",
    "MergeDifferences",
    "MergingFunction",
    "MersennePrimeExponent",
    "MersennePrimeExponentQ",
    "Mesh",
    "MeshCellCentroid",
    "MeshCellCount",
    "MeshCellHighlight",
    "MeshCellIndex",
    "MeshCellLabel",
    "MeshCellMarker",
    "MeshCellMeasure",
    "MeshCellQuality",
    "MeshCells",
    "MeshCellShapeFunction",
    "MeshCellStyle",
    "MeshConnectivityGraph",
    "MeshCoordinates",
    "MeshFunctions",
    "MeshPrimitives",
    "MeshQualityGoal",
    "MeshRange",
    "MeshRefinementFunction",
    "MeshRegion",
    "MeshRegionQ",
    "MeshShading",
    "MeshStyle",
    "Message",
    "MessageDialog",
    "MessageList",
    "MessageName",
    "MessageObject",
    "MessageOptions",
    "MessagePacket",
    "Messages",
    "MessagesNotebook",
    "MetaCharacters",
    "MetaInformation",
    "MeteorShowerData",
    "Method",
    "MethodOptions",
    "MexicanHatWavelet",
    "MeyerWavelet",
    "Midpoint",
    "MIMETypeToFormatList",
    "Min",
    "MinColorDistance",
    "MinDate",
    "MinDetect",
    "MineralData",
    "MinFilter",
    "MinimalBy",
    "MinimalPolynomial",
    "MinimalStateSpaceModel",
    "Minimize",
    "MinimumTimeIncrement",
    "MinIntervalSize",
    "MinkowskiQuestionMark",
    "MinLimit",
    "MinMax",
    "MinorPlanetData",
    "Minors",
    "MinPointSeparation",
    "MinRecursion",
    "MinSize",
    "MinStableDistribution",
    "Minus",
    "MinusPlus",
    "MinValue",
    "Missing",
    "MissingBehavior",
    "MissingDataMethod",
    "MissingDataRules",
    "MissingQ",
    "MissingString",
    "MissingStyle",
    "MissingValuePattern",
    "MissingValueSynthesis",
    "MittagLefflerE",
    "MixedFractionParts",
    "MixedGraphQ",
    "MixedMagnitude",
    "MixedRadix",
    "MixedRadixQuantity",
    "MixedUnit",
    "MixtureDistribution",
    "Mod",
    "Modal",
    "Mode",
    "ModelPredictiveController",
    "Modular",
    "ModularInverse",
    "ModularLambda",
    "Module",
    "Modulus",
    "MoebiusMu",
    "Molecule",
    "MoleculeAlign",
    "MoleculeContainsQ",
    "MoleculeDraw",
    "MoleculeEquivalentQ",
    "MoleculeFreeQ",
    "MoleculeGraph",
    "MoleculeMatchQ",
    "MoleculeMaximumCommonSubstructure",
    "MoleculeModify",
    "MoleculeName",
    "MoleculePattern",
    "MoleculePlot",
    "MoleculePlot3D",
    "MoleculeProperty",
    "MoleculeQ",
    "MoleculeRecognize",
    "MoleculeSubstructureCount",
    "MoleculeValue",
    "Moment",
    "MomentConvert",
    "MomentEvaluate",
    "MomentGeneratingFunction",
    "MomentOfInertia",
    "Monday",
    "Monitor",
    "MonomialList",
    "MonomialOrder",
    "MonsterGroupM",
    "MoonPhase",
    "MoonPosition",
    "MorletWavelet",
    "MorphologicalBinarize",
    "MorphologicalBranchPoints",
    "MorphologicalComponents",
    "MorphologicalEulerNumber",
    "MorphologicalGraph",
    "MorphologicalPerimeter",
    "MorphologicalTransform",
    "MortalityData",
    "Most",
    "MountainData",
    "MouseAnnotation",
    "MouseAppearance",
    "MouseAppearanceTag",
    "MouseButtons",
    "Mouseover",
    "MousePointerNote",
    "MousePosition",
    "MovieData",
    "MovingAverage",
    "MovingMap",
    "MovingMedian",
    "MoyalDistribution",
    "MultiaxisArrangement",
    "Multicolumn",
    "MultiedgeStyle",
    "MultigraphQ",
    "MultilaunchWarning",
    "MultiLetterItalics",
    "MultiLetterStyle",
    "MultilineFunction",
    "Multinomial",
    "MultinomialDistribution",
    "MultinormalDistribution",
    "MultiplicativeOrder",
    "Multiplicity",
    "MultiplySides",
    "MultiscriptBoxOptions",
    "Multiselection",
    "MultivariateHypergeometricDistribution",
    "MultivariatePoissonDistribution",
    "MultivariateTDistribution",
    "N",
    "NakagamiDistribution",
    "NameQ",
    "Names",
    "NamespaceBox",
    "NamespaceBoxOptions",
    "Nand",
    "NArgMax",
    "NArgMin",
    "NBernoulliB",
    "NBodySimulation",
    "NBodySimulationData",
    "NCache",
    "NCaputoD",
    "NDEigensystem",
    "NDEigenvalues",
    "NDSolve",
    "NDSolveValue",
    "Nearest",
    "NearestFunction",
    "NearestMeshCells",
    "NearestNeighborG",
    "NearestNeighborGraph",
    "NearestTo",
    "NebulaData",
    "NeedlemanWunschSimilarity",
    "Needs",
    "Negative",
    "NegativeBinomialDistribution",
    "NegativeDefiniteMatrixQ",
    "NegativeIntegers",
    "NegativelyOrientedPoints",
    "NegativeMultinomialDistribution",
    "NegativeRationals",
    "NegativeReals",
    "NegativeSemidefiniteMatrixQ",
    "NeighborhoodData",
    "NeighborhoodGraph",
    "Nest",
    "NestedGreaterGreater",
    "NestedLessLess",
    "NestedScriptRules",
    "NestGraph",
    "NestList",
    "NestTree",
    "NestWhile",
    "NestWhileList",
    "NetAppend",
    "NetArray",
    "NetArrayLayer",
    "NetBidirectionalOperator",
    "NetChain",
    "NetDecoder",
    "NetDelete",
    "NetDrop",
    "NetEncoder",
    "NetEvaluationMode",
    "NetExternalObject",
    "NetExtract",
    "NetFlatten",
    "NetFoldOperator",
    "NetGANOperator",
    "NetGraph",
    "NetInformation",
    "NetInitialize",
    "NetInsert",
    "NetInsertSharedArrays",
    "NetJoin",
    "NetMapOperator",
    "NetMapThreadOperator",
    "NetMeasurements",
    "NetModel",
    "NetNestOperator",
    "NetPairEmbeddingOperator",
    "NetPort",
    "NetPortGradient",
    "NetPrepend",
    "NetRename",
    "NetReplace",
    "NetReplacePart",
    "NetSharedArray",
    "NetStateObject",
    "NetTake",
    "NetTrain",
    "NetTrainResultsObject",
    "NetUnfold",
    "NetworkPacketCapture",
    "NetworkPacketRecording",
    "NetworkPacketRecordingDuring",
    "NetworkPacketTrace",
    "NeumannValue",
    "NevilleThetaC",
    "NevilleThetaD",
    "NevilleThetaN",
    "NevilleThetaS",
    "NewPrimitiveStyle",
    "NExpectation",
    "Next",
    "NextCell",
    "NextDate",
    "NextPrime",
    "NextScheduledTaskTime",
    "NeymanScottPointProcess",
    "NFractionalD",
    "NHoldAll",
    "NHoldFirst",
    "NHoldRest",
    "NicholsGridLines",
    "NicholsPlot",
    "NightHemisphere",
    "NIntegrate",
    "NMaximize",
    "NMaxValue",
    "NMinimize",
    "NMinValue",
    "NominalScale",
    "NominalVariables",
    "NonAssociative",
    "NoncentralBetaDistribution",
    "NoncentralChiSquareDistribution",
    "NoncentralFRatioDistribution",
    "NoncentralStudentTDistribution",
    "NonCommutativeMultiply",
    "NonConstants",
    "NondimensionalizationTransform",
    "None",
    "NoneTrue",
    "NonlinearModelFit",
    "NonlinearStateSpaceModel",
    "NonlocalMeansFilter",
    "NonNegative",
    "NonNegativeIntegers",
    "NonNegativeRationals",
    "NonNegativeReals",
    "NonPositive",
    "NonPositiveIntegers",
    "NonPositiveRationals",
    "NonPositiveReals",
    "Nor",
    "NorlundB",
    "Norm",
    "Normal",
    "NormalDistribution",
    "NormalGrouping",
    "NormalizationLayer",
    "Normalize",
    "Normalized",
    "NormalizedSquaredEuclideanDistance",
    "NormalMatrixQ",
    "NormalsFunction",
    "NormFunction",
    "Not",
    "NotCongruent",
    "NotCupCap",
    "NotDoubleVerticalBar",
    "Notebook",
    "NotebookApply",
    "NotebookAutoSave",
    "NotebookBrowseDirectory",
    "NotebookClose",
    "NotebookConvertSettings",
    "NotebookCreate",
    "NotebookDefault",
    "NotebookDelete",
    "NotebookDirectory",
    "NotebookDynamicExpression",
    "NotebookEvaluate",
    "NotebookEventActions",
    "NotebookFileName",
    "NotebookFind",
    "NotebookGet",
    "NotebookImport",
    "NotebookInformation",
    "NotebookInterfaceObject",
    "NotebookLocate",
    "NotebookObject",
    "NotebookOpen",
    "NotebookPath",
    "NotebookPrint",
    "NotebookPut",
    "NotebookRead",
    "Notebooks",
    "NotebookSave",
    "NotebookSelection",
    "NotebooksMenu",
    "NotebookTemplate",
    "NotebookWrite",
    "NotElement",
    "NotEqualTilde",
    "NotExists",
    "NotGreater",
    "NotGreaterEqual",
    "NotGreaterFullEqual",
    "NotGreaterGreater",
    "NotGreaterLess",
    "NotGreaterSlantEqual",
    "NotGreaterTilde",
    "Nothing",
    "NotHumpDownHump",
    "NotHumpEqual",
    "NotificationFunction",
    "NotLeftTriangle",
    "NotLeftTriangleBar",
    "NotLeftTriangleEqual",
    "NotLess",
    "NotLessEqual",
    "NotLessFullEqual",
    "NotLessGreater",
    "NotLessLess",
    "NotLessSlantEqual",
    "NotLessTilde",
    "NotNestedGreaterGreater",
    "NotNestedLessLess",
    "NotPrecedes",
    "NotPrecedesEqual",
    "NotPrecedesSlantEqual",
    "NotPrecedesTilde",
    "NotReverseElement",
    "NotRightTriangle",
    "NotRightTriangleBar",
    "NotRightTriangleEqual",
    "NotSquareSubset",
    "NotSquareSubsetEqual",
    "NotSquareSuperset",
    "NotSquareSupersetEqual",
    "NotSubset",
    "NotSubsetEqual",
    "NotSucceeds",
    "NotSucceedsEqual",
    "NotSucceedsSlantEqual",
    "NotSucceedsTilde",
    "NotSuperset",
    "NotSupersetEqual",
    "NotTilde",
    "NotTildeEqual",
    "NotTildeFullEqual",
    "NotTildeTilde",
    "NotVerticalBar",
    "Now",
    "NoWhitespace",
    "NProbability",
    "NProduct",
    "NProductFactors",
    "NRoots",
    "NSolve",
    "NSolveValues",
    "NSum",
    "NSumTerms",
    "NuclearExplosionData",
    "NuclearReactorData",
    "Null",
    "NullRecords",
    "NullSpace",
    "NullWords",
    "Number",
    "NumberCompose",
    "NumberDecompose",
    "NumberDigit",
    "NumberExpand",
    "NumberFieldClassNumber",
    "NumberFieldDiscriminant",
    "NumberFieldFundamentalUnits",
    "NumberFieldIntegralBasis",
    "NumberFieldNormRepresentatives",
    "NumberFieldRegulator",
    "NumberFieldRootsOfUnity",
    "NumberFieldSignature",
    "NumberForm",
    "NumberFormat",
    "NumberLinePlot",
    "NumberMarks",
    "NumberMultiplier",
    "NumberPadding",
    "NumberPoint",
    "NumberQ",
    "NumberSeparator",
    "NumberSigns",
    "NumberString",
    "Numerator",
    "NumeratorDenominator",
    "NumericalOrder",
    "NumericalSort",
    "NumericArray",
    "NumericArrayQ",
    "NumericArrayType",
    "NumericFunction",
    "NumericQ",
    "NuttallWindow",
    "NValues",
    "NyquistGridLines",
    "NyquistPlot",
    "O",
    "ObjectExistsQ",
    "ObservabilityGramian",
    "ObservabilityMatrix",
    "ObservableDecomposition",
    "ObservableModelQ",
    "OceanData",
    "Octahedron",
    "OddQ",
    "Off",
    "Offset",
    "OLEData",
    "On",
    "ONanGroupON",
    "Once",
    "OneIdentity",
    "Opacity",
    "OpacityFunction",
    "OpacityFunctionScaling",
    "Open",
    "OpenAppend",
    "Opener",
    "OpenerBox",
    "OpenerBoxOptions",
    "OpenerView",
    "OpenFunctionInspectorPacket",
    "Opening",
    "OpenRead",
    "OpenSpecialOptions",
    "OpenTemporary",
    "OpenWrite",
    "Operate",
    "OperatingSystem",
    "OperatorApplied",
    "OptimumFlowData",
    "Optional",
    "OptionalElement",
    "OptionInspectorSettings",
    "OptionQ",
    "Options",
    "OptionsPacket",
    "OptionsPattern",
    "OptionValue",
    "OptionValueBox",
    "OptionValueBoxOptions",
    "Or",
    "Orange",
    "Order",
    "OrderDistribution",
    "OrderedQ",
    "Ordering",
    "OrderingBy",
    "OrderingLayer",
    "Orderless",
    "OrderlessPatternSequence",
    "OrdinalScale",
    "OrnsteinUhlenbeckProcess",
    "Orthogonalize",
    "OrthogonalMatrixQ",
    "Out",
    "Outer",
    "OuterPolygon",
    "OuterPolyhedron",
    "OutputAutoOverwrite",
    "OutputControllabilityMatrix",
    "OutputControllableModelQ",
    "OutputForm",
    "OutputFormData",
    "OutputGrouping",
    "OutputMathEditExpression",
    "OutputNamePacket",
    "OutputPorts",
    "OutputResponse",
    "OutputSizeLimit",
    "OutputStream",
    "Over",
    "OverBar",
    "OverDot",
    "Overflow",
    "OverHat",
    "Overlaps",
    "Overlay",
    "OverlayBox",
    "OverlayBoxOptions",
    "OverlayVideo",
    "Overscript",
    "OverscriptBox",
    "OverscriptBoxOptions",
    "OverTilde",
    "OverVector",
    "OverwriteTarget",
    "OwenT",
    "OwnValues",
    "Package",
    "PackingMethod",
    "PackPaclet",
    "PacletDataRebuild",
    "PacletDirectoryAdd",
    "PacletDirectoryLoad",
    "PacletDirectoryRemove",
    "PacletDirectoryUnload",
    "PacletDisable",
    "PacletEnable",
    "PacletFind",
    "PacletFindRemote",
    "PacletInformation",
    "PacletInstall",
    "PacletInstallSubmit",
    "PacletNewerQ",
    "PacletObject",
    "PacletObjectQ",
    "PacletSite",
    "PacletSiteObject",
    "PacletSiteRegister",
    "PacletSites",
    "PacletSiteUnregister",
    "PacletSiteUpdate",
    "PacletSymbol",
    "PacletUninstall",
    "PacletUpdate",
    "PaddedForm",
    "Padding",
    "PaddingLayer",
    "PaddingSize",
    "PadeApproximant",
    "PadLeft",
    "PadRight",
    "PageBreakAbove",
    "PageBreakBelow",
    "PageBreakWithin",
    "PageFooterLines",
    "PageFooters",
    "PageHeaderLines",
    "PageHeaders",
    "PageHeight",
    "PageRankCentrality",
    "PageTheme",
    "PageWidth",
    "Pagination",
    "PairCorrelationG",
    "PairedBarChart",
    "PairedHistogram",
    "PairedSmoothHistogram",
    "PairedTTest",
    "PairedZTest",
    "PaletteNotebook",
    "PalettePath",
    "PalettesMenuSettings",
    "PalindromeQ",
    "Pane",
    "PaneBox",
    "PaneBoxOptions",
    "Panel",
    "PanelBox",
    "PanelBoxOptions",
    "Paneled",
    "PaneSelector",
    "PaneSelectorBox",
    "PaneSelectorBoxOptions",
    "PaperWidth",
    "ParabolicCylinderD",
    "ParagraphIndent",
    "ParagraphSpacing",
    "ParallelArray",
    "ParallelAxisPlot",
    "ParallelCombine",
    "ParallelDo",
    "Parallelepiped",
    "ParallelEvaluate",
    "Parallelization",
    "Parallelize",
    "ParallelKernels",
    "ParallelMap",
    "ParallelNeeds",
    "Parallelogram",
    "ParallelProduct",
    "ParallelSubmit",
    "ParallelSum",
    "ParallelTable",
    "ParallelTry",
    "Parameter",
    "ParameterEstimator",
    "ParameterMixtureDistribution",
    "ParameterVariables",
    "ParametricConvexOptimization",
    "ParametricFunction",
    "ParametricNDSolve",
    "ParametricNDSolveValue",
    "ParametricPlot",
    "ParametricPlot3D",
    "ParametricRampLayer",
    "ParametricRegion",
    "ParentBox",
    "ParentCell",
    "ParentConnect",
    "ParentDirectory",
    "ParentEdgeLabel",
    "ParentEdgeLabelFunction",
    "ParentEdgeLabelStyle",
    "ParentEdgeShapeFunction",
    "ParentEdgeStyle",
    "ParentEdgeStyleFunction",
    "ParentForm",
    "Parenthesize",
    "ParentList",
    "ParentNotebook",
    "ParetoDistribution",
    "ParetoPickandsDistribution",
    "ParkData",
    "Part",
    "PartBehavior",
    "PartialCorrelationFunction",
    "PartialD",
    "ParticleAcceleratorData",
    "ParticleData",
    "Partition",
    "PartitionGranularity",
    "PartitionsP",
    "PartitionsQ",
    "PartLayer",
    "PartOfSpeech",
    "PartProtection",
    "ParzenWindow",
    "PascalDistribution",
    "PassEventsDown",
    "PassEventsUp",
    "Paste",
    "PasteAutoQuoteCharacters",
    "PasteBoxFormInlineCells",
    "PasteButton",
    "Path",
    "PathGraph",
    "PathGraphQ",
    "Pattern",
    "PatternFilling",
    "PatternReaction",
    "PatternSequence",
    "PatternTest",
    "PauliMatrix",
    "PaulWavelet",
    "Pause",
    "PausedTime",
    "PDF",
    "PeakDetect",
    "PeanoCurve",
    "PearsonChiSquareTest",
    "PearsonCorrelationTest",
    "PearsonDistribution",
    "PenttinenPointProcess",
    "PercentForm",
    "PerfectNumber",
    "PerfectNumberQ",
    "PerformanceGoal",
    "Perimeter",
    "PeriodicBoundaryCondition",
    "PeriodicInterpolation",
    "Periodogram",
    "PeriodogramArray",
    "Permanent",
    "Permissions",
    "PermissionsGroup",
    "PermissionsGroupMemberQ",
    "PermissionsGroups",
    "PermissionsKey",
    "PermissionsKeys",
    "PermutationCycles",
    "PermutationCyclesQ",
    "PermutationGroup",
    "PermutationLength",
    "PermutationList",
    "PermutationListQ",
    "PermutationMatrix",
    "PermutationMax",
    "PermutationMin",
    "PermutationOrder",
    "PermutationPower",
    "PermutationProduct",
    "PermutationReplace",
    "Permutations",
    "PermutationSupport",
    "Permute",
    "PeronaMalikFilter",
    "Perpendicular",
    "PerpendicularBisector",
    "PersistenceLocation",
    "PersistenceTime",
    "PersistentObject",
    "PersistentObjects",
    "PersistentSymbol",
    "PersistentValue",
    "PersonData",
    "PERTDistribution",
    "PetersenGraph",
    "PhaseMargins",
    "PhaseRange",
    "PhongShading",
    "PhysicalSystemData",
    "Pi",
    "Pick",
    "PickedElements",
    "PickMode",
    "PIDData",
    "PIDDerivativeFilter",
    "PIDFeedforward",
    "PIDTune",
    "Piecewise",
    "PiecewiseExpand",
    "PieChart",
    "PieChart3D",
    "PillaiTrace",
    "PillaiTraceTest",
    "PingTime",
    "Pink",
    "PitchRecognize",
    "Pivoting",
    "PixelConstrained",
    "PixelValue",
    "PixelValuePositions",
    "Placed",
    "Placeholder",
    "PlaceholderLayer",
    "PlaceholderReplace",
    "Plain",
    "PlanarAngle",
    "PlanarFaceList",
    "PlanarGraph",
    "PlanarGraphQ",
    "PlanckRadiationLaw",
    "PlaneCurveData",
    "PlanetaryMoonData",
    "PlanetData",
    "PlantData",
    "Play",
    "PlaybackSettings",
    "PlayRange",
    "Plot",
    "Plot3D",
    "Plot3Matrix",
    "PlotDivision",
    "PlotJoined",
    "PlotLabel",
    "PlotLabels",
    "PlotLayout",
    "PlotLegends",
    "PlotMarkers",
    "PlotPoints",
    "PlotRange",
    "PlotRangeClipping",
    "PlotRangeClipPlanesStyle",
    "PlotRangePadding",
    "PlotRegion",
    "PlotStyle",
    "PlotTheme",
    "Pluralize",
    "Plus",
    "PlusMinus",
    "Pochhammer",
    "PodStates",
    "PodWidth",
    "Point",
    "Point3DBox",
    "Point3DBoxOptions",
    "PointBox",
    "PointBoxOptions",
    "PointCountDistribution",
    "PointDensity",
    "PointDensityFunction",
    "PointFigureChart",
    "PointLegend",
    "PointLight",
    "PointProcessEstimator",
    "PointProcessFitTest",
    "PointProcessParameterAssumptions",
    "PointProcessParameterQ",
    "PointSize",
    "PointStatisticFunction",
    "PointValuePlot",
    "PoissonConsulDistribution",
    "PoissonDistribution",
    "PoissonPDEComponent",
    "PoissonPointProcess",
    "PoissonProcess",
    "PoissonWindow",
    "PolarAxes",
    "PolarAxesOrigin",
    "PolarGridLines",
    "PolarPlot",
    "PolarTicks",
    "PoleZeroMarkers",
    "PolyaAeppliDistribution",
    "PolyGamma",
    "Polygon",
    "Polygon3DBox",
    "Polygon3DBoxOptions",
    "PolygonalNumber",
    "PolygonAngle",
    "PolygonBox",
    "PolygonBoxOptions",
    "PolygonCoordinates",
    "PolygonDecomposition",
    "PolygonHoleScale",
    "PolygonIntersections",
    "PolygonScale",
    "Polyhedron",
    "PolyhedronAngle",
    "PolyhedronBox",
    "PolyhedronBoxOptions",
    "PolyhedronCoordinates",
    "PolyhedronData",
    "PolyhedronDecomposition",
    "PolyhedronGenus",
    "PolyLog",
    "PolynomialExpressionQ",
    "PolynomialExtendedGCD",
    "PolynomialForm",
    "PolynomialGCD",
    "PolynomialLCM",
    "PolynomialMod",
    "PolynomialQ",
    "PolynomialQuotient",
    "PolynomialQuotientRemainder",
    "PolynomialReduce",
    "PolynomialRemainder",
    "Polynomials",
    "PolynomialSumOfSquaresList",
    "PoolingLayer",
    "PopupMenu",
    "PopupMenuBox",
    "PopupMenuBoxOptions",
    "PopupView",
    "PopupWindow",
    "Position",
    "PositionIndex",
    "PositionLargest",
    "PositionSmallest",
    "Positive",
    "PositiveDefiniteMatrixQ",
    "PositiveIntegers",
    "PositivelyOrientedPoints",
    "PositiveRationals",
    "PositiveReals",
    "PositiveSemidefiniteMatrixQ",
    "PossibleZeroQ",
    "Postfix",
    "PostScript",
    "Power",
    "PowerDistribution",
    "PowerExpand",
    "PowerMod",
    "PowerModList",
    "PowerRange",
    "PowerSpectralDensity",
    "PowersRepresentations",
    "PowerSymmetricPolynomial",
    "Precedence",
    "PrecedenceForm",
    "Precedes",
    "PrecedesEqual",
    "PrecedesSlantEqual",
    "PrecedesTilde",
    "Precision",
    "PrecisionGoal",
    "PreDecrement",
    "Predict",
    "PredictionRoot",
    "PredictorFunction",
    "PredictorInformation",
    "PredictorMeasurements",
    "PredictorMeasurementsObject",
    "PreemptProtect",
    "PreferencesPath",
    "PreferencesSettings",
    "Prefix",
    "PreIncrement",
    "Prepend",
    "PrependLayer",
    "PrependTo",
    "PreprocessingRules",
    "PreserveColor",
    "PreserveImageOptions",
    "Previous",
    "PreviousCell",
    "PreviousDate",
    "PriceGraphDistribution",
    "PrimaryPlaceholder",
    "Prime",
    "PrimeNu",
    "PrimeOmega",
    "PrimePi",
    "PrimePowerQ",
    "PrimeQ",
    "Primes",
    "PrimeZetaP",
    "PrimitivePolynomialQ",
    "PrimitiveRoot",
    "PrimitiveRootList",
    "PrincipalComponents",
    "PrincipalValue",
    "Print",
    "PrintableASCIIQ",
    "PrintAction",
    "PrintForm",
    "PrintingCopies",
    "PrintingOptions",
    "PrintingPageRange",
    "PrintingStartingPageNumber",
    "PrintingStyleEnvironment",
    "Printout3D",
    "Printout3DPreviewer",
    "PrintPrecision",
    "PrintTemporary",
    "Prism",
    "PrismBox",
    "PrismBoxOptions",
    "PrivateCellOptions",
    "PrivateEvaluationOptions",
    "PrivateFontOptions",
    "PrivateFrontEndOptions",
    "PrivateKey",
    "PrivateNotebookOptions",
    "PrivatePaths",
    "Probability",
    "ProbabilityDistribution",
    "ProbabilityPlot",
    "ProbabilityPr",
    "ProbabilityScalePlot",
    "ProbitModelFit",
    "ProcessConnection",
    "ProcessDirectory",
    "ProcessEnvironment",
    "Processes",
    "ProcessEstimator",
    "ProcessInformation",
    "ProcessObject",
    "ProcessParameterAssumptions",
    "ProcessParameterQ",
    "ProcessStateDomain",
    "ProcessStatus",
    "ProcessTimeDomain",
    "Product",
    "ProductDistribution",
    "ProductLog",
    "ProgressIndicator",
    "ProgressIndicatorBox",
    "ProgressIndicatorBoxOptions",
    "ProgressReporting",
    "Projection",
    "Prolog",
    "PromptForm",
    "ProofObject",
    "PropagateAborts",
    "Properties",
    "Property",
    "PropertyList",
    "PropertyValue",
    "Proportion",
    "Proportional",
    "Protect",
    "Protected",
    "ProteinData",
    "Pruning",
    "PseudoInverse",
    "PsychrometricPropertyData",
    "PublicKey",
    "PublisherID",
    "PulsarData",
    "PunctuationCharacter",
    "Purple",
    "Put",
    "PutAppend",
    "Pyramid",
    "PyramidBox",
    "PyramidBoxOptions",
    "QBinomial",
    "QFactorial",
    "QGamma",
    "QHypergeometricPFQ",
    "QnDispersion",
    "QPochhammer",
    "QPolyGamma",
    "QRDecomposition",
    "QuadraticIrrationalQ",
    "QuadraticOptimization",
    "Quantile",
    "QuantilePlot",
    "Quantity",
    "QuantityArray",
    "QuantityDistribution",
    "QuantityForm",
    "QuantityMagnitude",
    "QuantityQ",
    "QuantityUnit",
    "QuantityVariable",
    "QuantityVariableCanonicalUnit",
    "QuantityVariableDimensions",
    "QuantityVariableIdentifier",
    "QuantityVariablePhysicalQuantity",
    "Quartics",
    "QuartileDeviation",
    "Quartiles",
    "QuartileSkewness",
    "Query",
    "QuestionGenerator",
    "QuestionInterface",
    "QuestionObject",
    "QuestionSelector",
    "QueueingNetworkProcess",
    "QueueingProcess",
    "QueueProperties",
    "Quiet",
    "QuietEcho",
    "Quit",
    "Quotient",
    "QuotientRemainder",
    "RadialAxisPlot",
    "RadialGradientFilling",
    "RadialGradientImage",
    "RadialityCentrality",
    "RadicalBox",
    "RadicalBoxOptions",
    "RadioButton",
    "RadioButtonBar",
    "RadioButtonBox",
    "RadioButtonBoxOptions",
    "Radon",
    "RadonTransform",
    "RamanujanTau",
    "RamanujanTauL",
    "RamanujanTauTheta",
    "RamanujanTauZ",
    "Ramp",
    "Random",
    "RandomArrayLayer",
    "RandomChoice",
    "RandomColor",
    "RandomComplex",
    "RandomDate",
    "RandomEntity",
    "RandomFunction",
    "RandomGeneratorState",
    "RandomGeoPosition",
    "RandomGraph",
    "RandomImage",
    "RandomInstance",
    "RandomInteger",
    "RandomPermutation",
    "RandomPoint",
    "RandomPointConfiguration",
    "RandomPolygon",
    "RandomPolyhedron",
    "RandomPrime",
    "RandomReal",
    "RandomSample",
    "RandomSeed",
    "RandomSeeding",
    "RandomTime",
    "RandomTree",
    "RandomVariate",
    "RandomWalkProcess",
    "RandomWord",
    "Range",
    "RangeFilter",
    "RangeSpecification",
    "RankedMax",
    "RankedMin",
    "RarerProbability",
    "Raster",
    "Raster3D",
    "Raster3DBox",
    "Raster3DBoxOptions",
    "RasterArray",
    "RasterBox",
    "RasterBoxOptions",
    "Rasterize",
    "RasterSize",
    "Rational",
    "RationalExpressionQ",
    "RationalFunctions",
    "Rationalize",
    "Rationals",
    "Ratios",
    "RawArray",
    "RawBoxes",
    "RawData",
    "RawMedium",
    "RayleighDistribution",
    "Re",
    "ReactionBalance",
    "ReactionBalancedQ",
    "ReactionPDETerm",
    "Read",
    "ReadByteArray",
    "ReadLine",
    "ReadList",
    "ReadProtected",
    "ReadString",
    "Real",
    "RealAbs",
    "RealBlockDiagonalForm",
    "RealDigits",
    "RealExponent",
    "Reals",
    "RealSign",
    "Reap",
    "RebuildPacletData",
    "RecalibrationFunction",
    "RecognitionPrior",
    "RecognitionThreshold",
    "ReconstructionMesh",
    "Record",
    "RecordLists",
    "RecordSeparators",
    "Rectangle",
    "RectangleBox",
    "RectangleBoxOptions",
    "RectangleChart",
    "RectangleChart3D",
    "RectangularRepeatingElement",
    "RecurrenceFilter",
    "RecurrenceTable",
    "RecurringDigitsForm",
    "Red",
    "Reduce",
    "RefBox",
    "ReferenceLineStyle",
    "ReferenceMarkers",
    "ReferenceMarkerStyle",
    "Refine",
    "ReflectionMatrix",
    "ReflectionTransform",
    "Refresh",
    "RefreshRate",
    "Region",
    "RegionBinarize",
    "RegionBoundary",
    "RegionBoundaryStyle",
    "RegionBounds",
    "RegionCentroid",
    "RegionCongruent",
    "RegionConvert",
    "RegionDifference",
    "RegionDilation",
    "RegionDimension",
    "RegionDisjoint",
    "RegionDistance",
    "RegionDistanceFunction",
    "RegionEmbeddingDimension",
    "RegionEqual",
    "RegionErosion",
    "RegionFillingStyle",
    "RegionFit",
    "RegionFunction",
    "RegionImage",
    "RegionIntersection",
    "RegionMeasure",
    "RegionMember",
    "RegionMemberFunction",
    "RegionMoment",
    "RegionNearest",
    "RegionNearestFunction",
    "RegionPlot",
    "RegionPlot3D",
    "RegionProduct",
    "RegionQ",
    "RegionResize",
    "RegionSimilar",
    "RegionSize",
    "RegionSymmetricDifference",
    "RegionUnion",
    "RegionWithin",
    "RegisterExternalEvaluator",
    "RegularExpression",
    "Regularization",
    "RegularlySampledQ",
    "RegularPolygon",
    "ReIm",
    "ReImLabels",
    "ReImPlot",
    "ReImStyle",
    "Reinstall",
    "RelationalDatabase",
    "RelationGraph",
    "Release",
    "ReleaseHold",
    "ReliabilityDistribution",
    "ReliefImage",
    "ReliefPlot",
    "RemoteAuthorizationCaching",
    "RemoteBatchJobAbort",
    "RemoteBatchJobObject",
    "RemoteBatchJobs",
    "RemoteBatchMapSubmit",
    "RemoteBatchSubmissionEnvironment",
    "RemoteBatchSubmit",
    "RemoteConnect",
    "RemoteConnectionObject",
    "RemoteEvaluate",
    "RemoteFile",
    "RemoteInputFiles",
    "RemoteKernelObject",
    "RemoteProviderSettings",
    "RemoteRun",
    "RemoteRunProcess",
    "RemovalConditions",
    "Remove",
    "RemoveAlphaChannel",
    "RemoveAsynchronousTask",
    "RemoveAudioStream",
    "RemoveBackground",
    "RemoveChannelListener",
    "RemoveChannelSubscribers",
    "Removed",
    "RemoveDiacritics",
    "RemoveInputStreamMethod",
    "RemoveOutputStreamMethod",
    "RemoveProperty",
    "RemoveScheduledTask",
    "RemoveUsers",
    "RemoveVideoStream",
    "RenameDirectory",
    "RenameFile",
    "RenderAll",
    "RenderingOptions",
    "RenewalProcess",
    "RenkoChart",
    "RepairMesh",
    "Repeated",
    "RepeatedNull",
    "RepeatedString",
    "RepeatedTiming",
    "RepeatingElement",
    "Replace",
    "ReplaceAll",
    "ReplaceAt",
    "ReplaceHeldPart",
    "ReplaceImageValue",
    "ReplaceList",
    "ReplacePart",
    "ReplacePixelValue",
    "ReplaceRepeated",
    "ReplicateLayer",
    "RequiredPhysicalQuantities",
    "Resampling",
    "ResamplingAlgorithmData",
    "ResamplingMethod",
    "Rescale",
    "RescalingTransform",
    "ResetDirectory",
    "ResetScheduledTask",
    "ReshapeLayer",
    "Residue",
    "ResidueSum",
    "ResizeLayer",
    "Resolve",
    "ResolveContextAliases",
    "ResourceAcquire",
    "ResourceData",
    "ResourceFunction",
    "ResourceObject",
    "ResourceRegister",
    "ResourceRemove",
    "ResourceSearch",
    "ResourceSubmissionObject",
    "ResourceSubmit",
    "ResourceSystemBase",
    "ResourceSystemPath",
    "ResourceUpdate",
    "ResourceVersion",
    "ResponseForm",
    "Rest",
    "RestartInterval",
    "Restricted",
    "Resultant",
    "ResumePacket",
    "Return",
    "ReturnCreatesNewCell",
    "ReturnEntersInput",
    "ReturnExpressionPacket",
    "ReturnInputFormPacket",
    "ReturnPacket",
    "ReturnReceiptFunction",
    "ReturnTextPacket",
    "Reverse",
    "ReverseApplied",
    "ReverseBiorthogonalSplineWavelet",
    "ReverseElement",
    "ReverseEquilibrium",
    "ReverseGraph",
    "ReverseSort",
    "ReverseSortBy",
    "ReverseUpEquilibrium",
    "RevolutionAxis",
    "RevolutionPlot3D",
    "RGBColor",
    "RiccatiSolve",
    "RiceDistribution",
    "RidgeFilter",
    "RiemannR",
    "RiemannSiegelTheta",
    "RiemannSiegelZ",
    "RiemannXi",
    "Riffle",
    "Right",
    "RightArrow",
    "RightArrowBar",
    "RightArrowLeftArrow",
    "RightComposition",
    "RightCosetRepresentative",
    "RightDownTeeVector",
    "RightDownVector",
    "RightDownVectorBar",
    "RightTee",
    "RightTeeArrow",
    "RightTeeVector",
    "RightTriangle",
    "RightTriangleBar",
    "RightTriangleEqual",
    "RightUpDownVector",
    "RightUpTeeVector",
    "RightUpVector",
    "RightUpVectorBar",
    "RightVector",
    "RightVectorBar",
    "RipleyK",
    "RipleyRassonRegion",
    "RiskAchievementImportance",
    "RiskReductionImportance",
    "RobustConvexOptimization",
    "RogersTanimotoDissimilarity",
    "RollPitchYawAngles",
    "RollPitchYawMatrix",
    "RomanNumeral",
    "Root",
    "RootApproximant",
    "RootIntervals",
    "RootLocusPlot",
    "RootMeanSquare",
    "RootOfUnityQ",
    "RootReduce",
    "Roots",
    "RootSum",
    "RootTree",
    "Rotate",
    "RotateLabel",
    "RotateLeft",
    "RotateRight",
    "RotationAction",
    "RotationBox",
    "RotationBoxOptions",
    "RotationMatrix",
    "RotationTransform",
    "Round",
    "RoundImplies",
    "RoundingRadius",
    "Row",
    "RowAlignments",
    "RowBackgrounds",
    "RowBox",
    "RowHeights",
    "RowLines",
    "RowMinHeight",
    "RowReduce",
    "RowsEqual",
    "RowSpacings",
    "RSolve",
    "RSolveValue",
    "RudinShapiro",
    "RudvalisGroupRu",
    "Rule",
    "RuleCondition",
    "RuleDelayed",
    "RuleForm",
    "RulePlot",
    "RulerUnits",
    "RulesTree",
    "Run",
    "RunProcess",
    "RunScheduledTask",
    "RunThrough",
    "RuntimeAttributes",
    "RuntimeOptions",
    "RussellRaoDissimilarity",
    "SameAs",
    "SameQ",
    "SameTest",
    "SameTestProperties",
    "SampledEntityClass",
    "SampleDepth",
    "SampledSoundFunction",
    "SampledSoundList",
    "SampleRate",
    "SamplingPeriod",
    "SARIMAProcess",
    "SARMAProcess",
    "SASTriangle",
    "SatelliteData",
    "SatisfiabilityCount",
    "SatisfiabilityInstances",
    "SatisfiableQ",
    "Saturday",
    "Save",
    "Saveable",
    "SaveAutoDelete",
    "SaveConnection",
    "SaveDefinitions",
    "SavitzkyGolayMatrix",
    "SawtoothWave",
    "Scale",
    "Scaled",
    "ScaleDivisions",
    "ScaledMousePosition",
    "ScaleOrigin",
    "ScalePadding",
    "ScaleRanges",
    "ScaleRangeStyle",
    "ScalingFunctions",
    "ScalingMatrix",
    "ScalingTransform",
    "Scan",
    "ScheduledTask",
    "ScheduledTaskActiveQ",
    "ScheduledTaskInformation",
    "ScheduledTaskInformationData",
    "ScheduledTaskObject",
    "ScheduledTasks",
    "SchurDecomposition",
    "ScientificForm",
    "ScientificNotationThreshold",
    "ScorerGi",
    "ScorerGiPrime",
    "ScorerHi",
    "ScorerHiPrime",
    "ScreenRectangle",
    "ScreenStyleEnvironment",
    "ScriptBaselineShifts",
    "ScriptForm",
    "ScriptLevel",
    "ScriptMinSize",
    "ScriptRules",
    "ScriptSizeMultipliers",
    "Scrollbars",
    "ScrollingOptions",
    "ScrollPosition",
    "SearchAdjustment",
    "SearchIndexObject",
    "SearchIndices",
    "SearchQueryString",
    "SearchResultObject",
    "Sec",
    "Sech",
    "SechDistribution",
    "SecondOrderConeOptimization",
    "SectionGrouping",
    "SectorChart",
    "SectorChart3D",
    "SectorOrigin",
    "SectorSpacing",
    "SecuredAuthenticationKey",
    "SecuredAuthenticationKeys",
    "SecurityCertificate",
    "SeedRandom",
    "Select",
    "Selectable",
    "SelectComponents",
    "SelectedCells",
    "SelectedNotebook",
    "SelectFirst",
    "Selection",
    "SelectionAnimate",
    "SelectionCell",
    "SelectionCellCreateCell",
    "SelectionCellDefaultStyle",
    "SelectionCellParentStyle",
    "SelectionCreateCell",
    "SelectionDebuggerTag",
    "SelectionEvaluate",
    "SelectionEvaluateCreateCell",
    "SelectionMove",
    "SelectionPlaceholder",
    "SelectWithContents",
    "SelfLoops",
    "SelfLoopStyle",
    "SemanticImport",
    "SemanticImportString",
    "SemanticInterpretation",
    "SemialgebraicComponentInstances",
    "SemidefiniteOptimization",
    "SendMail",
    "SendMessage",
    "Sequence",
    "SequenceAlignment",
    "SequenceAttentionLayer",
    "SequenceCases",
    "SequenceCount",
    "SequenceFold",
    "SequenceFoldList",
    "SequenceForm",
    "SequenceHold",
    "SequenceIndicesLayer",
    "SequenceLastLayer",
    "SequenceMostLayer",
    "SequencePosition",
    "SequencePredict",
    "SequencePredictorFunction",
    "SequenceReplace",
    "SequenceRestLayer",
    "SequenceReverseLayer",
    "SequenceSplit",
    "Series",
    "SeriesCoefficient",
    "SeriesData",
    "SeriesTermGoal",
    "ServiceConnect",
    "ServiceDisconnect",
    "ServiceExecute",
    "ServiceObject",
    "ServiceRequest",
    "ServiceResponse",
    "ServiceSubmit",
    "SessionSubmit",
    "SessionTime",
    "Set",
    "SetAccuracy",
    "SetAlphaChannel",
    "SetAttributes",
    "Setbacks",
    "SetCloudDirectory",
    "SetCookies",
    "SetDelayed",
    "SetDirectory",
    "SetEnvironment",
    "SetFileDate",
    "SetFileFormatProperties",
    "SetOptions",
    "SetOptionsPacket",
    "SetPermissions",
    "SetPrecision",
    "SetProperty",
    "SetSecuredAuthenticationKey",
    "SetSelectedNotebook",
    "SetSharedFunction",
    "SetSharedVariable",
    "SetStreamPosition",
    "SetSystemModel",
    "SetSystemOptions",
    "Setter",
    "SetterBar",
    "SetterBox",
    "SetterBoxOptions",
    "Setting",
    "SetUsers",
    "Shading",
    "Shallow",
    "ShannonWavelet",
    "ShapiroWilkTest",
    "Share",
    "SharingList",
    "Sharpen",
    "ShearingMatrix",
    "ShearingTransform",
    "ShellRegion",
    "ShenCastanMatrix",
    "ShiftedGompertzDistribution",
    "ShiftRegisterSequence",
    "Short",
    "ShortDownArrow",
    "Shortest",
    "ShortestMatch",
    "ShortestPathFunction",
    "ShortLeftArrow",
    "ShortRightArrow",
    "ShortTimeFourier",
    "ShortTimeFourierData",
    "ShortUpArrow",
    "Show",
    "ShowAutoConvert",
    "ShowAutoSpellCheck",
    "ShowAutoStyles",
    "ShowCellBracket",
    "ShowCellLabel",
    "ShowCellTags",
    "ShowClosedCellArea",
    "ShowCodeAssist",
    "ShowContents",
    "ShowControls",
    "ShowCursorTracker",
    "ShowGroupOpenCloseIcon",
    "ShowGroupOpener",
    "ShowInvisibleCharacters",
    "ShowPageBreaks",
    "ShowPredictiveInterface",
    "ShowSelection",
    "ShowShortBoxForm",
    "ShowSpecialCharacters",
    "ShowStringCharacters",
    "ShowSyntaxStyles",
    "ShrinkingDelay",
    "ShrinkWrapBoundingBox",
    "SiderealTime",
    "SiegelTheta",
    "SiegelTukeyTest",
    "SierpinskiCurve",
    "SierpinskiMesh",
    "Sign",
    "Signature",
    "SignedRankTest",
    "SignedRegionDistance",
    "SignificanceLevel",
    "SignPadding",
    "SignTest",
    "SimilarityRules",
    "SimpleGraph",
    "SimpleGraphQ",
    "SimplePolygonQ",
    "SimplePolyhedronQ",
    "Simplex",
    "Simplify",
    "Sin",
    "Sinc",
    "SinghMaddalaDistribution",
    "SingleEvaluation",
    "SingleLetterItalics",
    "SingleLetterStyle",
    "SingularValueDecomposition",
    "SingularValueList",
    "SingularValuePlot",
    "SingularValues",
    "Sinh",
    "SinhIntegral",
    "SinIntegral",
    "SixJSymbol",
    "Skeleton",
    "SkeletonTransform",
    "SkellamDistribution",
    "Skewness",
    "SkewNormalDistribution",
    "SkinStyle",
    "Skip",
    "SliceContourPlot3D",
    "SliceDensityPlot3D",
    "SliceDistribution",
    "SliceVectorPlot3D",
    "Slider",
    "Slider2D",
    "Slider2DBox",
    "Slider2DBoxOptions",
    "SliderBox",
    "SliderBoxOptions",
    "SlideShowVideo",
    "SlideView",
    "Slot",
    "SlotSequence",
    "Small",
    "SmallCircle",
    "Smaller",
    "SmithDecomposition",
    "SmithDelayCompensator",
    "SmithWatermanSimilarity",
    "SmoothDensityHistogram",
    "SmoothHistogram",
    "SmoothHistogram3D",
    "SmoothKernelDistribution",
    "SmoothPointDensity",
    "SnDispersion",
    "Snippet",
    "SnippetsVideo",
    "SnubPolyhedron",
    "SocialMediaData",
    "Socket",
    "SocketConnect",
    "SocketListen",
    "SocketListener",
    "SocketObject",
    "SocketOpen",
    "SocketReadMessage",
    "SocketReadyQ",
    "Sockets",
    "SocketWaitAll",
    "SocketWaitNext",
    "SoftmaxLayer",
    "SokalSneathDissimilarity",
    "SolarEclipse",
    "SolarSystemFeatureData",
    "SolarTime",
    "SolidAngle",
    "SolidBoundaryLoadValue",
    "SolidData",
    "SolidDisplacementCondition",
    "SolidFixedCondition",
    "SolidMechanicsPDEComponent",
    "SolidMechanicsStrain",
    "SolidMechanicsStress",
    "SolidRegionQ",
    "Solve",
    "SolveAlways",
    "SolveDelayed",
    "SolveValues",
    "Sort",
    "SortBy",
    "SortedBy",
    "SortedEntityClass",
    "Sound",
    "SoundAndGraphics",
    "SoundNote",
    "SoundVolume",
    "SourceLink",
    "SourcePDETerm",
    "Sow",
    "Space",
    "SpaceCurveData",
    "SpaceForm",
    "Spacer",
    "Spacings",
    "Span",
    "SpanAdjustments",
    "SpanCharacterRounding",
    "SpanFromAbove",
    "SpanFromBoth",
    "SpanFromLeft",
    "SpanLineThickness",
    "SpanMaxSize",
    "SpanMinSize",
    "SpanningCharacters",
    "SpanSymmetric",
    "SparseArray",
    "SparseArrayQ",
    "SpatialBinnedPointData",
    "SpatialBoundaryCorrection",
    "SpatialEstimate",
    "SpatialEstimatorFunction",
    "SpatialGraphDistribution",
    "SpatialJ",
    "SpatialMedian",
    "SpatialNoiseLevel",
    "SpatialObservationRegionQ",
    "SpatialPointData",
    "SpatialPointSelect",
    "SpatialRandomnessTest",
    "SpatialTransformationLayer",
    "SpatialTrendFunction",
    "Speak",
    "SpeakerMatchQ",
    "SpearmanRankTest",
    "SpearmanRho",
    "SpeciesData",
    "SpecificityGoal",
    "SpectralLineData",
    "Spectrogram",
    "SpectrogramArray",
    "Specularity",
    "SpeechCases",
    "SpeechInterpreter",
    "SpeechRecognize",
    "SpeechSynthesize",
    "SpellingCorrection",
    "SpellingCorrectionList",
    "SpellingDictionaries",
    "SpellingDictionariesPath",
    "SpellingOptions",
    "Sphere",
    "SphereBox",
    "SphereBoxOptions",
    "SpherePoints",
    "SphericalBesselJ",
    "SphericalBesselY",
    "SphericalHankelH1",
    "SphericalHankelH2",
    "SphericalHarmonicY",
    "SphericalPlot3D",
    "SphericalRegion",
    "SphericalShell",
    "SpheroidalEigenvalue",
    "SpheroidalJoiningFactor",
    "SpheroidalPS",
    "SpheroidalPSPrime",
    "SpheroidalQS",
    "SpheroidalQSPrime",
    "SpheroidalRadialFactor",
    "SpheroidalS1",
    "SpheroidalS1Prime",
    "SpheroidalS2",
    "SpheroidalS2Prime",
    "Splice",
    "SplicedDistribution",
    "SplineClosed",
    "SplineDegree",
    "SplineKnots",
    "SplineWeights",
    "Split",
    "SplitBy",
    "SpokenString",
    "SpotLight",
    "Sqrt",
    "SqrtBox",
    "SqrtBoxOptions",
    "Square",
    "SquaredEuclideanDistance",
    "SquareFreeQ",
    "SquareIntersection",
    "SquareMatrixQ",
    "SquareRepeatingElement",
    "SquaresR",
    "SquareSubset",
    "SquareSubsetEqual",
    "SquareSuperset",
    "SquareSupersetEqual",
    "SquareUnion",
    "SquareWave",
    "SSSTriangle",
    "StabilityMargins",
    "StabilityMarginsStyle",
    "StableDistribution",
    "Stack",
    "StackBegin",
    "StackComplete",
    "StackedDateListPlot",
    "StackedListPlot",
    "StackInhibit",
    "StadiumShape",
    "StandardAtmosphereData",
    "StandardDeviation",
    "StandardDeviationFilter",
    "StandardForm",
    "Standardize",
    "Standardized",
    "StandardOceanData",
    "StandbyDistribution",
    "Star",
    "StarClusterData",
    "StarData",
    "StarGraph",
    "StartAsynchronousTask",
    "StartExternalSession",
    "StartingStepSize",
    "StartOfLine",
    "StartOfString",
    "StartProcess",
    "StartScheduledTask",
    "StartupSound",
    "StartWebSession",
    "StateDimensions",
    "StateFeedbackGains",
    "StateOutputEstimator",
    "StateResponse",
    "StateSpaceModel",
    "StateSpaceRealization",
    "StateSpaceTransform",
    "StateTransformationLinearize",
    "StationaryDistribution",
    "StationaryWaveletPacketTransform",
    "StationaryWaveletTransform",
    "StatusArea",
    "StatusCentrality",
    "StepMonitor",
    "StereochemistryElements",
    "StieltjesGamma",
    "StippleShading",
    "StirlingS1",
    "StirlingS2",
    "StopAsynchronousTask",
    "StoppingPowerData",
    "StopScheduledTask",
    "StrataVariables",
    "StratonovichProcess",
    "StraussHardcorePointProcess",
    "StraussPointProcess",
    "StreamColorFunction",
    "StreamColorFunctionScaling",
    "StreamDensityPlot",
    "StreamMarkers",
    "StreamPlot",
    "StreamPlot3D",
    "StreamPoints",
    "StreamPosition",
    "Streams",
    "StreamScale",
    "StreamStyle",
    "StrictInequalities",
    "String",
    "StringBreak",
    "StringByteCount",
    "StringCases",
    "StringContainsQ",
    "StringCount",
    "StringDelete",
    "StringDrop",
    "StringEndsQ",
    "StringExpression",
    "StringExtract",
    "StringForm",
    "StringFormat",
    "StringFormatQ",
    "StringFreeQ",
    "StringInsert",
    "StringJoin",
    "StringLength",
    "StringMatchQ",
    "StringPadLeft",
    "StringPadRight",
    "StringPart",
    "StringPartition",
    "StringPosition",
    "StringQ",
    "StringRepeat",
    "StringReplace",
    "StringReplaceList",
    "StringReplacePart",
    "StringReverse",
    "StringRiffle",
    "StringRotateLeft",
    "StringRotateRight",
    "StringSkeleton",
    "StringSplit",
    "StringStartsQ",
    "StringTake",
    "StringTakeDrop",
    "StringTemplate",
    "StringToByteArray",
    "StringToStream",
    "StringTrim",
    "StripBoxes",
    "StripOnInput",
    "StripStyleOnPaste",
    "StripWrapperBoxes",
    "StrokeForm",
    "Struckthrough",
    "StructuralImportance",
    "StructuredArray",
    "StructuredArrayHeadQ",
    "StructuredSelection",
    "StruveH",
    "StruveL",
    "Stub",
    "StudentTDistribution",
    "Style",
    "StyleBox",
    "StyleBoxAutoDelete",
    "StyleData",
    "StyleDefinitions",
    "StyleForm",
    "StyleHints",
    "StyleKeyMapping",
    "StyleMenuListing",
    "StyleNameDialogSettings",
    "StyleNames",
    "StylePrint",
    "StyleSheetPath",
    "Subdivide",
    "Subfactorial",
    "Subgraph",
    "SubMinus",
    "SubPlus",
    "SubresultantPolynomialRemainders",
    "SubresultantPolynomials",
    "Subresultants",
    "Subscript",
    "SubscriptBox",
    "SubscriptBoxOptions",
    "Subscripted",
    "Subsequences",
    "Subset",
    "SubsetCases",
    "SubsetCount",
    "SubsetEqual",
    "SubsetMap",
    "SubsetPosition",
    "SubsetQ",
    "SubsetReplace",
    "Subsets",
    "SubStar",
    "SubstitutionSystem",
    "Subsuperscript",
    "SubsuperscriptBox",
    "SubsuperscriptBoxOptions",
    "SubtitleEncoding",
    "SubtitleTrackSelection",
    "Subtract",
    "SubtractFrom",
    "SubtractSides",
    "SubValues",
    "Succeeds",
    "SucceedsEqual",
    "SucceedsSlantEqual",
    "SucceedsTilde",
    "Success",
    "SuchThat",
    "Sum",
    "SumConvergence",
    "SummationLayer",
    "Sunday",
    "SunPosition",
    "Sunrise",
    "Sunset",
    "SuperDagger",
    "SuperMinus",
    "SupernovaData",
    "SuperPlus",
    "Superscript",
    "SuperscriptBox",
    "SuperscriptBoxOptions",
    "Superset",
    "SupersetEqual",
    "SuperStar",
    "Surd",
    "SurdForm",
    "SurfaceAppearance",
    "SurfaceArea",
    "SurfaceColor",
    "SurfaceData",
    "SurfaceGraphics",
    "SurvivalDistribution",
    "SurvivalFunction",
    "SurvivalModel",
    "SurvivalModelFit",
    "SuspendPacket",
    "SuzukiDistribution",
    "SuzukiGroupSuz",
    "SwatchLegend",
    "Switch",
    "Symbol",
    "SymbolName",
    "SymletWavelet",
    "Symmetric",
    "SymmetricDifference",
    "SymmetricGroup",
    "SymmetricKey",
    "SymmetricMatrixQ",
    "SymmetricPolynomial",
    "SymmetricReduction",
    "Symmetrize",
    "SymmetrizedArray",
    "SymmetrizedArrayRules",
    "SymmetrizedDependentComponents",
    "SymmetrizedIndependentComponents",
    "SymmetrizedReplacePart",
    "SynchronousInitialization",
    "SynchronousUpdating",
    "Synonyms",
    "Syntax",
    "SyntaxForm",
    "SyntaxInformation",
    "SyntaxLength",
    "SyntaxPacket",
    "SyntaxQ",
    "SynthesizeMissingValues",
    "SystemCredential",
    "SystemCredentialData",
    "SystemCredentialKey",
    "SystemCredentialKeys",
    "SystemCredentialStoreObject",
    "SystemDialogInput",
    "SystemException",
    "SystemGet",
    "SystemHelpPath",
    "SystemInformation",
    "SystemInformationData",
    "SystemInstall",
    "SystemModel",
    "SystemModeler",
    "SystemModelExamples",
    "SystemModelLinearize",
    "SystemModelMeasurements",
    "SystemModelParametricSimulate",
    "SystemModelPlot",
    "SystemModelProgressReporting",
    "SystemModelReliability",
    "SystemModels",
    "SystemModelSimulate",
    "SystemModelSimulateSensitivity",
    "SystemModelSimulationData",
    "SystemOpen",
    "SystemOptions",
    "SystemProcessData",
    "SystemProcesses",
    "SystemsConnectionsModel",
    "SystemsModelControllerData",
    "SystemsModelDelay",
    "SystemsModelDelayApproximate",
    "SystemsModelDelete",
    "SystemsModelDimensions",
    "SystemsModelExtract",
    "SystemsModelFeedbackConnect",
    "SystemsModelLabels",
    "SystemsModelLinearity",
    "SystemsModelMerge",
    "SystemsModelOrder",
    "SystemsModelParallelConnect",
    "SystemsModelSeriesConnect",
    "SystemsModelStateFeedbackConnect",
    "SystemsModelVectorRelativeOrders",
    "SystemStub",
    "SystemTest",
    "Tab",
    "TabFilling",
    "Table",
    "TableAlignments",
    "TableDepth",
    "TableDirections",
    "TableForm",
    "TableHeadings",
    "TableSpacing",
    "TableView",
    "TableViewBox",
    "TableViewBoxAlignment",
    "TableViewBoxBackground",
    "TableViewBoxHeaders",
    "TableViewBoxItemSize",
    "TableViewBoxItemStyle",
    "TableViewBoxOptions",
    "TabSpacings",
    "TabView",
    "TabViewBox",
    "TabViewBoxOptions",
    "TagBox",
    "TagBoxNote",
    "TagBoxOptions",
    "TaggingRules",
    "TagSet",
    "TagSetDelayed",
    "TagStyle",
    "TagUnset",
    "Take",
    "TakeDrop",
    "TakeLargest",
    "TakeLargestBy",
    "TakeList",
    "TakeSmallest",
    "TakeSmallestBy",
    "TakeWhile",
    "Tally",
    "Tan",
    "Tanh",
    "TargetDevice",
    "TargetFunctions",
    "TargetSystem",
    "TargetUnits",
    "TaskAbort",
    "TaskExecute",
    "TaskObject",
    "TaskRemove",
    "TaskResume",
    "Tasks",
    "TaskSuspend",
    "TaskWait",
    "TautologyQ",
    "TelegraphProcess",
    "TemplateApply",
    "TemplateArgBox",
    "TemplateBox",
    "TemplateBoxOptions",
    "TemplateEvaluate",
    "TemplateExpression",
    "TemplateIf",
    "TemplateObject",
    "TemplateSequence",
    "TemplateSlot",
    "TemplateSlotSequence",
    "TemplateUnevaluated",
    "TemplateVerbatim",
    "TemplateWith",
    "TemporalData",
    "TemporalRegularity",
    "Temporary",
    "TemporaryVariable",
    "TensorContract",
    "TensorDimensions",
    "TensorExpand",
    "TensorProduct",
    "TensorQ",
    "TensorRank",
    "TensorReduce",
    "TensorSymmetry",
    "TensorTranspose",
    "TensorWedge",
    "TerminatedEvaluation",
    "TernaryListPlot",
    "TernaryPlotCorners",
    "TestID",
    "TestReport",
    "TestReportObject",
    "TestResultObject",
    "Tetrahedron",
    "TetrahedronBox",
    "TetrahedronBoxOptions",
    "TeXForm",
    "TeXSave",
    "Text",
    "Text3DBox",
    "Text3DBoxOptions",
    "TextAlignment",
    "TextBand",
    "TextBoundingBox",
    "TextBox",
    "TextCases",
    "TextCell",
    "TextClipboardType",
    "TextContents",
    "TextData",
    "TextElement",
    "TextForm",
    "TextGrid",
    "TextJustification",
    "TextLine",
    "TextPacket",
    "TextParagraph",
    "TextPosition",
    "TextRecognize",
    "TextSearch",
    "TextSearchReport",
    "TextSentences",
    "TextString",
    "TextStructure",
    "TextStyle",
    "TextTranslation",
    "Texture",
    "TextureCoordinateFunction",
    "TextureCoordinateScaling",
    "TextWords",
    "Therefore",
    "ThermodynamicData",
    "ThermometerGauge",
    "Thick",
    "Thickness",
    "Thin",
    "Thinning",
    "ThisLink",
    "ThomasPointProcess",
    "ThompsonGroupTh",
    "Thread",
    "Threaded",
    "ThreadingLayer",
    "ThreeJSymbol",
    "Threshold",
    "Through",
    "Throw",
    "ThueMorse",
    "Thumbnail",
    "Thursday",
    "TickDirection",
    "TickLabelOrientation",
    "TickLabelPositioning",
    "TickLabels",
    "TickLengths",
    "TickPositions",
    "Ticks",
    "TicksStyle",
    "TideData",
    "Tilde",
    "TildeEqual",
    "TildeFullEqual",
    "TildeTilde",
    "TimeConstrained",
    "TimeConstraint",
    "TimeDirection",
    "TimeFormat",
    "TimeGoal",
    "TimelinePlot",
    "TimeObject",
    "TimeObjectQ",
    "TimeRemaining",
    "Times",
    "TimesBy",
    "TimeSeries",
    "TimeSeriesAggregate",
    "TimeSeriesForecast",
    "TimeSeriesInsert",
    "TimeSeriesInvertibility",
    "TimeSeriesMap",
    "TimeSeriesMapThread",
    "TimeSeriesModel",
    "TimeSeriesModelFit",
    "TimeSeriesResample",
    "TimeSeriesRescale",
    "TimeSeriesShift",
    "TimeSeriesThread",
    "TimeSeriesWindow",
    "TimeSystem",
    "TimeSystemConvert",
    "TimeUsed",
    "TimeValue",
    "TimeWarpingCorrespondence",
    "TimeWarpingDistance",
    "TimeZone",
    "TimeZoneConvert",
    "TimeZoneOffset",
    "Timing",
    "Tiny",
    "TitleGrouping",
    "TitsGroupT",
    "ToBoxes",
    "ToCharacterCode",
    "ToColor",
    "ToContinuousTimeModel",
    "ToDate",
    "Today",
    "ToDiscreteTimeModel",
    "ToEntity",
    "ToeplitzMatrix",
    "ToExpression",
    "ToFileName",
    "Together",
    "Toggle",
    "ToggleFalse",
    "Toggler",
    "TogglerBar",
    "TogglerBox",
    "TogglerBoxOptions",
    "ToHeldExpression",
    "ToInvertibleTimeSeries",
    "TokenWords",
    "Tolerance",
    "ToLowerCase",
    "Tomorrow",
    "ToNumberField",
    "TooBig",
    "Tooltip",
    "TooltipBox",
    "TooltipBoxOptions",
    "TooltipDelay",
    "TooltipStyle",
    "ToonShading",
    "Top",
    "TopHatTransform",
    "ToPolarCoordinates",
    "TopologicalSort",
    "ToRadicals",
    "ToRawPointer",
    "ToRules",
    "Torus",
    "TorusGraph",
    "ToSphericalCoordinates",
    "ToString",
    "Total",
    "TotalHeight",
    "TotalLayer",
    "TotalVariationFilter",
    "TotalWidth",
    "TouchPosition",
    "TouchscreenAutoZoom",
    "TouchscreenControlPlacement",
    "ToUpperCase",
    "TourVideo",
    "Tr",
    "Trace",
    "TraceAbove",
    "TraceAction",
    "TraceBackward",
    "TraceDepth",
    "TraceDialog",
    "TraceForward",
    "TraceInternal",
    "TraceLevel",
    "TraceOff",
    "TraceOn",
    "TraceOriginal",
    "TracePrint",
    "TraceScan",
    "TrackCellChangeTimes",
    "TrackedSymbols",
    "TrackingFunction",
    "TracyWidomDistribution",
    "TradingChart",
    "TraditionalForm",
    "TraditionalFunctionNotation",
    "TraditionalNotation",
    "TraditionalOrder",
    "TrainImageContentDetector",
    "TrainingProgressCheckpointing",
    "TrainingProgressFunction",
    "TrainingProgressMeasurements",
    "TrainingProgressReporting",
    "TrainingStoppingCriterion",
    "TrainingUpdateSchedule",
    "TrainTextContentDetector",
    "TransferFunctionCancel",
    "TransferFunctionExpand",
    "TransferFunctionFactor",
    "TransferFunctionModel",
    "TransferFunctionPoles",
    "TransferFunctionTransform",
    "TransferFunctionZeros",
    "TransformationClass",
    "TransformationFunction",
    "TransformationFunctions",
    "TransformationMatrix",
    "TransformedDistribution",
    "TransformedField",
    "TransformedProcess",
    "TransformedRegion",
    "TransitionDirection",
    "TransitionDuration",
    "TransitionEffect",
    "TransitiveClosureGraph",
    "TransitiveReductionGraph",
    "Translate",
    "TranslationOptions",
    "TranslationTransform",
    "Transliterate",
    "Transparent",
    "TransparentColor",
    "Transpose",
    "TransposeLayer",
    "TrapEnterKey",
    "TrapSelection",
    "TravelDirections",
    "TravelDirectionsData",
    "TravelDistance",
    "TravelDistanceList",
    "TravelMethod",
    "TravelTime",
    "Tree",
    "TreeCases",
    "TreeChildren",
    "TreeCount",
    "TreeData",
    "TreeDelete",
    "TreeDepth",
    "TreeElementCoordinates",
    "TreeElementLabel",
    "TreeElementLabelFunction",
    "TreeElementLabelStyle",
    "TreeElementShape",
    "TreeElementShapeFunction",
    "TreeElementSize",
    "TreeElementSizeFunction",
    "TreeElementStyle",
    "TreeElementStyleFunction",
    "TreeExpression",
    "TreeExtract",
    "TreeFold",
    "TreeForm",
    "TreeGraph",
    "TreeGraphQ",
    "TreeInsert",
    "TreeLayout",
    "TreeLeafCount",
    "TreeLeafQ",
    "TreeLeaves",
    "TreeLevel",
    "TreeMap",
    "TreeMapAt",
    "TreeOutline",
    "TreePlot",
    "TreePosition",
    "TreeQ",
    "TreeReplacePart",
    "TreeRules",
    "TreeScan",
    "TreeSelect",
    "TreeSize",
    "TreeTraversalOrder",
    "TrendStyle",
    "Triangle",
    "TriangleCenter",
    "TriangleConstruct",
    "TriangleMeasurement",
    "TriangleWave",
    "TriangularDistribution",
    "TriangulateMesh",
    "Trig",
    "TrigExpand",
    "TrigFactor",
    "TrigFactorList",
    "Trigger",
    "TrigReduce",
    "TrigToExp",
    "TrimmedMean",
    "TrimmedVariance",
    "TropicalStormData",
    "True",
    "TrueQ",
    "TruncatedDistribution",
    "TruncatedPolyhedron",
    "TsallisQExponentialDistribution",
    "TsallisQGaussianDistribution",
    "TTest",
    "Tube",
    "TubeBezierCurveBox",
    "TubeBezierCurveBoxOptions",
    "TubeBox",
    "TubeBoxOptions",
    "TubeBSplineCurveBox",
    "TubeBSplineCurveBoxOptions",
    "Tuesday",
    "TukeyLambdaDistribution",
    "TukeyWindow",
    "TunnelData",
    "Tuples",
    "TuranGraph",
    "TuringMachine",
    "TuttePolynomial",
    "TwoWayRule",
    "Typed",
    "TypeDeclaration",
    "TypeEvaluate",
    "TypeHint",
    "TypeOf",
    "TypeSpecifier",
    "UnateQ",
    "Uncompress",
    "UnconstrainedParameters",
    "Undefined",
    "UnderBar",
    "Underflow",
    "Underlined",
    "Underoverscript",
    "UnderoverscriptBox",
    "UnderoverscriptBoxOptions",
    "Underscript",
    "UnderscriptBox",
    "UnderscriptBoxOptions",
    "UnderseaFeatureData",
    "UndirectedEdge",
    "UndirectedGraph",
    "UndirectedGraphQ",
    "UndoOptions",
    "UndoTrackedVariables",
    "Unequal",
    "UnequalTo",
    "Unevaluated",
    "UniformDistribution",
    "UniformGraphDistribution",
    "UniformPolyhedron",
    "UniformSumDistribution",
    "Uninstall",
    "Union",
    "UnionedEntityClass",
    "UnionPlus",
    "Unique",
    "UniqueElements",
    "UnitaryMatrixQ",
    "UnitBox",
    "UnitConvert",
    "UnitDimensions",
    "Unitize",
    "UnitRootTest",
    "UnitSimplify",
    "UnitStep",
    "UnitSystem",
    "UnitTriangle",
    "UnitVector",
    "UnitVectorLayer",
    "UnityDimensions",
    "UniverseModelData",
    "UniversityData",
    "UnixTime",
    "UnlabeledTree",
    "UnmanageObject",
    "Unprotect",
    "UnregisterExternalEvaluator",
    "UnsameQ",
    "UnsavedVariables",
    "Unset",
    "UnsetShared",
    "Until",
    "UntrackedVariables",
    "Up",
    "UpArrow",
    "UpArrowBar",
    "UpArrowDownArrow",
    "Update",
    "UpdateDynamicObjects",
    "UpdateDynamicObjectsSynchronous",
    "UpdateInterval",
    "UpdatePacletSites",
    "UpdateSearchIndex",
    "UpDownArrow",
    "UpEquilibrium",
    "UpperCaseQ",
    "UpperLeftArrow",
    "UpperRightArrow",
    "UpperTriangularize",
    "UpperTriangularMatrix",
    "UpperTriangularMatrixQ",
    "Upsample",
    "UpSet",
    "UpSetDelayed",
    "UpTee",
    "UpTeeArrow",
    "UpTo",
    "UpValues",
    "URL",
    "URLBuild",
    "URLDecode",
    "URLDispatcher",
    "URLDownload",
    "URLDownloadSubmit",
    "URLEncode",
    "URLExecute",
    "URLExpand",
    "URLFetch",
    "URLFetchAsynchronous",
    "URLParse",
    "URLQueryDecode",
    "URLQueryEncode",
    "URLRead",
    "URLResponseTime",
    "URLSave",
    "URLSaveAsynchronous",
    "URLShorten",
    "URLSubmit",
    "UseEmbeddedLibrary",
    "UseGraphicsRange",
    "UserDefinedWavelet",
    "Using",
    "UsingFrontEnd",
    "UtilityFunction",
    "V2Get",
    "ValenceErrorHandling",
    "ValenceFilling",
    "ValidationLength",
    "ValidationSet",
    "ValueBox",
    "ValueBoxOptions",
    "ValueDimensions",
    "ValueForm",
    "ValuePreprocessingFunction",
    "ValueQ",
    "Values",
    "ValuesData",
    "VandermondeMatrix",
    "Variables",
    "Variance",
    "VarianceEquivalenceTest",
    "VarianceEstimatorFunction",
    "VarianceGammaDistribution",
    "VarianceGammaPointProcess",
    "VarianceTest",
    "VariogramFunction",
    "VariogramModel",
    "VectorAngle",
    "VectorAround",
    "VectorAspectRatio",
    "VectorColorFunction",
    "VectorColorFunctionScaling",
    "VectorDensityPlot",
    "VectorDisplacementPlot",
    "VectorDisplacementPlot3D",
    "VectorGlyphData",
    "VectorGreater",
    "VectorGreaterEqual",
    "VectorLess",
    "VectorLessEqual",
    "VectorMarkers",
    "VectorPlot",
    "VectorPlot3D",
    "VectorPoints",
    "VectorQ",
    "VectorRange",
    "Vectors",
    "VectorScale",
    "VectorScaling",
    "VectorSizes",
    "VectorStyle",
    "Vee",
    "Verbatim",
    "Verbose",
    "VerificationTest",
    "VerifyConvergence",
    "VerifyDerivedKey",
    "VerifyDigitalSignature",
    "VerifyFileSignature",
    "VerifyInterpretation",
    "VerifySecurityCertificates",
    "VerifySolutions",
    "VerifyTestAssumptions",
    "VersionedPreferences",
    "VertexAdd",
    "VertexCapacity",
    "VertexChromaticNumber",
    "VertexColors",
    "VertexComponent",
    "VertexConnectivity",
    "VertexContract",
    "VertexCoordinateRules",
    "VertexCoordinates",
    "VertexCorrelationSimilarity",
    "VertexCosineSimilarity",
    "VertexCount",
    "VertexCoverQ",
    "VertexDataCoordinates",
    "VertexDegree",
    "VertexDelete",
    "VertexDiceSimilarity",
    "VertexEccentricity",
    "VertexInComponent",
    "VertexInComponentGraph",
    "VertexInDegree",
    "VertexIndex",
    "VertexJaccardSimilarity",
    "VertexLabeling",
    "VertexLabels",
    "VertexLabelStyle",
    "VertexList",
    "VertexNormals",
    "VertexOutComponent",
    "VertexOutComponentGraph",
    "VertexOutDegree",
    "VertexQ",
    "VertexRenderingFunction",
    "VertexReplace",
    "VertexShape",
    "VertexShapeFunction",
    "VertexSize",
    "VertexStyle",
    "VertexTextureCoordinates",
    "VertexTransitiveGraphQ",
    "VertexWeight",
    "VertexWeightedGraphQ",
    "Vertical",
    "VerticalBar",
    "VerticalForm",
    "VerticalGauge",
    "VerticalSeparator",
    "VerticalSlider",
    "VerticalTilde",
    "Video",
    "VideoCapture",
    "VideoCombine",
    "VideoDelete",
    "VideoEncoding",
    "VideoExtractFrames",
    "VideoFrameList",
    "VideoFrameMap",
    "VideoGenerator",
    "VideoInsert",
    "VideoIntervals",
    "VideoJoin",
    "VideoMap",
    "VideoMapList",
    "VideoMapTimeSeries",
    "VideoPadding",
    "VideoPause",
    "VideoPlay",
    "VideoQ",
    "VideoRecord",
    "VideoReplace",
    "VideoScreenCapture",
    "VideoSplit",
    "VideoStop",
    "VideoStream",
    "VideoStreams",
    "VideoTimeStretch",
    "VideoTrackSelection",
    "VideoTranscode",
    "VideoTransparency",
    "VideoTrim",
    "ViewAngle",
    "ViewCenter",
    "ViewMatrix",
    "ViewPoint",
    "ViewPointSelectorSettings",
    "ViewPort",
    "ViewProjection",
    "ViewRange",
    "ViewVector",
    "ViewVertical",
    "VirtualGroupData",
    "Visible",
    "VisibleCell",
    "VoiceStyleData",
    "VoigtDistribution",
    "VolcanoData",
    "Volume",
    "VonMisesDistribution",
    "VoronoiMesh",
    "WaitAll",
    "WaitAsynchronousTask",
    "WaitNext",
    "WaitUntil",
    "WakebyDistribution",
    "WalleniusHypergeometricDistribution",
    "WaringYuleDistribution",
    "WarpingCorrespondence",
    "WarpingDistance",
    "WatershedComponents",
    "WatsonUSquareTest",
    "WattsStrogatzGraphDistribution",
    "WaveletBestBasis",
    "WaveletFilterCoefficients",
    "WaveletImagePlot",
    "WaveletListPlot",
    "WaveletMapIndexed",
    "WaveletMatrixPlot",
    "WaveletPhi",
    "WaveletPsi",
    "WaveletScale",
    "WaveletScalogram",
    "WaveletThreshold",
    "WavePDEComponent",
    "WeaklyConnectedComponents",
    "WeaklyConnectedGraphComponents",
    "WeaklyConnectedGraphQ",
    "WeakStationarity",
    "WeatherData",
    "WeatherForecastData",
    "WebAudioSearch",
    "WebColumn",
    "WebElementObject",
    "WeberE",
    "WebExecute",
    "WebImage",
    "WebImageSearch",
    "WebItem",
    "WebPageMetaInformation",
    "WebRow",
    "WebSearch",
    "WebSessionObject",
    "WebSessions",
    "WebWindowObject",
    "Wedge",
    "Wednesday",
    "WeibullDistribution",
    "WeierstrassE1",
    "WeierstrassE2",
    "WeierstrassE3",
    "WeierstrassEta1",
    "WeierstrassEta2",
    "WeierstrassEta3",
    "WeierstrassHalfPeriods",
    "WeierstrassHalfPeriodW1",
    "WeierstrassHalfPeriodW2",
    "WeierstrassHalfPeriodW3",
    "WeierstrassInvariantG2",
    "WeierstrassInvariantG3",
    "WeierstrassInvariants",
    "WeierstrassP",
    "WeierstrassPPrime",
    "WeierstrassSigma",
    "WeierstrassZeta",
    "WeightedAdjacencyGraph",
    "WeightedAdjacencyMatrix",
    "WeightedData",
    "WeightedGraphQ",
    "Weights",
    "WelchWindow",
    "WheelGraph",
    "WhenEvent",
    "Which",
    "While",
    "White",
    "WhiteNoiseProcess",
    "WhitePoint",
    "Whitespace",
    "WhitespaceCharacter",
    "WhittakerM",
    "WhittakerW",
    "WholeCellGroupOpener",
    "WienerFilter",
    "WienerProcess",
    "WignerD",
    "WignerSemicircleDistribution",
    "WikidataData",
    "WikidataSearch",
    "WikipediaData",
    "WikipediaSearch",
    "WilksW",
    "WilksWTest",
    "WindDirectionData",
    "WindingCount",
    "WindingPolygon",
    "WindowClickSelect",
    "WindowElements",
    "WindowFloating",
    "WindowFrame",
    "WindowFrameElements",
    "WindowMargins",
    "WindowMovable",
    "WindowOpacity",
    "WindowPersistentStyles",
    "WindowSelected",
    "WindowSize",
    "WindowStatusArea",
    "WindowTitle",
    "WindowToolbars",
    "WindowWidth",
    "WindSpeedData",
    "WindVectorData",
    "WinsorizedMean",
    "WinsorizedVariance",
    "WishartMatrixDistribution",
    "With",
    "WithCleanup",
    "WithLock",
    "WolframAlpha",
    "WolframAlphaDate",
    "WolframAlphaQuantity",
    "WolframAlphaResult",
    "WolframCloudSettings",
    "WolframLanguageData",
    "Word",
    "WordBoundary",
    "WordCharacter",
    "WordCloud",
    "WordCount",
    "WordCounts",
    "WordData",
    "WordDefinition",
    "WordFrequency",
    "WordFrequencyData",
    "WordList",
    "WordOrientation",
    "WordSearch",
    "WordSelectionFunction",
    "WordSeparators",
    "WordSpacings",
    "WordStem",
    "WordTranslation",
    "WorkingPrecision",
    "WrapAround",
    "Write",
    "WriteLine",
    "WriteString",
    "Wronskian",
    "XMLElement",
    "XMLObject",
    "XMLTemplate",
    "Xnor",
    "Xor",
    "XYZColor",
    "Yellow",
    "Yesterday",
    "YuleDissimilarity",
    "ZernikeR",
    "ZeroSymmetric",
    "ZeroTest",
    "ZeroWidthTimes",
    "Zeta",
    "ZetaZero",
    "ZIPCodeData",
    "ZipfDistribution",
    "ZoomCenter",
    "ZoomFactor",
    "ZTest",
    "ZTransform",
    "$Aborted",
    "$ActivationGroupID",
    "$ActivationKey",
    "$ActivationUserRegistered",
    "$AddOnsDirectory",
    "$AllowDataUpdates",
    "$AllowExternalChannelFunctions",
    "$AllowInternet",
    "$AssertFunction",
    "$Assumptions",
    "$AsynchronousTask",
    "$AudioDecoders",
    "$AudioEncoders",
    "$AudioInputDevices",
    "$AudioOutputDevices",
    "$BaseDirectory",
    "$BasePacletsDirectory",
    "$BatchInput",
    "$BatchOutput",
    "$BlockchainBase",
    "$BoxForms",
    "$ByteOrdering",
    "$CacheBaseDirectory",
    "$Canceled",
    "$ChannelBase",
    "$CharacterEncoding",
    "$CharacterEncodings",
    "$CloudAccountName",
    "$CloudBase",
    "$CloudConnected",
    "$CloudConnection",
    "$CloudCreditsAvailable",
    "$CloudEvaluation",
    "$CloudExpressionBase",
    "$CloudObjectNameFormat",
    "$CloudObjectURLType",
    "$CloudRootDirectory",
    "$CloudSymbolBase",
    "$CloudUserID",
    "$CloudUserUUID",
    "$CloudVersion",
    "$CloudVersionNumber",
    "$CloudWolframEngineVersionNumber",
    "$CommandLine",
    "$CompilationTarget",
    "$CompilerEnvironment",
    "$ConditionHold",
    "$ConfiguredKernels",
    "$Context",
    "$ContextAliases",
    "$ContextPath",
    "$ControlActiveSetting",
    "$Cookies",
    "$CookieStore",
    "$CreationDate",
    "$CryptographicEllipticCurveNames",
    "$CurrentLink",
    "$CurrentTask",
    "$CurrentWebSession",
    "$DataStructures",
    "$DateStringFormat",
    "$DefaultAudioInputDevice",
    "$DefaultAudioOutputDevice",
    "$DefaultFont",
    "$DefaultFrontEnd",
    "$DefaultImagingDevice",
    "$DefaultKernels",
    "$DefaultLocalBase",
    "$DefaultLocalKernel",
    "$DefaultMailbox",
    "$DefaultNetworkInterface",
    "$DefaultPath",
    "$DefaultProxyRules",
    "$DefaultRemoteBatchSubmissionEnvironment",
    "$DefaultRemoteKernel",
    "$DefaultSystemCredentialStore",
    "$Display",
    "$DisplayFunction",
    "$DistributedContexts",
    "$DynamicEvaluation",
    "$Echo",
    "$EmbedCodeEnvironments",
    "$EmbeddableServices",
    "$EntityStores",
    "$Epilog",
    "$EvaluationCloudBase",
    "$EvaluationCloudObject",
    "$EvaluationEnvironment",
    "$ExportFormats",
    "$ExternalIdentifierTypes",
    "$ExternalStorageBase",
    "$Failed",
    "$FinancialDataSource",
    "$FontFamilies",
    "$FormatType",
    "$FrontEnd",
    "$FrontEndSession",
    "$GeneratedAssetLocation",
    "$GeoEntityTypes",
    "$GeoLocation",
    "$GeoLocationCity",
    "$GeoLocationCountry",
    "$GeoLocationPrecision",
    "$GeoLocationSource",
    "$HistoryLength",
    "$HomeDirectory",
    "$HTMLExportRules",
    "$HTTPCookies",
    "$HTTPRequest",
    "$IgnoreEOF",
    "$ImageFormattingWidth",
    "$ImageResolution",
    "$ImagingDevice",
    "$ImagingDevices",
    "$ImportFormats",
    "$IncomingMailSettings",
    "$InitialDirectory",
    "$Initialization",
    "$InitializationContexts",
    "$Input",
    "$InputFileName",
    "$InputStreamMethods",
    "$Inspector",
    "$InstallationDate",
    "$InstallationDirectory",
    "$InterfaceEnvironment",
    "$InterpreterTypes",
    "$IterationLimit",
    "$KernelCount",
    "$KernelID",
    "$Language",
    "$LaunchDirectory",
    "$LibraryPath",
    "$LicenseExpirationDate",
    "$LicenseID",
    "$LicenseProcesses",
    "$LicenseServer",
    "$LicenseSubprocesses",
    "$LicenseType",
    "$Line",
    "$Linked",
    "$LinkSupported",
    "$LoadedFiles",
    "$LocalBase",
    "$LocalSymbolBase",
    "$MachineAddresses",
    "$MachineDomain",
    "$MachineDomains",
    "$MachineEpsilon",
    "$MachineID",
    "$MachineName",
    "$MachinePrecision",
    "$MachineType",
    "$MaxDisplayedChildren",
    "$MaxExtraPrecision",
    "$MaxLicenseProcesses",
    "$MaxLicenseSubprocesses",
    "$MaxMachineNumber",
    "$MaxNumber",
    "$MaxPiecewiseCases",
    "$MaxPrecision",
    "$MaxRootDegree",
    "$MessageGroups",
    "$MessageList",
    "$MessagePrePrint",
    "$Messages",
    "$MinMachineNumber",
    "$MinNumber",
    "$MinorReleaseNumber",
    "$MinPrecision",
    "$MobilePhone",
    "$ModuleNumber",
    "$NetworkConnected",
    "$NetworkInterfaces",
    "$NetworkLicense",
    "$NewMessage",
    "$NewSymbol",
    "$NotebookInlineStorageLimit",
    "$Notebooks",
    "$NoValue",
    "$NumberMarks",
    "$Off",
    "$OperatingSystem",
    "$Output",
    "$OutputForms",
    "$OutputSizeLimit",
    "$OutputStreamMethods",
    "$Packages",
    "$ParentLink",
    "$ParentProcessID",
    "$PasswordFile",
    "$PatchLevelID",
    "$Path",
    "$PathnameSeparator",
    "$PerformanceGoal",
    "$Permissions",
    "$PermissionsGroupBase",
    "$PersistenceBase",
    "$PersistencePath",
    "$PipeSupported",
    "$PlotTheme",
    "$Post",
    "$Pre",
    "$PreferencesDirectory",
    "$PreInitialization",
    "$PrePrint",
    "$PreRead",
    "$PrintForms",
    "$PrintLiteral",
    "$Printout3DPreviewer",
    "$ProcessID",
    "$ProcessorCount",
    "$ProcessorType",
    "$ProductInformation",
    "$ProgramName",
    "$ProgressReporting",
    "$PublisherID",
    "$RandomGeneratorState",
    "$RandomState",
    "$RecursionLimit",
    "$RegisteredDeviceClasses",
    "$RegisteredUserName",
    "$ReleaseNumber",
    "$RequesterAddress",
    "$RequesterCloudUserID",
    "$RequesterCloudUserUUID",
    "$RequesterWolframID",
    "$RequesterWolframUUID",
    "$ResourceSystemBase",
    "$ResourceSystemPath",
    "$RootDirectory",
    "$ScheduledTask",
    "$ScriptCommandLine",
    "$ScriptInputString",
    "$SecuredAuthenticationKeyTokens",
    "$ServiceCreditsAvailable",
    "$Services",
    "$SessionID",
    "$SetParentLink",
    "$SharedFunctions",
    "$SharedVariables",
    "$SoundDisplay",
    "$SoundDisplayFunction",
    "$SourceLink",
    "$SSHAuthentication",
    "$SubtitleDecoders",
    "$SubtitleEncoders",
    "$SummaryBoxDataSizeLimit",
    "$SuppressInputFormHeads",
    "$SynchronousEvaluation",
    "$SyntaxHandler",
    "$System",
    "$SystemCharacterEncoding",
    "$SystemCredentialStore",
    "$SystemID",
    "$SystemMemory",
    "$SystemShell",
    "$SystemTimeZone",
    "$SystemWordLength",
    "$TargetSystems",
    "$TemplatePath",
    "$TemporaryDirectory",
    "$TemporaryPrefix",
    "$TestFileName",
    "$TextStyle",
    "$TimedOut",
    "$TimeUnit",
    "$TimeZone",
    "$TimeZoneEntity",
    "$TopDirectory",
    "$TraceOff",
    "$TraceOn",
    "$TracePattern",
    "$TracePostAction",
    "$TracePreAction",
    "$UnitSystem",
    "$Urgent",
    "$UserAddOnsDirectory",
    "$UserAgentLanguages",
    "$UserAgentMachine",
    "$UserAgentName",
    "$UserAgentOperatingSystem",
    "$UserAgentString",
    "$UserAgentVersion",
    "$UserBaseDirectory",
    "$UserBasePacletsDirectory",
    "$UserDocumentsDirectory",
    "$Username",
    "$UserName",
    "$UserURLBase",
    "$Version",
    "$VersionNumber",
    "$VideoDecoders",
    "$VideoEncoders",
    "$VoiceStyles",
    "$WolframDocumentsDirectory",
    "$WolframID",
    "$WolframUUID"
  ];
  function t(n) {
    const r = n.regex, i = /([2-9]|[1-2]\d|[3][0-5])\^\^/, a = /(\w*\.\w+|\w+\.\w*|\w+)/, o = /(\d*\.\d+|\d+\.\d*|\d+)/, s = r.either(r.concat(i, a), o), l = /``[+-]?(\d*\.\d+|\d+\.\d*|\d+)/, u = /`([+-]?(\d*\.\d+|\d+\.\d*|\d+))?/, c = r.either(l, u), d = /\*\^[+-]?\d+/, h = {
      className: "number",
      relevance: 0,
      begin: r.concat(
        s,
        r.optional(c),
        r.optional(d)
      )
    }, m = /[a-zA-Z$][a-zA-Z0-9$]*/, v = new Set(e), b = { variants: [
      {
        className: "builtin-symbol",
        begin: m,
        // for performance out of fear of regex.either(...Mathematica.SYSTEM_SYMBOLS)
        "on:begin": (O, R) => {
          v.has(O[0]) || R.ignoreMatch();
        }
      },
      {
        className: "symbol",
        relevance: 0,
        begin: m
      }
    ] }, y = {
      className: "named-character",
      begin: /\\\[[$a-zA-Z][$a-zA-Z0-9]+\]/
    }, g = {
      className: "operator",
      relevance: 0,
      begin: /[+\-*/,;.:@~=><&|_`'^?!%]+/
    }, E = {
      className: "pattern",
      relevance: 0,
      begin: /([a-zA-Z$][a-zA-Z0-9$]*)?_+([a-zA-Z$][a-zA-Z0-9$]*)?/
    }, S = {
      className: "slot",
      relevance: 0,
      begin: /#[a-zA-Z$][a-zA-Z0-9$]*|#+[0-9]?/
    }, C = {
      className: "brace",
      relevance: 0,
      begin: /[[\](){}]/
    }, T = {
      className: "message-name",
      relevance: 0,
      begin: r.concat("::", m)
    };
    return {
      name: "Mathematica",
      aliases: [
        "mma",
        "wl"
      ],
      classNameAliases: {
        brace: "punctuation",
        pattern: "type",
        slot: "type",
        symbol: "variable",
        "named-character": "variable",
        "builtin-symbol": "built_in",
        "message-name": "string"
      },
      contains: [
        n.COMMENT(/\(\*/, /\*\)/, { contains: ["self"] }),
        E,
        S,
        T,
        b,
        y,
        n.QUOTE_STRING_MODE,
        h,
        g,
        C
      ]
    };
  }
  return mS = t, mS;
}
var hS, yI;
function NJ() {
  if (yI) return hS;
  yI = 1;
  function e(t) {
    const n = "('|\\.')+", r = {
      relevance: 0,
      contains: [{ begin: n }]
    };
    return {
      name: "Matlab",
      keywords: {
        keyword: "arguments break case catch classdef continue else elseif end enumeration events for function global if methods otherwise parfor persistent properties return spmd switch try while",
        built_in: "sin sind sinh asin asind asinh cos cosd cosh acos acosd acosh tan tand tanh atan atand atan2 atanh sec secd sech asec asecd asech csc cscd csch acsc acscd acsch cot cotd coth acot acotd acoth hypot exp expm1 log log1p log10 log2 pow2 realpow reallog realsqrt sqrt nthroot nextpow2 abs angle complex conj imag real unwrap isreal cplxpair fix floor ceil round mod rem sign airy besselj bessely besselh besseli besselk beta betainc betaln ellipj ellipke erf erfc erfcx erfinv expint gamma gammainc gammaln psi legendre cross dot factor isprime primes gcd lcm rat rats perms nchoosek factorial cart2sph cart2pol pol2cart sph2cart hsv2rgb rgb2hsv zeros ones eye repmat rand randn linspace logspace freqspace meshgrid accumarray size length ndims numel disp isempty isequal isequalwithequalnans cat reshape diag blkdiag tril triu fliplr flipud flipdim rot90 find sub2ind ind2sub bsxfun ndgrid permute ipermute shiftdim circshift squeeze isscalar isvector ans eps realmax realmin pi i|0 inf nan isnan isinf isfinite j|0 why compan gallery hadamard hankel hilb invhilb magic pascal rosser toeplitz vander wilkinson max min nanmax nanmin mean nanmean type table readtable writetable sortrows sort figure plot plot3 scatter scatter3 cellfun legend intersect ismember procrustes hold num2cell "
      },
      illegal: '(//|"|#|/\\*|\\s+/\\w+)',
      contains: [
        {
          className: "function",
          beginKeywords: "function",
          end: "$",
          contains: [
            t.UNDERSCORE_TITLE_MODE,
            {
              className: "params",
              variants: [
                {
                  begin: "\\(",
                  end: "\\)"
                },
                {
                  begin: "\\[",
                  end: "\\]"
                }
              ]
            }
          ]
        },
        {
          className: "built_in",
          begin: /true|false/,
          relevance: 0,
          starts: r
        },
        {
          begin: "[a-zA-Z][a-zA-Z_0-9]*" + n,
          relevance: 0
        },
        {
          className: "number",
          begin: t.C_NUMBER_RE,
          relevance: 0,
          starts: r
        },
        {
          className: "string",
          begin: "'",
          end: "'",
          contains: [{ begin: "''" }]
        },
        {
          begin: /\]|\}|\)/,
          relevance: 0,
          starts: r
        },
        {
          className: "string",
          begin: '"',
          end: '"',
          contains: [{ begin: '""' }],
          starts: r
        },
        t.COMMENT("^\\s*%\\{\\s*$", "^\\s*%\\}\\s*$"),
        t.COMMENT("%", "$")
      ]
    };
  }
  return hS = e, hS;
}
var gS, TI;
function DJ() {
  if (TI) return gS;
  TI = 1;
  function e(t) {
    return {
      name: "Maxima",
      keywords: {
        $pattern: "[A-Za-z_%][0-9A-Za-z_%]*",
        keyword: "if then else elseif for thru do while unless step in and or not",
        literal: "true false unknown inf minf ind und %e %i %pi %phi %gamma",
        built_in: " abasep abs absint absolute_real_time acos acosh acot acoth acsc acsch activate addcol add_edge add_edges addmatrices addrow add_vertex add_vertices adjacency_matrix adjoin adjoint af agd airy airy_ai airy_bi airy_dai airy_dbi algsys alg_type alias allroots alphacharp alphanumericp amortization %and annuity_fv annuity_pv antid antidiff AntiDifference append appendfile apply apply1 apply2 applyb1 apropos args arit_amortization arithmetic arithsum array arrayapply arrayinfo arraymake arraysetapply ascii asec asech asin asinh askinteger asksign assoc assoc_legendre_p assoc_legendre_q assume assume_external_byte_order asympa at atan atan2 atanh atensimp atom atvalue augcoefmatrix augmented_lagrangian_method av average_degree backtrace bars barsplot barsplot_description base64 base64_decode bashindices batch batchload bc2 bdvac belln benefit_cost bern bernpoly bernstein_approx bernstein_expand bernstein_poly bessel bessel_i bessel_j bessel_k bessel_simplify bessel_y beta beta_incomplete beta_incomplete_generalized beta_incomplete_regularized bezout bfallroots bffac bf_find_root bf_fmin_cobyla bfhzeta bfloat bfloatp bfpsi bfpsi0 bfzeta biconnected_components bimetric binomial bipartition block blockmatrixp bode_gain bode_phase bothcoef box boxplot boxplot_description break bug_report build_info|10 buildq build_sample burn cabs canform canten cardinality carg cartan cartesian_product catch cauchy_matrix cbffac cdf_bernoulli cdf_beta cdf_binomial cdf_cauchy cdf_chi2 cdf_continuous_uniform cdf_discrete_uniform cdf_exp cdf_f cdf_gamma cdf_general_finite_discrete cdf_geometric cdf_gumbel cdf_hypergeometric cdf_laplace cdf_logistic cdf_lognormal cdf_negative_binomial cdf_noncentral_chi2 cdf_noncentral_student_t cdf_normal cdf_pareto cdf_poisson cdf_rank_sum cdf_rayleigh cdf_signed_rank cdf_student_t cdf_weibull cdisplay ceiling central_moment cequal cequalignore cf cfdisrep cfexpand cgeodesic cgreaterp cgreaterpignore changename changevar chaosgame charat charfun charfun2 charlist charp charpoly chdir chebyshev_t chebyshev_u checkdiv check_overlaps chinese cholesky christof chromatic_index chromatic_number cint circulant_graph clear_edge_weight clear_rules clear_vertex_label clebsch_gordan clebsch_graph clessp clesspignore close closefile cmetric coeff coefmatrix cograd col collapse collectterms columnop columnspace columnswap columnvector combination combine comp2pui compare compfile compile compile_file complement_graph complete_bipartite_graph complete_graph complex_number_p components compose_functions concan concat conjugate conmetderiv connected_components connect_vertices cons constant constantp constituent constvalue cont2part content continuous_freq contortion contour_plot contract contract_edge contragrad contrib_ode convert coord copy copy_file copy_graph copylist copymatrix cor cos cosh cot coth cov cov1 covdiff covect covers crc24sum create_graph create_list csc csch csetup cspline ctaylor ct_coordsys ctransform ctranspose cube_graph cuboctahedron_graph cunlisp cv cycle_digraph cycle_graph cylindrical days360 dblint deactivate declare declare_constvalue declare_dimensions declare_fundamental_dimensions declare_fundamental_units declare_qty declare_translated declare_unit_conversion declare_units declare_weights decsym defcon define define_alt_display define_variable defint defmatch defrule defstruct deftaylor degree_sequence del delete deleten delta demo demoivre denom depends derivdegree derivlist describe desolve determinant dfloat dgauss_a dgauss_b dgeev dgemm dgeqrf dgesv dgesvd diag diagmatrix diag_matrix diagmatrixp diameter diff digitcharp dimacs_export dimacs_import dimension dimensionless dimensions dimensions_as_list direct directory discrete_freq disjoin disjointp disolate disp dispcon dispform dispfun dispJordan display disprule dispterms distrib divide divisors divsum dkummer_m dkummer_u dlange dodecahedron_graph dotproduct dotsimp dpart draw draw2d draw3d drawdf draw_file draw_graph dscalar echelon edge_coloring edge_connectivity edges eigens_by_jacobi eigenvalues eigenvectors eighth einstein eivals eivects elapsed_real_time elapsed_run_time ele2comp ele2polynome ele2pui elem elementp elevation_grid elim elim_allbut eliminate eliminate_using ellipse elliptic_e elliptic_ec elliptic_eu elliptic_f elliptic_kc elliptic_pi ematrix empty_graph emptyp endcons entermatrix entertensor entier equal equalp equiv_classes erf erfc erf_generalized erfi errcatch error errormsg errors euler ev eval_string evenp every evolution evolution2d evundiff example exp expand expandwrt expandwrt_factored expint expintegral_chi expintegral_ci expintegral_e expintegral_e1 expintegral_ei expintegral_e_simplify expintegral_li expintegral_shi expintegral_si explicit explose exponentialize express expt exsec extdiff extract_linear_equations extremal_subset ezgcd %f f90 facsum factcomb factor factorfacsum factorial factorout factorsum facts fast_central_elements fast_linsolve fasttimes featurep fernfale fft fib fibtophi fifth filename_merge file_search file_type fillarray findde find_root find_root_abs find_root_error find_root_rel first fix flatten flength float floatnump floor flower_snark flush flush1deriv flushd flushnd flush_output fmin_cobyla forget fortran fourcos fourexpand fourier fourier_elim fourint fourintcos fourintsin foursimp foursin fourth fposition frame_bracket freeof freshline fresnel_c fresnel_s from_adjacency_matrix frucht_graph full_listify fullmap fullmapl fullratsimp fullratsubst fullsetify funcsolve fundamental_dimensions fundamental_units fundef funmake funp fv g0 g1 gamma gamma_greek gamma_incomplete gamma_incomplete_generalized gamma_incomplete_regularized gauss gauss_a gauss_b gaussprob gcd gcdex gcdivide gcfac gcfactor gd generalized_lambert_w genfact gen_laguerre genmatrix gensym geo_amortization geo_annuity_fv geo_annuity_pv geomap geometric geometric_mean geosum get getcurrentdirectory get_edge_weight getenv get_lu_factors get_output_stream_string get_pixel get_plot_option get_tex_environment get_tex_environment_default get_vertex_label gfactor gfactorsum ggf girth global_variances gn gnuplot_close gnuplot_replot gnuplot_reset gnuplot_restart gnuplot_start go Gosper GosperSum gr2d gr3d gradef gramschmidt graph6_decode graph6_encode graph6_export graph6_import graph_center graph_charpoly graph_eigenvalues graph_flow graph_order graph_periphery graph_product graph_size graph_union great_rhombicosidodecahedron_graph great_rhombicuboctahedron_graph grid_graph grind grobner_basis grotzch_graph hamilton_cycle hamilton_path hankel hankel_1 hankel_2 harmonic harmonic_mean hav heawood_graph hermite hessian hgfred hilbertmap hilbert_matrix hipow histogram histogram_description hodge horner hypergeometric i0 i1 %ibes ic1 ic2 ic_convert ichr1 ichr2 icosahedron_graph icosidodecahedron_graph icurvature ident identfor identity idiff idim idummy ieqn %if ifactors iframes ifs igcdex igeodesic_coords ilt image imagpart imetric implicit implicit_derivative implicit_plot indexed_tensor indices induced_subgraph inferencep inference_result infix info_display init_atensor init_ctensor in_neighbors innerproduct inpart inprod inrt integerp integer_partitions integrate intersect intersection intervalp intopois intosum invariant1 invariant2 inverse_fft inverse_jacobi_cd inverse_jacobi_cn inverse_jacobi_cs inverse_jacobi_dc inverse_jacobi_dn inverse_jacobi_ds inverse_jacobi_nc inverse_jacobi_nd inverse_jacobi_ns inverse_jacobi_sc inverse_jacobi_sd inverse_jacobi_sn invert invert_by_adjoint invert_by_lu inv_mod irr is is_biconnected is_bipartite is_connected is_digraph is_edge_in_graph is_graph is_graph_or_digraph ishow is_isomorphic isolate isomorphism is_planar isqrt isreal_p is_sconnected is_tree is_vertex_in_graph items_inference %j j0 j1 jacobi jacobian jacobi_cd jacobi_cn jacobi_cs jacobi_dc jacobi_dn jacobi_ds jacobi_nc jacobi_nd jacobi_ns jacobi_p jacobi_sc jacobi_sd jacobi_sn JF jn join jordan julia julia_set julia_sin %k kdels kdelta kill killcontext kostka kron_delta kronecker_product kummer_m kummer_u kurtosis kurtosis_bernoulli kurtosis_beta kurtosis_binomial kurtosis_chi2 kurtosis_continuous_uniform kurtosis_discrete_uniform kurtosis_exp kurtosis_f kurtosis_gamma kurtosis_general_finite_discrete kurtosis_geometric kurtosis_gumbel kurtosis_hypergeometric kurtosis_laplace kurtosis_logistic kurtosis_lognormal kurtosis_negative_binomial kurtosis_noncentral_chi2 kurtosis_noncentral_student_t kurtosis_normal kurtosis_pareto kurtosis_poisson kurtosis_rayleigh kurtosis_student_t kurtosis_weibull label labels lagrange laguerre lambda lambert_w laplace laplacian_matrix last lbfgs lc2kdt lcharp lc_l lcm lc_u ldefint ldisp ldisplay legendre_p legendre_q leinstein length let letrules letsimp levi_civita lfreeof lgtreillis lhs li liediff limit Lindstedt linear linearinterpol linear_program linear_regression line_graph linsolve listarray list_correlations listify list_matrix_entries list_nc_monomials listoftens listofvars listp lmax lmin load loadfile local locate_matrix_entry log logcontract log_gamma lopow lorentz_gauge lowercasep lpart lratsubst lreduce lriemann lsquares_estimates lsquares_estimates_approximate lsquares_estimates_exact lsquares_mse lsquares_residual_mse lsquares_residuals lsum ltreillis lu_backsub lucas lu_factor %m macroexpand macroexpand1 make_array makebox makefact makegamma make_graph make_level_picture makelist makeOrders make_poly_continent make_poly_country make_polygon make_random_state make_rgb_picture makeset make_string_input_stream make_string_output_stream make_transform mandelbrot mandelbrot_set map mapatom maplist matchdeclare matchfix mat_cond mat_fullunblocker mat_function mathml_display mat_norm matrix matrixmap matrixp matrix_size mattrace mat_trace mat_unblocker max max_clique max_degree max_flow maximize_lp max_independent_set max_matching maybe md5sum mean mean_bernoulli mean_beta mean_binomial mean_chi2 mean_continuous_uniform mean_deviation mean_discrete_uniform mean_exp mean_f mean_gamma mean_general_finite_discrete mean_geometric mean_gumbel mean_hypergeometric mean_laplace mean_logistic mean_lognormal mean_negative_binomial mean_noncentral_chi2 mean_noncentral_student_t mean_normal mean_pareto mean_poisson mean_rayleigh mean_student_t mean_weibull median median_deviation member mesh metricexpandall mgf1_sha1 min min_degree min_edge_cut minfactorial minimalPoly minimize_lp minimum_spanning_tree minor minpack_lsquares minpack_solve min_vertex_cover min_vertex_cut mkdir mnewton mod mode_declare mode_identity ModeMatrix moebius mon2schur mono monomial_dimensions multibernstein_poly multi_display_for_texinfo multi_elem multinomial multinomial_coeff multi_orbit multiplot_mode multi_pui multsym multthru mycielski_graph nary natural_unit nc_degree ncexpt ncharpoly negative_picture neighbors new newcontext newdet new_graph newline newton new_variable next_prime nicedummies niceindices ninth nofix nonarray noncentral_moment nonmetricity nonnegintegerp nonscalarp nonzeroandfreeof notequal nounify nptetrad npv nroots nterms ntermst nthroot nullity nullspace num numbered_boundaries numberp number_to_octets num_distinct_partitions numerval numfactor num_partitions nusum nzeta nzetai nzetar octets_to_number octets_to_oid odd_girth oddp ode2 ode_check odelin oid_to_octets op opena opena_binary openr openr_binary openw openw_binary operatorp opsubst optimize %or orbit orbits ordergreat ordergreatp orderless orderlessp orthogonal_complement orthopoly_recur orthopoly_weight outermap out_neighbors outofpois pade parabolic_cylinder_d parametric parametric_surface parg parGosper parse_string parse_timedate part part2cont partfrac partition partition_set partpol path_digraph path_graph pathname_directory pathname_name pathname_type pdf_bernoulli pdf_beta pdf_binomial pdf_cauchy pdf_chi2 pdf_continuous_uniform pdf_discrete_uniform pdf_exp pdf_f pdf_gamma pdf_general_finite_discrete pdf_geometric pdf_gumbel pdf_hypergeometric pdf_laplace pdf_logistic pdf_lognormal pdf_negative_binomial pdf_noncentral_chi2 pdf_noncentral_student_t pdf_normal pdf_pareto pdf_poisson pdf_rank_sum pdf_rayleigh pdf_signed_rank pdf_student_t pdf_weibull pearson_skewness permanent permut permutation permutations petersen_graph petrov pickapart picture_equalp picturep piechart piechart_description planar_embedding playback plog plot2d plot3d plotdf ploteq plsquares pochhammer points poisdiff poisexpt poisint poismap poisplus poissimp poissubst poistimes poistrim polar polarform polartorect polar_to_xy poly_add poly_buchberger poly_buchberger_criterion poly_colon_ideal poly_content polydecomp poly_depends_p poly_elimination_ideal poly_exact_divide poly_expand poly_expt poly_gcd polygon poly_grobner poly_grobner_equal poly_grobner_member poly_grobner_subsetp poly_ideal_intersection poly_ideal_polysaturation poly_ideal_polysaturation1 poly_ideal_saturation poly_ideal_saturation1 poly_lcm poly_minimization polymod poly_multiply polynome2ele polynomialp poly_normal_form poly_normalize poly_normalize_list poly_polysaturation_extension poly_primitive_part poly_pseudo_divide poly_reduced_grobner poly_reduction poly_saturation_extension poly_s_polynomial poly_subtract polytocompanion pop postfix potential power_mod powerseries powerset prefix prev_prime primep primes principal_components print printf printfile print_graph printpois printprops prodrac product properties propvars psi psubst ptriangularize pui pui2comp pui2ele pui2polynome pui_direct puireduc push put pv qput qrange qty quad_control quad_qag quad_qagi quad_qagp quad_qags quad_qawc quad_qawf quad_qawo quad_qaws quadrilateral quantile quantile_bernoulli quantile_beta quantile_binomial quantile_cauchy quantile_chi2 quantile_continuous_uniform quantile_discrete_uniform quantile_exp quantile_f quantile_gamma quantile_general_finite_discrete quantile_geometric quantile_gumbel quantile_hypergeometric quantile_laplace quantile_logistic quantile_lognormal quantile_negative_binomial quantile_noncentral_chi2 quantile_noncentral_student_t quantile_normal quantile_pareto quantile_poisson quantile_rayleigh quantile_student_t quantile_weibull quartile_skewness quit qunit quotient racah_v racah_w radcan radius random random_bernoulli random_beta random_binomial random_bipartite_graph random_cauchy random_chi2 random_continuous_uniform random_digraph random_discrete_uniform random_exp random_f random_gamma random_general_finite_discrete random_geometric random_graph random_graph1 random_gumbel random_hypergeometric random_laplace random_logistic random_lognormal random_negative_binomial random_network random_noncentral_chi2 random_noncentral_student_t random_normal random_pareto random_permutation random_poisson random_rayleigh random_regular_graph random_student_t random_tournament random_tree random_weibull range rank rat ratcoef ratdenom ratdiff ratdisrep ratexpand ratinterpol rational rationalize ratnumer ratnump ratp ratsimp ratsubst ratvars ratweight read read_array read_binary_array read_binary_list read_binary_matrix readbyte readchar read_hashed_array readline read_list read_matrix read_nested_list readonly read_xpm real_imagpart_to_conjugate realpart realroots rearray rectangle rectform rectform_log_if_constant recttopolar rediff reduce_consts reduce_order region region_boundaries region_boundaries_plus rem remainder remarray rembox remcomps remcon remcoord remfun remfunction remlet remove remove_constvalue remove_dimensions remove_edge remove_fundamental_dimensions remove_fundamental_units remove_plot_option remove_vertex rempart remrule remsym remvalue rename rename_file reset reset_displays residue resolvante resolvante_alternee1 resolvante_bipartite resolvante_diedrale resolvante_klein resolvante_klein3 resolvante_produit_sym resolvante_unitaire resolvante_vierer rest resultant return reveal reverse revert revert2 rgb2level rhs ricci riemann rinvariant risch rk rmdir rncombine romberg room rootscontract round row rowop rowswap rreduce run_testsuite %s save saving scalarp scaled_bessel_i scaled_bessel_i0 scaled_bessel_i1 scalefactors scanmap scatterplot scatterplot_description scene schur2comp sconcat scopy scsimp scurvature sdowncase sec sech second sequal sequalignore set_alt_display setdifference set_draw_defaults set_edge_weight setelmx setequalp setify setp set_partitions set_plot_option set_prompt set_random_state set_tex_environment set_tex_environment_default setunits setup_autoload set_up_dot_simplifications set_vertex_label seventh sexplode sf sha1sum sha256sum shortest_path shortest_weighted_path show showcomps showratvars sierpinskiale sierpinskimap sign signum similaritytransform simp_inequality simplify_sum simplode simpmetderiv simtran sin sinh sinsert sinvertcase sixth skewness skewness_bernoulli skewness_beta skewness_binomial skewness_chi2 skewness_continuous_uniform skewness_discrete_uniform skewness_exp skewness_f skewness_gamma skewness_general_finite_discrete skewness_geometric skewness_gumbel skewness_hypergeometric skewness_laplace skewness_logistic skewness_lognormal skewness_negative_binomial skewness_noncentral_chi2 skewness_noncentral_student_t skewness_normal skewness_pareto skewness_poisson skewness_rayleigh skewness_student_t skewness_weibull slength smake small_rhombicosidodecahedron_graph small_rhombicuboctahedron_graph smax smin smismatch snowmap snub_cube_graph snub_dodecahedron_graph solve solve_rec solve_rec_rat some somrac sort sparse6_decode sparse6_encode sparse6_export sparse6_import specint spherical spherical_bessel_j spherical_bessel_y spherical_hankel1 spherical_hankel2 spherical_harmonic spherical_to_xyz splice split sposition sprint sqfr sqrt sqrtdenest sremove sremovefirst sreverse ssearch ssort sstatus ssubst ssubstfirst staircase standardize standardize_inverse_trig starplot starplot_description status std std1 std_bernoulli std_beta std_binomial std_chi2 std_continuous_uniform std_discrete_uniform std_exp std_f std_gamma std_general_finite_discrete std_geometric std_gumbel std_hypergeometric std_laplace std_logistic std_lognormal std_negative_binomial std_noncentral_chi2 std_noncentral_student_t std_normal std_pareto std_poisson std_rayleigh std_student_t std_weibull stemplot stirling stirling1 stirling2 strim striml strimr string stringout stringp strong_components struve_h struve_l sublis sublist sublist_indices submatrix subsample subset subsetp subst substinpart subst_parallel substpart substring subvar subvarp sum sumcontract summand_to_rec supcase supcontext symbolp symmdifference symmetricp system take_channel take_inference tan tanh taylor taylorinfo taylorp taylor_simplifier taytorat tcl_output tcontract tellrat tellsimp tellsimpafter tentex tenth test_mean test_means_difference test_normality test_proportion test_proportions_difference test_rank_sum test_sign test_signed_rank test_variance test_variance_ratio tex tex1 tex_display texput %th third throw time timedate timer timer_info tldefint tlimit todd_coxeter toeplitz tokens to_lisp topological_sort to_poly to_poly_solve totaldisrep totalfourier totient tpartpol trace tracematrix trace_options transform_sample translate translate_file transpose treefale tree_reduce treillis treinat triangle triangularize trigexpand trigrat trigreduce trigsimp trunc truncate truncated_cube_graph truncated_dodecahedron_graph truncated_icosahedron_graph truncated_tetrahedron_graph tr_warnings_get tube tutte_graph ueivects uforget ultraspherical underlying_graph undiff union unique uniteigenvectors unitp units unit_step unitvector unorder unsum untellrat untimer untrace uppercasep uricci uriemann uvect vandermonde_matrix var var1 var_bernoulli var_beta var_binomial var_chi2 var_continuous_uniform var_discrete_uniform var_exp var_f var_gamma var_general_finite_discrete var_geometric var_gumbel var_hypergeometric var_laplace var_logistic var_lognormal var_negative_binomial var_noncentral_chi2 var_noncentral_student_t var_normal var_pareto var_poisson var_rayleigh var_student_t var_weibull vector vectorpotential vectorsimp verbify vers vertex_coloring vertex_connectivity vertex_degree vertex_distance vertex_eccentricity vertex_in_degree vertex_out_degree vertices vertices_to_cycle vertices_to_path %w weyl wheel_graph wiener_index wigner_3j wigner_6j wigner_9j with_stdout write_binary_data writebyte write_data writefile wronskian xreduce xthru %y Zeilberger zeroequiv zerofor zeromatrix zeromatrixp zeta zgeev zheev zlange zn_add_table zn_carmichael_lambda zn_characteristic_factors zn_determinant zn_factor_generators zn_invert_by_lu zn_log zn_mult_table absboxchar activecontexts adapt_depth additive adim aform algebraic algepsilon algexact aliases allbut all_dotsimp_denoms allocation allsym alphabetic animation antisymmetric arrays askexp assume_pos assume_pos_pred assumescalar asymbol atomgrad atrig1 axes axis_3d axis_bottom axis_left axis_right axis_top azimuth background background_color backsubst berlefact bernstein_explicit besselexpand beta_args_sum_to_integer beta_expand bftorat bftrunc bindtest border boundaries_array box boxchar breakup %c capping cauchysum cbrange cbtics center cflength cframe_flag cnonmet_flag color color_bar color_bar_tics colorbox columns commutative complex cone context contexts contour contour_levels cosnpiflag ctaypov ctaypt ctayswitch ctayvar ct_coords ctorsion_flag ctrgsimp cube current_let_rule_package cylinder data_file_name debugmode decreasing default_let_rule_package delay dependencies derivabbrev derivsubst detout diagmetric diff dim dimensions dispflag display2d|10 display_format_internal distribute_over doallmxops domain domxexpt domxmxops domxnctimes dontfactor doscmxops doscmxplus dot0nscsimp dot0simp dot1simp dotassoc dotconstrules dotdistrib dotexptsimp dotident dotscrules draw_graph_program draw_realpart edge_color edge_coloring edge_partition edge_type edge_width %edispflag elevation %emode endphi endtheta engineering_format_floats enhanced3d %enumer epsilon_lp erfflag erf_representation errormsg error_size error_syms error_type %e_to_numlog eval even evenfun evflag evfun ev_point expandwrt_denom expintexpand expintrep expon expop exptdispflag exptisolate exptsubst facexpand facsum_combine factlim factorflag factorial_expand factors_only fb feature features file_name file_output_append file_search_demo file_search_lisp file_search_maxima|10 file_search_tests file_search_usage file_type_lisp file_type_maxima|10 fill_color fill_density filled_func fixed_vertices flipflag float2bf font font_size fortindent fortspaces fpprec fpprintprec functions gamma_expand gammalim gdet genindex gensumnum GGFCFMAX GGFINFINITY globalsolve gnuplot_command gnuplot_curve_styles gnuplot_curve_titles gnuplot_default_term_command gnuplot_dumb_term_command gnuplot_file_args gnuplot_file_name gnuplot_out_file gnuplot_pdf_term_command gnuplot_pm3d gnuplot_png_term_command gnuplot_postamble gnuplot_preamble gnuplot_ps_term_command gnuplot_svg_term_command gnuplot_term gnuplot_view_args Gosper_in_Zeilberger gradefs grid grid2d grind halfangles head_angle head_both head_length head_type height hypergeometric_representation %iargs ibase icc1 icc2 icounter idummyx ieqnprint ifb ifc1 ifc2 ifg ifgi ifr iframe_bracket_form ifri igeowedge_flag ikt1 ikt2 imaginary inchar increasing infeval infinity inflag infolists inm inmc1 inmc2 intanalysis integer integervalued integrate_use_rootsof integration_constant integration_constant_counter interpolate_color intfaclim ip_grid ip_grid_in irrational isolate_wrt_times iterations itr julia_parameter %k1 %k2 keepfloat key key_pos kinvariant kt label label_alignment label_orientation labels lassociative lbfgs_ncorrections lbfgs_nfeval_max leftjust legend letrat let_rule_packages lfg lg lhospitallim limsubst linear linear_solver linechar linel|10 linenum line_type linewidth line_width linsolve_params linsolvewarn lispdisp listarith listconstvars listdummyvars lmxchar load_pathname loadprint logabs logarc logcb logconcoeffp logexpand lognegint logsimp logx logx_secondary logy logy_secondary logz lriem m1pbranch macroexpansion macros mainvar manual_demo maperror mapprint matrix_element_add matrix_element_mult matrix_element_transpose maxapplydepth maxapplyheight maxima_tempdir|10 maxima_userdir|10 maxnegex MAX_ORD maxposex maxpsifracdenom maxpsifracnum maxpsinegint maxpsiposint maxtayorder mesh_lines_color method mod_big_prime mode_check_errorp mode_checkp mode_check_warnp mod_test mod_threshold modular_linear_solver modulus multiplicative multiplicities myoptions nary negdistrib negsumdispflag newline newtonepsilon newtonmaxiter nextlayerfactor niceindicespref nm nmc noeval nolabels nonegative_lp noninteger nonscalar noun noundisp nouns np npi nticks ntrig numer numer_pbranch obase odd oddfun opacity opproperties opsubst optimprefix optionset orientation origin orthopoly_returns_intervals outative outchar packagefile palette partswitch pdf_file pfeformat phiresolution %piargs piece pivot_count_sx pivot_max_sx plot_format plot_options plot_realpart png_file pochhammer_max_index points pointsize point_size points_joined point_type poislim poisson poly_coefficient_ring poly_elimination_order polyfactor poly_grobner_algorithm poly_grobner_debug poly_monomial_order poly_primary_elimination_order poly_return_term_list poly_secondary_elimination_order poly_top_reduction_only posfun position powerdisp pred prederror primep_number_of_tests product_use_gamma program programmode promote_float_to_bigfloat prompt proportional_axes props psexpand ps_file radexpand radius radsubstflag rassociative ratalgdenom ratchristof ratdenomdivide rateinstein ratepsilon ratfac rational ratmx ratprint ratriemann ratsimpexpons ratvarswitch ratweights ratweyl ratwtlvl real realonly redraw refcheck resolution restart resultant ric riem rmxchar %rnum_list rombergabs rombergit rombergmin rombergtol rootsconmode rootsepsilon run_viewer same_xy same_xyz savedef savefactors scalar scalarmatrixp scale scale_lp setcheck setcheckbreak setval show_edge_color show_edges show_edge_type show_edge_width show_id show_label showtime show_vertex_color show_vertex_size show_vertex_type show_vertices show_weight simp simplified_output simplify_products simpproduct simpsum sinnpiflag solvedecomposes solveexplicit solvefactors solvenullwarn solveradcan solvetrigwarn space sparse sphere spring_embedding_depth sqrtdispflag stardisp startphi starttheta stats_numer stringdisp structures style sublis_apply_lambda subnumsimp sumexpand sumsplitfact surface surface_hide svg_file symmetric tab taylordepth taylor_logexpand taylor_order_coefficients taylor_truncate_polynomials tensorkill terminal testsuite_files thetaresolution timer_devalue title tlimswitch tr track transcompile transform transform_xy translate_fast_arrays transparent transrun tr_array_as_ref tr_bound_function_applyp tr_file_tty_messagesp tr_float_can_branch_complex tr_function_call_default trigexpandplus trigexpandtimes triginverses trigsign trivial_solutions tr_numer tr_optimize_max_loop tr_semicompile tr_state_vars tr_warn_bad_function_calls tr_warn_fexpr tr_warn_meval tr_warn_mode tr_warn_undeclared tr_warn_undefined_variable tstep ttyoff tube_extremes ufg ug %unitexpand unit_vectors uric uriem use_fast_arrays user_preamble usersetunits values vect_cross verbose vertex_color vertex_coloring vertex_partition vertex_size vertex_type view warnings weyl width windowname windowtitle wired_surface wireframe xaxis xaxis_color xaxis_secondary xaxis_type xaxis_width xlabel xlabel_secondary xlength xrange xrange_secondary xtics xtics_axis xtics_rotate xtics_rotate_secondary xtics_secondary xtics_secondary_axis xu_grid x_voxel xy_file xyplane xy_scale yaxis yaxis_color yaxis_secondary yaxis_type yaxis_width ylabel ylabel_secondary ylength yrange yrange_secondary ytics ytics_axis ytics_rotate ytics_rotate_secondary ytics_secondary ytics_secondary_axis yv_grid y_voxel yx_ratio zaxis zaxis_color zaxis_type zaxis_width zeroa zerob zerobern zeta%pi zlabel zlabel_rotate zlength zmin zn_primroot_limit zn_primroot_pretest",
        symbol: "_ __ %|0 %%|0"
      },
      contains: [
        {
          className: "comment",
          begin: "/\\*",
          end: "\\*/",
          contains: ["self"]
        },
        t.QUOTE_STRING_MODE,
        {
          className: "number",
          relevance: 0,
          variants: [
            {
              // float number w/ exponent
              // hmm, I wonder if we ought to include other exponent markers?
              begin: "\\b(\\d+|\\d+\\.|\\.\\d+|\\d+\\.\\d+)[Ee][-+]?\\d+\\b"
            },
            {
              // bigfloat number
              begin: "\\b(\\d+|\\d+\\.|\\.\\d+|\\d+\\.\\d+)[Bb][-+]?\\d+\\b",
              relevance: 10
            },
            {
              // float number w/out exponent
              // Doesn't seem to recognize floats which start with '.'
              begin: "\\b(\\.\\d+|\\d+\\.\\d+)\\b"
            },
            {
              // integer in base up to 36
              // Doesn't seem to recognize integers which end with '.'
              begin: "\\b(\\d+|0[0-9A-Za-z]+)\\.?\\b"
            }
          ]
        }
      ],
      illegal: /@/
    };
  }
  return gS = e, gS;
}
var _S, CI;
function IJ() {
  if (CI) return _S;
  CI = 1;
  function e(t) {
    return {
      name: "MEL",
      keywords: "int float string vector matrix if else switch case default while do for in break continue global proc return about abs addAttr addAttributeEditorNodeHelp addDynamic addNewShelfTab addPP addPanelCategory addPrefixToName advanceToNextDrivenKey affectedNet affects aimConstraint air alias aliasAttr align alignCtx alignCurve alignSurface allViewFit ambientLight angle angleBetween animCone animCurveEditor animDisplay animView annotate appendStringArray applicationName applyAttrPreset applyTake arcLenDimContext arcLengthDimension arclen arrayMapper art3dPaintCtx artAttrCtx artAttrPaintVertexCtx artAttrSkinPaintCtx artAttrTool artBuildPaintMenu artFluidAttrCtx artPuttyCtx artSelectCtx artSetPaintCtx artUserPaintCtx assignCommand assignInputDevice assignViewportFactories attachCurve attachDeviceAttr attachSurface attrColorSliderGrp attrCompatibility attrControlGrp attrEnumOptionMenu attrEnumOptionMenuGrp attrFieldGrp attrFieldSliderGrp attrNavigationControlGrp attrPresetEditWin attributeExists attributeInfo attributeMenu attributeQuery autoKeyframe autoPlace bakeClip bakeFluidShading bakePartialHistory bakeResults bakeSimulation basename basenameEx batchRender bessel bevel bevelPlus binMembership bindSkin blend2 blendShape blendShapeEditor blendShapePanel blendTwoAttr blindDataType boneLattice boundary boxDollyCtx boxZoomCtx bufferCurve buildBookmarkMenu buildKeyframeMenu button buttonManip CBG cacheFile cacheFileCombine cacheFileMerge cacheFileTrack camera cameraView canCreateManip canvas capitalizeString catch catchQuiet ceil changeSubdivComponentDisplayLevel changeSubdivRegion channelBox character characterMap characterOutlineEditor characterize chdir checkBox checkBoxGrp checkDefaultRenderGlobals choice circle circularFillet clamp clear clearCache clip clipEditor clipEditorCurrentTimeCtx clipSchedule clipSchedulerOutliner clipTrimBefore closeCurve closeSurface cluster cmdFileOutput cmdScrollFieldExecuter cmdScrollFieldReporter cmdShell coarsenSubdivSelectionList collision color colorAtPoint colorEditor colorIndex colorIndexSliderGrp colorSliderButtonGrp colorSliderGrp columnLayout commandEcho commandLine commandPort compactHairSystem componentEditor compositingInterop computePolysetVolume condition cone confirmDialog connectAttr connectControl connectDynamic connectJoint connectionInfo constrain constrainValue constructionHistory container containsMultibyte contextInfo control convertFromOldLayers convertIffToPsd convertLightmap convertSolidTx convertTessellation convertUnit copyArray copyFlexor copyKey copySkinWeights cos cpButton cpCache cpClothSet cpCollision cpConstraint cpConvClothToMesh cpForces cpGetSolverAttr cpPanel cpProperty cpRigidCollisionFilter cpSeam cpSetEdit cpSetSolverAttr cpSolver cpSolverTypes cpTool cpUpdateClothUVs createDisplayLayer createDrawCtx createEditor createLayeredPsdFile createMotionField createNewShelf createNode createRenderLayer createSubdivRegion cross crossProduct ctxAbort ctxCompletion ctxEditMode ctxTraverse currentCtx currentTime currentTimeCtx currentUnit curve curveAddPtCtx curveCVCtx curveEPCtx curveEditorCtx curveIntersect curveMoveEPCtx curveOnSurface curveSketchCtx cutKey cycleCheck cylinder dagPose date defaultLightListCheckBox defaultNavigation defineDataServer defineVirtualDevice deformer deg_to_rad delete deleteAttr deleteShadingGroupsAndMaterials deleteShelfTab deleteUI deleteUnusedBrushes delrandstr detachCurve detachDeviceAttr detachSurface deviceEditor devicePanel dgInfo dgdirty dgeval dgtimer dimWhen directKeyCtx directionalLight dirmap dirname disable disconnectAttr disconnectJoint diskCache displacementToPoly displayAffected displayColor displayCull displayLevelOfDetail displayPref displayRGBColor displaySmoothness displayStats displayString displaySurface distanceDimContext distanceDimension doBlur dolly dollyCtx dopeSheetEditor dot dotProduct doubleProfileBirailSurface drag dragAttrContext draggerContext dropoffLocator duplicate duplicateCurve duplicateSurface dynCache dynControl dynExport dynExpression dynGlobals dynPaintEditor dynParticleCtx dynPref dynRelEdPanel dynRelEditor dynamicLoad editAttrLimits editDisplayLayerGlobals editDisplayLayerMembers editRenderLayerAdjustment editRenderLayerGlobals editRenderLayerMembers editor editorTemplate effector emit emitter enableDevice encodeString endString endsWith env equivalent equivalentTol erf error eval evalDeferred evalEcho event exactWorldBoundingBox exclusiveLightCheckBox exec executeForEachObject exists exp expression expressionEditorListen extendCurve extendSurface extrude fcheck fclose feof fflush fgetline fgetword file fileBrowserDialog fileDialog fileExtension fileInfo filetest filletCurve filter filterCurve filterExpand filterStudioImport findAllIntersections findAnimCurves findKeyframe findMenuItem findRelatedSkinCluster finder firstParentOf fitBspline flexor floatEq floatField floatFieldGrp floatScrollBar floatSlider floatSlider2 floatSliderButtonGrp floatSliderGrp floor flow fluidCacheInfo fluidEmitter fluidVoxelInfo flushUndo fmod fontDialog fopen formLayout format fprint frameLayout fread freeFormFillet frewind fromNativePath fwrite gamma gauss geometryConstraint getApplicationVersionAsFloat getAttr getClassification getDefaultBrush getFileList getFluidAttr getInputDeviceRange getMayaPanelTypes getModifiers getPanel getParticleAttr getPluginResource getenv getpid glRender glRenderEditor globalStitch gmatch goal gotoBindPose grabColor gradientControl gradientControlNoAttr graphDollyCtx graphSelectContext graphTrackCtx gravity grid gridLayout group groupObjectsByName HfAddAttractorToAS HfAssignAS HfBuildEqualMap HfBuildFurFiles HfBuildFurImages HfCancelAFR HfConnectASToHF HfCreateAttractor HfDeleteAS HfEditAS HfPerformCreateAS HfRemoveAttractorFromAS HfSelectAttached HfSelectAttractors HfUnAssignAS hardenPointCurve hardware hardwareRenderPanel headsUpDisplay headsUpMessage help helpLine hermite hide hilite hitTest hotBox hotkey hotkeyCheck hsv_to_rgb hudButton hudSlider hudSliderButton hwReflectionMap hwRender hwRenderLoad hyperGraph hyperPanel hyperShade hypot iconTextButton iconTextCheckBox iconTextRadioButton iconTextRadioCollection iconTextScrollList iconTextStaticLabel ikHandle ikHandleCtx ikHandleDisplayScale ikSolver ikSplineHandleCtx ikSystem ikSystemInfo ikfkDisplayMethod illustratorCurves image imfPlugins inheritTransform insertJoint insertJointCtx insertKeyCtx insertKnotCurve insertKnotSurface instance instanceable instancer intField intFieldGrp intScrollBar intSlider intSliderGrp interToUI internalVar intersect iprEngine isAnimCurve isConnected isDirty isParentOf isSameObject isTrue isValidObjectName isValidString isValidUiName isolateSelect itemFilter itemFilterAttr itemFilterRender itemFilterType joint jointCluster jointCtx jointDisplayScale jointLattice keyTangent keyframe keyframeOutliner keyframeRegionCurrentTimeCtx keyframeRegionDirectKeyCtx keyframeRegionDollyCtx keyframeRegionInsertKeyCtx keyframeRegionMoveKeyCtx keyframeRegionScaleKeyCtx keyframeRegionSelectKeyCtx keyframeRegionSetKeyCtx keyframeRegionTrackCtx keyframeStats lassoContext lattice latticeDeformKeyCtx launch launchImageEditor layerButton layeredShaderPort layeredTexturePort layout layoutDialog lightList lightListEditor lightListPanel lightlink lineIntersection linearPrecision linstep listAnimatable listAttr listCameras listConnections listDeviceAttachments listHistory listInputDeviceAxes listInputDeviceButtons listInputDevices listMenuAnnotation listNodeTypes listPanelCategories listRelatives listSets listTransforms listUnselected listerEditor loadFluid loadNewShelf loadPlugin loadPluginLanguageResources loadPrefObjects localizedPanelLabel lockNode loft log longNameOf lookThru ls lsThroughFilter lsType lsUI Mayatomr mag makeIdentity makeLive makePaintable makeRoll makeSingleSurface makeTubeOn makebot manipMoveContext manipMoveLimitsCtx manipOptions manipRotateContext manipRotateLimitsCtx manipScaleContext manipScaleLimitsCtx marker match max memory menu menuBarLayout menuEditor menuItem menuItemToShelf menuSet menuSetPref messageLine min minimizeApp mirrorJoint modelCurrentTimeCtx modelEditor modelPanel mouse movIn movOut move moveIKtoFK moveKeyCtx moveVertexAlongDirection multiProfileBirailSurface mute nParticle nameCommand nameField namespace namespaceInfo newPanelItems newton nodeCast nodeIconButton nodeOutliner nodePreset nodeType noise nonLinear normalConstraint normalize nurbsBoolean nurbsCopyUVSet nurbsCube nurbsEditUV nurbsPlane nurbsSelect nurbsSquare nurbsToPoly nurbsToPolygonsPref nurbsToSubdiv nurbsToSubdivPref nurbsUVSet nurbsViewDirectionVector objExists objectCenter objectLayer objectType objectTypeUI obsoleteProc oceanNurbsPreviewPlane offsetCurve offsetCurveOnSurface offsetSurface openGLExtension openMayaPref optionMenu optionMenuGrp optionVar orbit orbitCtx orientConstraint outlinerEditor outlinerPanel overrideModifier paintEffectsDisplay pairBlend palettePort paneLayout panel panelConfiguration panelHistory paramDimContext paramDimension paramLocator parent parentConstraint particle particleExists particleInstancer particleRenderInfo partition pasteKey pathAnimation pause pclose percent performanceOptions pfxstrokes pickWalk picture pixelMove planarSrf plane play playbackOptions playblast plugAttr plugNode pluginInfo pluginResourceUtil pointConstraint pointCurveConstraint pointLight pointMatrixMult pointOnCurve pointOnSurface pointPosition poleVectorConstraint polyAppend polyAppendFacetCtx polyAppendVertex polyAutoProjection polyAverageNormal polyAverageVertex polyBevel polyBlendColor polyBlindData polyBoolOp polyBridgeEdge polyCacheMonitor polyCheck polyChipOff polyClipboard polyCloseBorder polyCollapseEdge polyCollapseFacet polyColorBlindData polyColorDel polyColorPerVertex polyColorSet polyCompare polyCone polyCopyUV polyCrease polyCreaseCtx polyCreateFacet polyCreateFacetCtx polyCube polyCut polyCutCtx polyCylinder polyCylindricalProjection polyDelEdge polyDelFacet polyDelVertex polyDuplicateAndConnect polyDuplicateEdge polyEditUV polyEditUVShell polyEvaluate polyExtrudeEdge polyExtrudeFacet polyExtrudeVertex polyFlipEdge polyFlipUV polyForceUV polyGeoSampler polyHelix polyInfo polyInstallAction polyLayoutUV polyListComponentConversion polyMapCut polyMapDel polyMapSew polyMapSewMove polyMergeEdge polyMergeEdgeCtx polyMergeFacet polyMergeFacetCtx polyMergeUV polyMergeVertex polyMirrorFace polyMoveEdge polyMoveFacet polyMoveFacetUV polyMoveUV polyMoveVertex polyNormal polyNormalPerVertex polyNormalizeUV polyOptUvs polyOptions polyOutput polyPipe polyPlanarProjection polyPlane polyPlatonicSolid polyPoke polyPrimitive polyPrism polyProjection polyPyramid polyQuad polyQueryBlindData polyReduce polySelect polySelectConstraint polySelectConstraintMonitor polySelectCtx polySelectEditCtx polySeparate polySetToFaceNormal polySewEdge polyShortestPathCtx polySmooth polySoftEdge polySphere polySphericalProjection polySplit polySplitCtx polySplitEdge polySplitRing polySplitVertex polyStraightenUVBorder polySubdivideEdge polySubdivideFacet polyToSubdiv polyTorus polyTransfer polyTriangulate polyUVSet polyUnite polyWedgeFace popen popupMenu pose pow preloadRefEd print progressBar progressWindow projFileViewer projectCurve projectTangent projectionContext projectionManip promptDialog propModCtx propMove psdChannelOutliner psdEditTextureFile psdExport psdTextureFile putenv pwd python querySubdiv quit rad_to_deg radial radioButton radioButtonGrp radioCollection radioMenuItemCollection rampColorPort rand randomizeFollicles randstate rangeControl readTake rebuildCurve rebuildSurface recordAttr recordDevice redo reference referenceEdit referenceQuery refineSubdivSelectionList refresh refreshAE registerPluginResource rehash reloadImage removeJoint removeMultiInstance removePanelCategory rename renameAttr renameSelectionList renameUI render renderGlobalsNode renderInfo renderLayerButton renderLayerParent renderLayerPostProcess renderLayerUnparent renderManip renderPartition renderQualityNode renderSettings renderThumbnailUpdate renderWindowEditor renderWindowSelectContext renderer reorder reorderDeformers requires reroot resampleFluid resetAE resetPfxToPolyCamera resetTool resolutionNode retarget reverseCurve reverseSurface revolve rgb_to_hsv rigidBody rigidSolver roll rollCtx rootOf rot rotate rotationInterpolation roundConstantRadius rowColumnLayout rowLayout runTimeCommand runup sampleImage saveAllShelves saveAttrPreset saveFluid saveImage saveInitialState saveMenu savePrefObjects savePrefs saveShelf saveToolSettings scale scaleBrushBrightness scaleComponents scaleConstraint scaleKey scaleKeyCtx sceneEditor sceneUIReplacement scmh scriptCtx scriptEditorInfo scriptJob scriptNode scriptTable scriptToShelf scriptedPanel scriptedPanelType scrollField scrollLayout sculpt searchPathArray seed selLoadSettings select selectContext selectCurveCV selectKey selectKeyCtx selectKeyframeRegionCtx selectMode selectPref selectPriority selectType selectedNodes selectionConnection separator setAttr setAttrEnumResource setAttrMapping setAttrNiceNameResource setConstraintRestPosition setDefaultShadingGroup setDrivenKeyframe setDynamic setEditCtx setEditor setFluidAttr setFocus setInfinity setInputDeviceMapping setKeyCtx setKeyPath setKeyframe setKeyframeBlendshapeTargetWts setMenuMode setNodeNiceNameResource setNodeTypeFlag setParent setParticleAttr setPfxToPolyCamera setPluginResource setProject setStampDensity setStartupMessage setState setToolTo setUITemplate setXformManip sets shadingConnection shadingGeometryRelCtx shadingLightRelCtx shadingNetworkCompare shadingNode shapeCompare shelfButton shelfLayout shelfTabLayout shellField shortNameOf showHelp showHidden showManipCtx showSelectionInTitle showShadingGroupAttrEditor showWindow sign simplify sin singleProfileBirailSurface size sizeBytes skinCluster skinPercent smoothCurve smoothTangentSurface smoothstep snap2to2 snapKey snapMode snapTogetherCtx snapshot soft softMod softModCtx sort sound soundControl source spaceLocator sphere sphrand spotLight spotLightPreviewPort spreadSheetEditor spring sqrt squareSurface srtContext stackTrace startString startsWith stitchAndExplodeShell stitchSurface stitchSurfacePoints strcmp stringArrayCatenate stringArrayContains stringArrayCount stringArrayInsertAtIndex stringArrayIntersector stringArrayRemove stringArrayRemoveAtIndex stringArrayRemoveDuplicates stringArrayRemoveExact stringArrayToString stringToStringArray strip stripPrefixFromName stroke subdAutoProjection subdCleanTopology subdCollapse subdDuplicateAndConnect subdEditUV subdListComponentConversion subdMapCut subdMapSewMove subdMatchTopology subdMirror subdToBlind subdToPoly subdTransferUVsToCache subdiv subdivCrease subdivDisplaySmoothness substitute substituteAllString substituteGeometry substring surface surfaceSampler surfaceShaderList swatchDisplayPort switchTable symbolButton symbolCheckBox sysFile system tabLayout tan tangentConstraint texLatticeDeformContext texManipContext texMoveContext texMoveUVShellContext texRotateContext texScaleContext texSelectContext texSelectShortestPathCtx texSmudgeUVContext texWinToolCtx text textCurves textField textFieldButtonGrp textFieldGrp textManip textScrollList textToShelf textureDisplacePlane textureHairColor texturePlacementContext textureWindow threadCount threePointArcCtx timeControl timePort timerX toNativePath toggle toggleAxis toggleWindowVisibility tokenize tokenizeList tolerance tolower toolButton toolCollection toolDropped toolHasOptions toolPropertyWindow torus toupper trace track trackCtx transferAttributes transformCompare transformLimits translator trim trunc truncateFluidCache truncateHairCache tumble tumbleCtx turbulence twoPointArcCtx uiRes uiTemplate unassignInputDevice undo undoInfo ungroup uniform unit unloadPlugin untangleUV untitledFileName untrim upAxis updateAE userCtx uvLink uvSnapshot validateShelfName vectorize view2dToolCtx viewCamera viewClipPlane viewFit viewHeadOn viewLookAt viewManip viewPlace viewSet visor volumeAxis vortex waitCursor warning webBrowser webBrowserPrefs whatIs window windowPref wire wireContext workspace wrinkle wrinkleContext writeTake xbmLangPathList xform",
      illegal: "</",
      contains: [
        t.C_NUMBER_MODE,
        t.APOS_STRING_MODE,
        t.QUOTE_STRING_MODE,
        {
          className: "string",
          begin: "`",
          end: "`",
          contains: [t.BACKSLASH_ESCAPE]
        },
        {
          // eats variables
          begin: /[$%@](\^\w\b|#\w+|[^\s\w{]|\{\w+\}|\w+)/
        },
        t.C_LINE_COMMENT_MODE,
        t.C_BLOCK_COMMENT_MODE
      ]
    };
  }
  return _S = e, _S;
}
var vS, AI;
function LJ() {
  if (AI) return vS;
  AI = 1;
  function e(t) {
    const n = {
      keyword: "module use_module import_module include_module end_module initialise mutable initialize finalize finalise interface implementation pred mode func type inst solver any_pred any_func is semidet det nondet multi erroneous failure cc_nondet cc_multi typeclass instance where pragma promise external trace atomic or_else require_complete_switch require_det require_semidet require_multi require_nondet require_cc_multi require_cc_nondet require_erroneous require_failure",
      meta: (
        // pragma
        "inline no_inline type_spec source_file fact_table obsolete memo loop_check minimal_model terminates does_not_terminate check_termination promise_equivalent_clauses foreign_proc foreign_decl foreign_code foreign_type foreign_import_module foreign_export_enum foreign_export foreign_enum may_call_mercury will_not_call_mercury thread_safe not_thread_safe maybe_thread_safe promise_pure promise_semipure tabled_for_io local untrailed trailed attach_to_io_state can_pass_as_mercury_type stable will_not_throw_exception may_modify_trail will_not_modify_trail may_duplicate may_not_duplicate affects_liveness does_not_affect_liveness doesnt_affect_liveness no_sharing unknown_sharing sharing"
      ),
      built_in: "some all not if then else true fail false try catch catch_any semidet_true semidet_false semidet_fail impure_true impure semipure"
    }, r = t.COMMENT("%", "$"), i = {
      className: "number",
      begin: "0'.\\|0[box][0-9a-fA-F]*"
    }, a = t.inherit(t.APOS_STRING_MODE, { relevance: 0 }), o = t.inherit(t.QUOTE_STRING_MODE, { relevance: 0 }), s = {
      className: "subst",
      begin: "\\\\[abfnrtv]\\|\\\\x[0-9a-fA-F]*\\\\\\|%[-+# *.0-9]*[dioxXucsfeEgGp]",
      relevance: 0
    };
    return o.contains = o.contains.slice(), o.contains.push(s), {
      name: "Mercury",
      aliases: [
        "m",
        "moo"
      ],
      keywords: n,
      contains: [
        {
          className: "built_in",
          variants: [
            { begin: "<=>" },
            {
              begin: "<=",
              relevance: 0
            },
            {
              begin: "=>",
              relevance: 0
            },
            { begin: "/\\\\" },
            { begin: "\\\\/" }
          ]
        },
        {
          className: "built_in",
          variants: [
            { begin: ":-\\|-->" },
            {
              begin: "=",
              relevance: 0
            }
          ]
        },
        r,
        t.C_BLOCK_COMMENT_MODE,
        i,
        t.NUMBER_MODE,
        a,
        o,
        {
          // relevance booster
          begin: /:-/
        },
        {
          // relevance booster
          begin: /\.$/
        }
      ]
    };
  }
  return vS = e, vS;
}
var bS, OI;
function kJ() {
  if (OI) return bS;
  OI = 1;
  function e(t) {
    return {
      name: "MIPS Assembly",
      case_insensitive: !0,
      aliases: ["mips"],
      keywords: {
        $pattern: "\\.?" + t.IDENT_RE,
        meta: (
          // GNU preprocs
          ".2byte .4byte .align .ascii .asciz .balign .byte .code .data .else .end .endif .endm .endr .equ .err .exitm .extern .global .hword .if .ifdef .ifndef .include .irp .long .macro .rept .req .section .set .skip .space .text .word .ltorg "
        ),
        built_in: "$0 $1 $2 $3 $4 $5 $6 $7 $8 $9 $10 $11 $12 $13 $14 $15 $16 $17 $18 $19 $20 $21 $22 $23 $24 $25 $26 $27 $28 $29 $30 $31 zero at v0 v1 a0 a1 a2 a3 a4 a5 a6 a7 t0 t1 t2 t3 t4 t5 t6 t7 t8 t9 s0 s1 s2 s3 s4 s5 s6 s7 s8 k0 k1 gp sp fp ra $f0 $f1 $f2 $f2 $f4 $f5 $f6 $f7 $f8 $f9 $f10 $f11 $f12 $f13 $f14 $f15 $f16 $f17 $f18 $f19 $f20 $f21 $f22 $f23 $f24 $f25 $f26 $f27 $f28 $f29 $f30 $f31 Context Random EntryLo0 EntryLo1 Context PageMask Wired EntryHi HWREna BadVAddr Count Compare SR IntCtl SRSCtl SRSMap Cause EPC PRId EBase Config Config1 Config2 Config3 LLAddr Debug DEPC DESAVE CacheErr ECC ErrorEPC TagLo DataLo TagHi DataHi WatchLo WatchHi PerfCtl PerfCnt "
        // Coprocessor 0 registers
      },
      contains: [
        {
          className: "keyword",
          begin: "\\b(addi?u?|andi?|b(al)?|beql?|bgez(al)?l?|bgtzl?|blezl?|bltz(al)?l?|bnel?|cl[oz]|divu?|ext|ins|j(al)?|jalr(\\.hb)?|jr(\\.hb)?|lbu?|lhu?|ll|lui|lw[lr]?|maddu?|mfhi|mflo|movn|movz|move|msubu?|mthi|mtlo|mul|multu?|nop|nor|ori?|rotrv?|sb|sc|se[bh]|sh|sllv?|slti?u?|srav?|srlv?|subu?|sw[lr]?|xori?|wsbh|abs\\.[sd]|add\\.[sd]|alnv.ps|bc1[ft]l?|c\\.(s?f|un|u?eq|[ou]lt|[ou]le|ngle?|seq|l[et]|ng[et])\\.[sd]|(ceil|floor|round|trunc)\\.[lw]\\.[sd]|cfc1|cvt\\.d\\.[lsw]|cvt\\.l\\.[dsw]|cvt\\.ps\\.s|cvt\\.s\\.[dlw]|cvt\\.s\\.p[lu]|cvt\\.w\\.[dls]|div\\.[ds]|ldx?c1|luxc1|lwx?c1|madd\\.[sd]|mfc1|mov[fntz]?\\.[ds]|msub\\.[sd]|mth?c1|mul\\.[ds]|neg\\.[ds]|nmadd\\.[ds]|nmsub\\.[ds]|p[lu][lu]\\.ps|recip\\.fmt|r?sqrt\\.[ds]|sdx?c1|sub\\.[ds]|suxc1|swx?c1|break|cache|d?eret|[de]i|ehb|mfc0|mtc0|pause|prefx?|rdhwr|rdpgpr|sdbbp|ssnop|synci?|syscall|teqi?|tgei?u?|tlb(p|r|w[ir])|tlti?u?|tnei?|wait|wrpgpr)",
          end: "\\s"
        },
        // lines ending with ; or # aren't really comments, probably auto-detect fail
        t.COMMENT("[;#](?!\\s*$)", "$"),
        t.C_BLOCK_COMMENT_MODE,
        t.QUOTE_STRING_MODE,
        {
          className: "string",
          begin: "'",
          end: "[^\\\\]'",
          relevance: 0
        },
        {
          className: "title",
          begin: "\\|",
          end: "\\|",
          illegal: "\\n",
          relevance: 0
        },
        {
          className: "number",
          variants: [
            {
              // hex
              begin: "0x[0-9a-f]+"
            },
            {
              // bare number
              begin: "\\b-?\\d+"
            }
          ],
          relevance: 0
        },
        {
          className: "symbol",
          variants: [
            {
              // GNU MIPS syntax
              begin: "^\\s*[a-z_\\.\\$][a-z0-9_\\.\\$]+:"
            },
            {
              // numbered local labels
              begin: "^\\s*[0-9]+:"
            },
            {
              // number local label reference (backwards, forwards)
              begin: "[0-9]+[bf]"
            }
          ],
          relevance: 0
        }
      ],
      // forward slashes are not allowed
      illegal: /\//
    };
  }
  return bS = e, bS;
}
var ES, RI;
function MJ() {
  if (RI) return ES;
  RI = 1;
  function e(t) {
    return {
      name: "Mizar",
      keywords: "environ vocabularies notations constructors definitions registrations theorems schemes requirements begin end definition registration cluster existence pred func defpred deffunc theorem proof let take assume then thus hence ex for st holds consider reconsider such that and in provided of as from be being by means equals implies iff redefine define now not or attr is mode suppose per cases set thesis contradiction scheme reserve struct correctness compatibility coherence symmetry assymetry reflexivity irreflexivity connectedness uniqueness commutativity idempotence involutiveness projectivity",
      contains: [t.COMMENT("::", "$")]
    };
  }
  return ES = e, ES;
}
var SS, wI;
function PJ() {
  if (wI) return SS;
  wI = 1;
  function e(t) {
    const n = t.regex, r = [
      "abs",
      "accept",
      "alarm",
      "and",
      "atan2",
      "bind",
      "binmode",
      "bless",
      "break",
      "caller",
      "chdir",
      "chmod",
      "chomp",
      "chop",
      "chown",
      "chr",
      "chroot",
      "close",
      "closedir",
      "connect",
      "continue",
      "cos",
      "crypt",
      "dbmclose",
      "dbmopen",
      "defined",
      "delete",
      "die",
      "do",
      "dump",
      "each",
      "else",
      "elsif",
      "endgrent",
      "endhostent",
      "endnetent",
      "endprotoent",
      "endpwent",
      "endservent",
      "eof",
      "eval",
      "exec",
      "exists",
      "exit",
      "exp",
      "fcntl",
      "fileno",
      "flock",
      "for",
      "foreach",
      "fork",
      "format",
      "formline",
      "getc",
      "getgrent",
      "getgrgid",
      "getgrnam",
      "gethostbyaddr",
      "gethostbyname",
      "gethostent",
      "getlogin",
      "getnetbyaddr",
      "getnetbyname",
      "getnetent",
      "getpeername",
      "getpgrp",
      "getpriority",
      "getprotobyname",
      "getprotobynumber",
      "getprotoent",
      "getpwent",
      "getpwnam",
      "getpwuid",
      "getservbyname",
      "getservbyport",
      "getservent",
      "getsockname",
      "getsockopt",
      "given",
      "glob",
      "gmtime",
      "goto",
      "grep",
      "gt",
      "hex",
      "if",
      "index",
      "int",
      "ioctl",
      "join",
      "keys",
      "kill",
      "last",
      "lc",
      "lcfirst",
      "length",
      "link",
      "listen",
      "local",
      "localtime",
      "log",
      "lstat",
      "lt",
      "ma",
      "map",
      "mkdir",
      "msgctl",
      "msgget",
      "msgrcv",
      "msgsnd",
      "my",
      "ne",
      "next",
      "no",
      "not",
      "oct",
      "open",
      "opendir",
      "or",
      "ord",
      "our",
      "pack",
      "package",
      "pipe",
      "pop",
      "pos",
      "print",
      "printf",
      "prototype",
      "push",
      "q|0",
      "qq",
      "quotemeta",
      "qw",
      "qx",
      "rand",
      "read",
      "readdir",
      "readline",
      "readlink",
      "readpipe",
      "recv",
      "redo",
      "ref",
      "rename",
      "require",
      "reset",
      "return",
      "reverse",
      "rewinddir",
      "rindex",
      "rmdir",
      "say",
      "scalar",
      "seek",
      "seekdir",
      "select",
      "semctl",
      "semget",
      "semop",
      "send",
      "setgrent",
      "sethostent",
      "setnetent",
      "setpgrp",
      "setpriority",
      "setprotoent",
      "setpwent",
      "setservent",
      "setsockopt",
      "shift",
      "shmctl",
      "shmget",
      "shmread",
      "shmwrite",
      "shutdown",
      "sin",
      "sleep",
      "socket",
      "socketpair",
      "sort",
      "splice",
      "split",
      "sprintf",
      "sqrt",
      "srand",
      "stat",
      "state",
      "study",
      "sub",
      "substr",
      "symlink",
      "syscall",
      "sysopen",
      "sysread",
      "sysseek",
      "system",
      "syswrite",
      "tell",
      "telldir",
      "tie",
      "tied",
      "time",
      "times",
      "tr",
      "truncate",
      "uc",
      "ucfirst",
      "umask",
      "undef",
      "unless",
      "unlink",
      "unpack",
      "unshift",
      "untie",
      "until",
      "use",
      "utime",
      "values",
      "vec",
      "wait",
      "waitpid",
      "wantarray",
      "warn",
      "when",
      "while",
      "write",
      "x|0",
      "xor",
      "y|0"
    ], i = /[dualxmsipngr]{0,12}/, a = {
      $pattern: /[\w.]+/,
      keyword: r.join(" ")
    }, o = {
      className: "subst",
      begin: "[$@]\\{",
      end: "\\}",
      keywords: a
    }, s = {
      begin: /->\{/,
      end: /\}/
      // contains defined later
    }, l = { variants: [
      { begin: /\$\d/ },
      { begin: n.concat(
        /[$%@](\^\w\b|#\w+(::\w+)*|\{\w+\}|\w+(::\w*)*)/,
        // negative look-ahead tries to avoid matching patterns that are not
        // Perl at all like $ident$, @ident@, etc.
        "(?![A-Za-z])(?![@$%])"
      ) },
      {
        begin: /[$%@][^\s\w{]/,
        relevance: 0
      }
    ] }, u = [
      t.BACKSLASH_ESCAPE,
      o,
      l
    ], c = [
      /!/,
      /\//,
      /\|/,
      /\?/,
      /'/,
      /"/,
      // valid but infrequent and weird
      /#/
      // valid but infrequent and weird
    ], d = (m, v, b = "\\1") => {
      const y = b === "\\1" ? b : n.concat(b, v);
      return n.concat(
        n.concat("(?:", m, ")"),
        v,
        /(?:\\.|[^\\\/])*?/,
        y,
        /(?:\\.|[^\\\/])*?/,
        b,
        i
      );
    }, f = (m, v, b) => n.concat(
      n.concat("(?:", m, ")"),
      v,
      /(?:\\.|[^\\\/])*?/,
      b,
      i
    ), h = [
      l,
      t.HASH_COMMENT_MODE,
      t.COMMENT(
        /^=\w/,
        /=cut/,
        { endsWithParent: !0 }
      ),
      s,
      {
        className: "string",
        contains: u,
        variants: [
          {
            begin: "q[qwxr]?\\s*\\(",
            end: "\\)",
            relevance: 5
          },
          {
            begin: "q[qwxr]?\\s*\\[",
            end: "\\]",
            relevance: 5
          },
          {
            begin: "q[qwxr]?\\s*\\{",
            end: "\\}",
            relevance: 5
          },
          {
            begin: "q[qwxr]?\\s*\\|",
            end: "\\|",
            relevance: 5
          },
          {
            begin: "q[qwxr]?\\s*<",
            end: ">",
            relevance: 5
          },
          {
            begin: "qw\\s+q",
            end: "q",
            relevance: 5
          },
          {
            begin: "'",
            end: "'",
            contains: [t.BACKSLASH_ESCAPE]
          },
          {
            begin: '"',
            end: '"'
          },
          {
            begin: "`",
            end: "`",
            contains: [t.BACKSLASH_ESCAPE]
          },
          {
            begin: /\{\w+\}/,
            relevance: 0
          },
          {
            begin: "-?\\w+\\s*=>",
            relevance: 0
          }
        ]
      },
      {
        className: "number",
        begin: "(\\b0[0-7_]+)|(\\b0x[0-9a-fA-F_]+)|(\\b[1-9][0-9_]*(\\.[0-9_]+)?)|[0_]\\b",
        relevance: 0
      },
      {
        // regexp container
        begin: "(\\/\\/|" + t.RE_STARTERS_RE + "|\\b(split|return|print|reverse|grep)\\b)\\s*",
        keywords: "split return print reverse grep",
        relevance: 0,
        contains: [
          t.HASH_COMMENT_MODE,
          {
            className: "regexp",
            variants: [
              // allow matching common delimiters
              { begin: d("s|tr|y", n.either(...c, { capture: !0 })) },
              // and then paired delmis
              { begin: d("s|tr|y", "\\(", "\\)") },
              { begin: d("s|tr|y", "\\[", "\\]") },
              { begin: d("s|tr|y", "\\{", "\\}") }
            ],
            relevance: 2
          },
          {
            className: "regexp",
            variants: [
              {
                // could be a comment in many languages so do not count
                // as relevant
                begin: /(m|qr)\/\//,
                relevance: 0
              },
              // prefix is optional with /regex/
              { begin: f("(?:m|qr)?", /\//, /\//) },
              // allow matching common delimiters
              { begin: f("m|qr", n.either(...c, { capture: !0 }), /\1/) },
              // allow common paired delmins
              { begin: f("m|qr", /\(/, /\)/) },
              { begin: f("m|qr", /\[/, /\]/) },
              { begin: f("m|qr", /\{/, /\}/) }
            ]
          }
        ]
      },
      {
        className: "function",
        beginKeywords: "sub",
        end: "(\\s*\\(.*?\\))?[;{]",
        excludeEnd: !0,
        relevance: 5,
        contains: [t.TITLE_MODE]
      },
      {
        begin: "-\\w\\b",
        relevance: 0
      },
      {
        begin: "^__DATA__$",
        end: "^__END__$",
        subLanguage: "mojolicious",
        contains: [
          {
            begin: "^@@.*",
            end: "$",
            className: "comment"
          }
        ]
      }
    ];
    return o.contains = h, s.contains = h, {
      name: "Perl",
      aliases: [
        "pl",
        "pm"
      ],
      keywords: a,
      contains: h
    };
  }
  return SS = e, SS;
}
var yS, xI;
function FJ() {
  if (xI) return yS;
  xI = 1;
  function e(t) {
    return {
      name: "Mojolicious",
      subLanguage: "xml",
      contains: [
        {
          className: "meta",
          begin: "^__(END|DATA)__$"
        },
        // mojolicious line
        {
          begin: "^\\s*%{1,2}={0,2}",
          end: "$",
          subLanguage: "perl"
        },
        // mojolicious block
        {
          begin: "<%{1,2}={0,2}",
          end: "={0,1}%>",
          subLanguage: "perl",
          excludeBegin: !0,
          excludeEnd: !0
        }
      ]
    };
  }
  return yS = e, yS;
}
var TS, NI;
function BJ() {
  if (NI) return TS;
  NI = 1;
  function e(t) {
    const n = {
      className: "number",
      relevance: 0,
      variants: [
        { begin: "[$][a-fA-F0-9]+" },
        t.NUMBER_MODE
      ]
    }, r = {
      variants: [
        { match: [
          /(function|method)/,
          /\s+/,
          t.UNDERSCORE_IDENT_RE
        ] }
      ],
      scope: {
        1: "keyword",
        3: "title.function"
      }
    }, i = {
      variants: [
        { match: [
          /(class|interface|extends|implements)/,
          /\s+/,
          t.UNDERSCORE_IDENT_RE
        ] }
      ],
      scope: {
        1: "keyword",
        3: "title.class"
      }
    };
    return {
      name: "Monkey",
      case_insensitive: !0,
      keywords: {
        keyword: [
          "public",
          "private",
          "property",
          "continue",
          "exit",
          "extern",
          "new",
          "try",
          "catch",
          "eachin",
          "not",
          "abstract",
          "final",
          "select",
          "case",
          "default",
          "const",
          "local",
          "global",
          "field",
          "end",
          "if",
          "then",
          "else",
          "elseif",
          "endif",
          "while",
          "wend",
          "repeat",
          "until",
          "forever",
          "for",
          "to",
          "step",
          "next",
          "return",
          "module",
          "inline",
          "throw",
          "import",
          // not positive, but these are not literals
          "and",
          "or",
          "shl",
          "shr",
          "mod"
        ],
        built_in: [
          "DebugLog",
          "DebugStop",
          "Error",
          "Print",
          "ACos",
          "ACosr",
          "ASin",
          "ASinr",
          "ATan",
          "ATan2",
          "ATan2r",
          "ATanr",
          "Abs",
          "Abs",
          "Ceil",
          "Clamp",
          "Clamp",
          "Cos",
          "Cosr",
          "Exp",
          "Floor",
          "Log",
          "Max",
          "Max",
          "Min",
          "Min",
          "Pow",
          "Sgn",
          "Sgn",
          "Sin",
          "Sinr",
          "Sqrt",
          "Tan",
          "Tanr",
          "Seed",
          "PI",
          "HALFPI",
          "TWOPI"
        ],
        literal: [
          "true",
          "false",
          "null"
        ]
      },
      illegal: /\/\*/,
      contains: [
        t.COMMENT("#rem", "#end"),
        t.COMMENT(
          "'",
          "$",
          { relevance: 0 }
        ),
        r,
        i,
        {
          className: "variable.language",
          begin: /\b(self|super)\b/
        },
        {
          className: "meta",
          begin: /\s*#/,
          end: "$",
          keywords: { keyword: "if else elseif endif end then" }
        },
        {
          match: [
            /^\s*/,
            /strict\b/
          ],
          scope: { 2: "meta" }
        },
        {
          beginKeywords: "alias",
          end: "=",
          contains: [t.UNDERSCORE_TITLE_MODE]
        },
        t.QUOTE_STRING_MODE,
        n
      ]
    };
  }
  return TS = e, TS;
}
var CS, DI;
function $J() {
  if (DI) return CS;
  DI = 1;
  function e(t) {
    const n = {
      keyword: (
        // Moonscript keywords
        "if then not for in while do return else elseif break continue switch and or unless when class extends super local import export from using"
      ),
      literal: "true false nil",
      built_in: "_G _VERSION assert collectgarbage dofile error getfenv getmetatable ipairs load loadfile loadstring module next pairs pcall print rawequal rawget rawset require select setfenv setmetatable tonumber tostring type unpack xpcall coroutine debug io math os package string table"
    }, r = "[A-Za-z$_][0-9A-Za-z$_]*", i = {
      className: "subst",
      begin: /#\{/,
      end: /\}/,
      keywords: n
    }, a = [
      t.inherit(
        t.C_NUMBER_MODE,
        { starts: {
          end: "(\\s*/)?",
          relevance: 0
        } }
      ),
      // a number tries to eat the following slash to prevent treating it as a regexp
      {
        className: "string",
        variants: [
          {
            begin: /'/,
            end: /'/,
            contains: [t.BACKSLASH_ESCAPE]
          },
          {
            begin: /"/,
            end: /"/,
            contains: [
              t.BACKSLASH_ESCAPE,
              i
            ]
          }
        ]
      },
      {
        className: "built_in",
        begin: "@__" + t.IDENT_RE
      },
      {
        begin: "@" + t.IDENT_RE
        // relevance booster on par with CoffeeScript
      },
      {
        begin: t.IDENT_RE + "\\\\" + t.IDENT_RE
        // inst\method
      }
    ];
    i.contains = a;
    const o = t.inherit(t.TITLE_MODE, { begin: r }), s = "(\\(.*\\)\\s*)?\\B[-=]>", l = {
      className: "params",
      begin: "\\([^\\(]",
      returnBegin: !0,
      /* We need another contained nameless mode to not have every nested
      pair of parens to be called "params" */
      contains: [
        {
          begin: /\(/,
          end: /\)/,
          keywords: n,
          contains: ["self"].concat(a)
        }
      ]
    };
    return {
      name: "MoonScript",
      aliases: ["moon"],
      keywords: n,
      illegal: /\/\*/,
      contains: a.concat([
        t.COMMENT("--", "$"),
        {
          className: "function",
          // function: -> =>
          begin: "^\\s*" + r + "\\s*=\\s*" + s,
          end: "[-=]>",
          returnBegin: !0,
          contains: [
            o,
            l
          ]
        },
        {
          begin: /[\(,:=]\s*/,
          // anonymous function start
          relevance: 0,
          contains: [
            {
              className: "function",
              begin: s,
              end: "[-=]>",
              returnBegin: !0,
              contains: [l]
            }
          ]
        },
        {
          className: "class",
          beginKeywords: "class",
          end: "$",
          illegal: /[:="\[\]]/,
          contains: [
            {
              beginKeywords: "extends",
              endsWithParent: !0,
              illegal: /[:="\[\]]/,
              contains: [o]
            },
            o
          ]
        },
        {
          className: "name",
          // table
          begin: r + ":",
          end: ":",
          returnBegin: !0,
          returnEnd: !0,
          relevance: 0
        }
      ])
    };
  }
  return CS = e, CS;
}
var AS, II;
function UJ() {
  if (II) return AS;
  II = 1;
  function e(t) {
    return {
      name: "N1QL",
      case_insensitive: !0,
      contains: [
        {
          beginKeywords: "build create index delete drop explain infer|10 insert merge prepare select update upsert|10",
          end: /;/,
          keywords: {
            keyword: [
              "all",
              "alter",
              "analyze",
              "and",
              "any",
              "array",
              "as",
              "asc",
              "begin",
              "between",
              "binary",
              "boolean",
              "break",
              "bucket",
              "build",
              "by",
              "call",
              "case",
              "cast",
              "cluster",
              "collate",
              "collection",
              "commit",
              "connect",
              "continue",
              "correlate",
              "cover",
              "create",
              "database",
              "dataset",
              "datastore",
              "declare",
              "decrement",
              "delete",
              "derived",
              "desc",
              "describe",
              "distinct",
              "do",
              "drop",
              "each",
              "element",
              "else",
              "end",
              "every",
              "except",
              "exclude",
              "execute",
              "exists",
              "explain",
              "fetch",
              "first",
              "flatten",
              "for",
              "force",
              "from",
              "function",
              "grant",
              "group",
              "gsi",
              "having",
              "if",
              "ignore",
              "ilike",
              "in",
              "include",
              "increment",
              "index",
              "infer",
              "inline",
              "inner",
              "insert",
              "intersect",
              "into",
              "is",
              "join",
              "key",
              "keys",
              "keyspace",
              "known",
              "last",
              "left",
              "let",
              "letting",
              "like",
              "limit",
              "lsm",
              "map",
              "mapping",
              "matched",
              "materialized",
              "merge",
              "minus",
              "namespace",
              "nest",
              "not",
              "number",
              "object",
              "offset",
              "on",
              "option",
              "or",
              "order",
              "outer",
              "over",
              "parse",
              "partition",
              "password",
              "path",
              "pool",
              "prepare",
              "primary",
              "private",
              "privilege",
              "procedure",
              "public",
              "raw",
              "realm",
              "reduce",
              "rename",
              "return",
              "returning",
              "revoke",
              "right",
              "role",
              "rollback",
              "satisfies",
              "schema",
              "select",
              "self",
              "semi",
              "set",
              "show",
              "some",
              "start",
              "statistics",
              "string",
              "system",
              "then",
              "to",
              "transaction",
              "trigger",
              "truncate",
              "under",
              "union",
              "unique",
              "unknown",
              "unnest",
              "unset",
              "update",
              "upsert",
              "use",
              "user",
              "using",
              "validate",
              "value",
              "valued",
              "values",
              "via",
              "view",
              "when",
              "where",
              "while",
              "with",
              "within",
              "work",
              "xor"
            ],
            literal: [
              "true",
              "false",
              "null",
              "missing|5"
            ],
            built_in: [
              "array_agg",
              "array_append",
              "array_concat",
              "array_contains",
              "array_count",
              "array_distinct",
              "array_ifnull",
              "array_length",
              "array_max",
              "array_min",
              "array_position",
              "array_prepend",
              "array_put",
              "array_range",
              "array_remove",
              "array_repeat",
              "array_replace",
              "array_reverse",
              "array_sort",
              "array_sum",
              "avg",
              "count",
              "max",
              "min",
              "sum",
              "greatest",
              "least",
              "ifmissing",
              "ifmissingornull",
              "ifnull",
              "missingif",
              "nullif",
              "ifinf",
              "ifnan",
              "ifnanorinf",
              "naninf",
              "neginfif",
              "posinfif",
              "clock_millis",
              "clock_str",
              "date_add_millis",
              "date_add_str",
              "date_diff_millis",
              "date_diff_str",
              "date_part_millis",
              "date_part_str",
              "date_trunc_millis",
              "date_trunc_str",
              "duration_to_str",
              "millis",
              "str_to_millis",
              "millis_to_str",
              "millis_to_utc",
              "millis_to_zone_name",
              "now_millis",
              "now_str",
              "str_to_duration",
              "str_to_utc",
              "str_to_zone_name",
              "decode_json",
              "encode_json",
              "encoded_size",
              "poly_length",
              "base64",
              "base64_encode",
              "base64_decode",
              "meta",
              "uuid",
              "abs",
              "acos",
              "asin",
              "atan",
              "atan2",
              "ceil",
              "cos",
              "degrees",
              "e",
              "exp",
              "ln",
              "log",
              "floor",
              "pi",
              "power",
              "radians",
              "random",
              "round",
              "sign",
              "sin",
              "sqrt",
              "tan",
              "trunc",
              "object_length",
              "object_names",
              "object_pairs",
              "object_inner_pairs",
              "object_values",
              "object_inner_values",
              "object_add",
              "object_put",
              "object_remove",
              "object_unwrap",
              "regexp_contains",
              "regexp_like",
              "regexp_position",
              "regexp_replace",
              "contains",
              "initcap",
              "length",
              "lower",
              "ltrim",
              "position",
              "repeat",
              "replace",
              "rtrim",
              "split",
              "substr",
              "title",
              "trim",
              "upper",
              "isarray",
              "isatom",
              "isboolean",
              "isnumber",
              "isobject",
              "isstring",
              "type",
              "toarray",
              "toatom",
              "toboolean",
              "tonumber",
              "toobject",
              "tostring"
            ]
          },
          contains: [
            {
              className: "string",
              begin: "'",
              end: "'",
              contains: [t.BACKSLASH_ESCAPE]
            },
            {
              className: "string",
              begin: '"',
              end: '"',
              contains: [t.BACKSLASH_ESCAPE]
            },
            {
              className: "symbol",
              begin: "`",
              end: "`",
              contains: [t.BACKSLASH_ESCAPE]
            },
            t.C_NUMBER_MODE,
            t.C_BLOCK_COMMENT_MODE
          ]
        },
        t.C_BLOCK_COMMENT_MODE
      ]
    };
  }
  return AS = e, AS;
}
var OS, LI;
function qJ() {
  if (LI) return OS;
  LI = 1;
  function e(t) {
    const n = {
      match: [
        /^\s*(?=\S)/,
        // have to look forward here to avoid polynomial backtracking
        /[^:]+/,
        /:\s*/,
        /$/
      ],
      className: {
        2: "attribute",
        3: "punctuation"
      }
    }, r = {
      match: [
        /^\s*(?=\S)/,
        // have to look forward here to avoid polynomial backtracking
        /[^:]*[^: ]/,
        /[ ]*:/,
        /[ ]/,
        /.*$/
      ],
      className: {
        2: "attribute",
        3: "punctuation",
        5: "string"
      }
    }, i = {
      match: [
        /^\s*/,
        />/,
        /[ ]/,
        /.*$/
      ],
      className: {
        2: "punctuation",
        4: "string"
      }
    }, a = {
      variants: [
        { match: [
          /^\s*/,
          /-/,
          /[ ]/,
          /.*$/
        ] },
        { match: [
          /^\s*/,
          /-$/
        ] }
      ],
      className: {
        2: "bullet",
        4: "string"
      }
    };
    return {
      name: "Nested Text",
      aliases: ["nt"],
      contains: [
        t.inherit(t.HASH_COMMENT_MODE, {
          begin: /^\s*(?=#)/,
          excludeBegin: !0
        }),
        a,
        i,
        n,
        r
      ]
    };
  }
  return OS = e, OS;
}
var RS, kI;
function GJ() {
  if (kI) return RS;
  kI = 1;
  function e(t) {
    const n = t.regex, r = {
      className: "variable",
      variants: [
        { begin: /\$\d+/ },
        { begin: /\$\{\w+\}/ },
        { begin: n.concat(/[$@]/, t.UNDERSCORE_IDENT_RE) }
      ]
    }, a = {
      endsWithParent: !0,
      keywords: {
        $pattern: /[a-z_]{2,}|\/dev\/poll/,
        literal: [
          "on",
          "off",
          "yes",
          "no",
          "true",
          "false",
          "none",
          "blocked",
          "debug",
          "info",
          "notice",
          "warn",
          "error",
          "crit",
          "select",
          "break",
          "last",
          "permanent",
          "redirect",
          "kqueue",
          "rtsig",
          "epoll",
          "poll",
          "/dev/poll"
        ]
      },
      relevance: 0,
      illegal: "=>",
      contains: [
        t.HASH_COMMENT_MODE,
        {
          className: "string",
          contains: [
            t.BACKSLASH_ESCAPE,
            r
          ],
          variants: [
            {
              begin: /"/,
              end: /"/
            },
            {
              begin: /'/,
              end: /'/
            }
          ]
        },
        // this swallows entire URLs to avoid detecting numbers within
        {
          begin: "([a-z]+):/",
          end: "\\s",
          endsWithParent: !0,
          excludeEnd: !0,
          contains: [r]
        },
        {
          className: "regexp",
          contains: [
            t.BACKSLASH_ESCAPE,
            r
          ],
          variants: [
            {
              begin: "\\s\\^",
              end: "\\s|\\{|;",
              returnEnd: !0
            },
            // regexp locations (~, ~*)
            {
              begin: "~\\*?\\s+",
              end: "\\s|\\{|;",
              returnEnd: !0
            },
            // *.example.com
            { begin: "\\*(\\.[a-z\\-]+)+" },
            // sub.example.*
            { begin: "([a-z\\-]+\\.)+\\*" }
          ]
        },
        // IP
        {
          className: "number",
          begin: "\\b\\d{1,3}\\.\\d{1,3}\\.\\d{1,3}\\.\\d{1,3}(:\\d{1,5})?\\b"
        },
        // units
        {
          className: "number",
          begin: "\\b\\d+[kKmMgGdshdwy]?\\b",
          relevance: 0
        },
        r
      ]
    };
    return {
      name: "Nginx config",
      aliases: ["nginxconf"],
      contains: [
        t.HASH_COMMENT_MODE,
        {
          beginKeywords: "upstream location",
          end: /;|\{/,
          contains: a.contains,
          keywords: { section: "upstream location" }
        },
        {
          className: "section",
          begin: n.concat(t.UNDERSCORE_IDENT_RE + n.lookahead(/\s+\{/)),
          relevance: 0
        },
        {
          begin: n.lookahead(t.UNDERSCORE_IDENT_RE + "\\s"),
          end: ";|\\{",
          contains: [
            {
              className: "attribute",
              begin: t.UNDERSCORE_IDENT_RE,
              starts: a
            }
          ],
          relevance: 0
        }
      ],
      illegal: "[^\\s\\}\\{]"
    };
  }
  return RS = e, RS;
}
var wS, MI;
function YJ() {
  if (MI) return wS;
  MI = 1;
  function e(t) {
    return {
      name: "Nim",
      keywords: {
        keyword: [
          "addr",
          "and",
          "as",
          "asm",
          "bind",
          "block",
          "break",
          "case",
          "cast",
          "const",
          "continue",
          "converter",
          "discard",
          "distinct",
          "div",
          "do",
          "elif",
          "else",
          "end",
          "enum",
          "except",
          "export",
          "finally",
          "for",
          "from",
          "func",
          "generic",
          "guarded",
          "if",
          "import",
          "in",
          "include",
          "interface",
          "is",
          "isnot",
          "iterator",
          "let",
          "macro",
          "method",
          "mixin",
          "mod",
          "nil",
          "not",
          "notin",
          "object",
          "of",
          "or",
          "out",
          "proc",
          "ptr",
          "raise",
          "ref",
          "return",
          "shared",
          "shl",
          "shr",
          "static",
          "template",
          "try",
          "tuple",
          "type",
          "using",
          "var",
          "when",
          "while",
          "with",
          "without",
          "xor",
          "yield"
        ],
        literal: [
          "true",
          "false"
        ],
        type: [
          "int",
          "int8",
          "int16",
          "int32",
          "int64",
          "uint",
          "uint8",
          "uint16",
          "uint32",
          "uint64",
          "float",
          "float32",
          "float64",
          "bool",
          "char",
          "string",
          "cstring",
          "pointer",
          "expr",
          "stmt",
          "void",
          "auto",
          "any",
          "range",
          "array",
          "openarray",
          "varargs",
          "seq",
          "set",
          "clong",
          "culong",
          "cchar",
          "cschar",
          "cshort",
          "cint",
          "csize",
          "clonglong",
          "cfloat",
          "cdouble",
          "clongdouble",
          "cuchar",
          "cushort",
          "cuint",
          "culonglong",
          "cstringarray",
          "semistatic"
        ],
        built_in: [
          "stdin",
          "stdout",
          "stderr",
          "result"
        ]
      },
      contains: [
        {
          className: "meta",
          // Actually pragma
          begin: /\{\./,
          end: /\.\}/,
          relevance: 10
        },
        {
          className: "string",
          begin: /[a-zA-Z]\w*"/,
          end: /"/,
          contains: [{ begin: /""/ }]
        },
        {
          className: "string",
          begin: /([a-zA-Z]\w*)?"""/,
          end: /"""/
        },
        t.QUOTE_STRING_MODE,
        {
          className: "type",
          begin: /\b[A-Z]\w+\b/,
          relevance: 0
        },
        {
          className: "number",
          relevance: 0,
          variants: [
            { begin: /\b(0[xX][0-9a-fA-F][_0-9a-fA-F]*)('?[iIuU](8|16|32|64))?/ },
            { begin: /\b(0o[0-7][_0-7]*)('?[iIuUfF](8|16|32|64))?/ },
            { begin: /\b(0(b|B)[01][_01]*)('?[iIuUfF](8|16|32|64))?/ },
            { begin: /\b(\d[_\d]*)('?[iIuUfF](8|16|32|64))?/ }
          ]
        },
        t.HASH_COMMENT_MODE
      ]
    };
  }
  return wS = e, wS;
}
var xS, PI;
function HJ() {
  if (PI) return xS;
  PI = 1;
  function e(t) {
    const n = {
      keyword: [
        "rec",
        "with",
        "let",
        "in",
        "inherit",
        "assert",
        "if",
        "else",
        "then"
      ],
      literal: [
        "true",
        "false",
        "or",
        "and",
        "null"
      ],
      built_in: [
        "import",
        "abort",
        "baseNameOf",
        "dirOf",
        "isNull",
        "builtins",
        "map",
        "removeAttrs",
        "throw",
        "toString",
        "derivation"
      ]
    }, r = {
      className: "subst",
      begin: /\$\{/,
      end: /\}/,
      keywords: n
    }, i = {
      className: "char.escape",
      begin: /''\$/
    }, a = {
      begin: /[a-zA-Z0-9-_]+(\s*=)/,
      returnBegin: !0,
      relevance: 0,
      contains: [
        {
          className: "attr",
          begin: /\S+/,
          relevance: 0.2
        }
      ]
    }, o = {
      className: "string",
      contains: [i, r],
      variants: [
        {
          begin: "''",
          end: "''"
        },
        {
          begin: '"',
          end: '"'
        }
      ]
    }, s = [
      t.NUMBER_MODE,
      t.HASH_COMMENT_MODE,
      t.C_BLOCK_COMMENT_MODE,
      o,
      a
    ];
    return r.contains = s, {
      name: "Nix",
      aliases: ["nixos"],
      keywords: n,
      contains: s
    };
  }
  return xS = e, xS;
}
var NS, FI;
function zJ() {
  if (FI) return NS;
  FI = 1;
  function e(t) {
    return {
      name: "Node REPL",
      contains: [
        {
          className: "meta.prompt",
          starts: {
            // a space separates the REPL prefix from the actual code
            // this is purely for cleaner HTML output
            end: / |$/,
            starts: {
              end: "$",
              subLanguage: "javascript"
            }
          },
          variants: [
            { begin: /^>(?=[ ]|$)/ },
            { begin: /^\.\.\.(?=[ ]|$)/ }
          ]
        }
      ]
    };
  }
  return NS = e, NS;
}
var DS, BI;
function VJ() {
  if (BI) return DS;
  BI = 1;
  function e(t) {
    const n = t.regex, r = [
      "ADMINTOOLS",
      "APPDATA",
      "CDBURN_AREA",
      "CMDLINE",
      "COMMONFILES32",
      "COMMONFILES64",
      "COMMONFILES",
      "COOKIES",
      "DESKTOP",
      "DOCUMENTS",
      "EXEDIR",
      "EXEFILE",
      "EXEPATH",
      "FAVORITES",
      "FONTS",
      "HISTORY",
      "HWNDPARENT",
      "INSTDIR",
      "INTERNET_CACHE",
      "LANGUAGE",
      "LOCALAPPDATA",
      "MUSIC",
      "NETHOOD",
      "OUTDIR",
      "PICTURES",
      "PLUGINSDIR",
      "PRINTHOOD",
      "PROFILE",
      "PROGRAMFILES32",
      "PROGRAMFILES64",
      "PROGRAMFILES",
      "QUICKLAUNCH",
      "RECENT",
      "RESOURCES_LOCALIZED",
      "RESOURCES",
      "SENDTO",
      "SMPROGRAMS",
      "SMSTARTUP",
      "STARTMENU",
      "SYSDIR",
      "TEMP",
      "TEMPLATES",
      "VIDEOS",
      "WINDIR"
    ], i = [
      "ARCHIVE",
      "FILE_ATTRIBUTE_ARCHIVE",
      "FILE_ATTRIBUTE_NORMAL",
      "FILE_ATTRIBUTE_OFFLINE",
      "FILE_ATTRIBUTE_READONLY",
      "FILE_ATTRIBUTE_SYSTEM",
      "FILE_ATTRIBUTE_TEMPORARY",
      "HKCR",
      "HKCU",
      "HKDD",
      "HKEY_CLASSES_ROOT",
      "HKEY_CURRENT_CONFIG",
      "HKEY_CURRENT_USER",
      "HKEY_DYN_DATA",
      "HKEY_LOCAL_MACHINE",
      "HKEY_PERFORMANCE_DATA",
      "HKEY_USERS",
      "HKLM",
      "HKPD",
      "HKU",
      "IDABORT",
      "IDCANCEL",
      "IDIGNORE",
      "IDNO",
      "IDOK",
      "IDRETRY",
      "IDYES",
      "MB_ABORTRETRYIGNORE",
      "MB_DEFBUTTON1",
      "MB_DEFBUTTON2",
      "MB_DEFBUTTON3",
      "MB_DEFBUTTON4",
      "MB_ICONEXCLAMATION",
      "MB_ICONINFORMATION",
      "MB_ICONQUESTION",
      "MB_ICONSTOP",
      "MB_OK",
      "MB_OKCANCEL",
      "MB_RETRYCANCEL",
      "MB_RIGHT",
      "MB_RTLREADING",
      "MB_SETFOREGROUND",
      "MB_TOPMOST",
      "MB_USERICON",
      "MB_YESNO",
      "NORMAL",
      "OFFLINE",
      "READONLY",
      "SHCTX",
      "SHELL_CONTEXT",
      "SYSTEM|TEMPORARY"
    ], a = [
      "addincludedir",
      "addplugindir",
      "appendfile",
      "assert",
      "cd",
      "define",
      "delfile",
      "echo",
      "else",
      "endif",
      "error",
      "execute",
      "finalize",
      "getdllversion",
      "gettlbversion",
      "if",
      "ifdef",
      "ifmacrodef",
      "ifmacrondef",
      "ifndef",
      "include",
      "insertmacro",
      "macro",
      "macroend",
      "makensis",
      "packhdr",
      "searchparse",
      "searchreplace",
      "system",
      "tempfile",
      "undef",
      "uninstfinalize",
      "verbose",
      "warning"
    ], o = {
      className: "variable.constant",
      begin: n.concat(/\$/, n.either(...r))
    }, s = {
      // ${defines}
      className: "variable",
      begin: /\$+\{[\!\w.:-]+\}/
    }, l = {
      // $variables
      className: "variable",
      begin: /\$+\w[\w\.]*/,
      illegal: /\(\)\{\}/
    }, u = {
      // $(language_strings)
      className: "variable",
      begin: /\$+\([\w^.:!-]+\)/
    }, c = {
      // command parameters
      className: "params",
      begin: n.either(...i)
    }, d = {
      // !compiler_flags
      className: "keyword",
      begin: n.concat(
        /!/,
        n.either(...a)
      )
    }, f = {
      // $\n, $\r, $\t, $$
      className: "char.escape",
      begin: /\$(\\[nrt]|\$)/
    }, h = {
      // plug::ins
      className: "title.function",
      begin: /\w+::\w+/
    }, m = {
      className: "string",
      variants: [
        {
          begin: '"',
          end: '"'
        },
        {
          begin: "'",
          end: "'"
        },
        {
          begin: "`",
          end: "`"
        }
      ],
      illegal: /\n/,
      contains: [
        f,
        o,
        s,
        l,
        u
      ]
    }, v = [
      "Abort",
      "AddBrandingImage",
      "AddSize",
      "AllowRootDirInstall",
      "AllowSkipFiles",
      "AutoCloseWindow",
      "BGFont",
      "BGGradient",
      "BrandingText",
      "BringToFront",
      "Call",
      "CallInstDLL",
      "Caption",
      "ChangeUI",
      "CheckBitmap",
      "ClearErrors",
      "CompletedText",
      "ComponentText",
      "CopyFiles",
      "CRCCheck",
      "CreateDirectory",
      "CreateFont",
      "CreateShortCut",
      "Delete",
      "DeleteINISec",
      "DeleteINIStr",
      "DeleteRegKey",
      "DeleteRegValue",
      "DetailPrint",
      "DetailsButtonText",
      "DirText",
      "DirVar",
      "DirVerify",
      "EnableWindow",
      "EnumRegKey",
      "EnumRegValue",
      "Exch",
      "Exec",
      "ExecShell",
      "ExecShellWait",
      "ExecWait",
      "ExpandEnvStrings",
      "File",
      "FileBufSize",
      "FileClose",
      "FileErrorText",
      "FileOpen",
      "FileRead",
      "FileReadByte",
      "FileReadUTF16LE",
      "FileReadWord",
      "FileWriteUTF16LE",
      "FileSeek",
      "FileWrite",
      "FileWriteByte",
      "FileWriteWord",
      "FindClose",
      "FindFirst",
      "FindNext",
      "FindWindow",
      "FlushINI",
      "GetCurInstType",
      "GetCurrentAddress",
      "GetDlgItem",
      "GetDLLVersion",
      "GetDLLVersionLocal",
      "GetErrorLevel",
      "GetFileTime",
      "GetFileTimeLocal",
      "GetFullPathName",
      "GetFunctionAddress",
      "GetInstDirError",
      "GetKnownFolderPath",
      "GetLabelAddress",
      "GetTempFileName",
      "GetWinVer",
      "Goto",
      "HideWindow",
      "Icon",
      "IfAbort",
      "IfErrors",
      "IfFileExists",
      "IfRebootFlag",
      "IfRtlLanguage",
      "IfShellVarContextAll",
      "IfSilent",
      "InitPluginsDir",
      "InstallButtonText",
      "InstallColors",
      "InstallDir",
      "InstallDirRegKey",
      "InstProgressFlags",
      "InstType",
      "InstTypeGetText",
      "InstTypeSetText",
      "Int64Cmp",
      "Int64CmpU",
      "Int64Fmt",
      "IntCmp",
      "IntCmpU",
      "IntFmt",
      "IntOp",
      "IntPtrCmp",
      "IntPtrCmpU",
      "IntPtrOp",
      "IsWindow",
      "LangString",
      "LicenseBkColor",
      "LicenseData",
      "LicenseForceSelection",
      "LicenseLangString",
      "LicenseText",
      "LoadAndSetImage",
      "LoadLanguageFile",
      "LockWindow",
      "LogSet",
      "LogText",
      "ManifestDPIAware",
      "ManifestLongPathAware",
      "ManifestMaxVersionTested",
      "ManifestSupportedOS",
      "MessageBox",
      "MiscButtonText",
      "Name|0",
      "Nop",
      "OutFile",
      "Page",
      "PageCallbacks",
      "PEAddResource",
      "PEDllCharacteristics",
      "PERemoveResource",
      "PESubsysVer",
      "Pop",
      "Push",
      "Quit",
      "ReadEnvStr",
      "ReadINIStr",
      "ReadRegDWORD",
      "ReadRegStr",
      "Reboot",
      "RegDLL",
      "Rename",
      "RequestExecutionLevel",
      "ReserveFile",
      "Return",
      "RMDir",
      "SearchPath",
      "SectionGetFlags",
      "SectionGetInstTypes",
      "SectionGetSize",
      "SectionGetText",
      "SectionIn",
      "SectionSetFlags",
      "SectionSetInstTypes",
      "SectionSetSize",
      "SectionSetText",
      "SendMessage",
      "SetAutoClose",
      "SetBrandingImage",
      "SetCompress",
      "SetCompressor",
      "SetCompressorDictSize",
      "SetCtlColors",
      "SetCurInstType",
      "SetDatablockOptimize",
      "SetDateSave",
      "SetDetailsPrint",
      "SetDetailsView",
      "SetErrorLevel",
      "SetErrors",
      "SetFileAttributes",
      "SetFont",
      "SetOutPath",
      "SetOverwrite",
      "SetRebootFlag",
      "SetRegView",
      "SetShellVarContext",
      "SetSilent",
      "ShowInstDetails",
      "ShowUninstDetails",
      "ShowWindow",
      "SilentInstall",
      "SilentUnInstall",
      "Sleep",
      "SpaceTexts",
      "StrCmp",
      "StrCmpS",
      "StrCpy",
      "StrLen",
      "SubCaption",
      "Unicode",
      "UninstallButtonText",
      "UninstallCaption",
      "UninstallIcon",
      "UninstallSubCaption",
      "UninstallText",
      "UninstPage",
      "UnRegDLL",
      "Var",
      "VIAddVersionKey",
      "VIFileVersion",
      "VIProductVersion",
      "WindowIcon",
      "WriteINIStr",
      "WriteRegBin",
      "WriteRegDWORD",
      "WriteRegExpandStr",
      "WriteRegMultiStr",
      "WriteRegNone",
      "WriteRegStr",
      "WriteUninstaller",
      "XPStyle"
    ], b = [
      "admin",
      "all",
      "auto",
      "both",
      "bottom",
      "bzip2",
      "colored",
      "components",
      "current",
      "custom",
      "directory",
      "false",
      "force",
      "hide",
      "highest",
      "ifdiff",
      "ifnewer",
      "instfiles",
      "lastused",
      "leave",
      "left",
      "license",
      "listonly",
      "lzma",
      "nevershow",
      "none",
      "normal",
      "notset",
      "off",
      "on",
      "open",
      "print",
      "right",
      "show",
      "silent",
      "silentlog",
      "smooth",
      "textonly",
      "top",
      "true",
      "try",
      "un.components",
      "un.custom",
      "un.directory",
      "un.instfiles",
      "un.license",
      "uninstConfirm",
      "user",
      "Win10",
      "Win7",
      "Win8",
      "WinVista",
      "zlib"
    ], y = {
      match: [
        /Function/,
        /\s+/,
        n.concat(/(\.)?/, t.IDENT_RE)
      ],
      scope: {
        1: "keyword",
        3: "title.function"
      }
    }, E = {
      match: [
        /Var/,
        /\s+/,
        /(?:\/GLOBAL\s+)?/,
        /[A-Za-z][\w.]*/
      ],
      scope: {
        1: "keyword",
        3: "params",
        4: "variable"
      }
    };
    return {
      name: "NSIS",
      case_insensitive: !0,
      keywords: {
        keyword: v,
        literal: b
      },
      contains: [
        t.HASH_COMMENT_MODE,
        t.C_BLOCK_COMMENT_MODE,
        t.COMMENT(
          ";",
          "$",
          { relevance: 0 }
        ),
        E,
        y,
        { beginKeywords: "Function PageEx Section SectionGroup FunctionEnd SectionEnd" },
        m,
        d,
        s,
        l,
        u,
        c,
        h,
        t.NUMBER_MODE
      ]
    };
  }
  return DS = e, DS;
}
var IS, $I;
function WJ() {
  if ($I) return IS;
  $I = 1;
  function e(t) {
    const n = {
      className: "built_in",
      begin: "\\b(AV|CA|CF|CG|CI|CL|CM|CN|CT|MK|MP|MTK|MTL|NS|SCN|SK|UI|WK|XC)\\w+"
    }, r = /[a-zA-Z@][a-zA-Z0-9_]*/, l = {
      "variable.language": [
        "this",
        "super"
      ],
      $pattern: r,
      keyword: [
        "while",
        "export",
        "sizeof",
        "typedef",
        "const",
        "struct",
        "for",
        "union",
        "volatile",
        "static",
        "mutable",
        "if",
        "do",
        "return",
        "goto",
        "enum",
        "else",
        "break",
        "extern",
        "asm",
        "case",
        "default",
        "register",
        "explicit",
        "typename",
        "switch",
        "continue",
        "inline",
        "readonly",
        "assign",
        "readwrite",
        "self",
        "@synchronized",
        "id",
        "typeof",
        "nonatomic",
        "IBOutlet",
        "IBAction",
        "strong",
        "weak",
        "copy",
        "in",
        "out",
        "inout",
        "bycopy",
        "byref",
        "oneway",
        "__strong",
        "__weak",
        "__block",
        "__autoreleasing",
        "@private",
        "@protected",
        "@public",
        "@try",
        "@property",
        "@end",
        "@throw",
        "@catch",
        "@finally",
        "@autoreleasepool",
        "@synthesize",
        "@dynamic",
        "@selector",
        "@optional",
        "@required",
        "@encode",
        "@package",
        "@import",
        "@defs",
        "@compatibility_alias",
        "__bridge",
        "__bridge_transfer",
        "__bridge_retained",
        "__bridge_retain",
        "__covariant",
        "__contravariant",
        "__kindof",
        "_Nonnull",
        "_Nullable",
        "_Null_unspecified",
        "__FUNCTION__",
        "__PRETTY_FUNCTION__",
        "__attribute__",
        "getter",
        "setter",
        "retain",
        "unsafe_unretained",
        "nonnull",
        "nullable",
        "null_unspecified",
        "null_resettable",
        "class",
        "instancetype",
        "NS_DESIGNATED_INITIALIZER",
        "NS_UNAVAILABLE",
        "NS_REQUIRES_SUPER",
        "NS_RETURNS_INNER_POINTER",
        "NS_INLINE",
        "NS_AVAILABLE",
        "NS_DEPRECATED",
        "NS_ENUM",
        "NS_OPTIONS",
        "NS_SWIFT_UNAVAILABLE",
        "NS_ASSUME_NONNULL_BEGIN",
        "NS_ASSUME_NONNULL_END",
        "NS_REFINED_FOR_SWIFT",
        "NS_SWIFT_NAME",
        "NS_SWIFT_NOTHROW",
        "NS_DURING",
        "NS_HANDLER",
        "NS_ENDHANDLER",
        "NS_VALUERETURN",
        "NS_VOIDRETURN"
      ],
      literal: [
        "false",
        "true",
        "FALSE",
        "TRUE",
        "nil",
        "YES",
        "NO",
        "NULL"
      ],
      built_in: [
        "dispatch_once_t",
        "dispatch_queue_t",
        "dispatch_sync",
        "dispatch_async",
        "dispatch_once"
      ],
      type: [
        "int",
        "float",
        "char",
        "unsigned",
        "signed",
        "short",
        "long",
        "double",
        "wchar_t",
        "unichar",
        "void",
        "bool",
        "BOOL",
        "id|0",
        "_Bool"
      ]
    }, u = {
      $pattern: r,
      keyword: [
        "@interface",
        "@class",
        "@protocol",
        "@implementation"
      ]
    };
    return {
      name: "Objective-C",
      aliases: [
        "mm",
        "objc",
        "obj-c",
        "obj-c++",
        "objective-c++"
      ],
      keywords: l,
      illegal: "</",
      contains: [
        n,
        t.C_LINE_COMMENT_MODE,
        t.C_BLOCK_COMMENT_MODE,
        t.C_NUMBER_MODE,
        t.QUOTE_STRING_MODE,
        t.APOS_STRING_MODE,
        {
          className: "string",
          variants: [
            {
              begin: '@"',
              end: '"',
              illegal: "\\n",
              contains: [t.BACKSLASH_ESCAPE]
            }
          ]
        },
        {
          className: "meta",
          begin: /#\s*[a-z]+\b/,
          end: /$/,
          keywords: { keyword: "if else elif endif define undef warning error line pragma ifdef ifndef include" },
          contains: [
            {
              begin: /\\\n/,
              relevance: 0
            },
            t.inherit(t.QUOTE_STRING_MODE, { className: "string" }),
            {
              className: "string",
              begin: /<.*?>/,
              end: /$/,
              illegal: "\\n"
            },
            t.C_LINE_COMMENT_MODE,
            t.C_BLOCK_COMMENT_MODE
          ]
        },
        {
          className: "class",
          begin: "(" + u.keyword.join("|") + ")\\b",
          end: /(\{|$)/,
          excludeEnd: !0,
          keywords: u,
          contains: [t.UNDERSCORE_TITLE_MODE]
        },
        {
          begin: "\\." + t.UNDERSCORE_IDENT_RE,
          relevance: 0
        }
      ]
    };
  }
  return IS = e, IS;
}
var LS, UI;
function KJ() {
  if (UI) return LS;
  UI = 1;
  function e(t) {
    return {
      name: "OCaml",
      aliases: ["ml"],
      keywords: {
        $pattern: "[a-z_]\\w*!?",
        keyword: "and as assert asr begin class constraint do done downto else end exception external for fun function functor if in include inherit! inherit initializer land lazy let lor lsl lsr lxor match method!|10 method mod module mutable new object of open! open or private rec sig struct then to try type val! val virtual when while with parser value",
        built_in: (
          /* built-in types */
          "array bool bytes char exn|5 float int int32 int64 list lazy_t|5 nativeint|5 string unit in_channel out_channel ref"
        ),
        literal: "true false"
      },
      illegal: /\/\/|>>/,
      contains: [
        {
          className: "literal",
          begin: "\\[(\\|\\|)?\\]|\\(\\)",
          relevance: 0
        },
        t.COMMENT(
          "\\(\\*",
          "\\*\\)",
          { contains: ["self"] }
        ),
        {
          /* type variable */
          className: "symbol",
          begin: "'[A-Za-z_](?!')[\\w']*"
          /* the grammar is ambiguous on how 'a'b should be interpreted but not the compiler */
        },
        {
          /* polymorphic variant */
          className: "type",
          begin: "`[A-Z][\\w']*"
        },
        {
          /* module or constructor */
          className: "type",
          begin: "\\b[A-Z][\\w']*",
          relevance: 0
        },
        {
          /* don't color identifiers, but safely catch all identifiers with ' */
          begin: "[a-z_]\\w*'[\\w']*",
          relevance: 0
        },
        t.inherit(t.APOS_STRING_MODE, {
          className: "string",
          relevance: 0
        }),
        t.inherit(t.QUOTE_STRING_MODE, { illegal: null }),
        {
          className: "number",
          begin: "\\b(0[xX][a-fA-F0-9_]+[Lln]?|0[oO][0-7_]+[Lln]?|0[bB][01_]+[Lln]?|[0-9][0-9_]*([Lln]|(\\.[0-9_]*)?([eE][-+]?[0-9_]+)?)?)",
          relevance: 0
        },
        {
          begin: /->/
          // relevance booster
        }
      ]
    };
  }
  return LS = e, LS;
}
var kS, qI;
function jJ() {
  if (qI) return kS;
  qI = 1;
  function e(t) {
    const n = {
      className: "keyword",
      begin: "\\$(f[asn]|t|vp[rtd]|children)"
    }, r = {
      className: "literal",
      begin: "false|true|PI|undef"
    }, i = {
      className: "number",
      begin: "\\b\\d+(\\.\\d+)?(e-?\\d+)?",
      // adds 1e5, 1e-10
      relevance: 0
    }, a = t.inherit(t.QUOTE_STRING_MODE, { illegal: null }), o = {
      className: "meta",
      keywords: { keyword: "include use" },
      begin: "include|use <",
      end: ">"
    }, s = {
      className: "params",
      begin: "\\(",
      end: "\\)",
      contains: [
        "self",
        i,
        a,
        n,
        r
      ]
    }, l = {
      begin: "[*!#%]",
      relevance: 0
    }, u = {
      className: "function",
      beginKeywords: "module function",
      end: /=|\{/,
      contains: [
        s,
        t.UNDERSCORE_TITLE_MODE
      ]
    };
    return {
      name: "OpenSCAD",
      aliases: ["scad"],
      keywords: {
        keyword: "function module include use for intersection_for if else \\%",
        literal: "false true PI undef",
        built_in: "circle square polygon text sphere cube cylinder polyhedron translate rotate scale resize mirror multmatrix color offset hull minkowski union difference intersection abs sign sin cos tan acos asin atan atan2 floor round ceil ln log pow sqrt exp rands min max concat lookup str chr search version version_num norm cross parent_module echo import import_dxf dxf_linear_extrude linear_extrude rotate_extrude surface projection render children dxf_cross dxf_dim let assign"
      },
      contains: [
        t.C_LINE_COMMENT_MODE,
        t.C_BLOCK_COMMENT_MODE,
        i,
        o,
        a,
        n,
        l,
        u
      ]
    };
  }
  return kS = e, kS;
}
var MS, GI;
function QJ() {
  if (GI) return MS;
  GI = 1;
  function e(t) {
    const n = {
      $pattern: /\.?\w+/,
      keyword: "abstract add and array as asc aspect assembly async begin break block by case class concat const copy constructor continue create default delegate desc distinct div do downto dynamic each else empty end ensure enum equals event except exit extension external false final finalize finalizer finally flags for forward from function future global group has if implementation implements implies in index inherited inline interface into invariants is iterator join locked locking loop matching method mod module namespace nested new nil not notify nullable of old on operator or order out override parallel params partial pinned private procedure property protected public queryable raise read readonly record reintroduce remove repeat require result reverse sealed select self sequence set shl shr skip static step soft take then to true try tuple type union unit unsafe until uses using var virtual raises volatile where while with write xor yield await mapped deprecated stdcall cdecl pascal register safecall overload library platform reference packed strict published autoreleasepool selector strong weak unretained"
    }, r = t.COMMENT(
      /\{/,
      /\}/,
      { relevance: 0 }
    ), i = t.COMMENT(
      "\\(\\*",
      "\\*\\)",
      { relevance: 10 }
    ), a = {
      className: "string",
      begin: "'",
      end: "'",
      contains: [{ begin: "''" }]
    }, o = {
      className: "string",
      begin: "(#\\d+)+"
    }, s = {
      beginKeywords: "function constructor destructor procedure method",
      end: "[:;]",
      keywords: "function constructor|10 destructor|10 procedure|10 method|10",
      contains: [
        t.inherit(t.TITLE_MODE, { scope: "title.function" }),
        {
          className: "params",
          begin: "\\(",
          end: "\\)",
          keywords: n,
          contains: [
            a,
            o
          ]
        },
        r,
        i
      ]
    }, l = {
      scope: "punctuation",
      match: /;/,
      relevance: 0
    };
    return {
      name: "Oxygene",
      case_insensitive: !0,
      keywords: n,
      illegal: '("|\\$[G-Zg-z]|\\/\\*|</|=>|->)',
      contains: [
        r,
        i,
        t.C_LINE_COMMENT_MODE,
        a,
        o,
        t.NUMBER_MODE,
        s,
        l
      ]
    };
  }
  return MS = e, MS;
}
var PS, YI;
function XJ() {
  if (YI) return PS;
  YI = 1;
  function e(t) {
    const n = t.COMMENT(
      /\{/,
      /\}/,
      { contains: ["self"] }
    );
    return {
      name: "Parser3",
      subLanguage: "xml",
      relevance: 0,
      contains: [
        t.COMMENT("^#", "$"),
        t.COMMENT(
          /\^rem\{/,
          /\}/,
          {
            relevance: 10,
            contains: [n]
          }
        ),
        {
          className: "meta",
          begin: "^@(?:BASE|USE|CLASS|OPTIONS)$",
          relevance: 10
        },
        {
          className: "title",
          begin: "@[\\w\\-]+\\[[\\w^;\\-]*\\](?:\\[[\\w^;\\-]*\\])?(?:.*)$"
        },
        {
          className: "variable",
          begin: /\$\{?[\w\-.:]+\}?/
        },
        {
          className: "keyword",
          begin: /\^[\w\-.:]+/
        },
        {
          className: "number",
          begin: "\\^#[0-9a-fA-F]+"
        },
        t.C_NUMBER_MODE
      ]
    };
  }
  return PS = e, PS;
}
var FS, HI;
function ZJ() {
  if (HI) return FS;
  HI = 1;
  function e(t) {
    const n = {
      className: "variable",
      begin: /\$[\w\d#@][\w\d_]*/,
      relevance: 0
    }, r = {
      className: "variable",
      begin: /<(?!\/)/,
      end: />/
    };
    return {
      name: "Packet Filter config",
      aliases: ["pf.conf"],
      keywords: {
        $pattern: /[a-z0-9_<>-]+/,
        built_in: (
          /* block match pass are "actions" in pf.conf(5), the rest are
           * lexically similar top-level commands.
           */
          "block match pass load anchor|5 antispoof|10 set table"
        ),
        keyword: "in out log quick on rdomain inet inet6 proto from port os to route allow-opts divert-packet divert-reply divert-to flags group icmp-type icmp6-type label once probability recieved-on rtable prio queue tos tag tagged user keep fragment for os drop af-to|10 binat-to|10 nat-to|10 rdr-to|10 bitmask least-stats random round-robin source-hash static-port dup-to reply-to route-to parent bandwidth default min max qlimit block-policy debug fingerprints hostid limit loginterface optimization reassemble ruleset-optimization basic none profile skip state-defaults state-policy timeout const counters persist no modulate synproxy state|5 floating if-bound no-sync pflow|10 sloppy source-track global rule max-src-nodes max-src-states max-src-conn max-src-conn-rate overload flush scrub|5 max-mss min-ttl no-df|10 random-id",
        literal: "all any no-route self urpf-failed egress|5 unknown"
      },
      contains: [
        t.HASH_COMMENT_MODE,
        t.NUMBER_MODE,
        t.QUOTE_STRING_MODE,
        n,
        r
      ]
    };
  }
  return FS = e, FS;
}
var BS, zI;
function JJ() {
  if (zI) return BS;
  zI = 1;
  function e(t) {
    const n = t.COMMENT("--", "$"), r = "[a-zA-Z_][a-zA-Z_0-9$]*", i = "\\$([a-zA-Z_]?|[a-zA-Z_][a-zA-Z_0-9]*)\\$", a = "<<\\s*" + r + "\\s*>>", o = (
      // https://www.postgresql.org/docs/11/static/sql-keywords-appendix.html
      // https://www.postgresql.org/docs/11/static/sql-commands.html
      // SQL commands (starting words)
      "ABORT ALTER ANALYZE BEGIN CALL CHECKPOINT|10 CLOSE CLUSTER COMMENT COMMIT COPY CREATE DEALLOCATE DECLARE DELETE DISCARD DO DROP END EXECUTE EXPLAIN FETCH GRANT IMPORT INSERT LISTEN LOAD LOCK MOVE NOTIFY PREPARE REASSIGN|10 REFRESH REINDEX RELEASE RESET REVOKE ROLLBACK SAVEPOINT SECURITY SELECT SET SHOW START TRUNCATE UNLISTEN|10 UPDATE VACUUM|10 VALUES AGGREGATE COLLATION CONVERSION|10 DATABASE DEFAULT PRIVILEGES DOMAIN TRIGGER EXTENSION FOREIGN WRAPPER|10 TABLE FUNCTION GROUP LANGUAGE LARGE OBJECT MATERIALIZED VIEW OPERATOR CLASS FAMILY POLICY PUBLICATION|10 ROLE RULE SCHEMA SEQUENCE SERVER STATISTICS SUBSCRIPTION SYSTEM TABLESPACE CONFIGURATION DICTIONARY PARSER TEMPLATE TYPE USER MAPPING PREPARED ACCESS METHOD CAST AS TRANSFORM TRANSACTION OWNED TO INTO SESSION AUTHORIZATION INDEX PROCEDURE ASSERTION ALL ANALYSE AND ANY ARRAY ASC ASYMMETRIC|10 BOTH CASE CHECK COLLATE COLUMN CONCURRENTLY|10 CONSTRAINT CROSS DEFERRABLE RANGE DESC DISTINCT ELSE EXCEPT FOR FREEZE|10 FROM FULL HAVING ILIKE IN INITIALLY INNER INTERSECT IS ISNULL JOIN LATERAL LEADING LIKE LIMIT NATURAL NOT NOTNULL NULL OFFSET ON ONLY OR ORDER OUTER OVERLAPS PLACING PRIMARY REFERENCES RETURNING SIMILAR SOME SYMMETRIC TABLESAMPLE THEN TRAILING UNION UNIQUE USING VARIADIC|10 VERBOSE WHEN WHERE WINDOW WITH BY RETURNS INOUT OUT SETOF|10 IF STRICT CURRENT CONTINUE OWNER LOCATION OVER PARTITION WITHIN BETWEEN ESCAPE EXTERNAL INVOKER DEFINER WORK RENAME VERSION CONNECTION CONNECT TABLES TEMP TEMPORARY FUNCTIONS SEQUENCES TYPES SCHEMAS OPTION CASCADE RESTRICT ADD ADMIN EXISTS VALID VALIDATE ENABLE DISABLE REPLICA|10 ALWAYS PASSING COLUMNS PATH REF VALUE OVERRIDING IMMUTABLE STABLE VOLATILE BEFORE AFTER EACH ROW PROCEDURAL ROUTINE NO HANDLER VALIDATOR OPTIONS STORAGE OIDS|10 WITHOUT INHERIT DEPENDS CALLED INPUT LEAKPROOF|10 COST ROWS NOWAIT SEARCH UNTIL ENCRYPTED|10 PASSWORD CONFLICT|10 INSTEAD INHERITS CHARACTERISTICS WRITE CURSOR ALSO STATEMENT SHARE EXCLUSIVE INLINE ISOLATION REPEATABLE READ COMMITTED SERIALIZABLE UNCOMMITTED LOCAL GLOBAL SQL PROCEDURES RECURSIVE SNAPSHOT ROLLUP CUBE TRUSTED|10 INCLUDE FOLLOWING PRECEDING UNBOUNDED RANGE GROUPS UNENCRYPTED|10 SYSID FORMAT DELIMITER HEADER QUOTE ENCODING FILTER OFF FORCE_QUOTE FORCE_NOT_NULL FORCE_NULL COSTS BUFFERS TIMING SUMMARY DISABLE_PAGE_SKIPPING RESTART CYCLE GENERATED IDENTITY DEFERRED IMMEDIATE LEVEL LOGGED UNLOGGED OF NOTHING NONE EXCLUDE ATTRIBUTE USAGE ROUTINES TRUE FALSE NAN INFINITY "
    ), s = (
      // only those not in keywrods already
      "SUPERUSER NOSUPERUSER CREATEDB NOCREATEDB CREATEROLE NOCREATEROLE INHERIT NOINHERIT LOGIN NOLOGIN REPLICATION NOREPLICATION BYPASSRLS NOBYPASSRLS "
    ), l = "ALIAS BEGIN CONSTANT DECLARE END EXCEPTION RETURN PERFORM|10 RAISE GET DIAGNOSTICS STACKED|10 FOREACH LOOP ELSIF EXIT WHILE REVERSE SLICE DEBUG LOG INFO NOTICE WARNING ASSERT OPEN ", u = (
      // https://www.postgresql.org/docs/11/static/datatype.html
      "BIGINT INT8 BIGSERIAL SERIAL8 BIT VARYING VARBIT BOOLEAN BOOL BOX BYTEA CHARACTER CHAR VARCHAR CIDR CIRCLE DATE DOUBLE PRECISION FLOAT8 FLOAT INET INTEGER INT INT4 INTERVAL JSON JSONB LINE LSEG|10 MACADDR MACADDR8 MONEY NUMERIC DEC DECIMAL PATH POINT POLYGON REAL FLOAT4 SMALLINT INT2 SMALLSERIAL|10 SERIAL2|10 SERIAL|10 SERIAL4|10 TEXT TIME ZONE TIMETZ|10 TIMESTAMP TIMESTAMPTZ|10 TSQUERY|10 TSVECTOR|10 TXID_SNAPSHOT|10 UUID XML NATIONAL NCHAR INT4RANGE|10 INT8RANGE|10 NUMRANGE|10 TSRANGE|10 TSTZRANGE|10 DATERANGE|10 ANYELEMENT ANYARRAY ANYNONARRAY ANYENUM ANYRANGE CSTRING INTERNAL RECORD PG_DDL_COMMAND VOID UNKNOWN OPAQUE REFCURSOR NAME OID REGPROC|10 REGPROCEDURE|10 REGOPER|10 REGOPERATOR|10 REGCLASS|10 REGTYPE|10 REGROLE|10 REGNAMESPACE|10 REGCONFIG|10 REGDICTIONARY|10 "
    ), c = u.trim().split(" ").map(function(b) {
      return b.split("|")[0];
    }).join("|"), d = "CURRENT_TIME CURRENT_TIMESTAMP CURRENT_USER CURRENT_CATALOG|10 CURRENT_DATE LOCALTIME LOCALTIMESTAMP CURRENT_ROLE|10 CURRENT_SCHEMA|10 SESSION_USER PUBLIC ", f = "FOUND NEW OLD TG_NAME|10 TG_WHEN|10 TG_LEVEL|10 TG_OP|10 TG_RELID|10 TG_RELNAME|10 TG_TABLE_NAME|10 TG_TABLE_SCHEMA|10 TG_NARGS|10 TG_ARGV|10 TG_EVENT|10 TG_TAG|10 ROW_COUNT RESULT_OID|10 PG_CONTEXT|10 RETURNED_SQLSTATE COLUMN_NAME CONSTRAINT_NAME PG_DATATYPE_NAME|10 MESSAGE_TEXT TABLE_NAME SCHEMA_NAME PG_EXCEPTION_DETAIL|10 PG_EXCEPTION_HINT|10 PG_EXCEPTION_CONTEXT|10 ", h = (
      // exceptions https://www.postgresql.org/docs/current/static/errcodes-appendix.html
      "SQLSTATE SQLERRM|10 SUCCESSFUL_COMPLETION WARNING DYNAMIC_RESULT_SETS_RETURNED IMPLICIT_ZERO_BIT_PADDING NULL_VALUE_ELIMINATED_IN_SET_FUNCTION PRIVILEGE_NOT_GRANTED PRIVILEGE_NOT_REVOKED STRING_DATA_RIGHT_TRUNCATION DEPRECATED_FEATURE NO_DATA NO_ADDITIONAL_DYNAMIC_RESULT_SETS_RETURNED SQL_STATEMENT_NOT_YET_COMPLETE CONNECTION_EXCEPTION CONNECTION_DOES_NOT_EXIST CONNECTION_FAILURE SQLCLIENT_UNABLE_TO_ESTABLISH_SQLCONNECTION SQLSERVER_REJECTED_ESTABLISHMENT_OF_SQLCONNECTION TRANSACTION_RESOLUTION_UNKNOWN PROTOCOL_VIOLATION TRIGGERED_ACTION_EXCEPTION FEATURE_NOT_SUPPORTED INVALID_TRANSACTION_INITIATION LOCATOR_EXCEPTION INVALID_LOCATOR_SPECIFICATION INVALID_GRANTOR INVALID_GRANT_OPERATION INVALID_ROLE_SPECIFICATION DIAGNOSTICS_EXCEPTION STACKED_DIAGNOSTICS_ACCESSED_WITHOUT_ACTIVE_HANDLER CASE_NOT_FOUND CARDINALITY_VIOLATION DATA_EXCEPTION ARRAY_SUBSCRIPT_ERROR CHARACTER_NOT_IN_REPERTOIRE DATETIME_FIELD_OVERFLOW DIVISION_BY_ZERO ERROR_IN_ASSIGNMENT ESCAPE_CHARACTER_CONFLICT INDICATOR_OVERFLOW INTERVAL_FIELD_OVERFLOW INVALID_ARGUMENT_FOR_LOGARITHM INVALID_ARGUMENT_FOR_NTILE_FUNCTION INVALID_ARGUMENT_FOR_NTH_VALUE_FUNCTION INVALID_ARGUMENT_FOR_POWER_FUNCTION INVALID_ARGUMENT_FOR_WIDTH_BUCKET_FUNCTION INVALID_CHARACTER_VALUE_FOR_CAST INVALID_DATETIME_FORMAT INVALID_ESCAPE_CHARACTER INVALID_ESCAPE_OCTET INVALID_ESCAPE_SEQUENCE NONSTANDARD_USE_OF_ESCAPE_CHARACTER INVALID_INDICATOR_PARAMETER_VALUE INVALID_PARAMETER_VALUE INVALID_REGULAR_EXPRESSION INVALID_ROW_COUNT_IN_LIMIT_CLAUSE INVALID_ROW_COUNT_IN_RESULT_OFFSET_CLAUSE INVALID_TABLESAMPLE_ARGUMENT INVALID_TABLESAMPLE_REPEAT INVALID_TIME_ZONE_DISPLACEMENT_VALUE INVALID_USE_OF_ESCAPE_CHARACTER MOST_SPECIFIC_TYPE_MISMATCH NULL_VALUE_NOT_ALLOWED NULL_VALUE_NO_INDICATOR_PARAMETER NUMERIC_VALUE_OUT_OF_RANGE SEQUENCE_GENERATOR_LIMIT_EXCEEDED STRING_DATA_LENGTH_MISMATCH STRING_DATA_RIGHT_TRUNCATION SUBSTRING_ERROR TRIM_ERROR UNTERMINATED_C_STRING ZERO_LENGTH_CHARACTER_STRING FLOATING_POINT_EXCEPTION INVALID_TEXT_REPRESENTATION INVALID_BINARY_REPRESENTATION BAD_COPY_FILE_FORMAT UNTRANSLATABLE_CHARACTER NOT_AN_XML_DOCUMENT INVALID_XML_DOCUMENT INVALID_XML_CONTENT INVALID_XML_COMMENT INVALID_XML_PROCESSING_INSTRUCTION INTEGRITY_CONSTRAINT_VIOLATION RESTRICT_VIOLATION NOT_NULL_VIOLATION FOREIGN_KEY_VIOLATION UNIQUE_VIOLATION CHECK_VIOLATION EXCLUSION_VIOLATION INVALID_CURSOR_STATE INVALID_TRANSACTION_STATE ACTIVE_SQL_TRANSACTION BRANCH_TRANSACTION_ALREADY_ACTIVE HELD_CURSOR_REQUIRES_SAME_ISOLATION_LEVEL INAPPROPRIATE_ACCESS_MODE_FOR_BRANCH_TRANSACTION INAPPROPRIATE_ISOLATION_LEVEL_FOR_BRANCH_TRANSACTION NO_ACTIVE_SQL_TRANSACTION_FOR_BRANCH_TRANSACTION READ_ONLY_SQL_TRANSACTION SCHEMA_AND_DATA_STATEMENT_MIXING_NOT_SUPPORTED NO_ACTIVE_SQL_TRANSACTION IN_FAILED_SQL_TRANSACTION IDLE_IN_TRANSACTION_SESSION_TIMEOUT INVALID_SQL_STATEMENT_NAME TRIGGERED_DATA_CHANGE_VIOLATION INVALID_AUTHORIZATION_SPECIFICATION INVALID_PASSWORD DEPENDENT_PRIVILEGE_DESCRIPTORS_STILL_EXIST DEPENDENT_OBJECTS_STILL_EXIST INVALID_TRANSACTION_TERMINATION SQL_ROUTINE_EXCEPTION FUNCTION_EXECUTED_NO_RETURN_STATEMENT MODIFYING_SQL_DATA_NOT_PERMITTED PROHIBITED_SQL_STATEMENT_ATTEMPTED READING_SQL_DATA_NOT_PERMITTED INVALID_CURSOR_NAME EXTERNAL_ROUTINE_EXCEPTION CONTAINING_SQL_NOT_PERMITTED MODIFYING_SQL_DATA_NOT_PERMITTED PROHIBITED_SQL_STATEMENT_ATTEMPTED READING_SQL_DATA_NOT_PERMITTED EXTERNAL_ROUTINE_INVOCATION_EXCEPTION INVALID_SQLSTATE_RETURNED NULL_VALUE_NOT_ALLOWED TRIGGER_PROTOCOL_VIOLATED SRF_PROTOCOL_VIOLATED EVENT_TRIGGER_PROTOCOL_VIOLATED SAVEPOINT_EXCEPTION INVALID_SAVEPOINT_SPECIFICATION INVALID_CATALOG_NAME INVALID_SCHEMA_NAME TRANSACTION_ROLLBACK TRANSACTION_INTEGRITY_CONSTRAINT_VIOLATION SERIALIZATION_FAILURE STATEMENT_COMPLETION_UNKNOWN DEADLOCK_DETECTED SYNTAX_ERROR_OR_ACCESS_RULE_VIOLATION SYNTAX_ERROR INSUFFICIENT_PRIVILEGE CANNOT_COERCE GROUPING_ERROR WINDOWING_ERROR INVALID_RECURSION INVALID_FOREIGN_KEY INVALID_NAME NAME_TOO_LONG RESERVED_NAME DATATYPE_MISMATCH INDETERMINATE_DATATYPE COLLATION_MISMATCH INDETERMINATE_COLLATION WRONG_OBJECT_TYPE GENERATED_ALWAYS UNDEFINED_COLUMN UNDEFINED_FUNCTION UNDEFINED_TABLE UNDEFINED_PARAMETER UNDEFINED_OBJECT DUPLICATE_COLUMN DUPLICATE_CURSOR DUPLICATE_DATABASE DUPLICATE_FUNCTION DUPLICATE_PREPARED_STATEMENT DUPLICATE_SCHEMA DUPLICATE_TABLE DUPLICATE_ALIAS DUPLICATE_OBJECT AMBIGUOUS_COLUMN AMBIGUOUS_FUNCTION AMBIGUOUS_PARAMETER AMBIGUOUS_ALIAS INVALID_COLUMN_REFERENCE INVALID_COLUMN_DEFINITION INVALID_CURSOR_DEFINITION INVALID_DATABASE_DEFINITION INVALID_FUNCTION_DEFINITION INVALID_PREPARED_STATEMENT_DEFINITION INVALID_SCHEMA_DEFINITION INVALID_TABLE_DEFINITION INVALID_OBJECT_DEFINITION WITH_CHECK_OPTION_VIOLATION INSUFFICIENT_RESOURCES DISK_FULL OUT_OF_MEMORY TOO_MANY_CONNECTIONS CONFIGURATION_LIMIT_EXCEEDED PROGRAM_LIMIT_EXCEEDED STATEMENT_TOO_COMPLEX TOO_MANY_COLUMNS TOO_MANY_ARGUMENTS OBJECT_NOT_IN_PREREQUISITE_STATE OBJECT_IN_USE CANT_CHANGE_RUNTIME_PARAM LOCK_NOT_AVAILABLE OPERATOR_INTERVENTION QUERY_CANCELED ADMIN_SHUTDOWN CRASH_SHUTDOWN CANNOT_CONNECT_NOW DATABASE_DROPPED SYSTEM_ERROR IO_ERROR UNDEFINED_FILE DUPLICATE_FILE SNAPSHOT_TOO_OLD CONFIG_FILE_ERROR LOCK_FILE_EXISTS FDW_ERROR FDW_COLUMN_NAME_NOT_FOUND FDW_DYNAMIC_PARAMETER_VALUE_NEEDED FDW_FUNCTION_SEQUENCE_ERROR FDW_INCONSISTENT_DESCRIPTOR_INFORMATION FDW_INVALID_ATTRIBUTE_VALUE FDW_INVALID_COLUMN_NAME FDW_INVALID_COLUMN_NUMBER FDW_INVALID_DATA_TYPE FDW_INVALID_DATA_TYPE_DESCRIPTORS FDW_INVALID_DESCRIPTOR_FIELD_IDENTIFIER FDW_INVALID_HANDLE FDW_INVALID_OPTION_INDEX FDW_INVALID_OPTION_NAME FDW_INVALID_STRING_LENGTH_OR_BUFFER_LENGTH FDW_INVALID_STRING_FORMAT FDW_INVALID_USE_OF_NULL_POINTER FDW_TOO_MANY_HANDLES FDW_OUT_OF_MEMORY FDW_NO_SCHEMAS FDW_OPTION_NAME_NOT_FOUND FDW_REPLY_HANDLE FDW_SCHEMA_NOT_FOUND FDW_TABLE_NOT_FOUND FDW_UNABLE_TO_CREATE_EXECUTION FDW_UNABLE_TO_CREATE_REPLY FDW_UNABLE_TO_ESTABLISH_CONNECTION PLPGSQL_ERROR RAISE_EXCEPTION NO_DATA_FOUND TOO_MANY_ROWS ASSERT_FAILURE INTERNAL_ERROR DATA_CORRUPTED INDEX_CORRUPTED "
    ), v = /* https://www.postgresql.org/docs/11/static/functions-aggregate.html */ "ARRAY_AGG AVG BIT_AND BIT_OR BOOL_AND BOOL_OR COUNT EVERY JSON_AGG JSONB_AGG JSON_OBJECT_AGG JSONB_OBJECT_AGG MAX MIN MODE STRING_AGG SUM XMLAGG CORR COVAR_POP COVAR_SAMP REGR_AVGX REGR_AVGY REGR_COUNT REGR_INTERCEPT REGR_R2 REGR_SLOPE REGR_SXX REGR_SXY REGR_SYY STDDEV STDDEV_POP STDDEV_SAMP VARIANCE VAR_POP VAR_SAMP PERCENTILE_CONT PERCENTILE_DISC ROW_NUMBER RANK DENSE_RANK PERCENT_RANK CUME_DIST NTILE LAG LEAD FIRST_VALUE LAST_VALUE NTH_VALUE NUM_NONNULLS NUM_NULLS ABS CBRT CEIL CEILING DEGREES DIV EXP FLOOR LN LOG MOD PI POWER RADIANS ROUND SCALE SIGN SQRT TRUNC WIDTH_BUCKET RANDOM SETSEED ACOS ACOSD ASIN ASIND ATAN ATAND ATAN2 ATAN2D COS COSD COT COTD SIN SIND TAN TAND BIT_LENGTH CHAR_LENGTH CHARACTER_LENGTH LOWER OCTET_LENGTH OVERLAY POSITION SUBSTRING TREAT TRIM UPPER ASCII BTRIM CHR CONCAT CONCAT_WS CONVERT CONVERT_FROM CONVERT_TO DECODE ENCODE INITCAP LEFT LENGTH LPAD LTRIM MD5 PARSE_IDENT PG_CLIENT_ENCODING QUOTE_IDENT|10 QUOTE_LITERAL|10 QUOTE_NULLABLE|10 REGEXP_MATCH REGEXP_MATCHES REGEXP_REPLACE REGEXP_SPLIT_TO_ARRAY REGEXP_SPLIT_TO_TABLE REPEAT REPLACE REVERSE RIGHT RPAD RTRIM SPLIT_PART STRPOS SUBSTR TO_ASCII TO_HEX TRANSLATE OCTET_LENGTH GET_BIT GET_BYTE SET_BIT SET_BYTE TO_CHAR TO_DATE TO_NUMBER TO_TIMESTAMP AGE CLOCK_TIMESTAMP|10 DATE_PART DATE_TRUNC ISFINITE JUSTIFY_DAYS JUSTIFY_HOURS JUSTIFY_INTERVAL MAKE_DATE MAKE_INTERVAL|10 MAKE_TIME MAKE_TIMESTAMP|10 MAKE_TIMESTAMPTZ|10 NOW STATEMENT_TIMESTAMP|10 TIMEOFDAY TRANSACTION_TIMESTAMP|10 ENUM_FIRST ENUM_LAST ENUM_RANGE AREA CENTER DIAMETER HEIGHT ISCLOSED ISOPEN NPOINTS PCLOSE POPEN RADIUS WIDTH BOX BOUND_BOX CIRCLE LINE LSEG PATH POLYGON ABBREV BROADCAST HOST HOSTMASK MASKLEN NETMASK NETWORK SET_MASKLEN TEXT INET_SAME_FAMILY INET_MERGE MACADDR8_SET7BIT ARRAY_TO_TSVECTOR GET_CURRENT_TS_CONFIG NUMNODE PLAINTO_TSQUERY PHRASETO_TSQUERY WEBSEARCH_TO_TSQUERY QUERYTREE SETWEIGHT STRIP TO_TSQUERY TO_TSVECTOR JSON_TO_TSVECTOR JSONB_TO_TSVECTOR TS_DELETE TS_FILTER TS_HEADLINE TS_RANK TS_RANK_CD TS_REWRITE TSQUERY_PHRASE TSVECTOR_TO_ARRAY TSVECTOR_UPDATE_TRIGGER TSVECTOR_UPDATE_TRIGGER_COLUMN XMLCOMMENT XMLCONCAT XMLELEMENT XMLFOREST XMLPI XMLROOT XMLEXISTS XML_IS_WELL_FORMED XML_IS_WELL_FORMED_DOCUMENT XML_IS_WELL_FORMED_CONTENT XPATH XPATH_EXISTS XMLTABLE XMLNAMESPACES TABLE_TO_XML TABLE_TO_XMLSCHEMA TABLE_TO_XML_AND_XMLSCHEMA QUERY_TO_XML QUERY_TO_XMLSCHEMA QUERY_TO_XML_AND_XMLSCHEMA CURSOR_TO_XML CURSOR_TO_XMLSCHEMA SCHEMA_TO_XML SCHEMA_TO_XMLSCHEMA SCHEMA_TO_XML_AND_XMLSCHEMA DATABASE_TO_XML DATABASE_TO_XMLSCHEMA DATABASE_TO_XML_AND_XMLSCHEMA XMLATTRIBUTES TO_JSON TO_JSONB ARRAY_TO_JSON ROW_TO_JSON JSON_BUILD_ARRAY JSONB_BUILD_ARRAY JSON_BUILD_OBJECT JSONB_BUILD_OBJECT JSON_OBJECT JSONB_OBJECT JSON_ARRAY_LENGTH JSONB_ARRAY_LENGTH JSON_EACH JSONB_EACH JSON_EACH_TEXT JSONB_EACH_TEXT JSON_EXTRACT_PATH JSONB_EXTRACT_PATH JSON_OBJECT_KEYS JSONB_OBJECT_KEYS JSON_POPULATE_RECORD JSONB_POPULATE_RECORD JSON_POPULATE_RECORDSET JSONB_POPULATE_RECORDSET JSON_ARRAY_ELEMENTS JSONB_ARRAY_ELEMENTS JSON_ARRAY_ELEMENTS_TEXT JSONB_ARRAY_ELEMENTS_TEXT JSON_TYPEOF JSONB_TYPEOF JSON_TO_RECORD JSONB_TO_RECORD JSON_TO_RECORDSET JSONB_TO_RECORDSET JSON_STRIP_NULLS JSONB_STRIP_NULLS JSONB_SET JSONB_INSERT JSONB_PRETTY CURRVAL LASTVAL NEXTVAL SETVAL COALESCE NULLIF GREATEST LEAST ARRAY_APPEND ARRAY_CAT ARRAY_NDIMS ARRAY_DIMS ARRAY_FILL ARRAY_LENGTH ARRAY_LOWER ARRAY_POSITION ARRAY_POSITIONS ARRAY_PREPEND ARRAY_REMOVE ARRAY_REPLACE ARRAY_TO_STRING ARRAY_UPPER CARDINALITY STRING_TO_ARRAY UNNEST ISEMPTY LOWER_INC UPPER_INC LOWER_INF UPPER_INF RANGE_MERGE GENERATE_SERIES GENERATE_SUBSCRIPTS CURRENT_DATABASE CURRENT_QUERY CURRENT_SCHEMA|10 CURRENT_SCHEMAS|10 INET_CLIENT_ADDR INET_CLIENT_PORT INET_SERVER_ADDR INET_SERVER_PORT ROW_SECURITY_ACTIVE FORMAT_TYPE TO_REGCLASS TO_REGPROC TO_REGPROCEDURE TO_REGOPER TO_REGOPERATOR TO_REGTYPE TO_REGNAMESPACE TO_REGROLE COL_DESCRIPTION OBJ_DESCRIPTION SHOBJ_DESCRIPTION TXID_CURRENT TXID_CURRENT_IF_ASSIGNED TXID_CURRENT_SNAPSHOT TXID_SNAPSHOT_XIP TXID_SNAPSHOT_XMAX TXID_SNAPSHOT_XMIN TXID_VISIBLE_IN_SNAPSHOT TXID_STATUS CURRENT_SETTING SET_CONFIG BRIN_SUMMARIZE_NEW_VALUES BRIN_SUMMARIZE_RANGE BRIN_DESUMMARIZE_RANGE GIN_CLEAN_PENDING_LIST SUPPRESS_REDUNDANT_UPDATES_TRIGGER LO_FROM_BYTEA LO_PUT LO_GET LO_CREAT LO_CREATE LO_UNLINK LO_IMPORT LO_EXPORT LOREAD LOWRITE GROUPING CAST ".trim().split(" ").map(function(b) {
      return b.split("|")[0];
    }).join("|");
    return {
      name: "PostgreSQL",
      aliases: [
        "postgres",
        "postgresql"
      ],
      supersetOf: "sql",
      case_insensitive: !0,
      keywords: {
        keyword: o + l + s,
        built_in: d + f + h
      },
      // Forbid some cunstructs from other languages to improve autodetect. In fact
      // "[a-z]:" is legal (as part of array slice), but improbabal.
      illegal: /:==|\W\s*\(\*|(^|\s)\$[a-z]|\{\{|[a-z]:\s*$|\.\.\.|TO:|DO:/,
      contains: [
        // special handling of some words, which are reserved only in some contexts
        {
          className: "keyword",
          variants: [
            { begin: /\bTEXT\s*SEARCH\b/ },
            { begin: /\b(PRIMARY|FOREIGN|FOR(\s+NO)?)\s+KEY\b/ },
            { begin: /\bPARALLEL\s+(UNSAFE|RESTRICTED|SAFE)\b/ },
            { begin: /\bSTORAGE\s+(PLAIN|EXTERNAL|EXTENDED|MAIN)\b/ },
            { begin: /\bMATCH\s+(FULL|PARTIAL|SIMPLE)\b/ },
            { begin: /\bNULLS\s+(FIRST|LAST)\b/ },
            { begin: /\bEVENT\s+TRIGGER\b/ },
            { begin: /\b(MAPPING|OR)\s+REPLACE\b/ },
            { begin: /\b(FROM|TO)\s+(PROGRAM|STDIN|STDOUT)\b/ },
            { begin: /\b(SHARE|EXCLUSIVE)\s+MODE\b/ },
            { begin: /\b(LEFT|RIGHT)\s+(OUTER\s+)?JOIN\b/ },
            { begin: /\b(FETCH|MOVE)\s+(NEXT|PRIOR|FIRST|LAST|ABSOLUTE|RELATIVE|FORWARD|BACKWARD)\b/ },
            { begin: /\bPRESERVE\s+ROWS\b/ },
            { begin: /\bDISCARD\s+PLANS\b/ },
            { begin: /\bREFERENCING\s+(OLD|NEW)\b/ },
            { begin: /\bSKIP\s+LOCKED\b/ },
            { begin: /\bGROUPING\s+SETS\b/ },
            { begin: /\b(BINARY|INSENSITIVE|SCROLL|NO\s+SCROLL)\s+(CURSOR|FOR)\b/ },
            { begin: /\b(WITH|WITHOUT)\s+HOLD\b/ },
            { begin: /\bWITH\s+(CASCADED|LOCAL)\s+CHECK\s+OPTION\b/ },
            { begin: /\bEXCLUDE\s+(TIES|NO\s+OTHERS)\b/ },
            { begin: /\bFORMAT\s+(TEXT|XML|JSON|YAML)\b/ },
            { begin: /\bSET\s+((SESSION|LOCAL)\s+)?NAMES\b/ },
            { begin: /\bIS\s+(NOT\s+)?UNKNOWN\b/ },
            { begin: /\bSECURITY\s+LABEL\b/ },
            { begin: /\bSTANDALONE\s+(YES|NO|NO\s+VALUE)\b/ },
            { begin: /\bWITH\s+(NO\s+)?DATA\b/ },
            { begin: /\b(FOREIGN|SET)\s+DATA\b/ },
            { begin: /\bSET\s+(CATALOG|CONSTRAINTS)\b/ },
            { begin: /\b(WITH|FOR)\s+ORDINALITY\b/ },
            { begin: /\bIS\s+(NOT\s+)?DOCUMENT\b/ },
            { begin: /\bXML\s+OPTION\s+(DOCUMENT|CONTENT)\b/ },
            { begin: /\b(STRIP|PRESERVE)\s+WHITESPACE\b/ },
            { begin: /\bNO\s+(ACTION|MAXVALUE|MINVALUE)\b/ },
            { begin: /\bPARTITION\s+BY\s+(RANGE|LIST|HASH)\b/ },
            { begin: /\bAT\s+TIME\s+ZONE\b/ },
            { begin: /\bGRANTED\s+BY\b/ },
            { begin: /\bRETURN\s+(QUERY|NEXT)\b/ },
            { begin: /\b(ATTACH|DETACH)\s+PARTITION\b/ },
            { begin: /\bFORCE\s+ROW\s+LEVEL\s+SECURITY\b/ },
            { begin: /\b(INCLUDING|EXCLUDING)\s+(COMMENTS|CONSTRAINTS|DEFAULTS|IDENTITY|INDEXES|STATISTICS|STORAGE|ALL)\b/ },
            { begin: /\bAS\s+(ASSIGNMENT|IMPLICIT|PERMISSIVE|RESTRICTIVE|ENUM|RANGE)\b/ }
          ]
        },
        // functions named as keywords, followed by '('
        {
          begin: /\b(FORMAT|FAMILY|VERSION)\s*\(/
          // keywords: { built_in: 'FORMAT FAMILY VERSION' }
        },
        // INCLUDE ( ... ) in index_parameters in CREATE TABLE
        {
          begin: /\bINCLUDE\s*\(/,
          keywords: "INCLUDE"
        },
        // not highlight RANGE if not in frame_clause (not 100% correct, but seems satisfactory)
        { begin: /\bRANGE(?!\s*(BETWEEN|UNBOUNDED|CURRENT|[-0-9]+))/ },
        // disable highlighting in commands CREATE AGGREGATE/COLLATION/DATABASE/OPERTOR/TEXT SEARCH .../TYPE
        // and in PL/pgSQL RAISE ... USING
        { begin: /\b(VERSION|OWNER|TEMPLATE|TABLESPACE|CONNECTION\s+LIMIT|PROCEDURE|RESTRICT|JOIN|PARSER|COPY|START|END|COLLATION|INPUT|ANALYZE|STORAGE|LIKE|DEFAULT|DELIMITER|ENCODING|COLUMN|CONSTRAINT|TABLE|SCHEMA)\s*=/ },
        // PG_smth; HAS_some_PRIVILEGE
        {
          // className: 'built_in',
          begin: /\b(PG_\w+?|HAS_[A-Z_]+_PRIVILEGE)\b/,
          relevance: 10
        },
        // extract
        {
          begin: /\bEXTRACT\s*\(/,
          end: /\bFROM\b/,
          returnEnd: !0,
          keywords: {
            // built_in: 'EXTRACT',
            type: "CENTURY DAY DECADE DOW DOY EPOCH HOUR ISODOW ISOYEAR MICROSECONDS MILLENNIUM MILLISECONDS MINUTE MONTH QUARTER SECOND TIMEZONE TIMEZONE_HOUR TIMEZONE_MINUTE WEEK YEAR"
          }
        },
        // xmlelement, xmlpi - special NAME
        {
          begin: /\b(XMLELEMENT|XMLPI)\s*\(\s*NAME/,
          keywords: {
            // built_in: 'XMLELEMENT XMLPI',
            keyword: "NAME"
          }
        },
        // xmlparse, xmlserialize
        {
          begin: /\b(XMLPARSE|XMLSERIALIZE)\s*\(\s*(DOCUMENT|CONTENT)/,
          keywords: {
            // built_in: 'XMLPARSE XMLSERIALIZE',
            keyword: "DOCUMENT CONTENT"
          }
        },
        // Sequences. We actually skip everything between CACHE|INCREMENT|MAXVALUE|MINVALUE and
        // nearest following numeric constant. Without with trick we find a lot of "keywords"
        // in 'avrasm' autodetection test...
        {
          beginKeywords: "CACHE INCREMENT MAXVALUE MINVALUE",
          end: t.C_NUMBER_RE,
          returnEnd: !0,
          keywords: "BY CACHE INCREMENT MAXVALUE MINVALUE"
        },
        // WITH|WITHOUT TIME ZONE as part of datatype
        {
          className: "type",
          begin: /\b(WITH|WITHOUT)\s+TIME\s+ZONE\b/
        },
        // INTERVAL optional fields
        {
          className: "type",
          begin: /\bINTERVAL\s+(YEAR|MONTH|DAY|HOUR|MINUTE|SECOND)(\s+TO\s+(MONTH|HOUR|MINUTE|SECOND))?\b/
        },
        // Pseudo-types which allowed only as return type
        {
          begin: /\bRETURNS\s+(LANGUAGE_HANDLER|TRIGGER|EVENT_TRIGGER|FDW_HANDLER|INDEX_AM_HANDLER|TSM_HANDLER)\b/,
          keywords: {
            keyword: "RETURNS",
            type: "LANGUAGE_HANDLER TRIGGER EVENT_TRIGGER FDW_HANDLER INDEX_AM_HANDLER TSM_HANDLER"
          }
        },
        // Known functions - only when followed by '('
        {
          begin: "\\b(" + v + ")\\s*\\("
          // keywords: { built_in: FUNCTIONS }
        },
        // Types
        {
          begin: "\\.(" + c + ")\\b"
          // prevent highlight as type, say, 'oid' in 'pgclass.oid'
        },
        {
          begin: "\\b(" + c + ")\\s+PATH\\b",
          // in XMLTABLE
          keywords: {
            keyword: "PATH",
            // hopefully no one would use PATH type in XMLTABLE...
            type: u.replace("PATH ", "")
          }
        },
        {
          className: "type",
          begin: "\\b(" + c + ")\\b"
        },
        // Strings, see https://www.postgresql.org/docs/11/static/sql-syntax-lexical.html#SQL-SYNTAX-CONSTANTS
        {
          className: "string",
          begin: "'",
          end: "'",
          contains: [{ begin: "''" }]
        },
        {
          className: "string",
          begin: "(e|E|u&|U&)'",
          end: "'",
          contains: [{ begin: "\\\\." }],
          relevance: 10
        },
        t.END_SAME_AS_BEGIN({
          begin: i,
          end: i,
          contains: [
            {
              // actually we want them all except SQL; listed are those with known implementations
              // and XML + JSON just in case
              subLanguage: [
                "pgsql",
                "perl",
                "python",
                "tcl",
                "r",
                "lua",
                "java",
                "php",
                "ruby",
                "bash",
                "scheme",
                "xml",
                "json"
              ],
              endsWithParent: !0
            }
          ]
        }),
        // identifiers in quotes
        {
          begin: '"',
          end: '"',
          contains: [{ begin: '""' }]
        },
        // numbers
        t.C_NUMBER_MODE,
        // comments
        t.C_BLOCK_COMMENT_MODE,
        n,
        // PL/pgSQL staff
        // %ROWTYPE, %TYPE, $n
        {
          className: "meta",
          variants: [
            {
              // %TYPE, %ROWTYPE
              begin: "%(ROW)?TYPE",
              relevance: 10
            },
            {
              // $n
              begin: "\\$\\d+"
            },
            {
              // #compiler option
              begin: "^#\\w",
              end: "$"
            }
          ]
        },
        // <<labeles>>
        {
          className: "symbol",
          begin: a,
          relevance: 10
        }
      ]
    };
  }
  return BS = e, BS;
}
var $S, VI;
function eee() {
  if (VI) return $S;
  VI = 1;
  function e(t) {
    const n = t.regex, r = /(?![A-Za-z0-9])(?![$])/, i = n.concat(
      /[a-zA-Z_\x7f-\xff][a-zA-Z0-9_\x7f-\xff]*/,
      r
    ), a = n.concat(
      /(\\?[A-Z][a-z0-9_\x7f-\xff]+|\\?[A-Z]+(?=[A-Z][a-z0-9_\x7f-\xff])){1,}/,
      r
    ), o = {
      scope: "variable",
      match: "\\$+" + i
    }, s = {
      scope: "meta",
      variants: [
        { begin: /<\?php/, relevance: 10 },
        // boost for obvious PHP
        { begin: /<\?=/ },
        // less relevant per PSR-1 which says not to use short-tags
        { begin: /<\?/, relevance: 0.1 },
        { begin: /\?>/ }
        // end php tag
      ]
    }, l = {
      scope: "subst",
      variants: [
        { begin: /\$\w+/ },
        {
          begin: /\{\$/,
          end: /\}/
        }
      ]
    }, u = t.inherit(t.APOS_STRING_MODE, { illegal: null }), c = t.inherit(t.QUOTE_STRING_MODE, {
      illegal: null,
      contains: t.QUOTE_STRING_MODE.contains.concat(l)
    }), d = {
      begin: /<<<[ \t]*(?:(\w+)|"(\w+)")\n/,
      end: /[ \t]*(\w+)\b/,
      contains: t.QUOTE_STRING_MODE.contains.concat(l),
      "on:begin": (L, x) => {
        x.data._beginMatch = L[1] || L[2];
      },
      "on:end": (L, x) => {
        x.data._beginMatch !== L[1] && x.ignoreMatch();
      }
    }, f = t.END_SAME_AS_BEGIN({
      begin: /<<<[ \t]*'(\w+)'\n/,
      end: /[ \t]*(\w+)\b/
    }), h = `[ 	
]`, m = {
      scope: "string",
      variants: [
        c,
        u,
        d,
        f
      ]
    }, v = {
      scope: "number",
      variants: [
        { begin: "\\b0[bB][01]+(?:_[01]+)*\\b" },
        // Binary w/ underscore support
        { begin: "\\b0[oO][0-7]+(?:_[0-7]+)*\\b" },
        // Octals w/ underscore support
        { begin: "\\b0[xX][\\da-fA-F]+(?:_[\\da-fA-F]+)*\\b" },
        // Hex w/ underscore support
        // Decimals w/ underscore support, with optional fragments and scientific exponent (e) suffix.
        { begin: "(?:\\b\\d+(?:_\\d+)*(\\.(?:\\d+(?:_\\d+)*))?|\\B\\.\\d+)(?:[eE][+-]?\\d+)?" }
      ],
      relevance: 0
    }, b = [
      "false",
      "null",
      "true"
    ], y = [
      // Magic constants:
      // <https://www.php.net/manual/en/language.constants.predefined.php>
      "__CLASS__",
      "__DIR__",
      "__FILE__",
      "__FUNCTION__",
      "__COMPILER_HALT_OFFSET__",
      "__LINE__",
      "__METHOD__",
      "__NAMESPACE__",
      "__TRAIT__",
      // Function that look like language construct or language construct that look like function:
      // List of keywords that may not require parenthesis
      "die",
      "echo",
      "exit",
      "include",
      "include_once",
      "print",
      "require",
      "require_once",
      // These are not language construct (function) but operate on the currently-executing function and can access the current symbol table
      // 'compact extract func_get_arg func_get_args func_num_args get_called_class get_parent_class ' +
      // Other keywords:
      // <https://www.php.net/manual/en/reserved.php>
      // <https://www.php.net/manual/en/language.types.type-juggling.php>
      "array",
      "abstract",
      "and",
      "as",
      "binary",
      "bool",
      "boolean",
      "break",
      "callable",
      "case",
      "catch",
      "class",
      "clone",
      "const",
      "continue",
      "declare",
      "default",
      "do",
      "double",
      "else",
      "elseif",
      "empty",
      "enddeclare",
      "endfor",
      "endforeach",
      "endif",
      "endswitch",
      "endwhile",
      "enum",
      "eval",
      "extends",
      "final",
      "finally",
      "float",
      "for",
      "foreach",
      "from",
      "global",
      "goto",
      "if",
      "implements",
      "instanceof",
      "insteadof",
      "int",
      "integer",
      "interface",
      "isset",
      "iterable",
      "list",
      "match|0",
      "mixed",
      "new",
      "never",
      "object",
      "or",
      "private",
      "protected",
      "public",
      "readonly",
      "real",
      "return",
      "string",
      "switch",
      "throw",
      "trait",
      "try",
      "unset",
      "use",
      "var",
      "void",
      "while",
      "xor",
      "yield"
    ], g = [
      // Standard PHP library:
      // <https://www.php.net/manual/en/book.spl.php>
      "Error|0",
      "AppendIterator",
      "ArgumentCountError",
      "ArithmeticError",
      "ArrayIterator",
      "ArrayObject",
      "AssertionError",
      "BadFunctionCallException",
      "BadMethodCallException",
      "CachingIterator",
      "CallbackFilterIterator",
      "CompileError",
      "Countable",
      "DirectoryIterator",
      "DivisionByZeroError",
      "DomainException",
      "EmptyIterator",
      "ErrorException",
      "Exception",
      "FilesystemIterator",
      "FilterIterator",
      "GlobIterator",
      "InfiniteIterator",
      "InvalidArgumentException",
      "IteratorIterator",
      "LengthException",
      "LimitIterator",
      "LogicException",
      "MultipleIterator",
      "NoRewindIterator",
      "OutOfBoundsException",
      "OutOfRangeException",
      "OuterIterator",
      "OverflowException",
      "ParentIterator",
      "ParseError",
      "RangeException",
      "RecursiveArrayIterator",
      "RecursiveCachingIterator",
      "RecursiveCallbackFilterIterator",
      "RecursiveDirectoryIterator",
      "RecursiveFilterIterator",
      "RecursiveIterator",
      "RecursiveIteratorIterator",
      "RecursiveRegexIterator",
      "RecursiveTreeIterator",
      "RegexIterator",
      "RuntimeException",
      "SeekableIterator",
      "SplDoublyLinkedList",
      "SplFileInfo",
      "SplFileObject",
      "SplFixedArray",
      "SplHeap",
      "SplMaxHeap",
      "SplMinHeap",
      "SplObjectStorage",
      "SplObserver",
      "SplPriorityQueue",
      "SplQueue",
      "SplStack",
      "SplSubject",
      "SplTempFileObject",
      "TypeError",
      "UnderflowException",
      "UnexpectedValueException",
      "UnhandledMatchError",
      // Reserved interfaces:
      // <https://www.php.net/manual/en/reserved.interfaces.php>
      "ArrayAccess",
      "BackedEnum",
      "Closure",
      "Fiber",
      "Generator",
      "Iterator",
      "IteratorAggregate",
      "Serializable",
      "Stringable",
      "Throwable",
      "Traversable",
      "UnitEnum",
      "WeakReference",
      "WeakMap",
      // Reserved classes:
      // <https://www.php.net/manual/en/reserved.classes.php>
      "Directory",
      "__PHP_Incomplete_Class",
      "parent",
      "php_user_filter",
      "self",
      "static",
      "stdClass"
    ], S = {
      keyword: y,
      literal: ((L) => {
        const x = [];
        return L.forEach((I) => {
          x.push(I), I.toLowerCase() === I ? x.push(I.toUpperCase()) : x.push(I.toLowerCase());
        }), x;
      })(b),
      built_in: g
    }, C = (L) => L.map((x) => x.replace(/\|\d+$/, "")), T = { variants: [
      {
        match: [
          /new/,
          n.concat(h, "+"),
          // to prevent built ins from being confused as the class constructor call
          n.concat("(?!", C(g).join("\\b|"), "\\b)"),
          a
        ],
        scope: {
          1: "keyword",
          4: "title.class"
        }
      }
    ] }, O = n.concat(i, "\\b(?!\\()"), R = { variants: [
      {
        match: [
          n.concat(
            /::/,
            n.lookahead(/(?!class\b)/)
          ),
          O
        ],
        scope: { 2: "variable.constant" }
      },
      {
        match: [
          /::/,
          /class/
        ],
        scope: { 2: "variable.language" }
      },
      {
        match: [
          a,
          n.concat(
            /::/,
            n.lookahead(/(?!class\b)/)
          ),
          O
        ],
        scope: {
          1: "title.class",
          3: "variable.constant"
        }
      },
      {
        match: [
          a,
          n.concat(
            "::",
            n.lookahead(/(?!class\b)/)
          )
        ],
        scope: { 1: "title.class" }
      },
      {
        match: [
          a,
          /::/,
          /class/
        ],
        scope: {
          1: "title.class",
          3: "variable.language"
        }
      }
    ] }, D = {
      scope: "attr",
      match: n.concat(i, n.lookahead(":"), n.lookahead(/(?!::)/))
    }, q = {
      relevance: 0,
      begin: /\(/,
      end: /\)/,
      keywords: S,
      contains: [
        D,
        o,
        R,
        t.C_BLOCK_COMMENT_MODE,
        m,
        v,
        T
      ]
    }, $ = {
      relevance: 0,
      match: [
        /\b/,
        // to prevent keywords from being confused as the function title
        n.concat("(?!fn\\b|function\\b|", C(y).join("\\b|"), "|", C(g).join("\\b|"), "\\b)"),
        i,
        n.concat(h, "*"),
        n.lookahead(/(?=\()/)
      ],
      scope: { 3: "title.function.invoke" },
      contains: [q]
    };
    q.contains.push($);
    const P = [
      D,
      R,
      t.C_BLOCK_COMMENT_MODE,
      m,
      v,
      T
    ], Y = {
      begin: n.concat(/#\[\s*/, a),
      beginScope: "meta",
      end: /]/,
      endScope: "meta",
      keywords: {
        literal: b,
        keyword: [
          "new",
          "array"
        ]
      },
      contains: [
        {
          begin: /\[/,
          end: /]/,
          keywords: {
            literal: b,
            keyword: [
              "new",
              "array"
            ]
          },
          contains: [
            "self",
            ...P
          ]
        },
        ...P,
        {
          scope: "meta",
          match: a
        }
      ]
    };
    return {
      case_insensitive: !1,
      keywords: S,
      contains: [
        Y,
        t.HASH_COMMENT_MODE,
        t.COMMENT("//", "$"),
        t.COMMENT(
          "/\\*",
          "\\*/",
          { contains: [
            {
              scope: "doctag",
              match: "@[A-Za-z]+"
            }
          ] }
        ),
        {
          match: /__halt_compiler\(\);/,
          keywords: "__halt_compiler",
          starts: {
            scope: "comment",
            end: t.MATCH_NOTHING_RE,
            contains: [
              {
                match: /\?>/,
                scope: "meta",
                endsParent: !0
              }
            ]
          }
        },
        s,
        {
          scope: "variable.language",
          match: /\$this\b/
        },
        o,
        $,
        R,
        {
          match: [
            /const/,
            /\s/,
            i
          ],
          scope: {
            1: "keyword",
            3: "variable.constant"
          }
        },
        T,
        {
          scope: "function",
          relevance: 0,
          beginKeywords: "fn function",
          end: /[;{]/,
          excludeEnd: !0,
          illegal: "[$%\\[]",
          contains: [
            { beginKeywords: "use" },
            t.UNDERSCORE_TITLE_MODE,
            {
              begin: "=>",
              // No markup, just a relevance booster
              endsParent: !0
            },
            {
              scope: "params",
              begin: "\\(",
              end: "\\)",
              excludeBegin: !0,
              excludeEnd: !0,
              keywords: S,
              contains: [
                "self",
                o,
                R,
                t.C_BLOCK_COMMENT_MODE,
                m,
                v
              ]
            }
          ]
        },
        {
          scope: "class",
          variants: [
            {
              beginKeywords: "enum",
              illegal: /[($"]/
            },
            {
              beginKeywords: "class interface trait",
              illegal: /[:($"]/
            }
          ],
          relevance: 0,
          end: /\{/,
          excludeEnd: !0,
          contains: [
            { beginKeywords: "extends implements" },
            t.UNDERSCORE_TITLE_MODE
          ]
        },
        // both use and namespace still use "old style" rules (vs multi-match)
        // because the namespace name can include `\` and we still want each
        // element to be treated as its own *individual* title
        {
          beginKeywords: "namespace",
          relevance: 0,
          end: ";",
          illegal: /[.']/,
          contains: [t.inherit(t.UNDERSCORE_TITLE_MODE, { scope: "title.class" })]
        },
        {
          beginKeywords: "use",
          relevance: 0,
          end: ";",
          contains: [
            // TODO: title.function vs title.class
            {
              match: /\b(as|const|function)\b/,
              scope: "keyword"
            },
            // TODO: could be title.class or title.function
            t.UNDERSCORE_TITLE_MODE
          ]
        },
        m,
        v
      ]
    };
  }
  return $S = e, $S;
}
var US, WI;
function tee() {
  if (WI) return US;
  WI = 1;
  function e(t) {
    return {
      name: "PHP template",
      subLanguage: "xml",
      contains: [
        {
          begin: /<\?(php|=)?/,
          end: /\?>/,
          subLanguage: "php",
          contains: [
            // We don't want the php closing tag ?> to close the PHP block when
            // inside any of the following blocks:
            {
              begin: "/\\*",
              end: "\\*/",
              skip: !0
            },
            {
              begin: 'b"',
              end: '"',
              skip: !0
            },
            {
              begin: "b'",
              end: "'",
              skip: !0
            },
            t.inherit(t.APOS_STRING_MODE, {
              illegal: null,
              className: null,
              contains: null,
              skip: !0
            }),
            t.inherit(t.QUOTE_STRING_MODE, {
              illegal: null,
              className: null,
              contains: null,
              skip: !0
            })
          ]
        }
      ]
    };
  }
  return US = e, US;
}
var qS, KI;
function nee() {
  if (KI) return qS;
  KI = 1;
  function e(t) {
    return {
      name: "Plain text",
      aliases: [
        "text",
        "txt"
      ],
      disableAutodetect: !0
    };
  }
  return qS = e, qS;
}
var GS, jI;
function ree() {
  if (jI) return GS;
  jI = 1;
  function e(t) {
    const n = {
      keyword: "actor addressof and as be break class compile_error compile_intrinsic consume continue delegate digestof do else elseif embed end error for fun if ifdef in interface is isnt lambda let match new not object or primitive recover repeat return struct then trait try type until use var where while with xor",
      meta: "iso val tag trn box ref",
      literal: "this false true"
    }, r = {
      className: "string",
      begin: '"""',
      end: '"""',
      relevance: 10
    }, i = {
      className: "string",
      begin: '"',
      end: '"',
      contains: [t.BACKSLASH_ESCAPE]
    }, a = {
      className: "string",
      begin: "'",
      end: "'",
      contains: [t.BACKSLASH_ESCAPE],
      relevance: 0
    }, o = {
      className: "type",
      begin: "\\b_?[A-Z][\\w]*",
      relevance: 0
    }, s = {
      begin: t.IDENT_RE + "'",
      relevance: 0
    };
    return {
      name: "Pony",
      keywords: n,
      contains: [
        o,
        r,
        i,
        a,
        s,
        {
          className: "number",
          begin: "(-?)(\\b0[xX][a-fA-F0-9]+|\\b0[bB][01]+|(\\b\\d+(_\\d+)?(\\.\\d*)?|\\.\\d+)([eE][-+]?\\d+)?)",
          relevance: 0
        },
        t.C_LINE_COMMENT_MODE,
        t.C_BLOCK_COMMENT_MODE
      ]
    };
  }
  return GS = e, GS;
}
var YS, QI;
function iee() {
  if (QI) return YS;
  QI = 1;
  function e(t) {
    const n = [
      "string",
      "char",
      "byte",
      "int",
      "long",
      "bool",
      "decimal",
      "single",
      "double",
      "DateTime",
      "xml",
      "array",
      "hashtable",
      "void"
    ], r = "Add|Clear|Close|Copy|Enter|Exit|Find|Format|Get|Hide|Join|Lock|Move|New|Open|Optimize|Pop|Push|Redo|Remove|Rename|Reset|Resize|Search|Select|Set|Show|Skip|Split|Step|Switch|Undo|Unlock|Watch|Backup|Checkpoint|Compare|Compress|Convert|ConvertFrom|ConvertTo|Dismount|Edit|Expand|Export|Group|Import|Initialize|Limit|Merge|Mount|Out|Publish|Restore|Save|Sync|Unpublish|Update|Approve|Assert|Build|Complete|Confirm|Deny|Deploy|Disable|Enable|Install|Invoke|Register|Request|Restart|Resume|Start|Stop|Submit|Suspend|Uninstall|Unregister|Wait|Debug|Measure|Ping|Repair|Resolve|Test|Trace|Connect|Disconnect|Read|Receive|Send|Write|Block|Grant|Protect|Revoke|Unblock|Unprotect|Use|ForEach|Sort|Tee|Where", i = "-and|-as|-band|-bnot|-bor|-bxor|-casesensitive|-ccontains|-ceq|-cge|-cgt|-cle|-clike|-clt|-cmatch|-cne|-cnotcontains|-cnotlike|-cnotmatch|-contains|-creplace|-csplit|-eq|-exact|-f|-file|-ge|-gt|-icontains|-ieq|-ige|-igt|-ile|-ilike|-ilt|-imatch|-in|-ine|-inotcontains|-inotlike|-inotmatch|-ireplace|-is|-isnot|-isplit|-join|-le|-like|-lt|-match|-ne|-not|-notcontains|-notin|-notlike|-notmatch|-or|-regex|-replace|-shl|-shr|-split|-wildcard|-xor", a = {
      $pattern: /-?[A-z\.\-]+\b/,
      keyword: "if else foreach return do while until elseif begin for trap data dynamicparam end break throw param continue finally in switch exit filter try process catch hidden static parameter",
      // "echo" relevance has been set to 0 to avoid auto-detect conflicts with shell transcripts
      built_in: "ac asnp cat cd CFS chdir clc clear clhy cli clp cls clv cnsn compare copy cp cpi cpp curl cvpa dbp del diff dir dnsn ebp echo|0 epal epcsv epsn erase etsn exsn fc fhx fl ft fw gal gbp gc gcb gci gcm gcs gdr gerr ghy gi gin gjb gl gm gmo gp gps gpv group gsn gsnp gsv gtz gu gv gwmi h history icm iex ihy ii ipal ipcsv ipmo ipsn irm ise iwmi iwr kill lp ls man md measure mi mount move mp mv nal ndr ni nmo npssc nsn nv ogv oh popd ps pushd pwd r rbp rcjb rcsn rd rdr ren ri rjb rm rmdir rmo rni rnp rp rsn rsnp rujb rv rvpa rwmi sajb sal saps sasv sbp sc scb select set shcm si sl sleep sls sort sp spjb spps spsv start stz sujb sv swmi tee trcm type wget where wjb write"
      // TODO: 'validate[A-Z]+' can't work in keywords
    }, o = /\w[\w\d]*((-)[\w\d]+)*/, s = {
      begin: "`[\\s\\S]",
      relevance: 0
    }, l = {
      className: "variable",
      variants: [
        { begin: /\$\B/ },
        {
          className: "keyword",
          begin: /\$this/
        },
        { begin: /\$[\w\d][\w\d_:]*/ }
      ]
    }, u = {
      className: "literal",
      begin: /\$(null|true|false)\b/
    }, c = {
      className: "string",
      variants: [
        {
          begin: /"/,
          end: /"/
        },
        {
          begin: /@"/,
          end: /^"@/
        }
      ],
      contains: [
        s,
        l,
        {
          className: "variable",
          begin: /\$[A-z]/,
          end: /[^A-z]/
        }
      ]
    }, d = {
      className: "string",
      variants: [
        {
          begin: /'/,
          end: /'/
        },
        {
          begin: /@'/,
          end: /^'@/
        }
      ]
    }, f = {
      className: "doctag",
      variants: [
        /* no paramater help tags */
        { begin: /\.(synopsis|description|example|inputs|outputs|notes|link|component|role|functionality)/ },
        /* one parameter help tags */
        { begin: /\.(parameter|forwardhelptargetname|forwardhelpcategory|remotehelprunspace|externalhelp)\s+\S+/ }
      ]
    }, h = t.inherit(
      t.COMMENT(null, null),
      {
        variants: [
          /* single-line comment */
          {
            begin: /#/,
            end: /$/
          },
          /* multi-line comment */
          {
            begin: /<#/,
            end: /#>/
          }
        ],
        contains: [f]
      }
    ), m = {
      className: "built_in",
      variants: [{ begin: "(".concat(r, ")+(-)[\\w\\d]+") }]
    }, v = {
      className: "class",
      beginKeywords: "class enum",
      end: /\s*[{]/,
      excludeEnd: !0,
      relevance: 0,
      contains: [t.TITLE_MODE]
    }, b = {
      className: "function",
      begin: /function\s+/,
      end: /\s*\{|$/,
      excludeEnd: !0,
      returnBegin: !0,
      relevance: 0,
      contains: [
        {
          begin: "function",
          relevance: 0,
          className: "keyword"
        },
        {
          className: "title",
          begin: o,
          relevance: 0
        },
        {
          begin: /\(/,
          end: /\)/,
          className: "params",
          relevance: 0,
          contains: [l]
        }
        // CMDLETS
      ]
    }, y = {
      begin: /using\s/,
      end: /$/,
      returnBegin: !0,
      contains: [
        c,
        d,
        {
          className: "keyword",
          begin: /(using|assembly|command|module|namespace|type)/
        }
      ]
    }, g = { variants: [
      // PS literals are pretty verbose so it's a good idea to accent them a bit.
      {
        className: "operator",
        begin: "(".concat(i, ")\\b")
      },
      {
        className: "literal",
        begin: /(-){1,2}[\w\d-]+/,
        relevance: 0
      }
    ] }, E = {
      className: "selector-tag",
      begin: /@\B/,
      relevance: 0
    }, S = {
      className: "function",
      begin: /\[.*\]\s*[\w]+[ ]??\(/,
      end: /$/,
      returnBegin: !0,
      relevance: 0,
      contains: [
        {
          className: "keyword",
          begin: "(".concat(
            a.keyword.toString().replace(
              /\s/g,
              "|"
            ),
            ")\\b"
          ),
          endsParent: !0,
          relevance: 0
        },
        t.inherit(t.TITLE_MODE, { endsParent: !0 })
      ]
    }, C = [
      // STATIC_MEMBER,
      S,
      h,
      s,
      t.NUMBER_MODE,
      c,
      d,
      // PS_NEW_OBJECT_TYPE,
      m,
      l,
      u,
      E
    ], T = {
      begin: /\[/,
      end: /\]/,
      excludeBegin: !0,
      excludeEnd: !0,
      relevance: 0,
      contains: [].concat(
        "self",
        C,
        {
          begin: "(" + n.join("|") + ")",
          className: "built_in",
          relevance: 0
        },
        {
          className: "type",
          begin: /[\.\w\d]+/,
          relevance: 0
        }
      )
    };
    return S.contains.unshift(T), {
      name: "PowerShell",
      aliases: [
        "pwsh",
        "ps",
        "ps1"
      ],
      case_insensitive: !0,
      keywords: a,
      contains: C.concat(
        v,
        b,
        y,
        g,
        T
      )
    };
  }
  return YS = e, YS;
}
var HS, XI;
function aee() {
  if (XI) return HS;
  XI = 1;
  function e(t) {
    const n = t.regex, r = [
      "displayHeight",
      "displayWidth",
      "mouseY",
      "mouseX",
      "mousePressed",
      "pmouseX",
      "pmouseY",
      "key",
      "keyCode",
      "pixels",
      "focused",
      "frameCount",
      "frameRate",
      "height",
      "width",
      "size",
      "createGraphics",
      "beginDraw",
      "createShape",
      "loadShape",
      "PShape",
      "arc",
      "ellipse",
      "line",
      "point",
      "quad",
      "rect",
      "triangle",
      "bezier",
      "bezierDetail",
      "bezierPoint",
      "bezierTangent",
      "curve",
      "curveDetail",
      "curvePoint",
      "curveTangent",
      "curveTightness",
      "shape",
      "shapeMode",
      "beginContour",
      "beginShape",
      "bezierVertex",
      "curveVertex",
      "endContour",
      "endShape",
      "quadraticVertex",
      "vertex",
      "ellipseMode",
      "noSmooth",
      "rectMode",
      "smooth",
      "strokeCap",
      "strokeJoin",
      "strokeWeight",
      "mouseClicked",
      "mouseDragged",
      "mouseMoved",
      "mousePressed",
      "mouseReleased",
      "mouseWheel",
      "keyPressed",
      "keyPressedkeyReleased",
      "keyTyped",
      "print",
      "println",
      "save",
      "saveFrame",
      "day",
      "hour",
      "millis",
      "minute",
      "month",
      "second",
      "year",
      "background",
      "clear",
      "colorMode",
      "fill",
      "noFill",
      "noStroke",
      "stroke",
      "alpha",
      "blue",
      "brightness",
      "color",
      "green",
      "hue",
      "lerpColor",
      "red",
      "saturation",
      "modelX",
      "modelY",
      "modelZ",
      "screenX",
      "screenY",
      "screenZ",
      "ambient",
      "emissive",
      "shininess",
      "specular",
      "add",
      "createImage",
      "beginCamera",
      "camera",
      "endCamera",
      "frustum",
      "ortho",
      "perspective",
      "printCamera",
      "printProjection",
      "cursor",
      "frameRate",
      "noCursor",
      "exit",
      "loop",
      "noLoop",
      "popStyle",
      "pushStyle",
      "redraw",
      "binary",
      "boolean",
      "byte",
      "char",
      "float",
      "hex",
      "int",
      "str",
      "unbinary",
      "unhex",
      "join",
      "match",
      "matchAll",
      "nf",
      "nfc",
      "nfp",
      "nfs",
      "split",
      "splitTokens",
      "trim",
      "append",
      "arrayCopy",
      "concat",
      "expand",
      "reverse",
      "shorten",
      "sort",
      "splice",
      "subset",
      "box",
      "sphere",
      "sphereDetail",
      "createInput",
      "createReader",
      "loadBytes",
      "loadJSONArray",
      "loadJSONObject",
      "loadStrings",
      "loadTable",
      "loadXML",
      "open",
      "parseXML",
      "saveTable",
      "selectFolder",
      "selectInput",
      "beginRaw",
      "beginRecord",
      "createOutput",
      "createWriter",
      "endRaw",
      "endRecord",
      "PrintWritersaveBytes",
      "saveJSONArray",
      "saveJSONObject",
      "saveStream",
      "saveStrings",
      "saveXML",
      "selectOutput",
      "popMatrix",
      "printMatrix",
      "pushMatrix",
      "resetMatrix",
      "rotate",
      "rotateX",
      "rotateY",
      "rotateZ",
      "scale",
      "shearX",
      "shearY",
      "translate",
      "ambientLight",
      "directionalLight",
      "lightFalloff",
      "lights",
      "lightSpecular",
      "noLights",
      "normal",
      "pointLight",
      "spotLight",
      "image",
      "imageMode",
      "loadImage",
      "noTint",
      "requestImage",
      "tint",
      "texture",
      "textureMode",
      "textureWrap",
      "blend",
      "copy",
      "filter",
      "get",
      "loadPixels",
      "set",
      "updatePixels",
      "blendMode",
      "loadShader",
      "PShaderresetShader",
      "shader",
      "createFont",
      "loadFont",
      "text",
      "textFont",
      "textAlign",
      "textLeading",
      "textMode",
      "textSize",
      "textWidth",
      "textAscent",
      "textDescent",
      "abs",
      "ceil",
      "constrain",
      "dist",
      "exp",
      "floor",
      "lerp",
      "log",
      "mag",
      "map",
      "max",
      "min",
      "norm",
      "pow",
      "round",
      "sq",
      "sqrt",
      "acos",
      "asin",
      "atan",
      "atan2",
      "cos",
      "degrees",
      "radians",
      "sin",
      "tan",
      "noise",
      "noiseDetail",
      "noiseSeed",
      "random",
      "randomGaussian",
      "randomSeed"
    ], i = t.IDENT_RE, a = { variants: [
      {
        match: n.concat(n.either(...r), n.lookahead(/\s*\(/)),
        className: "built_in"
      },
      {
        relevance: 0,
        match: n.concat(
          /\b(?!for|if|while)/,
          i,
          n.lookahead(/\s*\(/)
        ),
        className: "title.function"
      }
    ] }, o = {
      match: [
        /new\s+/,
        i
      ],
      className: {
        1: "keyword",
        2: "class.title"
      }
    }, s = {
      relevance: 0,
      match: [
        /\./,
        i
      ],
      className: { 2: "property" }
    }, l = {
      variants: [
        { match: [
          /class/,
          /\s+/,
          i,
          /\s+/,
          /extends/,
          /\s+/,
          i
        ] },
        { match: [
          /class/,
          /\s+/,
          i
        ] }
      ],
      className: {
        1: "keyword",
        3: "title.class",
        5: "keyword",
        7: "title.class.inherited"
      }
    }, u = [
      "boolean",
      "byte",
      "char",
      "color",
      "double",
      "float",
      "int",
      "long",
      "short"
    ], c = [
      "BufferedReader",
      "PVector",
      "PFont",
      "PImage",
      "PGraphics",
      "HashMap",
      "String",
      "Array",
      "FloatDict",
      "ArrayList",
      "FloatList",
      "IntDict",
      "IntList",
      "JSONArray",
      "JSONObject",
      "Object",
      "StringDict",
      "StringList",
      "Table",
      "TableRow",
      "XML"
    ];
    return {
      name: "Processing",
      aliases: ["pde"],
      keywords: {
        keyword: [...[
          "abstract",
          "assert",
          "break",
          "case",
          "catch",
          "const",
          "continue",
          "default",
          "else",
          "enum",
          "final",
          "finally",
          "for",
          "if",
          "import",
          "instanceof",
          "long",
          "native",
          "new",
          "package",
          "private",
          "private",
          "protected",
          "protected",
          "public",
          "public",
          "return",
          "static",
          "strictfp",
          "switch",
          "synchronized",
          "throw",
          "throws",
          "transient",
          "try",
          "void",
          "volatile",
          "while"
        ]],
        literal: "P2D P3D HALF_PI PI QUARTER_PI TAU TWO_PI null true false",
        title: "setup draw",
        variable: "super this",
        built_in: [
          ...r,
          ...c
        ],
        type: u
      },
      contains: [
        l,
        o,
        a,
        s,
        t.C_LINE_COMMENT_MODE,
        t.C_BLOCK_COMMENT_MODE,
        t.APOS_STRING_MODE,
        t.QUOTE_STRING_MODE,
        t.C_NUMBER_MODE
      ]
    };
  }
  return HS = e, HS;
}
var zS, ZI;
function oee() {
  if (ZI) return zS;
  ZI = 1;
  function e(t) {
    return {
      name: "Python profiler",
      contains: [
        t.C_NUMBER_MODE,
        {
          begin: "[a-zA-Z_][\\da-zA-Z_]+\\.[\\da-zA-Z_]{1,3}",
          end: ":",
          excludeEnd: !0
        },
        {
          begin: "(ncalls|tottime|cumtime)",
          end: "$",
          keywords: "ncalls tottime|10 cumtime|10 filename",
          relevance: 10
        },
        {
          begin: "function calls",
          end: "$",
          contains: [t.C_NUMBER_MODE],
          relevance: 10
        },
        t.APOS_STRING_MODE,
        t.QUOTE_STRING_MODE,
        {
          className: "string",
          begin: "\\(",
          end: "\\)$",
          excludeBegin: !0,
          excludeEnd: !0,
          relevance: 0
        }
      ]
    };
  }
  return zS = e, zS;
}
var VS, JI;
function see() {
  if (JI) return VS;
  JI = 1;
  function e(t) {
    const n = {
      begin: /[a-z][A-Za-z0-9_]*/,
      relevance: 0
    }, r = {
      className: "symbol",
      variants: [
        { begin: /[A-Z][a-zA-Z0-9_]*/ },
        { begin: /_[A-Za-z0-9_]*/ }
      ],
      relevance: 0
    }, i = {
      begin: /\(/,
      end: /\)/,
      relevance: 0
    }, a = {
      begin: /\[/,
      end: /\]/
    }, o = {
      className: "comment",
      begin: /%/,
      end: /$/,
      contains: [t.PHRASAL_WORDS_MODE]
    }, s = {
      className: "string",
      begin: /`/,
      end: /`/,
      contains: [t.BACKSLASH_ESCAPE]
    }, l = {
      className: "string",
      // 0'a etc.
      begin: /0'(\\'|.)/
    }, u = {
      className: "string",
      begin: /0'\\s/
      // 0'\s
    }, d = [
      n,
      r,
      i,
      {
        // relevance booster
        begin: /:-/
      },
      a,
      o,
      t.C_BLOCK_COMMENT_MODE,
      t.QUOTE_STRING_MODE,
      t.APOS_STRING_MODE,
      s,
      l,
      u,
      t.C_NUMBER_MODE
    ];
    return i.contains = d, a.contains = d, {
      name: "Prolog",
      contains: d.concat([
        {
          // relevance booster
          begin: /\.$/
        }
      ])
    };
  }
  return VS = e, VS;
}
var WS, eL;
function lee() {
  if (eL) return WS;
  eL = 1;
  function e(t) {
    const n = "[ \\t\\f]*", r = "[ \\t\\f]+", i = n + "[:=]" + n, a = r, o = "(" + i + "|" + a + ")", s = "([^\\\\:= \\t\\f\\n]|\\\\.)+", l = {
      // skip DELIM
      end: o,
      relevance: 0,
      starts: {
        // value: everything until end of line (again, taking into account backslashes)
        className: "string",
        end: /$/,
        relevance: 0,
        contains: [
          { begin: "\\\\\\\\" },
          { begin: "\\\\\\n" }
        ]
      }
    };
    return {
      name: ".properties",
      disableAutodetect: !0,
      case_insensitive: !0,
      illegal: /\S/,
      contains: [
        t.COMMENT("^\\s*[!#]", "$"),
        // key: everything until whitespace or = or : (taking into account backslashes)
        // case of a key-value pair
        {
          returnBegin: !0,
          variants: [
            { begin: s + i },
            { begin: s + a }
          ],
          contains: [
            {
              className: "attr",
              begin: s,
              endsParent: !0
            }
          ],
          starts: l
        },
        // case of an empty key
        {
          className: "attr",
          begin: s + n + "$"
        }
      ]
    };
  }
  return WS = e, WS;
}
var KS, tL;
function uee() {
  if (tL) return KS;
  tL = 1;
  function e(t) {
    const n = [
      "package",
      "import",
      "option",
      "optional",
      "required",
      "repeated",
      "group",
      "oneof"
    ], r = [
      "double",
      "float",
      "int32",
      "int64",
      "uint32",
      "uint64",
      "sint32",
      "sint64",
      "fixed32",
      "fixed64",
      "sfixed32",
      "sfixed64",
      "bool",
      "string",
      "bytes"
    ], i = {
      match: [
        /(message|enum|service)\s+/,
        t.IDENT_RE
      ],
      scope: {
        1: "keyword",
        2: "title.class"
      }
    };
    return {
      name: "Protocol Buffers",
      aliases: ["proto"],
      keywords: {
        keyword: n,
        type: r,
        literal: [
          "true",
          "false"
        ]
      },
      contains: [
        t.QUOTE_STRING_MODE,
        t.NUMBER_MODE,
        t.C_LINE_COMMENT_MODE,
        t.C_BLOCK_COMMENT_MODE,
        i,
        {
          className: "function",
          beginKeywords: "rpc",
          end: /[{;]/,
          excludeEnd: !0,
          keywords: "rpc returns"
        },
        {
          // match enum items (relevance)
          // BLAH = ...;
          begin: /^\s*[A-Z_]+(?=\s*=[^\n]+;$)/
        }
      ]
    };
  }
  return KS = e, KS;
}
var jS, nL;
function cee() {
  if (nL) return jS;
  nL = 1;
  function e(t) {
    const n = {
      keyword: (
        /* language keywords */
        "and case default else elsif false if in import enherits node or true undef unless main settings $string "
      ),
      literal: (
        /* metaparameters */
        "alias audit before loglevel noop require subscribe tag owner ensure group mode name|0 changes context force incl lens load_path onlyif provider returns root show_diff type_check en_address ip_address realname command environment hour monute month monthday special target weekday creates cwd ogoutput refresh refreshonly tries try_sleep umask backup checksum content ctime force ignore links mtime purge recurse recurselimit replace selinux_ignore_defaults selrange selrole seltype seluser source souirce_permissions sourceselect validate_cmd validate_replacement allowdupe attribute_membership auth_membership forcelocal gid ia_load_module members system host_aliases ip allowed_trunk_vlans description device_url duplex encapsulation etherchannel native_vlan speed principals allow_root auth_class auth_type authenticate_user k_of_n mechanisms rule session_owner shared options device fstype enable hasrestart directory present absent link atboot blockdevice device dump pass remounts poller_tag use message withpath adminfile allow_virtual allowcdrom category configfiles flavor install_options instance package_settings platform responsefile status uninstall_options vendor unless_system_user unless_uid binary control flags hasstatus manifest pattern restart running start stop allowdupe auths expiry gid groups home iterations key_membership keys managehome membership password password_max_age password_min_age profile_membership profiles project purge_ssh_keys role_membership roles salt shell uid baseurl cost descr enabled enablegroups exclude failovermethod gpgcheck gpgkey http_caching include includepkgs keepalive metadata_expire metalink mirrorlist priority protect proxy proxy_password proxy_username repo_gpgcheck s3_enabled skip_if_unavailable sslcacert sslclientcert sslclientkey sslverify mounted"
      ),
      built_in: (
        /* core facts */
        "architecture augeasversion blockdevices boardmanufacturer boardproductname boardserialnumber cfkey dhcp_servers domain ec2_ ec2_userdata facterversion filesystems ldom fqdn gid hardwareisa hardwaremodel hostname id|0 interfaces ipaddress ipaddress_ ipaddress6 ipaddress6_ iphostnumber is_virtual kernel kernelmajversion kernelrelease kernelversion kernelrelease kernelversion lsbdistcodename lsbdistdescription lsbdistid lsbdistrelease lsbmajdistrelease lsbminordistrelease lsbrelease macaddress macaddress_ macosx_buildversion macosx_productname macosx_productversion macosx_productverson_major macosx_productversion_minor manufacturer memoryfree memorysize netmask metmask_ network_ operatingsystem operatingsystemmajrelease operatingsystemrelease osfamily partitions path physicalprocessorcount processor processorcount productname ps puppetversion rubysitedir rubyversion selinux selinux_config_mode selinux_config_policy selinux_current_mode selinux_current_mode selinux_enforced selinux_policyversion serialnumber sp_ sshdsakey sshecdsakey sshrsakey swapencrypted swapfree swapsize timezone type uniqueid uptime uptime_days uptime_hours uptime_seconds uuid virtual vlans xendomains zfs_version zonenae zones zpool_version"
      )
    }, r = t.COMMENT("#", "$"), i = "([A-Za-z_]|::)(\\w|::)*", a = t.inherit(t.TITLE_MODE, { begin: i }), o = {
      className: "variable",
      begin: "\\$" + i
    }, s = {
      className: "string",
      contains: [
        t.BACKSLASH_ESCAPE,
        o
      ],
      variants: [
        {
          begin: /'/,
          end: /'/
        },
        {
          begin: /"/,
          end: /"/
        }
      ]
    };
    return {
      name: "Puppet",
      aliases: ["pp"],
      contains: [
        r,
        o,
        s,
        {
          beginKeywords: "class",
          end: "\\{|;",
          illegal: /=/,
          contains: [
            a,
            r
          ]
        },
        {
          beginKeywords: "define",
          end: /\{/,
          contains: [
            {
              className: "section",
              begin: t.IDENT_RE,
              endsParent: !0
            }
          ]
        },
        {
          begin: t.IDENT_RE + "\\s+\\{",
          returnBegin: !0,
          end: /\S/,
          contains: [
            {
              className: "keyword",
              begin: t.IDENT_RE,
              relevance: 0.2
            },
            {
              begin: /\{/,
              end: /\}/,
              keywords: n,
              relevance: 0,
              contains: [
                s,
                r,
                {
                  begin: "[a-zA-Z_]+\\s*=>",
                  returnBegin: !0,
                  end: "=>",
                  contains: [
                    {
                      className: "attr",
                      begin: t.IDENT_RE
                    }
                  ]
                },
                {
                  className: "number",
                  begin: "(\\b0[0-7_]+)|(\\b0x[0-9a-fA-F_]+)|(\\b[1-9][0-9_]*(\\.[0-9_]+)?)|[0_]\\b",
                  relevance: 0
                },
                o
              ]
            }
          ],
          relevance: 0
        }
      ]
    };
  }
  return jS = e, jS;
}
var QS, rL;
function dee() {
  if (rL) return QS;
  rL = 1;
  function e(t) {
    const n = {
      // PB IDE color: #0080FF (Azure Radiance)
      className: "string",
      begin: '(~)?"',
      end: '"',
      illegal: "\\n"
    }, r = {
      // PB IDE color: #924B72 (Cannon Pink)
      //  "#" + a letter or underscore + letters, digits or underscores + (optional) "$"
      className: "symbol",
      begin: "#[a-zA-Z_]\\w*\\$?"
    };
    return {
      name: "PureBASIC",
      aliases: [
        "pb",
        "pbi"
      ],
      keywords: (
        // PB IDE color: #006666 (Blue Stone) + Bold
        // Keywords from all version of PureBASIC 5.00 upward ...
        "Align And Array As Break CallDebugger Case CompilerCase CompilerDefault CompilerElse CompilerElseIf CompilerEndIf CompilerEndSelect CompilerError CompilerIf CompilerSelect CompilerWarning Continue Data DataSection Debug DebugLevel Declare DeclareC DeclareCDLL DeclareDLL DeclareModule Default Define Dim DisableASM DisableDebugger DisableExplicit Else ElseIf EnableASM EnableDebugger EnableExplicit End EndDataSection EndDeclareModule EndEnumeration EndIf EndImport EndInterface EndMacro EndModule EndProcedure EndSelect EndStructure EndStructureUnion EndWith Enumeration EnumerationBinary Extends FakeReturn For ForEach ForEver Global Gosub Goto If Import ImportC IncludeBinary IncludeFile IncludePath Interface List Macro MacroExpandedCount Map Module NewList NewMap Next Not Or Procedure ProcedureC ProcedureCDLL ProcedureDLL ProcedureReturn Protected Prototype PrototypeC ReDim Read Repeat Restore Return Runtime Select Shared Static Step Structure StructureUnion Swap Threaded To UndefineMacro Until Until  UnuseModule UseModule Wend While With XIncludeFile XOr"
      ),
      contains: [
        // COMMENTS | PB IDE color: #00AAAA (Persian Green)
        t.COMMENT(";", "$", { relevance: 0 }),
        {
          // PROCEDURES DEFINITIONS
          className: "function",
          begin: "\\b(Procedure|Declare)(C|CDLL|DLL)?\\b",
          end: "\\(",
          excludeEnd: !0,
          returnBegin: !0,
          contains: [
            {
              // PROCEDURE KEYWORDS | PB IDE color: #006666 (Blue Stone) + Bold
              className: "keyword",
              begin: "(Procedure|Declare)(C|CDLL|DLL)?",
              excludeEnd: !0
            },
            {
              // PROCEDURE RETURN TYPE SETTING | PB IDE color: #000000 (Black)
              className: "type",
              begin: "\\.\\w*"
              // end: ' ',
            },
            t.UNDERSCORE_TITLE_MODE
            // PROCEDURE NAME | PB IDE color: #006666 (Blue Stone)
          ]
        },
        n,
        r
      ]
    };
  }
  return QS = e, QS;
}
var XS, iL;
function fee() {
  if (iL) return XS;
  iL = 1;
  function e(t) {
    const n = t.regex, r = new RegExp("[\\p{XID_Start}_]\\p{XID_Continue}*", "u"), i = [
      "and",
      "as",
      "assert",
      "async",
      "await",
      "break",
      "case",
      "class",
      "continue",
      "def",
      "del",
      "elif",
      "else",
      "except",
      "finally",
      "for",
      "from",
      "global",
      "if",
      "import",
      "in",
      "is",
      "lambda",
      "match",
      "nonlocal|10",
      "not",
      "or",
      "pass",
      "raise",
      "return",
      "try",
      "while",
      "with",
      "yield"
    ], l = {
      $pattern: /[A-Za-z]\w+|__\w+__/,
      keyword: i,
      built_in: [
        "__import__",
        "abs",
        "all",
        "any",
        "ascii",
        "bin",
        "bool",
        "breakpoint",
        "bytearray",
        "bytes",
        "callable",
        "chr",
        "classmethod",
        "compile",
        "complex",
        "delattr",
        "dict",
        "dir",
        "divmod",
        "enumerate",
        "eval",
        "exec",
        "filter",
        "float",
        "format",
        "frozenset",
        "getattr",
        "globals",
        "hasattr",
        "hash",
        "help",
        "hex",
        "id",
        "input",
        "int",
        "isinstance",
        "issubclass",
        "iter",
        "len",
        "list",
        "locals",
        "map",
        "max",
        "memoryview",
        "min",
        "next",
        "object",
        "oct",
        "open",
        "ord",
        "pow",
        "print",
        "property",
        "range",
        "repr",
        "reversed",
        "round",
        "set",
        "setattr",
        "slice",
        "sorted",
        "staticmethod",
        "str",
        "sum",
        "super",
        "tuple",
        "type",
        "vars",
        "zip"
      ],
      literal: [
        "__debug__",
        "Ellipsis",
        "False",
        "None",
        "NotImplemented",
        "True"
      ],
      type: [
        "Any",
        "Callable",
        "Coroutine",
        "Dict",
        "List",
        "Literal",
        "Generic",
        "Optional",
        "Sequence",
        "Set",
        "Tuple",
        "Type",
        "Union"
      ]
    }, u = {
      className: "meta",
      begin: /^(>>>|\.\.\.) /
    }, c = {
      className: "subst",
      begin: /\{/,
      end: /\}/,
      keywords: l,
      illegal: /#/
    }, d = {
      begin: /\{\{/,
      relevance: 0
    }, f = {
      className: "string",
      contains: [t.BACKSLASH_ESCAPE],
      variants: [
        {
          begin: /([uU]|[bB]|[rR]|[bB][rR]|[rR][bB])?'''/,
          end: /'''/,
          contains: [
            t.BACKSLASH_ESCAPE,
            u
          ],
          relevance: 10
        },
        {
          begin: /([uU]|[bB]|[rR]|[bB][rR]|[rR][bB])?"""/,
          end: /"""/,
          contains: [
            t.BACKSLASH_ESCAPE,
            u
          ],
          relevance: 10
        },
        {
          begin: /([fF][rR]|[rR][fF]|[fF])'''/,
          end: /'''/,
          contains: [
            t.BACKSLASH_ESCAPE,
            u,
            d,
            c
          ]
        },
        {
          begin: /([fF][rR]|[rR][fF]|[fF])"""/,
          end: /"""/,
          contains: [
            t.BACKSLASH_ESCAPE,
            u,
            d,
            c
          ]
        },
        {
          begin: /([uU]|[rR])'/,
          end: /'/,
          relevance: 10
        },
        {
          begin: /([uU]|[rR])"/,
          end: /"/,
          relevance: 10
        },
        {
          begin: /([bB]|[bB][rR]|[rR][bB])'/,
          end: /'/
        },
        {
          begin: /([bB]|[bB][rR]|[rR][bB])"/,
          end: /"/
        },
        {
          begin: /([fF][rR]|[rR][fF]|[fF])'/,
          end: /'/,
          contains: [
            t.BACKSLASH_ESCAPE,
            d,
            c
          ]
        },
        {
          begin: /([fF][rR]|[rR][fF]|[fF])"/,
          end: /"/,
          contains: [
            t.BACKSLASH_ESCAPE,
            d,
            c
          ]
        },
        t.APOS_STRING_MODE,
        t.QUOTE_STRING_MODE
      ]
    }, h = "[0-9](_?[0-9])*", m = `(\\b(${h}))?\\.(${h})|\\b(${h})\\.`, v = `\\b|${i.join("|")}`, b = {
      className: "number",
      relevance: 0,
      variants: [
        // exponentfloat, pointfloat
        // https://docs.python.org/3.9/reference/lexical_analysis.html#floating-point-literals
        // optionally imaginary
        // https://docs.python.org/3.9/reference/lexical_analysis.html#imaginary-literals
        // Note: no leading \b because floats can start with a decimal point
        // and we don't want to mishandle e.g. `fn(.5)`,
        // no trailing \b for pointfloat because it can end with a decimal point
        // and we don't want to mishandle e.g. `0..hex()`; this should be safe
        // because both MUST contain a decimal point and so cannot be confused with
        // the interior part of an identifier
        {
          begin: `(\\b(${h})|(${m}))[eE][+-]?(${h})[jJ]?(?=${v})`
        },
        {
          begin: `(${m})[jJ]?`
        },
        // decinteger, bininteger, octinteger, hexinteger
        // https://docs.python.org/3.9/reference/lexical_analysis.html#integer-literals
        // optionally "long" in Python 2
        // https://docs.python.org/2.7/reference/lexical_analysis.html#integer-and-long-integer-literals
        // decinteger is optionally imaginary
        // https://docs.python.org/3.9/reference/lexical_analysis.html#imaginary-literals
        {
          begin: `\\b([1-9](_?[0-9])*|0+(_?0)*)[lLjJ]?(?=${v})`
        },
        {
          begin: `\\b0[bB](_?[01])+[lL]?(?=${v})`
        },
        {
          begin: `\\b0[oO](_?[0-7])+[lL]?(?=${v})`
        },
        {
          begin: `\\b0[xX](_?[0-9a-fA-F])+[lL]?(?=${v})`
        },
        // imagnumber (digitpart-based)
        // https://docs.python.org/3.9/reference/lexical_analysis.html#imaginary-literals
        {
          begin: `\\b(${h})[jJ](?=${v})`
        }
      ]
    }, y = {
      className: "comment",
      begin: n.lookahead(/# type:/),
      end: /$/,
      keywords: l,
      contains: [
        {
          // prevent keywords from coloring `type`
          begin: /# type:/
        },
        // comment within a datatype comment includes no keywords
        {
          begin: /#/,
          end: /\b\B/,
          endsWithParent: !0
        }
      ]
    }, g = {
      className: "params",
      variants: [
        // Exclude params in functions without params
        {
          className: "",
          begin: /\(\s*\)/,
          skip: !0
        },
        {
          begin: /\(/,
          end: /\)/,
          excludeBegin: !0,
          excludeEnd: !0,
          keywords: l,
          contains: [
            "self",
            u,
            b,
            f,
            t.HASH_COMMENT_MODE
          ]
        }
      ]
    };
    return c.contains = [
      f,
      b,
      u
    ], {
      name: "Python",
      aliases: [
        "py",
        "gyp",
        "ipython"
      ],
      unicodeRegex: !0,
      keywords: l,
      illegal: /(<\/|\?)|=>/,
      contains: [
        u,
        b,
        {
          // very common convention
          begin: /\bself\b/
        },
        {
          // eat "if" prior to string so that it won't accidentally be
          // labeled as an f-string
          beginKeywords: "if",
          relevance: 0
        },
        f,
        y,
        t.HASH_COMMENT_MODE,
        {
          match: [
            /\bdef/,
            /\s+/,
            r
          ],
          scope: {
            1: "keyword",
            3: "title.function"
          },
          contains: [g]
        },
        {
          variants: [
            {
              match: [
                /\bclass/,
                /\s+/,
                r,
                /\s*/,
                /\(\s*/,
                r,
                /\s*\)/
              ]
            },
            {
              match: [
                /\bclass/,
                /\s+/,
                r
              ]
            }
          ],
          scope: {
            1: "keyword",
            3: "title.class",
            6: "title.class.inherited"
          }
        },
        {
          className: "meta",
          begin: /^[\t ]*@/,
          end: /(?=#)|$/,
          contains: [
            b,
            g,
            f
          ]
        }
      ]
    };
  }
  return XS = e, XS;
}
var ZS, aL;
function pee() {
  if (aL) return ZS;
  aL = 1;
  function e(t) {
    return {
      aliases: ["pycon"],
      contains: [
        {
          className: "meta.prompt",
          starts: {
            // a space separates the REPL prefix from the actual code
            // this is purely for cleaner HTML output
            end: / |$/,
            starts: {
              end: "$",
              subLanguage: "python"
            }
          },
          variants: [
            { begin: /^>>>(?=[ ]|$)/ },
            { begin: /^\.\.\.(?=[ ]|$)/ }
          ]
        }
      ]
    };
  }
  return ZS = e, ZS;
}
var JS, oL;
function mee() {
  if (oL) return JS;
  oL = 1;
  function e(t) {
    return {
      name: "Q",
      aliases: [
        "k",
        "kdb"
      ],
      keywords: {
        $pattern: /(`?)[A-Za-z0-9_]+\b/,
        keyword: "do while select delete by update from",
        literal: "0b 1b",
        built_in: "neg not null string reciprocal floor ceiling signum mod xbar xlog and or each scan over prior mmu lsq inv md5 ltime gtime count first var dev med cov cor all any rand sums prds mins maxs fills deltas ratios avgs differ prev next rank reverse iasc idesc asc desc msum mcount mavg mdev xrank mmin mmax xprev rotate distinct group where flip type key til get value attr cut set upsert raze union inter except cross sv vs sublist enlist read0 read1 hopen hclose hdel hsym hcount peach system ltrim rtrim trim lower upper ssr view tables views cols xcols keys xkey xcol xasc xdesc fkeys meta lj aj aj0 ij pj asof uj ww wj wj1 fby xgroup ungroup ej save load rsave rload show csv parse eval min max avg wavg wsum sin cos tan sum",
        type: "`float `double int `timestamp `timespan `datetime `time `boolean `symbol `char `byte `short `long `real `month `date `minute `second `guid"
      },
      contains: [
        t.C_LINE_COMMENT_MODE,
        t.QUOTE_STRING_MODE,
        t.C_NUMBER_MODE
      ]
    };
  }
  return JS = e, JS;
}
var ey, sL;
function hee() {
  if (sL) return ey;
  sL = 1;
  function e(t) {
    const n = t.regex, r = {
      keyword: "in of on if for while finally var new function do return void else break catch instanceof with throw case default try this switch continue typeof delete let yield const export super debugger as async await import",
      literal: "true false null undefined NaN Infinity",
      built_in: "eval isFinite isNaN parseFloat parseInt decodeURI decodeURIComponent encodeURI encodeURIComponent escape unescape Object Function Boolean Error EvalError InternalError RangeError ReferenceError StopIteration SyntaxError TypeError URIError Number Math Date String RegExp Array Float32Array Float64Array Int16Array Int32Array Int8Array Uint16Array Uint32Array Uint8Array Uint8ClampedArray ArrayBuffer DataView JSON Intl arguments require module console window document Symbol Set Map WeakSet WeakMap Proxy Reflect Behavior bool color coordinate date double enumeration font geocircle georectangle geoshape int list matrix4x4 parent point quaternion real rect size string url variant vector2d vector3d vector4d Promise"
    }, i = "[a-zA-Z_][a-zA-Z0-9\\._]*", a = {
      className: "keyword",
      begin: "\\bproperty\\b",
      starts: {
        className: "string",
        end: "(:|=|;|,|//|/\\*|$)",
        returnEnd: !0
      }
    }, o = {
      className: "keyword",
      begin: "\\bsignal\\b",
      starts: {
        className: "string",
        end: "(\\(|:|=|;|,|//|/\\*|$)",
        returnEnd: !0
      }
    }, s = {
      className: "attribute",
      begin: "\\bid\\s*:",
      starts: {
        className: "string",
        end: i,
        returnEnd: !1
      }
    }, l = {
      begin: i + "\\s*:",
      returnBegin: !0,
      contains: [
        {
          className: "attribute",
          begin: i,
          end: "\\s*:",
          excludeEnd: !0,
          relevance: 0
        }
      ],
      relevance: 0
    }, u = {
      begin: n.concat(i, /\s*\{/),
      end: /\{/,
      returnBegin: !0,
      relevance: 0,
      contains: [t.inherit(t.TITLE_MODE, { begin: i })]
    };
    return {
      name: "QML",
      aliases: ["qt"],
      case_insensitive: !1,
      keywords: r,
      contains: [
        {
          className: "meta",
          begin: /^\s*['"]use (strict|asm)['"]/
        },
        t.APOS_STRING_MODE,
        t.QUOTE_STRING_MODE,
        {
          // template string
          className: "string",
          begin: "`",
          end: "`",
          contains: [
            t.BACKSLASH_ESCAPE,
            {
              className: "subst",
              begin: "\\$\\{",
              end: "\\}"
            }
          ]
        },
        t.C_LINE_COMMENT_MODE,
        t.C_BLOCK_COMMENT_MODE,
        {
          className: "number",
          variants: [
            { begin: "\\b(0[bB][01]+)" },
            { begin: "\\b(0[oO][0-7]+)" },
            { begin: t.C_NUMBER_RE }
          ],
          relevance: 0
        },
        {
          // "value" container
          begin: "(" + t.RE_STARTERS_RE + "|\\b(case|return|throw)\\b)\\s*",
          keywords: "return throw case",
          contains: [
            t.C_LINE_COMMENT_MODE,
            t.C_BLOCK_COMMENT_MODE,
            t.REGEXP_MODE,
            {
              // E4X / JSX
              begin: /</,
              end: />\s*[);\]]/,
              relevance: 0,
              subLanguage: "xml"
            }
          ],
          relevance: 0
        },
        o,
        a,
        {
          className: "function",
          beginKeywords: "function",
          end: /\{/,
          excludeEnd: !0,
          contains: [
            t.inherit(t.TITLE_MODE, { begin: /[A-Za-z$_][0-9A-Za-z$_]*/ }),
            {
              className: "params",
              begin: /\(/,
              end: /\)/,
              excludeBegin: !0,
              excludeEnd: !0,
              contains: [
                t.C_LINE_COMMENT_MODE,
                t.C_BLOCK_COMMENT_MODE
              ]
            }
          ],
          illegal: /\[|%/
        },
        {
          // hack: prevents detection of keywords after dots
          begin: "\\." + t.IDENT_RE,
          relevance: 0
        },
        s,
        l,
        u
      ],
      illegal: /#/
    };
  }
  return ey = e, ey;
}
var ty, lL;
function gee() {
  if (lL) return ty;
  lL = 1;
  function e(t) {
    const n = t.regex, r = /(?:(?:[a-zA-Z]|\.[._a-zA-Z])[._a-zA-Z0-9]*)|\.(?!\d)/, i = n.either(
      // Special case: only hexadecimal binary powers can contain fractions
      /0[xX][0-9a-fA-F]+\.[0-9a-fA-F]*[pP][+-]?\d+i?/,
      // Hexadecimal numbers without fraction and optional binary power
      /0[xX][0-9a-fA-F]+(?:[pP][+-]?\d+)?[Li]?/,
      // Decimal numbers
      /(?:\d+(?:\.\d*)?|\.\d+)(?:[eE][+-]?\d+)?[Li]?/
    ), a = /[=!<>:]=|\|\||&&|:::?|<-|<<-|->>|->|\|>|[-+*\/?!$&|:<=>@^~]|\*\*/, o = n.either(
      /[()]/,
      /[{}]/,
      /\[\[/,
      /[[\]]/,
      /\\/,
      /,/
    );
    return {
      name: "R",
      keywords: {
        $pattern: r,
        keyword: "function if in break next repeat else for while",
        literal: "NULL NA TRUE FALSE Inf NaN NA_integer_|10 NA_real_|10 NA_character_|10 NA_complex_|10",
        built_in: (
          // Builtin constants
          "LETTERS letters month.abb month.name pi T F abs acos acosh all any anyNA Arg as.call as.character as.complex as.double as.environment as.integer as.logical as.null.default as.numeric as.raw asin asinh atan atanh attr attributes baseenv browser c call ceiling class Conj cos cosh cospi cummax cummin cumprod cumsum digamma dim dimnames emptyenv exp expression floor forceAndCall gamma gc.time globalenv Im interactive invisible is.array is.atomic is.call is.character is.complex is.double is.environment is.expression is.finite is.function is.infinite is.integer is.language is.list is.logical is.matrix is.na is.name is.nan is.null is.numeric is.object is.pairlist is.raw is.recursive is.single is.symbol lazyLoadDBfetch length lgamma list log max min missing Mod names nargs nzchar oldClass on.exit pos.to.env proc.time prod quote range Re rep retracemem return round seq_along seq_len seq.int sign signif sin sinh sinpi sqrt standardGeneric substitute sum switch tan tanh tanpi tracemem trigamma trunc unclass untracemem UseMethod xtfrm"
        )
      },
      contains: [
        // Roxygen comments
        t.COMMENT(
          /#'/,
          /$/,
          { contains: [
            {
              // Handle `@examples` separately to cause all subsequent code
              // until the next `@`-tag on its own line to be kept as-is,
              // preventing highlighting. This code is example R code, so nested
              // doctags shouldn’t be treated as such. See
              // `test/markup/r/roxygen.txt` for an example.
              scope: "doctag",
              match: /@examples/,
              starts: {
                end: n.lookahead(n.either(
                  // end if another doc comment
                  /\n^#'\s*(?=@[a-zA-Z]+)/,
                  // or a line with no comment
                  /\n^(?!#')/
                )),
                endsParent: !0
              }
            },
            {
              // Handle `@param` to highlight the parameter name following
              // after.
              scope: "doctag",
              begin: "@param",
              end: /$/,
              contains: [
                {
                  scope: "variable",
                  variants: [
                    { match: r },
                    { match: /`(?:\\.|[^`\\])+`/ }
                  ],
                  endsParent: !0
                }
              ]
            },
            {
              scope: "doctag",
              match: /@[a-zA-Z]+/
            },
            {
              scope: "keyword",
              match: /\\[a-zA-Z]+/
            }
          ] }
        ),
        t.HASH_COMMENT_MODE,
        {
          scope: "string",
          contains: [t.BACKSLASH_ESCAPE],
          variants: [
            t.END_SAME_AS_BEGIN({
              begin: /[rR]"(-*)\(/,
              end: /\)(-*)"/
            }),
            t.END_SAME_AS_BEGIN({
              begin: /[rR]"(-*)\{/,
              end: /\}(-*)"/
            }),
            t.END_SAME_AS_BEGIN({
              begin: /[rR]"(-*)\[/,
              end: /\](-*)"/
            }),
            t.END_SAME_AS_BEGIN({
              begin: /[rR]'(-*)\(/,
              end: /\)(-*)'/
            }),
            t.END_SAME_AS_BEGIN({
              begin: /[rR]'(-*)\{/,
              end: /\}(-*)'/
            }),
            t.END_SAME_AS_BEGIN({
              begin: /[rR]'(-*)\[/,
              end: /\](-*)'/
            }),
            {
              begin: '"',
              end: '"',
              relevance: 0
            },
            {
              begin: "'",
              end: "'",
              relevance: 0
            }
          ]
        },
        // Matching numbers immediately following punctuation and operators is
        // tricky since we need to look at the character ahead of a number to
        // ensure the number is not part of an identifier, and we cannot use
        // negative look-behind assertions. So instead we explicitly handle all
        // possible combinations of (operator|punctuation), number.
        // TODO: replace with negative look-behind when available
        // { begin: /(?<![a-zA-Z0-9._])0[xX][0-9a-fA-F]+\.[0-9a-fA-F]*[pP][+-]?\d+i?/ },
        // { begin: /(?<![a-zA-Z0-9._])0[xX][0-9a-fA-F]+([pP][+-]?\d+)?[Li]?/ },
        // { begin: /(?<![a-zA-Z0-9._])(\d+(\.\d*)?|\.\d+)([eE][+-]?\d+)?[Li]?/ }
        {
          relevance: 0,
          variants: [
            {
              scope: {
                1: "operator",
                2: "number"
              },
              match: [
                a,
                i
              ]
            },
            {
              scope: {
                1: "operator",
                2: "number"
              },
              match: [
                /%[^%]*%/,
                i
              ]
            },
            {
              scope: {
                1: "punctuation",
                2: "number"
              },
              match: [
                o,
                i
              ]
            },
            {
              scope: { 2: "number" },
              match: [
                /[^a-zA-Z0-9._]|^/,
                // not part of an identifier, or start of document
                i
              ]
            }
          ]
        },
        // Operators/punctuation when they're not directly followed by numbers
        {
          // Relevance boost for the most common assignment form.
          scope: { 3: "operator" },
          match: [
            r,
            /\s+/,
            /<-/,
            /\s+/
          ]
        },
        {
          scope: "operator",
          relevance: 0,
          variants: [
            { match: a },
            { match: /%[^%]*%/ }
          ]
        },
        {
          scope: "punctuation",
          relevance: 0,
          match: o
        },
        {
          // Escaped identifier
          begin: "`",
          end: "`",
          contains: [{ begin: /\\./ }]
        }
      ]
    };
  }
  return ty = e, ty;
}
var ny, uL;
function _ee() {
  if (uL) return ny;
  uL = 1;
  function e(t) {
    return {
      name: "ReasonML",
      aliases: ["re"],
      keywords: {
        $pattern: /[a-z_]\w*!?/,
        keyword: [
          "and",
          "as",
          "asr",
          "assert",
          "begin",
          "class",
          "constraint",
          "do",
          "done",
          "downto",
          "else",
          "end",
          "esfun",
          "exception",
          "external",
          "for",
          "fun",
          "function",
          "functor",
          "if",
          "in",
          "include",
          "inherit",
          "initializer",
          "land",
          "lazy",
          "let",
          "lor",
          "lsl",
          "lsr",
          "lxor",
          "mod",
          "module",
          "mutable",
          "new",
          "nonrec",
          "object",
          "of",
          "open",
          "or",
          "pri",
          "pub",
          "rec",
          "sig",
          "struct",
          "switch",
          "then",
          "to",
          "try",
          "type",
          "val",
          "virtual",
          "when",
          "while",
          "with"
        ],
        built_in: [
          "array",
          "bool",
          "bytes",
          "char",
          "exn|5",
          "float",
          "int",
          "int32",
          "int64",
          "list",
          "lazy_t|5",
          "nativeint|5",
          "ref",
          "string",
          "unit"
        ],
        literal: ["true", "false"]
      },
      illegal: /(:-|:=|\$\{|\+=)/,
      contains: [
        {
          scope: "literal",
          match: /\[(\|\|)?\]|\(\)/,
          relevance: 0
        },
        t.C_LINE_COMMENT_MODE,
        t.COMMENT(/\/\*/, /\*\//, { illegal: /^(#,\/\/)/ }),
        {
          /* type variable */
          scope: "symbol",
          match: /\'[A-Za-z_](?!\')[\w\']*/
          /* the grammar is ambiguous on how 'a'b should be interpreted but not the compiler */
        },
        {
          /* polymorphic variant */
          scope: "type",
          match: /`[A-Z][\w\']*/
        },
        {
          /* module or constructor */
          scope: "type",
          match: /\b[A-Z][\w\']*/,
          relevance: 0
        },
        {
          /* don't color identifiers, but safely catch all identifiers with ' */
          match: /[a-z_]\w*\'[\w\']*/,
          relevance: 0
        },
        {
          scope: "operator",
          match: /\s+(\|\||\+[\+\.]?|\*[\*\/\.]?|\/[\.]?|\.\.\.|\|>|&&|===?)\s+/,
          relevance: 0
        },
        t.inherit(t.APOS_STRING_MODE, {
          scope: "string",
          relevance: 0
        }),
        t.inherit(t.QUOTE_STRING_MODE, { illegal: null }),
        {
          scope: "number",
          variants: [
            { match: /\b0[xX][a-fA-F0-9_]+[Lln]?/ },
            { match: /\b0[oO][0-7_]+[Lln]?/ },
            { match: /\b0[bB][01_]+[Lln]?/ },
            { match: /\b[0-9][0-9_]*([Lln]|(\.[0-9_]*)?([eE][-+]?[0-9_]+)?)/ }
          ],
          relevance: 0
        }
      ]
    };
  }
  return ny = e, ny;
}
var ry, cL;
function vee() {
  if (cL) return ry;
  cL = 1;
  function e(t) {
    return {
      name: "RenderMan RIB",
      keywords: "ArchiveRecord AreaLightSource Atmosphere Attribute AttributeBegin AttributeEnd Basis Begin Blobby Bound Clipping ClippingPlane Color ColorSamples ConcatTransform Cone CoordinateSystem CoordSysTransform CropWindow Curves Cylinder DepthOfField Detail DetailRange Disk Displacement Display End ErrorHandler Exposure Exterior Format FrameAspectRatio FrameBegin FrameEnd GeneralPolygon GeometricApproximation Geometry Hider Hyperboloid Identity Illuminate Imager Interior LightSource MakeCubeFaceEnvironment MakeLatLongEnvironment MakeShadow MakeTexture Matte MotionBegin MotionEnd NuPatch ObjectBegin ObjectEnd ObjectInstance Opacity Option Orientation Paraboloid Patch PatchMesh Perspective PixelFilter PixelSamples PixelVariance Points PointsGeneralPolygons PointsPolygons Polygon Procedural Projection Quantize ReadArchive RelativeDetail ReverseOrientation Rotate Scale ScreenWindow ShadingInterpolation ShadingRate Shutter Sides Skew SolidBegin SolidEnd Sphere SubdivisionMesh Surface TextureCoordinates Torus Transform TransformBegin TransformEnd TransformPoints Translate TrimCurve WorldBegin WorldEnd",
      illegal: "</",
      contains: [
        t.HASH_COMMENT_MODE,
        t.C_NUMBER_MODE,
        t.APOS_STRING_MODE,
        t.QUOTE_STRING_MODE
      ]
    };
  }
  return ry = e, ry;
}
var iy, dL;
function bee() {
  if (dL) return iy;
  dL = 1;
  function e(t) {
    const n = "[a-zA-Z-_][^\\n{]+\\{", r = {
      className: "attribute",
      begin: /[a-zA-Z-_]+/,
      end: /\s*:/,
      excludeEnd: !0,
      starts: {
        end: ";",
        relevance: 0,
        contains: [
          {
            className: "variable",
            begin: /\.[a-zA-Z-_]+/
          },
          {
            className: "keyword",
            begin: /\(optional\)/
          }
        ]
      }
    };
    return {
      name: "Roboconf",
      aliases: [
        "graph",
        "instances"
      ],
      case_insensitive: !0,
      keywords: "import",
      contains: [
        // Facet sections
        {
          begin: "^facet " + n,
          end: /\}/,
          keywords: "facet",
          contains: [
            r,
            t.HASH_COMMENT_MODE
          ]
        },
        // Instance sections
        {
          begin: "^\\s*instance of " + n,
          end: /\}/,
          keywords: "name count channels instance-data instance-state instance of",
          illegal: /\S/,
          contains: [
            "self",
            r,
            t.HASH_COMMENT_MODE
          ]
        },
        // Component sections
        {
          begin: "^" + n,
          end: /\}/,
          contains: [
            r,
            t.HASH_COMMENT_MODE
          ]
        },
        // Comments
        t.HASH_COMMENT_MODE
      ]
    };
  }
  return iy = e, iy;
}
var ay, fL;
function Eee() {
  if (fL) return ay;
  fL = 1;
  function e(t) {
    const n = "foreach do while for if from to step else on-error and or not in", r = "global local beep delay put len typeof pick log time set find environment terminal error execute parse resolve toarray tobool toid toip toip6 tonum tostr totime", i = "add remove enable disable set get print export edit find run debug error info warning", a = "true false yes no nothing nil null", o = "traffic-flow traffic-generator firewall scheduler aaa accounting address-list address align area bandwidth-server bfd bgp bridge client clock community config connection console customer default dhcp-client dhcp-server discovery dns e-mail ethernet filter firmware gps graphing group hardware health hotspot identity igmp-proxy incoming instance interface ip ipsec ipv6 irq l2tp-server lcd ldp logging mac-server mac-winbox mangle manual mirror mme mpls nat nd neighbor network note ntp ospf ospf-v3 ovpn-server page peer pim ping policy pool port ppp pppoe-client pptp-server prefix profile proposal proxy queue radius resource rip ripng route routing screen script security-profiles server service service-port settings shares smb sms sniffer snmp snooper socks sstp-server system tool tracking type upgrade upnp user-manager users user vlan secret vrrp watchdog web-access wireless pptp pppoe lan wan layer7-protocol lease simple raw", s = {
      className: "variable",
      variants: [
        { begin: /\$[\w\d#@][\w\d_]*/ },
        { begin: /\$\{(.*?)\}/ }
      ]
    }, l = {
      className: "string",
      begin: /"/,
      end: /"/,
      contains: [
        t.BACKSLASH_ESCAPE,
        s,
        {
          className: "variable",
          begin: /\$\(/,
          end: /\)/,
          contains: [t.BACKSLASH_ESCAPE]
        }
      ]
    }, u = {
      className: "string",
      begin: /'/,
      end: /'/
    };
    return {
      name: "MikroTik RouterOS script",
      aliases: ["mikrotik"],
      case_insensitive: !0,
      keywords: {
        $pattern: /:?[\w-]+/,
        literal: a,
        keyword: n + " :" + n.split(" ").join(" :") + " :" + r.split(" ").join(" :")
      },
      contains: [
        {
          // illegal syntax
          variants: [
            {
              // -- comment
              begin: /\/\*/,
              end: /\*\//
            },
            {
              // Stan comment
              begin: /\/\//,
              end: /$/
            },
            {
              // HTML tags
              begin: /<\//,
              end: />/
            }
          ],
          illegal: /./
        },
        t.COMMENT("^#", "$"),
        l,
        u,
        s,
        // attribute=value
        {
          // > is to avoid matches with => in other grammars
          begin: /[\w-]+=([^\s{}[\]()>]+)/,
          relevance: 0,
          returnBegin: !0,
          contains: [
            {
              className: "attribute",
              begin: /[^=]+/
            },
            {
              begin: /=/,
              endsWithParent: !0,
              relevance: 0,
              contains: [
                l,
                u,
                s,
                {
                  className: "literal",
                  begin: "\\b(" + a.split(" ").join("|") + ")\\b"
                },
                {
                  // Do not format unclassified values. Needed to exclude highlighting of values as built_in.
                  begin: /("[^"]*"|[^\s{}[\]]+)/
                }
                /*
                {
                  // IPv4 addresses and subnets
                  className: 'number',
                  variants: [
                    {begin: IPADDR_wBITMASK+'(,'+IPADDR_wBITMASK+')*'}, //192.168.0.0/24,1.2.3.0/24
                    {begin: IPADDR+'-'+IPADDR},       // 192.168.0.1-192.168.0.3
                    {begin: IPADDR+'(,'+IPADDR+')*'}, // 192.168.0.1,192.168.0.34,192.168.24.1,192.168.0.1
                  ]
                },
                {
                  // MAC addresses and DHCP Client IDs
                  className: 'number',
                  begin: /\b(1:)?([0-9A-Fa-f]{1,2}[:-]){5}([0-9A-Fa-f]){1,2}\b/,
                },
                */
              ]
            }
          ]
        },
        {
          // HEX values
          className: "number",
          begin: /\*[0-9a-fA-F]+/
        },
        {
          begin: "\\b(" + i.split(" ").join("|") + ")([\\s[(\\]|])",
          returnBegin: !0,
          contains: [
            {
              className: "built_in",
              // 'function',
              begin: /\w+/
            }
          ]
        },
        {
          className: "built_in",
          variants: [
            { begin: "(\\.\\./|/|\\s)((" + o.split(" ").join("|") + ");?\\s)+" },
            {
              begin: /\.\./,
              relevance: 0
            }
          ]
        }
      ]
    };
  }
  return ay = e, ay;
}
var oy, pL;
function See() {
  if (pL) return oy;
  pL = 1;
  function e(t) {
    const n = [
      "abs",
      "acos",
      "ambient",
      "area",
      "asin",
      "atan",
      "atmosphere",
      "attribute",
      "calculatenormal",
      "ceil",
      "cellnoise",
      "clamp",
      "comp",
      "concat",
      "cos",
      "degrees",
      "depth",
      "Deriv",
      "diffuse",
      "distance",
      "Du",
      "Dv",
      "environment",
      "exp",
      "faceforward",
      "filterstep",
      "floor",
      "format",
      "fresnel",
      "incident",
      "length",
      "lightsource",
      "log",
      "match",
      "max",
      "min",
      "mod",
      "noise",
      "normalize",
      "ntransform",
      "opposite",
      "option",
      "phong",
      "pnoise",
      "pow",
      "printf",
      "ptlined",
      "radians",
      "random",
      "reflect",
      "refract",
      "renderinfo",
      "round",
      "setcomp",
      "setxcomp",
      "setycomp",
      "setzcomp",
      "shadow",
      "sign",
      "sin",
      "smoothstep",
      "specular",
      "specularbrdf",
      "spline",
      "sqrt",
      "step",
      "tan",
      "texture",
      "textureinfo",
      "trace",
      "transform",
      "vtransform",
      "xcomp",
      "ycomp",
      "zcomp"
    ], r = [
      "matrix",
      "float",
      "color",
      "point",
      "normal",
      "vector"
    ], i = [
      "while",
      "for",
      "if",
      "do",
      "return",
      "else",
      "break",
      "extern",
      "continue"
    ], a = {
      match: [
        /(surface|displacement|light|volume|imager)/,
        /\s+/,
        t.IDENT_RE
      ],
      scope: {
        1: "keyword",
        3: "title.class"
      }
    };
    return {
      name: "RenderMan RSL",
      keywords: {
        keyword: i,
        built_in: n,
        type: r
      },
      illegal: "</",
      contains: [
        t.C_LINE_COMMENT_MODE,
        t.C_BLOCK_COMMENT_MODE,
        t.QUOTE_STRING_MODE,
        t.APOS_STRING_MODE,
        t.C_NUMBER_MODE,
        {
          className: "meta",
          begin: "#",
          end: "$"
        },
        a,
        {
          beginKeywords: "illuminate illuminance gather",
          end: "\\("
        }
      ]
    };
  }
  return oy = e, oy;
}
var sy, mL;
function yee() {
  if (mL) return sy;
  mL = 1;
  function e(t) {
    return {
      name: "Oracle Rules Language",
      keywords: {
        keyword: "BILL_PERIOD BILL_START BILL_STOP RS_EFFECTIVE_START RS_EFFECTIVE_STOP RS_JURIS_CODE RS_OPCO_CODE INTDADDATTRIBUTE|5 INTDADDVMSG|5 INTDBLOCKOP|5 INTDBLOCKOPNA|5 INTDCLOSE|5 INTDCOUNT|5 INTDCOUNTSTATUSCODE|5 INTDCREATEMASK|5 INTDCREATEDAYMASK|5 INTDCREATEFACTORMASK|5 INTDCREATEHANDLE|5 INTDCREATEOVERRIDEDAYMASK|5 INTDCREATEOVERRIDEMASK|5 INTDCREATESTATUSCODEMASK|5 INTDCREATETOUPERIOD|5 INTDDELETE|5 INTDDIPTEST|5 INTDEXPORT|5 INTDGETERRORCODE|5 INTDGETERRORMESSAGE|5 INTDISEQUAL|5 INTDJOIN|5 INTDLOAD|5 INTDLOADACTUALCUT|5 INTDLOADDATES|5 INTDLOADHIST|5 INTDLOADLIST|5 INTDLOADLISTDATES|5 INTDLOADLISTENERGY|5 INTDLOADLISTHIST|5 INTDLOADRELATEDCHANNEL|5 INTDLOADSP|5 INTDLOADSTAGING|5 INTDLOADUOM|5 INTDLOADUOMDATES|5 INTDLOADUOMHIST|5 INTDLOADVERSION|5 INTDOPEN|5 INTDREADFIRST|5 INTDREADNEXT|5 INTDRECCOUNT|5 INTDRELEASE|5 INTDREPLACE|5 INTDROLLAVG|5 INTDROLLPEAK|5 INTDSCALAROP|5 INTDSCALE|5 INTDSETATTRIBUTE|5 INTDSETDSTPARTICIPANT|5 INTDSETSTRING|5 INTDSETVALUE|5 INTDSETVALUESTATUS|5 INTDSHIFTSTARTTIME|5 INTDSMOOTH|5 INTDSORT|5 INTDSPIKETEST|5 INTDSUBSET|5 INTDTOU|5 INTDTOURELEASE|5 INTDTOUVALUE|5 INTDUPDATESTATS|5 INTDVALUE|5 STDEV INTDDELETEEX|5 INTDLOADEXACTUAL|5 INTDLOADEXCUT|5 INTDLOADEXDATES|5 INTDLOADEX|5 INTDLOADEXRELATEDCHANNEL|5 INTDSAVEEX|5 MVLOAD|5 MVLOADACCT|5 MVLOADACCTDATES|5 MVLOADACCTHIST|5 MVLOADDATES|5 MVLOADHIST|5 MVLOADLIST|5 MVLOADLISTDATES|5 MVLOADLISTHIST|5 IF FOR NEXT DONE SELECT END CALL ABORT CLEAR CHANNEL FACTOR LIST NUMBER OVERRIDE SET WEEK DISTRIBUTIONNODE ELSE WHEN THEN OTHERWISE IENUM CSV INCLUDE LEAVE RIDER SAVE DELETE NOVALUE SECTION WARN SAVE_UPDATE DETERMINANT LABEL REPORT REVENUE EACH IN FROM TOTAL CHARGE BLOCK AND OR CSV_FILE RATE_CODE AUXILIARY_DEMAND UIDACCOUNT RS BILL_PERIOD_SELECT HOURS_PER_MONTH INTD_ERROR_STOP SEASON_SCHEDULE_NAME ACCOUNTFACTOR ARRAYUPPERBOUND CALLSTOREDPROC GETADOCONNECTION GETCONNECT GETDATASOURCE GETQUALIFIER GETUSERID HASVALUE LISTCOUNT LISTOP LISTUPDATE LISTVALUE PRORATEFACTOR RSPRORATE SETBINPATH SETDBMONITOR WQ_OPEN BILLINGHOURS DATE DATEFROMFLOAT DATETIMEFROMSTRING DATETIMETOSTRING DATETOFLOAT DAY DAYDIFF DAYNAME DBDATETIME HOUR MINUTE MONTH MONTHDIFF MONTHHOURS MONTHNAME ROUNDDATE SAMEWEEKDAYLASTYEAR SECOND WEEKDAY WEEKDIFF YEAR YEARDAY YEARSTR COMPSUM HISTCOUNT HISTMAX HISTMIN HISTMINNZ HISTVALUE MAXNRANGE MAXRANGE MINRANGE COMPIKVA COMPKVA COMPKVARFROMKQKW COMPLF IDATTR FLAG LF2KW LF2KWH MAXKW POWERFACTOR READING2USAGE AVGSEASON MAXSEASON MONTHLYMERGE SEASONVALUE SUMSEASON ACCTREADDATES ACCTTABLELOAD CONFIGADD CONFIGGET CREATEOBJECT CREATEREPORT EMAILCLIENT EXPBLKMDMUSAGE EXPMDMUSAGE EXPORT_USAGE FACTORINEFFECT GETUSERSPECIFIEDSTOP INEFFECT ISHOLIDAY RUNRATE SAVE_PROFILE SETREPORTTITLE USEREXIT WATFORRUNRATE TO TABLE ACOS ASIN ATAN ATAN2 BITAND CEIL COS COSECANT COSH COTANGENT DIVQUOT DIVREM EXP FABS FLOOR FMOD FREPM FREXPN LOG LOG10 MAX MAXN MIN MINNZ MODF POW ROUND ROUND2VALUE ROUNDINT SECANT SIN SINH SQROOT TAN TANH FLOAT2STRING FLOAT2STRINGNC INSTR LEFT LEN LTRIM MID RIGHT RTRIM STRING STRINGNC TOLOWER TOUPPER TRIM NUMDAYS READ_DATE STAGING",
        built_in: "IDENTIFIER OPTIONS XML_ELEMENT XML_OP XML_ELEMENT_OF DOMDOCCREATE DOMDOCLOADFILE DOMDOCLOADXML DOMDOCSAVEFILE DOMDOCGETROOT DOMDOCADDPI DOMNODEGETNAME DOMNODEGETTYPE DOMNODEGETVALUE DOMNODEGETCHILDCT DOMNODEGETFIRSTCHILD DOMNODEGETSIBLING DOMNODECREATECHILDELEMENT DOMNODESETATTRIBUTE DOMNODEGETCHILDELEMENTCT DOMNODEGETFIRSTCHILDELEMENT DOMNODEGETSIBLINGELEMENT DOMNODEGETATTRIBUTECT DOMNODEGETATTRIBUTEI DOMNODEGETATTRIBUTEBYNAME DOMNODEGETBYNAME"
      },
      contains: [
        t.C_LINE_COMMENT_MODE,
        t.C_BLOCK_COMMENT_MODE,
        t.APOS_STRING_MODE,
        t.QUOTE_STRING_MODE,
        t.C_NUMBER_MODE,
        {
          className: "literal",
          variants: [
            {
              // looks like #-comment
              begin: "#\\s+",
              relevance: 0
            },
            { begin: "#[a-zA-Z .]+" }
          ]
        }
      ]
    };
  }
  return sy = e, sy;
}
var ly, hL;
function Tee() {
  if (hL) return ly;
  hL = 1;
  function e(t) {
    const n = t.regex, r = {
      className: "title.function.invoke",
      relevance: 0,
      begin: n.concat(
        /\b/,
        /(?!let|for|while|if|else|match\b)/,
        t.IDENT_RE,
        n.lookahead(/\s*\(/)
      )
    }, i = "([ui](8|16|32|64|128|size)|f(32|64))?", a = [
      "abstract",
      "as",
      "async",
      "await",
      "become",
      "box",
      "break",
      "const",
      "continue",
      "crate",
      "do",
      "dyn",
      "else",
      "enum",
      "extern",
      "false",
      "final",
      "fn",
      "for",
      "if",
      "impl",
      "in",
      "let",
      "loop",
      "macro",
      "match",
      "mod",
      "move",
      "mut",
      "override",
      "priv",
      "pub",
      "ref",
      "return",
      "self",
      "Self",
      "static",
      "struct",
      "super",
      "trait",
      "true",
      "try",
      "type",
      "typeof",
      "unsafe",
      "unsized",
      "use",
      "virtual",
      "where",
      "while",
      "yield"
    ], o = [
      "true",
      "false",
      "Some",
      "None",
      "Ok",
      "Err"
    ], s = [
      // functions
      "drop ",
      // traits
      "Copy",
      "Send",
      "Sized",
      "Sync",
      "Drop",
      "Fn",
      "FnMut",
      "FnOnce",
      "ToOwned",
      "Clone",
      "Debug",
      "PartialEq",
      "PartialOrd",
      "Eq",
      "Ord",
      "AsRef",
      "AsMut",
      "Into",
      "From",
      "Default",
      "Iterator",
      "Extend",
      "IntoIterator",
      "DoubleEndedIterator",
      "ExactSizeIterator",
      "SliceConcatExt",
      "ToString",
      // macros
      "assert!",
      "assert_eq!",
      "bitflags!",
      "bytes!",
      "cfg!",
      "col!",
      "concat!",
      "concat_idents!",
      "debug_assert!",
      "debug_assert_eq!",
      "env!",
      "eprintln!",
      "panic!",
      "file!",
      "format!",
      "format_args!",
      "include_bytes!",
      "include_str!",
      "line!",
      "local_data_key!",
      "module_path!",
      "option_env!",
      "print!",
      "println!",
      "select!",
      "stringify!",
      "try!",
      "unimplemented!",
      "unreachable!",
      "vec!",
      "write!",
      "writeln!",
      "macro_rules!",
      "assert_ne!",
      "debug_assert_ne!"
    ], l = [
      "i8",
      "i16",
      "i32",
      "i64",
      "i128",
      "isize",
      "u8",
      "u16",
      "u32",
      "u64",
      "u128",
      "usize",
      "f32",
      "f64",
      "str",
      "char",
      "bool",
      "Box",
      "Option",
      "Result",
      "String",
      "Vec"
    ];
    return {
      name: "Rust",
      aliases: ["rs"],
      keywords: {
        $pattern: t.IDENT_RE + "!?",
        type: l,
        keyword: a,
        literal: o,
        built_in: s
      },
      illegal: "</",
      contains: [
        t.C_LINE_COMMENT_MODE,
        t.COMMENT("/\\*", "\\*/", { contains: ["self"] }),
        t.inherit(t.QUOTE_STRING_MODE, {
          begin: /b?"/,
          illegal: null
        }),
        {
          className: "string",
          variants: [
            { begin: /b?r(#*)"(.|\n)*?"\1(?!#)/ },
            { begin: /b?'\\?(x\w{2}|u\w{4}|U\w{8}|.)'/ }
          ]
        },
        {
          className: "symbol",
          begin: /'[a-zA-Z_][a-zA-Z0-9_]*/
        },
        {
          className: "number",
          variants: [
            { begin: "\\b0b([01_]+)" + i },
            { begin: "\\b0o([0-7_]+)" + i },
            { begin: "\\b0x([A-Fa-f0-9_]+)" + i },
            { begin: "\\b(\\d[\\d_]*(\\.[0-9_]+)?([eE][+-]?[0-9_]+)?)" + i }
          ],
          relevance: 0
        },
        {
          begin: [
            /fn/,
            /\s+/,
            t.UNDERSCORE_IDENT_RE
          ],
          className: {
            1: "keyword",
            3: "title.function"
          }
        },
        {
          className: "meta",
          begin: "#!?\\[",
          end: "\\]",
          contains: [
            {
              className: "string",
              begin: /"/,
              end: /"/
            }
          ]
        },
        {
          begin: [
            /let/,
            /\s+/,
            /(?:mut\s+)?/,
            t.UNDERSCORE_IDENT_RE
          ],
          className: {
            1: "keyword",
            3: "keyword",
            4: "variable"
          }
        },
        // must come before impl/for rule later
        {
          begin: [
            /for/,
            /\s+/,
            t.UNDERSCORE_IDENT_RE,
            /\s+/,
            /in/
          ],
          className: {
            1: "keyword",
            3: "variable",
            5: "keyword"
          }
        },
        {
          begin: [
            /type/,
            /\s+/,
            t.UNDERSCORE_IDENT_RE
          ],
          className: {
            1: "keyword",
            3: "title.class"
          }
        },
        {
          begin: [
            /(?:trait|enum|struct|union|impl|for)/,
            /\s+/,
            t.UNDERSCORE_IDENT_RE
          ],
          className: {
            1: "keyword",
            3: "title.class"
          }
        },
        {
          begin: t.IDENT_RE + "::",
          keywords: {
            keyword: "Self",
            built_in: s,
            type: l
          }
        },
        {
          className: "punctuation",
          begin: "->"
        },
        r
      ]
    };
  }
  return ly = e, ly;
}
var uy, gL;
function Cee() {
  if (gL) return uy;
  gL = 1;
  function e(t) {
    const n = t.regex, r = [
      "do",
      "if",
      "then",
      "else",
      "end",
      "until",
      "while",
      "abort",
      "array",
      "attrib",
      "by",
      "call",
      "cards",
      "cards4",
      "catname",
      "continue",
      "datalines",
      "datalines4",
      "delete",
      "delim",
      "delimiter",
      "display",
      "dm",
      "drop",
      "endsas",
      "error",
      "file",
      "filename",
      "footnote",
      "format",
      "goto",
      "in",
      "infile",
      "informat",
      "input",
      "keep",
      "label",
      "leave",
      "length",
      "libname",
      "link",
      "list",
      "lostcard",
      "merge",
      "missing",
      "modify",
      "options",
      "output",
      "out",
      "page",
      "put",
      "redirect",
      "remove",
      "rename",
      "replace",
      "retain",
      "return",
      "select",
      "set",
      "skip",
      "startsas",
      "stop",
      "title",
      "update",
      "waitsas",
      "where",
      "window",
      "x|0",
      "systask",
      "add",
      "and",
      "alter",
      "as",
      "cascade",
      "check",
      "create",
      "delete",
      "describe",
      "distinct",
      "drop",
      "foreign",
      "from",
      "group",
      "having",
      "index",
      "insert",
      "into",
      "in",
      "key",
      "like",
      "message",
      "modify",
      "msgtype",
      "not",
      "null",
      "on",
      "or",
      "order",
      "primary",
      "references",
      "reset",
      "restrict",
      "select",
      "set",
      "table",
      "unique",
      "update",
      "validate",
      "view",
      "where"
    ], i = [
      "abs",
      "addr",
      "airy",
      "arcos",
      "arsin",
      "atan",
      "attrc",
      "attrn",
      "band",
      "betainv",
      "blshift",
      "bnot",
      "bor",
      "brshift",
      "bxor",
      "byte",
      "cdf",
      "ceil",
      "cexist",
      "cinv",
      "close",
      "cnonct",
      "collate",
      "compbl",
      "compound",
      "compress",
      "cos",
      "cosh",
      "css",
      "curobs",
      "cv",
      "daccdb",
      "daccdbsl",
      "daccsl",
      "daccsyd",
      "dacctab",
      "dairy",
      "date",
      "datejul",
      "datepart",
      "datetime",
      "day",
      "dclose",
      "depdb",
      "depdbsl",
      "depdbsl",
      "depsl",
      "depsl",
      "depsyd",
      "depsyd",
      "deptab",
      "deptab",
      "dequote",
      "dhms",
      "dif",
      "digamma",
      "dim",
      "dinfo",
      "dnum",
      "dopen",
      "doptname",
      "doptnum",
      "dread",
      "dropnote",
      "dsname",
      "erf",
      "erfc",
      "exist",
      "exp",
      "fappend",
      "fclose",
      "fcol",
      "fdelete",
      "fetch",
      "fetchobs",
      "fexist",
      "fget",
      "fileexist",
      "filename",
      "fileref",
      "finfo",
      "finv",
      "fipname",
      "fipnamel",
      "fipstate",
      "floor",
      "fnonct",
      "fnote",
      "fopen",
      "foptname",
      "foptnum",
      "fpoint",
      "fpos",
      "fput",
      "fread",
      "frewind",
      "frlen",
      "fsep",
      "fuzz",
      "fwrite",
      "gaminv",
      "gamma",
      "getoption",
      "getvarc",
      "getvarn",
      "hbound",
      "hms",
      "hosthelp",
      "hour",
      "ibessel",
      "index",
      "indexc",
      "indexw",
      "input",
      "inputc",
      "inputn",
      "int",
      "intck",
      "intnx",
      "intrr",
      "irr",
      "jbessel",
      "juldate",
      "kurtosis",
      "lag",
      "lbound",
      "left",
      "length",
      "lgamma",
      "libname",
      "libref",
      "log",
      "log10",
      "log2",
      "logpdf",
      "logpmf",
      "logsdf",
      "lowcase",
      "max",
      "mdy",
      "mean",
      "min",
      "minute",
      "mod",
      "month",
      "mopen",
      "mort",
      "n",
      "netpv",
      "nmiss",
      "normal",
      "note",
      "npv",
      "open",
      "ordinal",
      "pathname",
      "pdf",
      "peek",
      "peekc",
      "pmf",
      "point",
      "poisson",
      "poke",
      "probbeta",
      "probbnml",
      "probchi",
      "probf",
      "probgam",
      "probhypr",
      "probit",
      "probnegb",
      "probnorm",
      "probt",
      "put",
      "putc",
      "putn",
      "qtr",
      "quote",
      "ranbin",
      "rancau",
      "ranexp",
      "rangam",
      "range",
      "rank",
      "rannor",
      "ranpoi",
      "rantbl",
      "rantri",
      "ranuni",
      "repeat",
      "resolve",
      "reverse",
      "rewind",
      "right",
      "round",
      "saving",
      "scan",
      "sdf",
      "second",
      "sign",
      "sin",
      "sinh",
      "skewness",
      "soundex",
      "spedis",
      "sqrt",
      "std",
      "stderr",
      "stfips",
      "stname",
      "stnamel",
      "substr",
      "sum",
      "symget",
      "sysget",
      "sysmsg",
      "sysprod",
      "sysrc",
      "system",
      "tan",
      "tanh",
      "time",
      "timepart",
      "tinv",
      "tnonct",
      "today",
      "translate",
      "tranwrd",
      "trigamma",
      "trim",
      "trimn",
      "trunc",
      "uniform",
      "upcase",
      "uss",
      "var",
      "varfmt",
      "varinfmt",
      "varlabel",
      "varlen",
      "varname",
      "varnum",
      "varray",
      "varrayx",
      "vartype",
      "verify",
      "vformat",
      "vformatd",
      "vformatdx",
      "vformatn",
      "vformatnx",
      "vformatw",
      "vformatwx",
      "vformatx",
      "vinarray",
      "vinarrayx",
      "vinformat",
      "vinformatd",
      "vinformatdx",
      "vinformatn",
      "vinformatnx",
      "vinformatw",
      "vinformatwx",
      "vinformatx",
      "vlabel",
      "vlabelx",
      "vlength",
      "vlengthx",
      "vname",
      "vnamex",
      "vtype",
      "vtypex",
      "weekday",
      "year",
      "yyq",
      "zipfips",
      "zipname",
      "zipnamel",
      "zipstate"
    ], a = [
      "bquote",
      "nrbquote",
      "cmpres",
      "qcmpres",
      "compstor",
      "datatyp",
      "display",
      "do",
      "else",
      "end",
      "eval",
      "global",
      "goto",
      "if",
      "index",
      "input",
      "keydef",
      "label",
      "left",
      "length",
      "let",
      "local",
      "lowcase",
      "macro",
      "mend",
      "nrbquote",
      "nrquote",
      "nrstr",
      "put",
      "qcmpres",
      "qleft",
      "qlowcase",
      "qscan",
      "qsubstr",
      "qsysfunc",
      "qtrim",
      "quote",
      "qupcase",
      "scan",
      "str",
      "substr",
      "superq",
      "syscall",
      "sysevalf",
      "sysexec",
      "sysfunc",
      "sysget",
      "syslput",
      "sysprod",
      "sysrc",
      "sysrput",
      "then",
      "to",
      "trim",
      "unquote",
      "until",
      "upcase",
      "verify",
      "while",
      "window"
    ];
    return {
      name: "SAS",
      case_insensitive: !0,
      keywords: {
        literal: [
          "null",
          "missing",
          "_all_",
          "_automatic_",
          "_character_",
          "_infile_",
          "_n_",
          "_name_",
          "_null_",
          "_numeric_",
          "_user_",
          "_webout_"
        ],
        keyword: r
      },
      contains: [
        {
          // Distinct highlight for proc <proc>, data, run, quit
          className: "keyword",
          begin: /^\s*(proc [\w\d_]+|data|run|quit)[\s;]/
        },
        {
          // Macro variables
          className: "variable",
          begin: /&[a-zA-Z_&][a-zA-Z0-9_]*\.?/
        },
        {
          begin: [
            /^\s*/,
            /datalines;|cards;/,
            /(?:.*\n)+/,
            /^\s*;\s*$/
          ],
          className: {
            2: "keyword",
            3: "string"
          }
        },
        {
          begin: [
            /%mend|%macro/,
            /\s+/,
            /[a-zA-Z_&][a-zA-Z0-9_]*/
          ],
          className: {
            1: "built_in",
            3: "title.function"
          }
        },
        {
          // Built-in macro variables
          className: "built_in",
          begin: "%" + n.either(...a)
        },
        {
          // User-defined macro functions
          className: "title.function",
          begin: /%[a-zA-Z_][a-zA-Z_0-9]*/
        },
        {
          // TODO: this is most likely an incorrect classification
          // built_in may need more nuance
          // https://github.com/highlightjs/highlight.js/issues/2521
          className: "meta",
          begin: n.either(...i) + "(?=\\()"
        },
        {
          className: "string",
          variants: [
            t.APOS_STRING_MODE,
            t.QUOTE_STRING_MODE
          ]
        },
        t.COMMENT("\\*", ";"),
        t.C_BLOCK_COMMENT_MODE
      ]
    };
  }
  return uy = e, uy;
}
var cy, _L;
function Aee() {
  if (_L) return cy;
  _L = 1;
  function e(t) {
    const n = t.regex, r = {
      className: "meta",
      begin: "@[A-Za-z]+"
    }, i = {
      className: "subst",
      variants: [
        { begin: "\\$[A-Za-z0-9_]+" },
        {
          begin: /\$\{/,
          end: /\}/
        }
      ]
    }, a = {
      className: "string",
      variants: [
        {
          begin: '"""',
          end: '"""'
        },
        {
          begin: '"',
          end: '"',
          illegal: "\\n",
          contains: [t.BACKSLASH_ESCAPE]
        },
        {
          begin: '[a-z]+"',
          end: '"',
          illegal: "\\n",
          contains: [
            t.BACKSLASH_ESCAPE,
            i
          ]
        },
        {
          className: "string",
          begin: '[a-z]+"""',
          end: '"""',
          contains: [i],
          relevance: 10
        }
      ]
    }, o = {
      className: "type",
      begin: "\\b[A-Z][A-Za-z0-9_]*",
      relevance: 0
    }, s = {
      className: "title",
      begin: /[^0-9\n\t "'(),.`{}\[\]:;][^\n\t "'(),.`{}\[\]:;]+|[^0-9\n\t "'(),.`{}\[\]:;=]/,
      relevance: 0
    }, l = {
      className: "class",
      beginKeywords: "class object trait type",
      end: /[:={\[\n;]/,
      excludeEnd: !0,
      contains: [
        t.C_LINE_COMMENT_MODE,
        t.C_BLOCK_COMMENT_MODE,
        {
          beginKeywords: "extends with",
          relevance: 10
        },
        {
          begin: /\[/,
          end: /\]/,
          excludeBegin: !0,
          excludeEnd: !0,
          relevance: 0,
          contains: [
            o,
            t.C_LINE_COMMENT_MODE,
            t.C_BLOCK_COMMENT_MODE
          ]
        },
        {
          className: "params",
          begin: /\(/,
          end: /\)/,
          excludeBegin: !0,
          excludeEnd: !0,
          relevance: 0,
          contains: [
            o,
            t.C_LINE_COMMENT_MODE,
            t.C_BLOCK_COMMENT_MODE
          ]
        },
        s
      ]
    }, u = {
      className: "function",
      beginKeywords: "def",
      end: n.lookahead(/[:={\[(\n;]/),
      contains: [s]
    }, c = {
      begin: [
        /^\s*/,
        // Is first token on the line
        "extension",
        /\s+(?=[[(])/
        // followed by at least one space and `[` or `(`
      ],
      beginScope: { 2: "keyword" }
    }, d = {
      begin: [
        /^\s*/,
        // Is first token on the line
        /end/,
        /\s+/,
        /(extension\b)?/
        // `extension` is the only marker that follows an `end` that cannot be captured by another rule.
      ],
      beginScope: {
        2: "keyword",
        4: "keyword"
      }
    }, f = [
      { match: /\.inline\b/ },
      {
        begin: /\binline(?=\s)/,
        keywords: "inline"
      }
    ], h = {
      begin: [
        /\(\s*/,
        // Opening `(` of a parameter or argument list
        /using/,
        /\s+(?!\))/
        // Spaces not followed by `)`
      ],
      beginScope: { 2: "keyword" }
    };
    return {
      name: "Scala",
      keywords: {
        literal: "true false null",
        keyword: "type yield lazy override def with val var sealed abstract private trait object if then forSome for while do throw finally protected extends import final return else break new catch super class case package default try this match continue throws implicit export enum given transparent"
      },
      contains: [
        {
          begin: [
            "//>",
            /\s+/,
            /using/,
            /\s+/,
            /\S+/
          ],
          beginScope: {
            1: "comment",
            3: "keyword",
            5: "type"
          },
          end: /$/,
          contains: [
            {
              className: "string",
              begin: /\S+/
            }
          ]
        },
        t.C_LINE_COMMENT_MODE,
        t.C_BLOCK_COMMENT_MODE,
        a,
        o,
        u,
        l,
        t.C_NUMBER_MODE,
        c,
        d,
        ...f,
        h,
        r
      ]
    };
  }
  return cy = e, cy;
}
var dy, vL;
function Oee() {
  if (vL) return dy;
  vL = 1;
  function e(t) {
    const n = "[^\\(\\)\\[\\]\\{\\}\",'`;#|\\\\\\s]+", r = "(-|\\+)?\\d+([./]\\d+)?", i = r + "[+\\-]" + r + "i", a = {
      $pattern: n,
      built_in: "case-lambda call/cc class define-class exit-handler field import inherit init-field interface let*-values let-values let/ec mixin opt-lambda override protect provide public rename require require-for-syntax syntax syntax-case syntax-error unit/sig unless when with-syntax and begin call-with-current-continuation call-with-input-file call-with-output-file case cond define define-syntax delay do dynamic-wind else for-each if lambda let let* let-syntax letrec letrec-syntax map or syntax-rules ' * + , ,@ - ... / ; < <= = => > >= ` abs acos angle append apply asin assoc assq assv atan boolean? caar cadr call-with-input-file call-with-output-file call-with-values car cdddar cddddr cdr ceiling char->integer char-alphabetic? char-ci<=? char-ci<? char-ci=? char-ci>=? char-ci>? char-downcase char-lower-case? char-numeric? char-ready? char-upcase char-upper-case? char-whitespace? char<=? char<? char=? char>=? char>? char? close-input-port close-output-port complex? cons cos current-input-port current-output-port denominator display eof-object? eq? equal? eqv? eval even? exact->inexact exact? exp expt floor force gcd imag-part inexact->exact inexact? input-port? integer->char integer? interaction-environment lcm length list list->string list->vector list-ref list-tail list? load log magnitude make-polar make-rectangular make-string make-vector max member memq memv min modulo negative? newline not null-environment null? number->string number? numerator odd? open-input-file open-output-file output-port? pair? peek-char port? positive? procedure? quasiquote quote quotient rational? rationalize read read-char real-part real? remainder reverse round scheme-report-environment set! set-car! set-cdr! sin sqrt string string->list string->number string->symbol string-append string-ci<=? string-ci<? string-ci=? string-ci>=? string-ci>? string-copy string-fill! string-length string-ref string-set! string<=? string<? string=? string>=? string>? string? substring symbol->string symbol? tan transcript-off transcript-on truncate values vector vector->list vector-fill! vector-length vector-ref vector-set! with-input-from-file with-output-to-file write write-char zero?"
    }, o = {
      className: "literal",
      begin: "(#t|#f|#\\\\" + n + "|#\\\\.)"
    }, s = {
      className: "number",
      variants: [
        {
          begin: r,
          relevance: 0
        },
        {
          begin: i,
          relevance: 0
        },
        { begin: "#b[0-1]+(/[0-1]+)?" },
        { begin: "#o[0-7]+(/[0-7]+)?" },
        { begin: "#x[0-9a-f]+(/[0-9a-f]+)?" }
      ]
    }, l = t.QUOTE_STRING_MODE, u = [
      t.COMMENT(
        ";",
        "$",
        { relevance: 0 }
      ),
      t.COMMENT("#\\|", "\\|#")
    ], c = {
      begin: n,
      relevance: 0
    }, d = {
      className: "symbol",
      begin: "'" + n
    }, f = {
      endsWithParent: !0,
      relevance: 0
    }, h = {
      variants: [
        { begin: /'/ },
        { begin: "`" }
      ],
      contains: [
        {
          begin: "\\(",
          end: "\\)",
          contains: [
            "self",
            o,
            l,
            s,
            c,
            d
          ]
        }
      ]
    }, m = {
      className: "name",
      relevance: 0,
      begin: n,
      keywords: a
    }, b = {
      variants: [
        {
          begin: "\\(",
          end: "\\)"
        },
        {
          begin: "\\[",
          end: "\\]"
        }
      ],
      contains: [
        {
          begin: /lambda/,
          endsWithParent: !0,
          returnBegin: !0,
          contains: [
            m,
            {
              endsParent: !0,
              variants: [
                {
                  begin: /\(/,
                  end: /\)/
                },
                {
                  begin: /\[/,
                  end: /\]/
                }
              ],
              contains: [c]
            }
          ]
        },
        m,
        f
      ]
    };
    return f.contains = [
      o,
      s,
      l,
      c,
      d,
      h,
      b
    ].concat(u), {
      name: "Scheme",
      aliases: ["scm"],
      illegal: /\S/,
      contains: [
        t.SHEBANG(),
        s,
        l,
        d,
        h,
        b
      ].concat(u)
    };
  }
  return dy = e, dy;
}
var fy, bL;
function Ree() {
  if (bL) return fy;
  bL = 1;
  function e(t) {
    const n = [
      t.C_NUMBER_MODE,
      {
        className: "string",
        begin: `'|"`,
        end: `'|"`,
        contains: [
          t.BACKSLASH_ESCAPE,
          { begin: "''" }
        ]
      }
    ];
    return {
      name: "Scilab",
      aliases: ["sci"],
      keywords: {
        $pattern: /%?\w+/,
        keyword: "abort break case clear catch continue do elseif else endfunction end for function global if pause return resume select try then while",
        literal: "%f %F %t %T %pi %eps %inf %nan %e %i %z %s",
        built_in: (
          // Scilab has more than 2000 functions. Just list the most commons
          "abs and acos asin atan ceil cd chdir clearglobal cosh cos cumprod deff disp error exec execstr exists exp eye gettext floor fprintf fread fsolve imag isdef isempty isinfisnan isvector lasterror length load linspace list listfiles log10 log2 log max min msprintf mclose mopen ones or pathconvert poly printf prod pwd rand real round sinh sin size gsort sprintf sqrt strcat strcmps tring sum system tanh tan type typename warning zeros matrix"
        )
      },
      illegal: '("|#|/\\*|\\s+/\\w+)',
      contains: [
        {
          className: "function",
          beginKeywords: "function",
          end: "$",
          contains: [
            t.UNDERSCORE_TITLE_MODE,
            {
              className: "params",
              begin: "\\(",
              end: "\\)"
            }
          ]
        },
        // seems to be a guard against [ident]' or [ident].
        // perhaps to prevent attributes from flagging as keywords?
        {
          begin: "[a-zA-Z_][a-zA-Z_0-9]*[\\.']+",
          relevance: 0
        },
        {
          begin: "\\[",
          end: "\\][\\.']*",
          relevance: 0,
          contains: n
        },
        t.COMMENT("//", "$")
      ].concat(n)
    };
  }
  return fy = e, fy;
}
var py, EL;
function wee() {
  if (EL) return py;
  EL = 1;
  const e = (s) => ({
    IMPORTANT: {
      scope: "meta",
      begin: "!important"
    },
    BLOCK_COMMENT: s.C_BLOCK_COMMENT_MODE,
    HEXCOLOR: {
      scope: "number",
      begin: /#(([0-9a-fA-F]{3,4})|(([0-9a-fA-F]{2}){3,4}))\b/
    },
    FUNCTION_DISPATCH: {
      className: "built_in",
      begin: /[\w-]+(?=\()/
    },
    ATTRIBUTE_SELECTOR_MODE: {
      scope: "selector-attr",
      begin: /\[/,
      end: /\]/,
      illegal: "$",
      contains: [
        s.APOS_STRING_MODE,
        s.QUOTE_STRING_MODE
      ]
    },
    CSS_NUMBER_MODE: {
      scope: "number",
      begin: s.NUMBER_RE + "(%|em|ex|ch|rem|vw|vh|vmin|vmax|cm|mm|in|pt|pc|px|deg|grad|rad|turn|s|ms|Hz|kHz|dpi|dpcm|dppx)?",
      relevance: 0
    },
    CSS_VARIABLE: {
      className: "attr",
      begin: /--[A-Za-z_][A-Za-z0-9_-]*/
    }
  }), t = [
    "a",
    "abbr",
    "address",
    "article",
    "aside",
    "audio",
    "b",
    "blockquote",
    "body",
    "button",
    "canvas",
    "caption",
    "cite",
    "code",
    "dd",
    "del",
    "details",
    "dfn",
    "div",
    "dl",
    "dt",
    "em",
    "fieldset",
    "figcaption",
    "figure",
    "footer",
    "form",
    "h1",
    "h2",
    "h3",
    "h4",
    "h5",
    "h6",
    "header",
    "hgroup",
    "html",
    "i",
    "iframe",
    "img",
    "input",
    "ins",
    "kbd",
    "label",
    "legend",
    "li",
    "main",
    "mark",
    "menu",
    "nav",
    "object",
    "ol",
    "p",
    "q",
    "quote",
    "samp",
    "section",
    "span",
    "strong",
    "summary",
    "sup",
    "table",
    "tbody",
    "td",
    "textarea",
    "tfoot",
    "th",
    "thead",
    "time",
    "tr",
    "ul",
    "var",
    "video"
  ], n = [
    "any-hover",
    "any-pointer",
    "aspect-ratio",
    "color",
    "color-gamut",
    "color-index",
    "device-aspect-ratio",
    "device-height",
    "device-width",
    "display-mode",
    "forced-colors",
    "grid",
    "height",
    "hover",
    "inverted-colors",
    "monochrome",
    "orientation",
    "overflow-block",
    "overflow-inline",
    "pointer",
    "prefers-color-scheme",
    "prefers-contrast",
    "prefers-reduced-motion",
    "prefers-reduced-transparency",
    "resolution",
    "scan",
    "scripting",
    "update",
    "width",
    // TODO: find a better solution?
    "min-width",
    "max-width",
    "min-height",
    "max-height"
  ], r = [
    "active",
    "any-link",
    "blank",
    "checked",
    "current",
    "default",
    "defined",
    "dir",
    // dir()
    "disabled",
    "drop",
    "empty",
    "enabled",
    "first",
    "first-child",
    "first-of-type",
    "fullscreen",
    "future",
    "focus",
    "focus-visible",
    "focus-within",
    "has",
    // has()
    "host",
    // host or host()
    "host-context",
    // host-context()
    "hover",
    "indeterminate",
    "in-range",
    "invalid",
    "is",
    // is()
    "lang",
    // lang()
    "last-child",
    "last-of-type",
    "left",
    "link",
    "local-link",
    "not",
    // not()
    "nth-child",
    // nth-child()
    "nth-col",
    // nth-col()
    "nth-last-child",
    // nth-last-child()
    "nth-last-col",
    // nth-last-col()
    "nth-last-of-type",
    //nth-last-of-type()
    "nth-of-type",
    //nth-of-type()
    "only-child",
    "only-of-type",
    "optional",
    "out-of-range",
    "past",
    "placeholder-shown",
    "read-only",
    "read-write",
    "required",
    "right",
    "root",
    "scope",
    "target",
    "target-within",
    "user-invalid",
    "valid",
    "visited",
    "where"
    // where()
  ], i = [
    "after",
    "backdrop",
    "before",
    "cue",
    "cue-region",
    "first-letter",
    "first-line",
    "grammar-error",
    "marker",
    "part",
    "placeholder",
    "selection",
    "slotted",
    "spelling-error"
  ], a = [
    "align-content",
    "align-items",
    "align-self",
    "all",
    "animation",
    "animation-delay",
    "animation-direction",
    "animation-duration",
    "animation-fill-mode",
    "animation-iteration-count",
    "animation-name",
    "animation-play-state",
    "animation-timing-function",
    "backface-visibility",
    "background",
    "background-attachment",
    "background-blend-mode",
    "background-clip",
    "background-color",
    "background-image",
    "background-origin",
    "background-position",
    "background-repeat",
    "background-size",
    "block-size",
    "border",
    "border-block",
    "border-block-color",
    "border-block-end",
    "border-block-end-color",
    "border-block-end-style",
    "border-block-end-width",
    "border-block-start",
    "border-block-start-color",
    "border-block-start-style",
    "border-block-start-width",
    "border-block-style",
    "border-block-width",
    "border-bottom",
    "border-bottom-color",
    "border-bottom-left-radius",
    "border-bottom-right-radius",
    "border-bottom-style",
    "border-bottom-width",
    "border-collapse",
    "border-color",
    "border-image",
    "border-image-outset",
    "border-image-repeat",
    "border-image-slice",
    "border-image-source",
    "border-image-width",
    "border-inline",
    "border-inline-color",
    "border-inline-end",
    "border-inline-end-color",
    "border-inline-end-style",
    "border-inline-end-width",
    "border-inline-start",
    "border-inline-start-color",
    "border-inline-start-style",
    "border-inline-start-width",
    "border-inline-style",
    "border-inline-width",
    "border-left",
    "border-left-color",
    "border-left-style",
    "border-left-width",
    "border-radius",
    "border-right",
    "border-right-color",
    "border-right-style",
    "border-right-width",
    "border-spacing",
    "border-style",
    "border-top",
    "border-top-color",
    "border-top-left-radius",
    "border-top-right-radius",
    "border-top-style",
    "border-top-width",
    "border-width",
    "bottom",
    "box-decoration-break",
    "box-shadow",
    "box-sizing",
    "break-after",
    "break-before",
    "break-inside",
    "caption-side",
    "caret-color",
    "clear",
    "clip",
    "clip-path",
    "clip-rule",
    "color",
    "column-count",
    "column-fill",
    "column-gap",
    "column-rule",
    "column-rule-color",
    "column-rule-style",
    "column-rule-width",
    "column-span",
    "column-width",
    "columns",
    "contain",
    "content",
    "content-visibility",
    "counter-increment",
    "counter-reset",
    "cue",
    "cue-after",
    "cue-before",
    "cursor",
    "direction",
    "display",
    "empty-cells",
    "filter",
    "flex",
    "flex-basis",
    "flex-direction",
    "flex-flow",
    "flex-grow",
    "flex-shrink",
    "flex-wrap",
    "float",
    "flow",
    "font",
    "font-display",
    "font-family",
    "font-feature-settings",
    "font-kerning",
    "font-language-override",
    "font-size",
    "font-size-adjust",
    "font-smoothing",
    "font-stretch",
    "font-style",
    "font-synthesis",
    "font-variant",
    "font-variant-caps",
    "font-variant-east-asian",
    "font-variant-ligatures",
    "font-variant-numeric",
    "font-variant-position",
    "font-variation-settings",
    "font-weight",
    "gap",
    "glyph-orientation-vertical",
    "grid",
    "grid-area",
    "grid-auto-columns",
    "grid-auto-flow",
    "grid-auto-rows",
    "grid-column",
    "grid-column-end",
    "grid-column-start",
    "grid-gap",
    "grid-row",
    "grid-row-end",
    "grid-row-start",
    "grid-template",
    "grid-template-areas",
    "grid-template-columns",
    "grid-template-rows",
    "hanging-punctuation",
    "height",
    "hyphens",
    "icon",
    "image-orientation",
    "image-rendering",
    "image-resolution",
    "ime-mode",
    "inline-size",
    "isolation",
    "justify-content",
    "left",
    "letter-spacing",
    "line-break",
    "line-height",
    "list-style",
    "list-style-image",
    "list-style-position",
    "list-style-type",
    "margin",
    "margin-block",
    "margin-block-end",
    "margin-block-start",
    "margin-bottom",
    "margin-inline",
    "margin-inline-end",
    "margin-inline-start",
    "margin-left",
    "margin-right",
    "margin-top",
    "marks",
    "mask",
    "mask-border",
    "mask-border-mode",
    "mask-border-outset",
    "mask-border-repeat",
    "mask-border-slice",
    "mask-border-source",
    "mask-border-width",
    "mask-clip",
    "mask-composite",
    "mask-image",
    "mask-mode",
    "mask-origin",
    "mask-position",
    "mask-repeat",
    "mask-size",
    "mask-type",
    "max-block-size",
    "max-height",
    "max-inline-size",
    "max-width",
    "min-block-size",
    "min-height",
    "min-inline-size",
    "min-width",
    "mix-blend-mode",
    "nav-down",
    "nav-index",
    "nav-left",
    "nav-right",
    "nav-up",
    "none",
    "normal",
    "object-fit",
    "object-position",
    "opacity",
    "order",
    "orphans",
    "outline",
    "outline-color",
    "outline-offset",
    "outline-style",
    "outline-width",
    "overflow",
    "overflow-wrap",
    "overflow-x",
    "overflow-y",
    "padding",
    "padding-block",
    "padding-block-end",
    "padding-block-start",
    "padding-bottom",
    "padding-inline",
    "padding-inline-end",
    "padding-inline-start",
    "padding-left",
    "padding-right",
    "padding-top",
    "page-break-after",
    "page-break-before",
    "page-break-inside",
    "pause",
    "pause-after",
    "pause-before",
    "perspective",
    "perspective-origin",
    "pointer-events",
    "position",
    "quotes",
    "resize",
    "rest",
    "rest-after",
    "rest-before",
    "right",
    "row-gap",
    "scroll-margin",
    "scroll-margin-block",
    "scroll-margin-block-end",
    "scroll-margin-block-start",
    "scroll-margin-bottom",
    "scroll-margin-inline",
    "scroll-margin-inline-end",
    "scroll-margin-inline-start",
    "scroll-margin-left",
    "scroll-margin-right",
    "scroll-margin-top",
    "scroll-padding",
    "scroll-padding-block",
    "scroll-padding-block-end",
    "scroll-padding-block-start",
    "scroll-padding-bottom",
    "scroll-padding-inline",
    "scroll-padding-inline-end",
    "scroll-padding-inline-start",
    "scroll-padding-left",
    "scroll-padding-right",
    "scroll-padding-top",
    "scroll-snap-align",
    "scroll-snap-stop",
    "scroll-snap-type",
    "scrollbar-color",
    "scrollbar-gutter",
    "scrollbar-width",
    "shape-image-threshold",
    "shape-margin",
    "shape-outside",
    "speak",
    "speak-as",
    "src",
    // @font-face
    "tab-size",
    "table-layout",
    "text-align",
    "text-align-all",
    "text-align-last",
    "text-combine-upright",
    "text-decoration",
    "text-decoration-color",
    "text-decoration-line",
    "text-decoration-style",
    "text-emphasis",
    "text-emphasis-color",
    "text-emphasis-position",
    "text-emphasis-style",
    "text-indent",
    "text-justify",
    "text-orientation",
    "text-overflow",
    "text-rendering",
    "text-shadow",
    "text-transform",
    "text-underline-position",
    "top",
    "transform",
    "transform-box",
    "transform-origin",
    "transform-style",
    "transition",
    "transition-delay",
    "transition-duration",
    "transition-property",
    "transition-timing-function",
    "unicode-bidi",
    "vertical-align",
    "visibility",
    "voice-balance",
    "voice-duration",
    "voice-family",
    "voice-pitch",
    "voice-range",
    "voice-rate",
    "voice-stress",
    "voice-volume",
    "white-space",
    "widows",
    "width",
    "will-change",
    "word-break",
    "word-spacing",
    "word-wrap",
    "writing-mode",
    "z-index"
    // reverse makes sure longer attributes `font-weight` are matched fully
    // instead of getting false positives on say `font`
  ].reverse();
  function o(s) {
    const l = e(s), u = i, c = r, d = "@[a-z-]+", f = "and or not only", m = {
      className: "variable",
      begin: "(\\$" + "[a-zA-Z-][a-zA-Z0-9_-]*" + ")\\b",
      relevance: 0
    };
    return {
      name: "SCSS",
      case_insensitive: !0,
      illegal: "[=/|']",
      contains: [
        s.C_LINE_COMMENT_MODE,
        s.C_BLOCK_COMMENT_MODE,
        // to recognize keyframe 40% etc which are outside the scope of our
        // attribute value mode
        l.CSS_NUMBER_MODE,
        {
          className: "selector-id",
          begin: "#[A-Za-z0-9_-]+",
          relevance: 0
        },
        {
          className: "selector-class",
          begin: "\\.[A-Za-z0-9_-]+",
          relevance: 0
        },
        l.ATTRIBUTE_SELECTOR_MODE,
        {
          className: "selector-tag",
          begin: "\\b(" + t.join("|") + ")\\b",
          // was there, before, but why?
          relevance: 0
        },
        {
          className: "selector-pseudo",
          begin: ":(" + c.join("|") + ")"
        },
        {
          className: "selector-pseudo",
          begin: ":(:)?(" + u.join("|") + ")"
        },
        m,
        {
          // pseudo-selector params
          begin: /\(/,
          end: /\)/,
          contains: [l.CSS_NUMBER_MODE]
        },
        l.CSS_VARIABLE,
        {
          className: "attribute",
          begin: "\\b(" + a.join("|") + ")\\b"
        },
        { begin: "\\b(whitespace|wait|w-resize|visible|vertical-text|vertical-ideographic|uppercase|upper-roman|upper-alpha|underline|transparent|top|thin|thick|text|text-top|text-bottom|tb-rl|table-header-group|table-footer-group|sw-resize|super|strict|static|square|solid|small-caps|separate|se-resize|scroll|s-resize|rtl|row-resize|ridge|right|repeat|repeat-y|repeat-x|relative|progress|pointer|overline|outside|outset|oblique|nowrap|not-allowed|normal|none|nw-resize|no-repeat|no-drop|newspaper|ne-resize|n-resize|move|middle|medium|ltr|lr-tb|lowercase|lower-roman|lower-alpha|loose|list-item|line|line-through|line-edge|lighter|left|keep-all|justify|italic|inter-word|inter-ideograph|inside|inset|inline|inline-block|inherit|inactive|ideograph-space|ideograph-parenthesis|ideograph-numeric|ideograph-alpha|horizontal|hidden|help|hand|groove|fixed|ellipsis|e-resize|double|dotted|distribute|distribute-space|distribute-letter|distribute-all-lines|disc|disabled|default|decimal|dashed|crosshair|collapse|col-resize|circle|char|center|capitalize|break-word|break-all|bottom|both|bolder|bold|block|bidi-override|below|baseline|auto|always|all-scroll|absolute|table|table-cell)\\b" },
        {
          begin: /:/,
          end: /[;}{]/,
          relevance: 0,
          contains: [
            l.BLOCK_COMMENT,
            m,
            l.HEXCOLOR,
            l.CSS_NUMBER_MODE,
            s.QUOTE_STRING_MODE,
            s.APOS_STRING_MODE,
            l.IMPORTANT,
            l.FUNCTION_DISPATCH
          ]
        },
        // matching these here allows us to treat them more like regular CSS
        // rules so everything between the {} gets regular rule highlighting,
        // which is what we want for page and font-face
        {
          begin: "@(page|font-face)",
          keywords: {
            $pattern: d,
            keyword: "@page @font-face"
          }
        },
        {
          begin: "@",
          end: "[{;]",
          returnBegin: !0,
          keywords: {
            $pattern: /[a-z-]+/,
            keyword: f,
            attribute: n.join(" ")
          },
          contains: [
            {
              begin: d,
              className: "keyword"
            },
            {
              begin: /[a-z-]+(?=:)/,
              className: "attribute"
            },
            m,
            s.QUOTE_STRING_MODE,
            s.APOS_STRING_MODE,
            l.HEXCOLOR,
            l.CSS_NUMBER_MODE
          ]
        },
        l.FUNCTION_DISPATCH
      ]
    };
  }
  return py = o, py;
}
var my, SL;
function xee() {
  if (SL) return my;
  SL = 1;
  function e(t) {
    return {
      name: "Shell Session",
      aliases: [
        "console",
        "shellsession"
      ],
      contains: [
        {
          className: "meta.prompt",
          // We cannot add \s (spaces) in the regular expression otherwise it will be too broad and produce unexpected result.
          // For instance, in the following example, it would match "echo /path/to/home >" as a prompt:
          // echo /path/to/home > t.exe
          begin: /^\s{0,3}[/~\w\d[\]()@-]*[>%$#][ ]?/,
          starts: {
            end: /[^\\](?=\s*$)/,
            subLanguage: "bash"
          }
        }
      ]
    };
  }
  return my = e, my;
}
var hy, yL;
function Nee() {
  if (yL) return hy;
  yL = 1;
  function e(t) {
    const n = [
      "add",
      "and",
      "cmp",
      "cmpg",
      "cmpl",
      "const",
      "div",
      "double",
      "float",
      "goto",
      "if",
      "int",
      "long",
      "move",
      "mul",
      "neg",
      "new",
      "nop",
      "not",
      "or",
      "rem",
      "return",
      "shl",
      "shr",
      "sput",
      "sub",
      "throw",
      "ushr",
      "xor"
    ], r = [
      "aget",
      "aput",
      "array",
      "check",
      "execute",
      "fill",
      "filled",
      "goto/16",
      "goto/32",
      "iget",
      "instance",
      "invoke",
      "iput",
      "monitor",
      "packed",
      "sget",
      "sparse"
    ], i = [
      "transient",
      "constructor",
      "abstract",
      "final",
      "synthetic",
      "public",
      "private",
      "protected",
      "static",
      "bridge",
      "system"
    ];
    return {
      name: "Smali",
      contains: [
        {
          className: "string",
          begin: '"',
          end: '"',
          relevance: 0
        },
        t.COMMENT(
          "#",
          "$",
          { relevance: 0 }
        ),
        {
          className: "keyword",
          variants: [
            { begin: "\\s*\\.end\\s[a-zA-Z0-9]*" },
            {
              begin: "^[ ]*\\.[a-zA-Z]*",
              relevance: 0
            },
            {
              begin: "\\s:[a-zA-Z_0-9]*",
              relevance: 0
            },
            { begin: "\\s(" + i.join("|") + ")" }
          ]
        },
        {
          className: "built_in",
          variants: [
            { begin: "\\s(" + n.join("|") + ")\\s" },
            {
              begin: "\\s(" + n.join("|") + ")((-|/)[a-zA-Z0-9]+)+\\s",
              relevance: 10
            },
            {
              begin: "\\s(" + r.join("|") + ")((-|/)[a-zA-Z0-9]+)*\\s",
              relevance: 10
            }
          ]
        },
        {
          className: "class",
          begin: `L[^(;:
]*;`,
          relevance: 0
        },
        { begin: "[vp][0-9]+" }
      ]
    };
  }
  return hy = e, hy;
}
var gy, TL;
function Dee() {
  if (TL) return gy;
  TL = 1;
  function e(t) {
    const n = "[a-z][a-zA-Z0-9_]*", r = {
      className: "string",
      begin: "\\$.{1}"
    }, i = {
      className: "symbol",
      begin: "#" + t.UNDERSCORE_IDENT_RE
    };
    return {
      name: "Smalltalk",
      aliases: ["st"],
      keywords: [
        "self",
        "super",
        "nil",
        "true",
        "false",
        "thisContext"
      ],
      contains: [
        t.COMMENT('"', '"'),
        t.APOS_STRING_MODE,
        {
          className: "type",
          begin: "\\b[A-Z][A-Za-z0-9_]*",
          relevance: 0
        },
        {
          begin: n + ":",
          relevance: 0
        },
        t.C_NUMBER_MODE,
        i,
        r,
        {
          // This looks more complicated than needed to avoid combinatorial
          // explosion under V8. It effectively means `| var1 var2 ... |` with
          // whitespace adjacent to `|` being optional.
          begin: "\\|[ ]*" + n + "([ ]+" + n + ")*[ ]*\\|",
          returnBegin: !0,
          end: /\|/,
          illegal: /\S/,
          contains: [{ begin: "(\\|[ ]*)?" + n }]
        },
        {
          begin: "#\\(",
          end: "\\)",
          contains: [
            t.APOS_STRING_MODE,
            r,
            t.C_NUMBER_MODE,
            i
          ]
        }
      ]
    };
  }
  return gy = e, gy;
}
var _y, CL;
function Iee() {
  if (CL) return _y;
  CL = 1;
  function e(t) {
    return {
      name: "SML (Standard ML)",
      aliases: ["ml"],
      keywords: {
        $pattern: "[a-z_]\\w*!?",
        keyword: (
          /* according to Definition of Standard ML 97  */
          "abstype and andalso as case datatype do else end eqtype exception fn fun functor handle if in include infix infixr let local nonfix of op open orelse raise rec sharing sig signature struct structure then type val with withtype where while"
        ),
        built_in: (
          /* built-in types according to basis library */
          "array bool char exn int list option order real ref string substring vector unit word"
        ),
        literal: "true false NONE SOME LESS EQUAL GREATER nil"
      },
      illegal: /\/\/|>>/,
      contains: [
        {
          className: "literal",
          begin: /\[(\|\|)?\]|\(\)/,
          relevance: 0
        },
        t.COMMENT(
          "\\(\\*",
          "\\*\\)",
          { contains: ["self"] }
        ),
        {
          /* type variable */
          className: "symbol",
          begin: "'[A-Za-z_](?!')[\\w']*"
          /* the grammar is ambiguous on how 'a'b should be interpreted but not the compiler */
        },
        {
          /* polymorphic variant */
          className: "type",
          begin: "`[A-Z][\\w']*"
        },
        {
          /* module or constructor */
          className: "type",
          begin: "\\b[A-Z][\\w']*",
          relevance: 0
        },
        {
          /* don't color identifiers, but safely catch all identifiers with ' */
          begin: "[a-z_]\\w*'[\\w']*"
        },
        t.inherit(t.APOS_STRING_MODE, {
          className: "string",
          relevance: 0
        }),
        t.inherit(t.QUOTE_STRING_MODE, { illegal: null }),
        {
          className: "number",
          begin: "\\b(0[xX][a-fA-F0-9_]+[Lln]?|0[oO][0-7_]+[Lln]?|0[bB][01_]+[Lln]?|[0-9][0-9_]*([Lln]|(\\.[0-9_]*)?([eE][-+]?[0-9_]+)?)?)",
          relevance: 0
        },
        {
          begin: /[-=]>/
          // relevance booster
        }
      ]
    };
  }
  return _y = e, _y;
}
var vy, AL;
function Lee() {
  if (AL) return vy;
  AL = 1;
  function e(t) {
    const n = {
      className: "variable",
      begin: /\b_+[a-zA-Z]\w*/
    }, r = {
      className: "title",
      begin: /[a-zA-Z][a-zA-Z_0-9]*_fnc_[a-zA-Z_0-9]+/
    }, i = {
      className: "string",
      variants: [
        {
          begin: '"',
          end: '"',
          contains: [
            {
              begin: '""',
              relevance: 0
            }
          ]
        },
        {
          begin: "'",
          end: "'",
          contains: [
            {
              begin: "''",
              relevance: 0
            }
          ]
        }
      ]
    }, a = [
      "break",
      "breakWith",
      "breakOut",
      "breakTo",
      "case",
      "catch",
      "continue",
      "continueWith",
      "default",
      "do",
      "else",
      "exit",
      "exitWith",
      "for",
      "forEach",
      "from",
      "if",
      "local",
      "private",
      "switch",
      "step",
      "then",
      "throw",
      "to",
      "try",
      "waitUntil",
      "while",
      "with"
    ], o = [
      "blufor",
      "civilian",
      "configNull",
      "controlNull",
      "displayNull",
      "diaryRecordNull",
      "east",
      "endl",
      "false",
      "grpNull",
      "independent",
      "lineBreak",
      "locationNull",
      "nil",
      "objNull",
      "opfor",
      "pi",
      "resistance",
      "scriptNull",
      "sideAmbientLife",
      "sideEmpty",
      "sideEnemy",
      "sideFriendly",
      "sideLogic",
      "sideUnknown",
      "taskNull",
      "teamMemberNull",
      "true",
      "west"
    ], s = [
      "abs",
      "accTime",
      "acos",
      "action",
      "actionIDs",
      "actionKeys",
      "actionKeysEx",
      "actionKeysImages",
      "actionKeysNames",
      "actionKeysNamesArray",
      "actionName",
      "actionParams",
      "activateAddons",
      "activatedAddons",
      "activateKey",
      "activeTitleEffectParams",
      "add3DENConnection",
      "add3DENEventHandler",
      "add3DENLayer",
      "addAction",
      "addBackpack",
      "addBackpackCargo",
      "addBackpackCargoGlobal",
      "addBackpackGlobal",
      "addBinocularItem",
      "addCamShake",
      "addCuratorAddons",
      "addCuratorCameraArea",
      "addCuratorEditableObjects",
      "addCuratorEditingArea",
      "addCuratorPoints",
      "addEditorObject",
      "addEventHandler",
      "addForce",
      "addForceGeneratorRTD",
      "addGoggles",
      "addGroupIcon",
      "addHandgunItem",
      "addHeadgear",
      "addItem",
      "addItemCargo",
      "addItemCargoGlobal",
      "addItemPool",
      "addItemToBackpack",
      "addItemToUniform",
      "addItemToVest",
      "addLiveStats",
      "addMagazine",
      "addMagazineAmmoCargo",
      "addMagazineCargo",
      "addMagazineCargoGlobal",
      "addMagazineGlobal",
      "addMagazinePool",
      "addMagazines",
      "addMagazineTurret",
      "addMenu",
      "addMenuItem",
      "addMissionEventHandler",
      "addMPEventHandler",
      "addMusicEventHandler",
      "addonFiles",
      "addOwnedMine",
      "addPlayerScores",
      "addPrimaryWeaponItem",
      "addPublicVariableEventHandler",
      "addRating",
      "addResources",
      "addScore",
      "addScoreSide",
      "addSecondaryWeaponItem",
      "addSwitchableUnit",
      "addTeamMember",
      "addToRemainsCollector",
      "addTorque",
      "addUniform",
      "addUserActionEventHandler",
      "addVehicle",
      "addVest",
      "addWaypoint",
      "addWeapon",
      "addWeaponCargo",
      "addWeaponCargoGlobal",
      "addWeaponGlobal",
      "addWeaponItem",
      "addWeaponPool",
      "addWeaponTurret",
      "addWeaponWithAttachmentsCargo",
      "addWeaponWithAttachmentsCargoGlobal",
      "admin",
      "agent",
      "agents",
      "AGLToASL",
      "aimedAtTarget",
      "aimPos",
      "airDensityCurveRTD",
      "airDensityRTD",
      "airplaneThrottle",
      "airportSide",
      "AISFinishHeal",
      "alive",
      "all3DENEntities",
      "allActiveTitleEffects",
      "allAddonsInfo",
      "allAirports",
      "allControls",
      "allCurators",
      "allCutLayers",
      "allDead",
      "allDeadMen",
      "allDiaryRecords",
      "allDiarySubjects",
      "allDisplays",
      "allEnv3DSoundSources",
      "allGroups",
      "allLODs",
      "allMapMarkers",
      "allMines",
      "allMissionObjects",
      "allObjects",
      "allow3DMode",
      "allowCrewInImmobile",
      "allowCuratorLogicIgnoreAreas",
      "allowDamage",
      "allowDammage",
      "allowedService",
      "allowFileOperations",
      "allowFleeing",
      "allowGetIn",
      "allowService",
      "allowSprint",
      "allPlayers",
      "allSimpleObjects",
      "allSites",
      "allTurrets",
      "allUnits",
      "allUnitsUAV",
      "allUsers",
      "allVariables",
      "ambientTemperature",
      "ammo",
      "ammoOnPylon",
      "and",
      "animate",
      "animateBay",
      "animateDoor",
      "animatePylon",
      "animateSource",
      "animationNames",
      "animationPhase",
      "animationSourcePhase",
      "animationState",
      "apertureParams",
      "append",
      "apply",
      "armoryPoints",
      "arrayIntersect",
      "asin",
      "ASLToAGL",
      "ASLToATL",
      "assert",
      "assignAsCargo",
      "assignAsCargoIndex",
      "assignAsCommander",
      "assignAsDriver",
      "assignAsGunner",
      "assignAsTurret",
      "assignCurator",
      "assignedCargo",
      "assignedCommander",
      "assignedDriver",
      "assignedGroup",
      "assignedGunner",
      "assignedItems",
      "assignedTarget",
      "assignedTeam",
      "assignedVehicle",
      "assignedVehicleRole",
      "assignedVehicles",
      "assignItem",
      "assignTeam",
      "assignToAirport",
      "atan",
      "atan2",
      "atg",
      "ATLToASL",
      "attachedObject",
      "attachedObjects",
      "attachedTo",
      "attachObject",
      "attachTo",
      "attackEnabled",
      "awake",
      "backpack",
      "backpackCargo",
      "backpackContainer",
      "backpackItems",
      "backpackMagazines",
      "backpackSpaceFor",
      "behaviour",
      "benchmark",
      "bezierInterpolation",
      "binocular",
      "binocularItems",
      "binocularMagazine",
      "boundingBox",
      "boundingBoxReal",
      "boundingCenter",
      "brakesDisabled",
      "briefingName",
      "buildingExit",
      "buildingPos",
      "buldozer_EnableRoadDiag",
      "buldozer_IsEnabledRoadDiag",
      "buldozer_LoadNewRoads",
      "buldozer_reloadOperMap",
      "buttonAction",
      "buttonSetAction",
      "cadetMode",
      "calculatePath",
      "calculatePlayerVisibilityByFriendly",
      "call",
      "callExtension",
      "camCommand",
      "camCommit",
      "camCommitPrepared",
      "camCommitted",
      "camConstuctionSetParams",
      "camCreate",
      "camDestroy",
      "cameraEffect",
      "cameraEffectEnableHUD",
      "cameraInterest",
      "cameraOn",
      "cameraView",
      "campaignConfigFile",
      "camPreload",
      "camPreloaded",
      "camPrepareBank",
      "camPrepareDir",
      "camPrepareDive",
      "camPrepareFocus",
      "camPrepareFov",
      "camPrepareFovRange",
      "camPreparePos",
      "camPrepareRelPos",
      "camPrepareTarget",
      "camSetBank",
      "camSetDir",
      "camSetDive",
      "camSetFocus",
      "camSetFov",
      "camSetFovRange",
      "camSetPos",
      "camSetRelPos",
      "camSetTarget",
      "camTarget",
      "camUseNVG",
      "canAdd",
      "canAddItemToBackpack",
      "canAddItemToUniform",
      "canAddItemToVest",
      "cancelSimpleTaskDestination",
      "canDeployWeapon",
      "canFire",
      "canMove",
      "canSlingLoad",
      "canStand",
      "canSuspend",
      "canTriggerDynamicSimulation",
      "canUnloadInCombat",
      "canVehicleCargo",
      "captive",
      "captiveNum",
      "cbChecked",
      "cbSetChecked",
      "ceil",
      "channelEnabled",
      "cheatsEnabled",
      "checkAIFeature",
      "checkVisibility",
      "className",
      "clear3DENAttribute",
      "clear3DENInventory",
      "clearAllItemsFromBackpack",
      "clearBackpackCargo",
      "clearBackpackCargoGlobal",
      "clearForcesRTD",
      "clearGroupIcons",
      "clearItemCargo",
      "clearItemCargoGlobal",
      "clearItemPool",
      "clearMagazineCargo",
      "clearMagazineCargoGlobal",
      "clearMagazinePool",
      "clearOverlay",
      "clearRadio",
      "clearWeaponCargo",
      "clearWeaponCargoGlobal",
      "clearWeaponPool",
      "clientOwner",
      "closeDialog",
      "closeDisplay",
      "closeOverlay",
      "collapseObjectTree",
      "collect3DENHistory",
      "collectiveRTD",
      "collisionDisabledWith",
      "combatBehaviour",
      "combatMode",
      "commandArtilleryFire",
      "commandChat",
      "commander",
      "commandFire",
      "commandFollow",
      "commandFSM",
      "commandGetOut",
      "commandingMenu",
      "commandMove",
      "commandRadio",
      "commandStop",
      "commandSuppressiveFire",
      "commandTarget",
      "commandWatch",
      "comment",
      "commitOverlay",
      "compatibleItems",
      "compatibleMagazines",
      "compile",
      "compileFinal",
      "compileScript",
      "completedFSM",
      "composeText",
      "configClasses",
      "configFile",
      "configHierarchy",
      "configName",
      "configOf",
      "configProperties",
      "configSourceAddonList",
      "configSourceMod",
      "configSourceModList",
      "confirmSensorTarget",
      "connectTerminalToUAV",
      "connectToServer",
      "controlsGroupCtrl",
      "conversationDisabled",
      "copyFromClipboard",
      "copyToClipboard",
      "copyWaypoints",
      "cos",
      "count",
      "countEnemy",
      "countFriendly",
      "countSide",
      "countType",
      "countUnknown",
      "create3DENComposition",
      "create3DENEntity",
      "createAgent",
      "createCenter",
      "createDialog",
      "createDiaryLink",
      "createDiaryRecord",
      "createDiarySubject",
      "createDisplay",
      "createGearDialog",
      "createGroup",
      "createGuardedPoint",
      "createHashMap",
      "createHashMapFromArray",
      "createLocation",
      "createMarker",
      "createMarkerLocal",
      "createMenu",
      "createMine",
      "createMissionDisplay",
      "createMPCampaignDisplay",
      "createSimpleObject",
      "createSimpleTask",
      "createSite",
      "createSoundSource",
      "createTask",
      "createTeam",
      "createTrigger",
      "createUnit",
      "createVehicle",
      "createVehicleCrew",
      "createVehicleLocal",
      "crew",
      "ctAddHeader",
      "ctAddRow",
      "ctClear",
      "ctCurSel",
      "ctData",
      "ctFindHeaderRows",
      "ctFindRowHeader",
      "ctHeaderControls",
      "ctHeaderCount",
      "ctRemoveHeaders",
      "ctRemoveRows",
      "ctrlActivate",
      "ctrlAddEventHandler",
      "ctrlAngle",
      "ctrlAnimateModel",
      "ctrlAnimationPhaseModel",
      "ctrlAt",
      "ctrlAutoScrollDelay",
      "ctrlAutoScrollRewind",
      "ctrlAutoScrollSpeed",
      "ctrlBackgroundColor",
      "ctrlChecked",
      "ctrlClassName",
      "ctrlCommit",
      "ctrlCommitted",
      "ctrlCreate",
      "ctrlDelete",
      "ctrlEnable",
      "ctrlEnabled",
      "ctrlFade",
      "ctrlFontHeight",
      "ctrlForegroundColor",
      "ctrlHTMLLoaded",
      "ctrlIDC",
      "ctrlIDD",
      "ctrlMapAnimAdd",
      "ctrlMapAnimClear",
      "ctrlMapAnimCommit",
      "ctrlMapAnimDone",
      "ctrlMapCursor",
      "ctrlMapMouseOver",
      "ctrlMapPosition",
      "ctrlMapScale",
      "ctrlMapScreenToWorld",
      "ctrlMapSetPosition",
      "ctrlMapWorldToScreen",
      "ctrlModel",
      "ctrlModelDirAndUp",
      "ctrlModelScale",
      "ctrlMousePosition",
      "ctrlParent",
      "ctrlParentControlsGroup",
      "ctrlPosition",
      "ctrlRemoveAllEventHandlers",
      "ctrlRemoveEventHandler",
      "ctrlScale",
      "ctrlScrollValues",
      "ctrlSetActiveColor",
      "ctrlSetAngle",
      "ctrlSetAutoScrollDelay",
      "ctrlSetAutoScrollRewind",
      "ctrlSetAutoScrollSpeed",
      "ctrlSetBackgroundColor",
      "ctrlSetChecked",
      "ctrlSetDisabledColor",
      "ctrlSetEventHandler",
      "ctrlSetFade",
      "ctrlSetFocus",
      "ctrlSetFont",
      "ctrlSetFontH1",
      "ctrlSetFontH1B",
      "ctrlSetFontH2",
      "ctrlSetFontH2B",
      "ctrlSetFontH3",
      "ctrlSetFontH3B",
      "ctrlSetFontH4",
      "ctrlSetFontH4B",
      "ctrlSetFontH5",
      "ctrlSetFontH5B",
      "ctrlSetFontH6",
      "ctrlSetFontH6B",
      "ctrlSetFontHeight",
      "ctrlSetFontHeightH1",
      "ctrlSetFontHeightH2",
      "ctrlSetFontHeightH3",
      "ctrlSetFontHeightH4",
      "ctrlSetFontHeightH5",
      "ctrlSetFontHeightH6",
      "ctrlSetFontHeightSecondary",
      "ctrlSetFontP",
      "ctrlSetFontPB",
      "ctrlSetFontSecondary",
      "ctrlSetForegroundColor",
      "ctrlSetModel",
      "ctrlSetModelDirAndUp",
      "ctrlSetModelScale",
      "ctrlSetMousePosition",
      "ctrlSetPixelPrecision",
      "ctrlSetPosition",
      "ctrlSetPositionH",
      "ctrlSetPositionW",
      "ctrlSetPositionX",
      "ctrlSetPositionY",
      "ctrlSetScale",
      "ctrlSetScrollValues",
      "ctrlSetShadow",
      "ctrlSetStructuredText",
      "ctrlSetText",
      "ctrlSetTextColor",
      "ctrlSetTextColorSecondary",
      "ctrlSetTextSecondary",
      "ctrlSetTextSelection",
      "ctrlSetTooltip",
      "ctrlSetTooltipColorBox",
      "ctrlSetTooltipColorShade",
      "ctrlSetTooltipColorText",
      "ctrlSetTooltipMaxWidth",
      "ctrlSetURL",
      "ctrlSetURLOverlayMode",
      "ctrlShadow",
      "ctrlShow",
      "ctrlShown",
      "ctrlStyle",
      "ctrlText",
      "ctrlTextColor",
      "ctrlTextHeight",
      "ctrlTextSecondary",
      "ctrlTextSelection",
      "ctrlTextWidth",
      "ctrlTooltip",
      "ctrlType",
      "ctrlURL",
      "ctrlURLOverlayMode",
      "ctrlVisible",
      "ctRowControls",
      "ctRowCount",
      "ctSetCurSel",
      "ctSetData",
      "ctSetHeaderTemplate",
      "ctSetRowTemplate",
      "ctSetValue",
      "ctValue",
      "curatorAddons",
      "curatorCamera",
      "curatorCameraArea",
      "curatorCameraAreaCeiling",
      "curatorCoef",
      "curatorEditableObjects",
      "curatorEditingArea",
      "curatorEditingAreaType",
      "curatorMouseOver",
      "curatorPoints",
      "curatorRegisteredObjects",
      "curatorSelected",
      "curatorWaypointCost",
      "current3DENOperation",
      "currentChannel",
      "currentCommand",
      "currentMagazine",
      "currentMagazineDetail",
      "currentMagazineDetailTurret",
      "currentMagazineTurret",
      "currentMuzzle",
      "currentNamespace",
      "currentPilot",
      "currentTask",
      "currentTasks",
      "currentThrowable",
      "currentVisionMode",
      "currentWaypoint",
      "currentWeapon",
      "currentWeaponMode",
      "currentWeaponTurret",
      "currentZeroing",
      "cursorObject",
      "cursorTarget",
      "customChat",
      "customRadio",
      "customWaypointPosition",
      "cutFadeOut",
      "cutObj",
      "cutRsc",
      "cutText",
      "damage",
      "date",
      "dateToNumber",
      "dayTime",
      "deActivateKey",
      "debriefingText",
      "debugFSM",
      "debugLog",
      "decayGraphValues",
      "deg",
      "delete3DENEntities",
      "deleteAt",
      "deleteCenter",
      "deleteCollection",
      "deleteEditorObject",
      "deleteGroup",
      "deleteGroupWhenEmpty",
      "deleteIdentity",
      "deleteLocation",
      "deleteMarker",
      "deleteMarkerLocal",
      "deleteRange",
      "deleteResources",
      "deleteSite",
      "deleteStatus",
      "deleteTeam",
      "deleteVehicle",
      "deleteVehicleCrew",
      "deleteWaypoint",
      "detach",
      "detectedMines",
      "diag_activeMissionFSMs",
      "diag_activeScripts",
      "diag_activeSQFScripts",
      "diag_activeSQSScripts",
      "diag_allMissionEventHandlers",
      "diag_captureFrame",
      "diag_captureFrameToFile",
      "diag_captureSlowFrame",
      "diag_codePerformance",
      "diag_deltaTime",
      "diag_drawmode",
      "diag_dumpCalltraceToLog",
      "diag_dumpScriptAssembly",
      "diag_dumpTerrainSynth",
      "diag_dynamicSimulationEnd",
      "diag_enable",
      "diag_enabled",
      "diag_exportConfig",
      "diag_exportTerrainSVG",
      "diag_fps",
      "diag_fpsmin",
      "diag_frameno",
      "diag_getTerrainSegmentOffset",
      "diag_lightNewLoad",
      "diag_list",
      "diag_localized",
      "diag_log",
      "diag_logSlowFrame",
      "diag_mergeConfigFile",
      "diag_recordTurretLimits",
      "diag_resetFSM",
      "diag_resetshapes",
      "diag_scope",
      "diag_setLightNew",
      "diag_stacktrace",
      "diag_tickTime",
      "diag_toggle",
      "dialog",
      "diarySubjectExists",
      "didJIP",
      "didJIPOwner",
      "difficulty",
      "difficultyEnabled",
      "difficultyEnabledRTD",
      "difficultyOption",
      "direction",
      "directionStabilizationEnabled",
      "directSay",
      "disableAI",
      "disableBrakes",
      "disableCollisionWith",
      "disableConversation",
      "disableDebriefingStats",
      "disableMapIndicators",
      "disableNVGEquipment",
      "disableRemoteSensors",
      "disableSerialization",
      "disableTIEquipment",
      "disableUAVConnectability",
      "disableUserInput",
      "displayAddEventHandler",
      "displayChild",
      "displayCtrl",
      "displayParent",
      "displayRemoveAllEventHandlers",
      "displayRemoveEventHandler",
      "displaySetEventHandler",
      "displayUniqueName",
      "displayUpdate",
      "dissolveTeam",
      "distance",
      "distance2D",
      "distanceSqr",
      "distributionRegion",
      "do3DENAction",
      "doArtilleryFire",
      "doFire",
      "doFollow",
      "doFSM",
      "doGetOut",
      "doMove",
      "doorPhase",
      "doStop",
      "doSuppressiveFire",
      "doTarget",
      "doWatch",
      "drawArrow",
      "drawEllipse",
      "drawIcon",
      "drawIcon3D",
      "drawLaser",
      "drawLine",
      "drawLine3D",
      "drawLink",
      "drawLocation",
      "drawPolygon",
      "drawRectangle",
      "drawTriangle",
      "driver",
      "drop",
      "dynamicSimulationDistance",
      "dynamicSimulationDistanceCoef",
      "dynamicSimulationEnabled",
      "dynamicSimulationSystemEnabled",
      "echo",
      "edit3DENMissionAttributes",
      "editObject",
      "editorSetEventHandler",
      "effectiveCommander",
      "elevatePeriscope",
      "emptyPositions",
      "enableAI",
      "enableAIFeature",
      "enableAimPrecision",
      "enableAttack",
      "enableAudioFeature",
      "enableAutoStartUpRTD",
      "enableAutoTrimRTD",
      "enableCamShake",
      "enableCaustics",
      "enableChannel",
      "enableCollisionWith",
      "enableCopilot",
      "enableDebriefingStats",
      "enableDiagLegend",
      "enableDirectionStabilization",
      "enableDynamicSimulation",
      "enableDynamicSimulationSystem",
      "enableEndDialog",
      "enableEngineArtillery",
      "enableEnvironment",
      "enableFatigue",
      "enableGunLights",
      "enableInfoPanelComponent",
      "enableIRLasers",
      "enableMimics",
      "enablePersonTurret",
      "enableRadio",
      "enableReload",
      "enableRopeAttach",
      "enableSatNormalOnDetail",
      "enableSaving",
      "enableSentences",
      "enableSimulation",
      "enableSimulationGlobal",
      "enableStamina",
      "enableStressDamage",
      "enableTeamSwitch",
      "enableTraffic",
      "enableUAVConnectability",
      "enableUAVWaypoints",
      "enableVehicleCargo",
      "enableVehicleSensor",
      "enableWeaponDisassembly",
      "endLoadingScreen",
      "endMission",
      "engineOn",
      "enginesIsOnRTD",
      "enginesPowerRTD",
      "enginesRpmRTD",
      "enginesTorqueRTD",
      "entities",
      "environmentEnabled",
      "environmentVolume",
      "equipmentDisabled",
      "estimatedEndServerTime",
      "estimatedTimeLeft",
      "evalObjectArgument",
      "everyBackpack",
      "everyContainer",
      "exec",
      "execEditorScript",
      "execFSM",
      "execVM",
      "exp",
      "expectedDestination",
      "exportJIPMessages",
      "eyeDirection",
      "eyePos",
      "face",
      "faction",
      "fadeEnvironment",
      "fadeMusic",
      "fadeRadio",
      "fadeSound",
      "fadeSpeech",
      "failMission",
      "fileExists",
      "fillWeaponsFromPool",
      "find",
      "findAny",
      "findCover",
      "findDisplay",
      "findEditorObject",
      "findEmptyPosition",
      "findEmptyPositionReady",
      "findIf",
      "findNearestEnemy",
      "finishMissionInit",
      "finite",
      "fire",
      "fireAtTarget",
      "firstBackpack",
      "flag",
      "flagAnimationPhase",
      "flagOwner",
      "flagSide",
      "flagTexture",
      "flatten",
      "fleeing",
      "floor",
      "flyInHeight",
      "flyInHeightASL",
      "focusedCtrl",
      "fog",
      "fogForecast",
      "fogParams",
      "forceAddUniform",
      "forceAtPositionRTD",
      "forceCadetDifficulty",
      "forcedMap",
      "forceEnd",
      "forceFlagTexture",
      "forceFollowRoad",
      "forceGeneratorRTD",
      "forceMap",
      "forceRespawn",
      "forceSpeed",
      "forceUnicode",
      "forceWalk",
      "forceWeaponFire",
      "forceWeatherChange",
      "forEachMember",
      "forEachMemberAgent",
      "forEachMemberTeam",
      "forgetTarget",
      "format",
      "formation",
      "formationDirection",
      "formationLeader",
      "formationMembers",
      "formationPosition",
      "formationTask",
      "formatText",
      "formLeader",
      "freeExtension",
      "freeLook",
      "fromEditor",
      "fuel",
      "fullCrew",
      "gearIDCAmmoCount",
      "gearSlotAmmoCount",
      "gearSlotData",
      "gestureState",
      "get",
      "get3DENActionState",
      "get3DENAttribute",
      "get3DENCamera",
      "get3DENConnections",
      "get3DENEntity",
      "get3DENEntityID",
      "get3DENGrid",
      "get3DENIconsVisible",
      "get3DENLayerEntities",
      "get3DENLinesVisible",
      "get3DENMissionAttribute",
      "get3DENMouseOver",
      "get3DENSelected",
      "getAimingCoef",
      "getAllEnv3DSoundControllers",
      "getAllEnvSoundControllers",
      "getAllHitPointsDamage",
      "getAllOwnedMines",
      "getAllPylonsInfo",
      "getAllSoundControllers",
      "getAllUnitTraits",
      "getAmmoCargo",
      "getAnimAimPrecision",
      "getAnimSpeedCoef",
      "getArray",
      "getArtilleryAmmo",
      "getArtilleryComputerSettings",
      "getArtilleryETA",
      "getAssetDLCInfo",
      "getAssignedCuratorLogic",
      "getAssignedCuratorUnit",
      "getAttackTarget",
      "getAudioOptionVolumes",
      "getBackpackCargo",
      "getBleedingRemaining",
      "getBurningValue",
      "getCalculatePlayerVisibilityByFriendly",
      "getCameraViewDirection",
      "getCargoIndex",
      "getCenterOfMass",
      "getClientState",
      "getClientStateNumber",
      "getCompatiblePylonMagazines",
      "getConnectedUAV",
      "getConnectedUAVUnit",
      "getContainerMaxLoad",
      "getCorpse",
      "getCruiseControl",
      "getCursorObjectParams",
      "getCustomAimCoef",
      "getCustomSoundController",
      "getCustomSoundControllerCount",
      "getDammage",
      "getDebriefingText",
      "getDescription",
      "getDir",
      "getDirVisual",
      "getDiverState",
      "getDLCAssetsUsage",
      "getDLCAssetsUsageByName",
      "getDLCs",
      "getDLCUsageTime",
      "getEditorCamera",
      "getEditorMode",
      "getEditorObjectScope",
      "getElevationOffset",
      "getEngineTargetRPMRTD",
      "getEnv3DSoundController",
      "getEnvSoundController",
      "getEventHandlerInfo",
      "getFatigue",
      "getFieldManualStartPage",
      "getForcedFlagTexture",
      "getForcedSpeed",
      "getFriend",
      "getFSMVariable",
      "getFuelCargo",
      "getGraphValues",
      "getGroupIcon",
      "getGroupIconParams",
      "getGroupIcons",
      "getHideFrom",
      "getHit",
      "getHitIndex",
      "getHitPointDamage",
      "getItemCargo",
      "getLighting",
      "getLightingAt",
      "getLoadedModsInfo",
      "getMagazineCargo",
      "getMarkerColor",
      "getMarkerPos",
      "getMarkerSize",
      "getMarkerType",
      "getMass",
      "getMissionConfig",
      "getMissionConfigValue",
      "getMissionDLCs",
      "getMissionLayerEntities",
      "getMissionLayers",
      "getMissionPath",
      "getModelInfo",
      "getMousePosition",
      "getMusicPlayedTime",
      "getNumber",
      "getObjectArgument",
      "getObjectChildren",
      "getObjectDLC",
      "getObjectFOV",
      "getObjectID",
      "getObjectMaterials",
      "getObjectProxy",
      "getObjectScale",
      "getObjectTextures",
      "getObjectType",
      "getObjectViewDistance",
      "getOpticsMode",
      "getOrDefault",
      "getOrDefaultCall",
      "getOxygenRemaining",
      "getPersonUsedDLCs",
      "getPilotCameraDirection",
      "getPilotCameraPosition",
      "getPilotCameraRotation",
      "getPilotCameraTarget",
      "getPiPViewDistance",
      "getPlateNumber",
      "getPlayerChannel",
      "getPlayerID",
      "getPlayerScores",
      "getPlayerUID",
      "getPlayerVoNVolume",
      "getPos",
      "getPosASL",
      "getPosASLVisual",
      "getPosASLW",
      "getPosATL",
      "getPosATLVisual",
      "getPosVisual",
      "getPosWorld",
      "getPosWorldVisual",
      "getPylonMagazines",
      "getRelDir",
      "getRelPos",
      "getRemoteSensorsDisabled",
      "getRepairCargo",
      "getResolution",
      "getRoadInfo",
      "getRotorBrakeRTD",
      "getSensorTargets",
      "getSensorThreats",
      "getShadowDistance",
      "getShotParents",
      "getSlingLoad",
      "getSoundController",
      "getSoundControllerResult",
      "getSpeed",
      "getStamina",
      "getStatValue",
      "getSteamFriendsServers",
      "getSubtitleOptions",
      "getSuppression",
      "getTerrainGrid",
      "getTerrainHeight",
      "getTerrainHeightASL",
      "getTerrainInfo",
      "getText",
      "getTextRaw",
      "getTextureInfo",
      "getTextWidth",
      "getTiParameters",
      "getTotalDLCUsageTime",
      "getTrimOffsetRTD",
      "getTurretLimits",
      "getTurretOpticsMode",
      "getUnitFreefallInfo",
      "getUnitLoadout",
      "getUnitTrait",
      "getUnloadInCombat",
      "getUserInfo",
      "getUserMFDText",
      "getUserMFDValue",
      "getVariable",
      "getVehicleCargo",
      "getVehicleTiPars",
      "getWeaponCargo",
      "getWeaponSway",
      "getWingsOrientationRTD",
      "getWingsPositionRTD",
      "getWPPos",
      "glanceAt",
      "globalChat",
      "globalRadio",
      "goggles",
      "goto",
      "group",
      "groupChat",
      "groupFromNetId",
      "groupIconSelectable",
      "groupIconsVisible",
      "groupID",
      "groupOwner",
      "groupRadio",
      "groups",
      "groupSelectedUnits",
      "groupSelectUnit",
      "gunner",
      "gusts",
      "halt",
      "handgunItems",
      "handgunMagazine",
      "handgunWeapon",
      "handsHit",
      "hashValue",
      "hasInterface",
      "hasPilotCamera",
      "hasWeapon",
      "hcAllGroups",
      "hcGroupParams",
      "hcLeader",
      "hcRemoveAllGroups",
      "hcRemoveGroup",
      "hcSelected",
      "hcSelectGroup",
      "hcSetGroup",
      "hcShowBar",
      "hcShownBar",
      "headgear",
      "hideBody",
      "hideObject",
      "hideObjectGlobal",
      "hideSelection",
      "hint",
      "hintC",
      "hintCadet",
      "hintSilent",
      "hmd",
      "hostMission",
      "htmlLoad",
      "HUDMovementLevels",
      "humidity",
      "image",
      "importAllGroups",
      "importance",
      "in",
      "inArea",
      "inAreaArray",
      "incapacitatedState",
      "inflame",
      "inflamed",
      "infoPanel",
      "infoPanelComponentEnabled",
      "infoPanelComponents",
      "infoPanels",
      "inGameUISetEventHandler",
      "inheritsFrom",
      "initAmbientLife",
      "inPolygon",
      "inputAction",
      "inputController",
      "inputMouse",
      "inRangeOfArtillery",
      "insert",
      "insertEditorObject",
      "intersect",
      "is3DEN",
      "is3DENMultiplayer",
      "is3DENPreview",
      "isAbleToBreathe",
      "isActionMenuVisible",
      "isAgent",
      "isAimPrecisionEnabled",
      "isAllowedCrewInImmobile",
      "isArray",
      "isAutoHoverOn",
      "isAutonomous",
      "isAutoStartUpEnabledRTD",
      "isAutotest",
      "isAutoTrimOnRTD",
      "isAwake",
      "isBleeding",
      "isBurning",
      "isClass",
      "isCollisionLightOn",
      "isCopilotEnabled",
      "isDamageAllowed",
      "isDedicated",
      "isDLCAvailable",
      "isEngineOn",
      "isEqualRef",
      "isEqualTo",
      "isEqualType",
      "isEqualTypeAll",
      "isEqualTypeAny",
      "isEqualTypeArray",
      "isEqualTypeParams",
      "isFilePatchingEnabled",
      "isFinal",
      "isFlashlightOn",
      "isFlatEmpty",
      "isForcedWalk",
      "isFormationLeader",
      "isGameFocused",
      "isGamePaused",
      "isGroupDeletedWhenEmpty",
      "isHidden",
      "isInRemainsCollector",
      "isInstructorFigureEnabled",
      "isIRLaserOn",
      "isKeyActive",
      "isKindOf",
      "isLaserOn",
      "isLightOn",
      "isLocalized",
      "isManualFire",
      "isMarkedForCollection",
      "isMissionProfileNamespaceLoaded",
      "isMultiplayer",
      "isMultiplayerSolo",
      "isNil",
      "isNotEqualRef",
      "isNotEqualTo",
      "isNull",
      "isNumber",
      "isObjectHidden",
      "isObjectRTD",
      "isOnRoad",
      "isPiPEnabled",
      "isPlayer",
      "isRealTime",
      "isRemoteExecuted",
      "isRemoteExecutedJIP",
      "isSaving",
      "isSensorTargetConfirmed",
      "isServer",
      "isShowing3DIcons",
      "isSimpleObject",
      "isSprintAllowed",
      "isStaminaEnabled",
      "isSteamMission",
      "isSteamOverlayEnabled",
      "isStreamFriendlyUIEnabled",
      "isStressDamageEnabled",
      "isText",
      "isTouchingGround",
      "isTurnedOut",
      "isTutHintsEnabled",
      "isUAVConnectable",
      "isUAVConnected",
      "isUIContext",
      "isUniformAllowed",
      "isVehicleCargo",
      "isVehicleRadarOn",
      "isVehicleSensorEnabled",
      "isWalking",
      "isWeaponDeployed",
      "isWeaponRested",
      "itemCargo",
      "items",
      "itemsWithMagazines",
      "join",
      "joinAs",
      "joinAsSilent",
      "joinSilent",
      "joinString",
      "kbAddDatabase",
      "kbAddDatabaseTargets",
      "kbAddTopic",
      "kbHasTopic",
      "kbReact",
      "kbRemoveTopic",
      "kbTell",
      "kbWasSaid",
      "keyImage",
      "keyName",
      "keys",
      "knowsAbout",
      "land",
      "landAt",
      "landResult",
      "language",
      "laserTarget",
      "lbAdd",
      "lbClear",
      "lbColor",
      "lbColorRight",
      "lbCurSel",
      "lbData",
      "lbDelete",
      "lbIsSelected",
      "lbPicture",
      "lbPictureRight",
      "lbSelection",
      "lbSetColor",
      "lbSetColorRight",
      "lbSetCurSel",
      "lbSetData",
      "lbSetPicture",
      "lbSetPictureColor",
      "lbSetPictureColorDisabled",
      "lbSetPictureColorSelected",
      "lbSetPictureRight",
      "lbSetPictureRightColor",
      "lbSetPictureRightColorDisabled",
      "lbSetPictureRightColorSelected",
      "lbSetSelectColor",
      "lbSetSelectColorRight",
      "lbSetSelected",
      "lbSetText",
      "lbSetTextRight",
      "lbSetTooltip",
      "lbSetValue",
      "lbSize",
      "lbSort",
      "lbSortBy",
      "lbSortByValue",
      "lbText",
      "lbTextRight",
      "lbTooltip",
      "lbValue",
      "leader",
      "leaderboardDeInit",
      "leaderboardGetRows",
      "leaderboardInit",
      "leaderboardRequestRowsFriends",
      "leaderboardRequestRowsGlobal",
      "leaderboardRequestRowsGlobalAroundUser",
      "leaderboardsRequestUploadScore",
      "leaderboardsRequestUploadScoreKeepBest",
      "leaderboardState",
      "leaveVehicle",
      "libraryCredits",
      "libraryDisclaimers",
      "lifeState",
      "lightAttachObject",
      "lightDetachObject",
      "lightIsOn",
      "lightnings",
      "limitSpeed",
      "linearConversion",
      "lineIntersects",
      "lineIntersectsObjs",
      "lineIntersectsSurfaces",
      "lineIntersectsWith",
      "linkItem",
      "list",
      "listObjects",
      "listRemoteTargets",
      "listVehicleSensors",
      "ln",
      "lnbAddArray",
      "lnbAddColumn",
      "lnbAddRow",
      "lnbClear",
      "lnbColor",
      "lnbColorRight",
      "lnbCurSelRow",
      "lnbData",
      "lnbDeleteColumn",
      "lnbDeleteRow",
      "lnbGetColumnsPosition",
      "lnbPicture",
      "lnbPictureRight",
      "lnbSetColor",
      "lnbSetColorRight",
      "lnbSetColumnsPos",
      "lnbSetCurSelRow",
      "lnbSetData",
      "lnbSetPicture",
      "lnbSetPictureColor",
      "lnbSetPictureColorRight",
      "lnbSetPictureColorSelected",
      "lnbSetPictureColorSelectedRight",
      "lnbSetPictureRight",
      "lnbSetText",
      "lnbSetTextRight",
      "lnbSetTooltip",
      "lnbSetValue",
      "lnbSize",
      "lnbSort",
      "lnbSortBy",
      "lnbSortByValue",
      "lnbText",
      "lnbTextRight",
      "lnbValue",
      "load",
      "loadAbs",
      "loadBackpack",
      "loadConfig",
      "loadFile",
      "loadGame",
      "loadIdentity",
      "loadMagazine",
      "loadOverlay",
      "loadStatus",
      "loadUniform",
      "loadVest",
      "localize",
      "localNamespace",
      "locationPosition",
      "lock",
      "lockCameraTo",
      "lockCargo",
      "lockDriver",
      "locked",
      "lockedCameraTo",
      "lockedCargo",
      "lockedDriver",
      "lockedInventory",
      "lockedTurret",
      "lockIdentity",
      "lockInventory",
      "lockTurret",
      "lockWp",
      "log",
      "logEntities",
      "logNetwork",
      "logNetworkTerminate",
      "lookAt",
      "lookAtPos",
      "magazineCargo",
      "magazines",
      "magazinesAllTurrets",
      "magazinesAmmo",
      "magazinesAmmoCargo",
      "magazinesAmmoFull",
      "magazinesDetail",
      "magazinesDetailBackpack",
      "magazinesDetailUniform",
      "magazinesDetailVest",
      "magazinesTurret",
      "magazineTurretAmmo",
      "mapAnimAdd",
      "mapAnimClear",
      "mapAnimCommit",
      "mapAnimDone",
      "mapCenterOnCamera",
      "mapGridPosition",
      "markAsFinishedOnSteam",
      "markerAlpha",
      "markerBrush",
      "markerChannel",
      "markerColor",
      "markerDir",
      "markerPolyline",
      "markerPos",
      "markerShadow",
      "markerShape",
      "markerSize",
      "markerText",
      "markerType",
      "matrixMultiply",
      "matrixTranspose",
      "max",
      "maxLoad",
      "members",
      "menuAction",
      "menuAdd",
      "menuChecked",
      "menuClear",
      "menuCollapse",
      "menuData",
      "menuDelete",
      "menuEnable",
      "menuEnabled",
      "menuExpand",
      "menuHover",
      "menuPicture",
      "menuSetAction",
      "menuSetCheck",
      "menuSetData",
      "menuSetPicture",
      "menuSetShortcut",
      "menuSetText",
      "menuSetURL",
      "menuSetValue",
      "menuShortcut",
      "menuShortcutText",
      "menuSize",
      "menuSort",
      "menuText",
      "menuURL",
      "menuValue",
      "merge",
      "min",
      "mineActive",
      "mineDetectedBy",
      "missileTarget",
      "missileTargetPos",
      "missionConfigFile",
      "missionDifficulty",
      "missionEnd",
      "missionName",
      "missionNameSource",
      "missionNamespace",
      "missionProfileNamespace",
      "missionStart",
      "missionVersion",
      "mod",
      "modelToWorld",
      "modelToWorldVisual",
      "modelToWorldVisualWorld",
      "modelToWorldWorld",
      "modParams",
      "moonIntensity",
      "moonPhase",
      "morale",
      "move",
      "move3DENCamera",
      "moveInAny",
      "moveInCargo",
      "moveInCommander",
      "moveInDriver",
      "moveInGunner",
      "moveInTurret",
      "moveObjectToEnd",
      "moveOut",
      "moveTime",
      "moveTo",
      "moveToCompleted",
      "moveToFailed",
      "musicVolume",
      "name",
      "namedProperties",
      "nameSound",
      "nearEntities",
      "nearestBuilding",
      "nearestLocation",
      "nearestLocations",
      "nearestLocationWithDubbing",
      "nearestMines",
      "nearestObject",
      "nearestObjects",
      "nearestTerrainObjects",
      "nearObjects",
      "nearObjectsReady",
      "nearRoads",
      "nearSupplies",
      "nearTargets",
      "needReload",
      "needService",
      "netId",
      "netObjNull",
      "newOverlay",
      "nextMenuItemIndex",
      "nextWeatherChange",
      "nMenuItems",
      "not",
      "numberOfEnginesRTD",
      "numberToDate",
      "objectCurators",
      "objectFromNetId",
      "objectParent",
      "objStatus",
      "onBriefingGroup",
      "onBriefingNotes",
      "onBriefingPlan",
      "onBriefingTeamSwitch",
      "onCommandModeChanged",
      "onDoubleClick",
      "onEachFrame",
      "onGroupIconClick",
      "onGroupIconOverEnter",
      "onGroupIconOverLeave",
      "onHCGroupSelectionChanged",
      "onMapSingleClick",
      "onPlayerConnected",
      "onPlayerDisconnected",
      "onPreloadFinished",
      "onPreloadStarted",
      "onShowNewObject",
      "onTeamSwitch",
      "openCuratorInterface",
      "openDLCPage",
      "openGPS",
      "openMap",
      "openSteamApp",
      "openYoutubeVideo",
      "or",
      "orderGetIn",
      "overcast",
      "overcastForecast",
      "owner",
      "param",
      "params",
      "parseNumber",
      "parseSimpleArray",
      "parseText",
      "parsingNamespace",
      "particlesQuality",
      "periscopeElevation",
      "pickWeaponPool",
      "pitch",
      "pixelGrid",
      "pixelGridBase",
      "pixelGridNoUIScale",
      "pixelH",
      "pixelW",
      "playableSlotsNumber",
      "playableUnits",
      "playAction",
      "playActionNow",
      "player",
      "playerRespawnTime",
      "playerSide",
      "playersNumber",
      "playGesture",
      "playMission",
      "playMove",
      "playMoveNow",
      "playMusic",
      "playScriptedMission",
      "playSound",
      "playSound3D",
      "playSoundUI",
      "pose",
      "position",
      "positionCameraToWorld",
      "posScreenToWorld",
      "posWorldToScreen",
      "ppEffectAdjust",
      "ppEffectCommit",
      "ppEffectCommitted",
      "ppEffectCreate",
      "ppEffectDestroy",
      "ppEffectEnable",
      "ppEffectEnabled",
      "ppEffectForceInNVG",
      "precision",
      "preloadCamera",
      "preloadObject",
      "preloadSound",
      "preloadTitleObj",
      "preloadTitleRsc",
      "preprocessFile",
      "preprocessFileLineNumbers",
      "primaryWeapon",
      "primaryWeaponItems",
      "primaryWeaponMagazine",
      "priority",
      "processDiaryLink",
      "productVersion",
      "profileName",
      "profileNamespace",
      "profileNameSteam",
      "progressLoadingScreen",
      "progressPosition",
      "progressSetPosition",
      "publicVariable",
      "publicVariableClient",
      "publicVariableServer",
      "pushBack",
      "pushBackUnique",
      "putWeaponPool",
      "queryItemsPool",
      "queryMagazinePool",
      "queryWeaponPool",
      "rad",
      "radioChannelAdd",
      "radioChannelCreate",
      "radioChannelInfo",
      "radioChannelRemove",
      "radioChannelSetCallSign",
      "radioChannelSetLabel",
      "radioEnabled",
      "radioVolume",
      "rain",
      "rainbow",
      "rainParams",
      "random",
      "rank",
      "rankId",
      "rating",
      "rectangular",
      "regexFind",
      "regexMatch",
      "regexReplace",
      "registeredTasks",
      "registerTask",
      "reload",
      "reloadEnabled",
      "remoteControl",
      "remoteExec",
      "remoteExecCall",
      "remoteExecutedOwner",
      "remove3DENConnection",
      "remove3DENEventHandler",
      "remove3DENLayer",
      "removeAction",
      "removeAll3DENEventHandlers",
      "removeAllActions",
      "removeAllAssignedItems",
      "removeAllBinocularItems",
      "removeAllContainers",
      "removeAllCuratorAddons",
      "removeAllCuratorCameraAreas",
      "removeAllCuratorEditingAreas",
      "removeAllEventHandlers",
      "removeAllHandgunItems",
      "removeAllItems",
      "removeAllItemsWithMagazines",
      "removeAllMissionEventHandlers",
      "removeAllMPEventHandlers",
      "removeAllMusicEventHandlers",
      "removeAllOwnedMines",
      "removeAllPrimaryWeaponItems",
      "removeAllSecondaryWeaponItems",
      "removeAllUserActionEventHandlers",
      "removeAllWeapons",
      "removeBackpack",
      "removeBackpackGlobal",
      "removeBinocularItem",
      "removeCuratorAddons",
      "removeCuratorCameraArea",
      "removeCuratorEditableObjects",
      "removeCuratorEditingArea",
      "removeDiaryRecord",
      "removeDiarySubject",
      "removeDrawIcon",
      "removeDrawLinks",
      "removeEventHandler",
      "removeFromRemainsCollector",
      "removeGoggles",
      "removeGroupIcon",
      "removeHandgunItem",
      "removeHeadgear",
      "removeItem",
      "removeItemFromBackpack",
      "removeItemFromUniform",
      "removeItemFromVest",
      "removeItems",
      "removeMagazine",
      "removeMagazineGlobal",
      "removeMagazines",
      "removeMagazinesTurret",
      "removeMagazineTurret",
      "removeMenuItem",
      "removeMissionEventHandler",
      "removeMPEventHandler",
      "removeMusicEventHandler",
      "removeOwnedMine",
      "removePrimaryWeaponItem",
      "removeSecondaryWeaponItem",
      "removeSimpleTask",
      "removeSwitchableUnit",
      "removeTeamMember",
      "removeUniform",
      "removeUserActionEventHandler",
      "removeVest",
      "removeWeapon",
      "removeWeaponAttachmentCargo",
      "removeWeaponCargo",
      "removeWeaponGlobal",
      "removeWeaponTurret",
      "reportRemoteTarget",
      "requiredVersion",
      "resetCamShake",
      "resetSubgroupDirection",
      "resize",
      "resources",
      "respawnVehicle",
      "restartEditorCamera",
      "reveal",
      "revealMine",
      "reverse",
      "reversedMouseY",
      "roadAt",
      "roadsConnectedTo",
      "roleDescription",
      "ropeAttachedObjects",
      "ropeAttachedTo",
      "ropeAttachEnabled",
      "ropeAttachTo",
      "ropeCreate",
      "ropeCut",
      "ropeDestroy",
      "ropeDetach",
      "ropeEndPosition",
      "ropeLength",
      "ropes",
      "ropesAttachedTo",
      "ropeSegments",
      "ropeUnwind",
      "ropeUnwound",
      "rotorsForcesRTD",
      "rotorsRpmRTD",
      "round",
      "runInitScript",
      "safeZoneH",
      "safeZoneW",
      "safeZoneWAbs",
      "safeZoneX",
      "safeZoneXAbs",
      "safeZoneY",
      "save3DENInventory",
      "saveGame",
      "saveIdentity",
      "saveJoysticks",
      "saveMissionProfileNamespace",
      "saveOverlay",
      "saveProfileNamespace",
      "saveStatus",
      "saveVar",
      "savingEnabled",
      "say",
      "say2D",
      "say3D",
      "scopeName",
      "score",
      "scoreSide",
      "screenshot",
      "screenToWorld",
      "scriptDone",
      "scriptName",
      "scudState",
      "secondaryWeapon",
      "secondaryWeaponItems",
      "secondaryWeaponMagazine",
      "select",
      "selectBestPlaces",
      "selectDiarySubject",
      "selectedEditorObjects",
      "selectEditorObject",
      "selectionNames",
      "selectionPosition",
      "selectionVectorDirAndUp",
      "selectLeader",
      "selectMax",
      "selectMin",
      "selectNoPlayer",
      "selectPlayer",
      "selectRandom",
      "selectRandomWeighted",
      "selectWeapon",
      "selectWeaponTurret",
      "sendAUMessage",
      "sendSimpleCommand",
      "sendTask",
      "sendTaskResult",
      "sendUDPMessage",
      "sentencesEnabled",
      "serverCommand",
      "serverCommandAvailable",
      "serverCommandExecutable",
      "serverName",
      "serverNamespace",
      "serverTime",
      "set",
      "set3DENAttribute",
      "set3DENAttributes",
      "set3DENGrid",
      "set3DENIconsVisible",
      "set3DENLayer",
      "set3DENLinesVisible",
      "set3DENLogicType",
      "set3DENMissionAttribute",
      "set3DENMissionAttributes",
      "set3DENModelsVisible",
      "set3DENObjectType",
      "set3DENSelected",
      "setAccTime",
      "setActualCollectiveRTD",
      "setAirplaneThrottle",
      "setAirportSide",
      "setAmmo",
      "setAmmoCargo",
      "setAmmoOnPylon",
      "setAnimSpeedCoef",
      "setAperture",
      "setApertureNew",
      "setArmoryPoints",
      "setAttributes",
      "setAutonomous",
      "setBehaviour",
      "setBehaviourStrong",
      "setBleedingRemaining",
      "setBrakesRTD",
      "setCameraInterest",
      "setCamShakeDefParams",
      "setCamShakeParams",
      "setCamUseTi",
      "setCaptive",
      "setCenterOfMass",
      "setCollisionLight",
      "setCombatBehaviour",
      "setCombatMode",
      "setCompassOscillation",
      "setConvoySeparation",
      "setCruiseControl",
      "setCuratorCameraAreaCeiling",
      "setCuratorCoef",
      "setCuratorEditingAreaType",
      "setCuratorWaypointCost",
      "setCurrentChannel",
      "setCurrentTask",
      "setCurrentWaypoint",
      "setCustomAimCoef",
      "SetCustomMissionData",
      "setCustomSoundController",
      "setCustomWeightRTD",
      "setDamage",
      "setDammage",
      "setDate",
      "setDebriefingText",
      "setDefaultCamera",
      "setDestination",
      "setDetailMapBlendPars",
      "setDiaryRecordText",
      "setDiarySubjectPicture",
      "setDir",
      "setDirection",
      "setDrawIcon",
      "setDriveOnPath",
      "setDropInterval",
      "setDynamicSimulationDistance",
      "setDynamicSimulationDistanceCoef",
      "setEditorMode",
      "setEditorObjectScope",
      "setEffectCondition",
      "setEffectiveCommander",
      "setEngineRpmRTD",
      "setFace",
      "setFaceanimation",
      "setFatigue",
      "setFeatureType",
      "setFlagAnimationPhase",
      "setFlagOwner",
      "setFlagSide",
      "setFlagTexture",
      "setFog",
      "setForceGeneratorRTD",
      "setFormation",
      "setFormationTask",
      "setFormDir",
      "setFriend",
      "setFromEditor",
      "setFSMVariable",
      "setFuel",
      "setFuelCargo",
      "setGroupIcon",
      "setGroupIconParams",
      "setGroupIconsSelectable",
      "setGroupIconsVisible",
      "setGroupid",
      "setGroupIdGlobal",
      "setGroupOwner",
      "setGusts",
      "setHideBehind",
      "setHit",
      "setHitIndex",
      "setHitPointDamage",
      "setHorizonParallaxCoef",
      "setHUDMovementLevels",
      "setHumidity",
      "setIdentity",
      "setImportance",
      "setInfoPanel",
      "setLeader",
      "setLightAmbient",
      "setLightAttenuation",
      "setLightBrightness",
      "setLightColor",
      "setLightConePars",
      "setLightDayLight",
      "setLightFlareMaxDistance",
      "setLightFlareSize",
      "setLightIntensity",
      "setLightIR",
      "setLightnings",
      "setLightUseFlare",
      "setLightVolumeShape",
      "setLocalWindParams",
      "setMagazineTurretAmmo",
      "setMarkerAlpha",
      "setMarkerAlphaLocal",
      "setMarkerBrush",
      "setMarkerBrushLocal",
      "setMarkerColor",
      "setMarkerColorLocal",
      "setMarkerDir",
      "setMarkerDirLocal",
      "setMarkerPolyline",
      "setMarkerPolylineLocal",
      "setMarkerPos",
      "setMarkerPosLocal",
      "setMarkerShadow",
      "setMarkerShadowLocal",
      "setMarkerShape",
      "setMarkerShapeLocal",
      "setMarkerSize",
      "setMarkerSizeLocal",
      "setMarkerText",
      "setMarkerTextLocal",
      "setMarkerType",
      "setMarkerTypeLocal",
      "setMass",
      "setMaxLoad",
      "setMimic",
      "setMissileTarget",
      "setMissileTargetPos",
      "setMousePosition",
      "setMusicEffect",
      "setMusicEventHandler",
      "setName",
      "setNameSound",
      "setObjectArguments",
      "setObjectMaterial",
      "setObjectMaterialGlobal",
      "setObjectProxy",
      "setObjectScale",
      "setObjectTexture",
      "setObjectTextureGlobal",
      "setObjectViewDistance",
      "setOpticsMode",
      "setOvercast",
      "setOwner",
      "setOxygenRemaining",
      "setParticleCircle",
      "setParticleClass",
      "setParticleFire",
      "setParticleParams",
      "setParticleRandom",
      "setPilotCameraDirection",
      "setPilotCameraRotation",
      "setPilotCameraTarget",
      "setPilotLight",
      "setPiPEffect",
      "setPiPViewDistance",
      "setPitch",
      "setPlateNumber",
      "setPlayable",
      "setPlayerRespawnTime",
      "setPlayerVoNVolume",
      "setPos",
      "setPosASL",
      "setPosASL2",
      "setPosASLW",
      "setPosATL",
      "setPosition",
      "setPosWorld",
      "setPylonLoadout",
      "setPylonsPriority",
      "setRadioMsg",
      "setRain",
      "setRainbow",
      "setRandomLip",
      "setRank",
      "setRectangular",
      "setRepairCargo",
      "setRotorBrakeRTD",
      "setShadowDistance",
      "setShotParents",
      "setSide",
      "setSimpleTaskAlwaysVisible",
      "setSimpleTaskCustomData",
      "setSimpleTaskDescription",
      "setSimpleTaskDestination",
      "setSimpleTaskTarget",
      "setSimpleTaskType",
      "setSimulWeatherLayers",
      "setSize",
      "setSkill",
      "setSlingLoad",
      "setSoundEffect",
      "setSpeaker",
      "setSpeech",
      "setSpeedMode",
      "setStamina",
      "setStaminaScheme",
      "setStatValue",
      "setSuppression",
      "setSystemOfUnits",
      "setTargetAge",
      "setTaskMarkerOffset",
      "setTaskResult",
      "setTaskState",
      "setTerrainGrid",
      "setTerrainHeight",
      "setText",
      "setTimeMultiplier",
      "setTiParameter",
      "setTitleEffect",
      "setTowParent",
      "setTrafficDensity",
      "setTrafficDistance",
      "setTrafficGap",
      "setTrafficSpeed",
      "setTriggerActivation",
      "setTriggerArea",
      "setTriggerInterval",
      "setTriggerStatements",
      "setTriggerText",
      "setTriggerTimeout",
      "setTriggerType",
      "setTurretLimits",
      "setTurretOpticsMode",
      "setType",
      "setUnconscious",
      "setUnitAbility",
      "setUnitCombatMode",
      "setUnitFreefallHeight",
      "setUnitLoadout",
      "setUnitPos",
      "setUnitPosWeak",
      "setUnitRank",
      "setUnitRecoilCoefficient",
      "setUnitTrait",
      "setUnloadInCombat",
      "setUserActionText",
      "setUserMFDText",
      "setUserMFDValue",
      "setVariable",
      "setVectorDir",
      "setVectorDirAndUp",
      "setVectorUp",
      "setVehicleAmmo",
      "setVehicleAmmoDef",
      "setVehicleArmor",
      "setVehicleCargo",
      "setVehicleId",
      "setVehicleLock",
      "setVehiclePosition",
      "setVehicleRadar",
      "setVehicleReceiveRemoteTargets",
      "setVehicleReportOwnPosition",
      "setVehicleReportRemoteTargets",
      "setVehicleTiPars",
      "setVehicleVarName",
      "setVelocity",
      "setVelocityModelSpace",
      "setVelocityTransformation",
      "setViewDistance",
      "setVisibleIfTreeCollapsed",
      "setWantedRPMRTD",
      "setWaves",
      "setWaypointBehaviour",
      "setWaypointCombatMode",
      "setWaypointCompletionRadius",
      "setWaypointDescription",
      "setWaypointForceBehaviour",
      "setWaypointFormation",
      "setWaypointHousePosition",
      "setWaypointLoiterAltitude",
      "setWaypointLoiterRadius",
      "setWaypointLoiterType",
      "setWaypointName",
      "setWaypointPosition",
      "setWaypointScript",
      "setWaypointSpeed",
      "setWaypointStatements",
      "setWaypointTimeout",
      "setWaypointType",
      "setWaypointVisible",
      "setWeaponReloadingTime",
      "setWeaponZeroing",
      "setWind",
      "setWindDir",
      "setWindForce",
      "setWindStr",
      "setWingForceScaleRTD",
      "setWPPos",
      "show3DIcons",
      "showChat",
      "showCinemaBorder",
      "showCommandingMenu",
      "showCompass",
      "showCuratorCompass",
      "showGps",
      "showHUD",
      "showLegend",
      "showMap",
      "shownArtilleryComputer",
      "shownChat",
      "shownCompass",
      "shownCuratorCompass",
      "showNewEditorObject",
      "shownGps",
      "shownHUD",
      "shownMap",
      "shownPad",
      "shownRadio",
      "shownScoretable",
      "shownSubtitles",
      "shownUAVFeed",
      "shownWarrant",
      "shownWatch",
      "showPad",
      "showRadio",
      "showScoretable",
      "showSubtitles",
      "showUAVFeed",
      "showWarrant",
      "showWatch",
      "showWaypoint",
      "showWaypoints",
      "side",
      "sideChat",
      "sideRadio",
      "simpleTasks",
      "simulationEnabled",
      "simulCloudDensity",
      "simulCloudOcclusion",
      "simulInClouds",
      "simulWeatherSync",
      "sin",
      "size",
      "sizeOf",
      "skill",
      "skillFinal",
      "skipTime",
      "sleep",
      "sliderPosition",
      "sliderRange",
      "sliderSetPosition",
      "sliderSetRange",
      "sliderSetSpeed",
      "sliderSpeed",
      "slingLoadAssistantShown",
      "soldierMagazines",
      "someAmmo",
      "sort",
      "soundVolume",
      "spawn",
      "speaker",
      "speechVolume",
      "speed",
      "speedMode",
      "splitString",
      "sqrt",
      "squadParams",
      "stance",
      "startLoadingScreen",
      "stop",
      "stopEngineRTD",
      "stopped",
      "str",
      "sunOrMoon",
      "supportInfo",
      "suppressFor",
      "surfaceIsWater",
      "surfaceNormal",
      "surfaceTexture",
      "surfaceType",
      "swimInDepth",
      "switchableUnits",
      "switchAction",
      "switchCamera",
      "switchGesture",
      "switchLight",
      "switchMove",
      "synchronizedObjects",
      "synchronizedTriggers",
      "synchronizedWaypoints",
      "synchronizeObjectsAdd",
      "synchronizeObjectsRemove",
      "synchronizeTrigger",
      "synchronizeWaypoint",
      "systemChat",
      "systemOfUnits",
      "systemTime",
      "systemTimeUTC",
      "tan",
      "targetKnowledge",
      "targets",
      "targetsAggregate",
      "targetsQuery",
      "taskAlwaysVisible",
      "taskChildren",
      "taskCompleted",
      "taskCustomData",
      "taskDescription",
      "taskDestination",
      "taskHint",
      "taskMarkerOffset",
      "taskName",
      "taskParent",
      "taskResult",
      "taskState",
      "taskType",
      "teamMember",
      "teamName",
      "teams",
      "teamSwitch",
      "teamSwitchEnabled",
      "teamType",
      "terminate",
      "terrainIntersect",
      "terrainIntersectASL",
      "terrainIntersectAtASL",
      "text",
      "textLog",
      "textLogFormat",
      "tg",
      "time",
      "timeMultiplier",
      "titleCut",
      "titleFadeOut",
      "titleObj",
      "titleRsc",
      "titleText",
      "toArray",
      "toFixed",
      "toLower",
      "toLowerANSI",
      "toString",
      "toUpper",
      "toUpperANSI",
      "triggerActivated",
      "triggerActivation",
      "triggerAmmo",
      "triggerArea",
      "triggerAttachedVehicle",
      "triggerAttachObject",
      "triggerAttachVehicle",
      "triggerDynamicSimulation",
      "triggerInterval",
      "triggerStatements",
      "triggerText",
      "triggerTimeout",
      "triggerTimeoutCurrent",
      "triggerType",
      "trim",
      "turretLocal",
      "turretOwner",
      "turretUnit",
      "tvAdd",
      "tvClear",
      "tvCollapse",
      "tvCollapseAll",
      "tvCount",
      "tvCurSel",
      "tvData",
      "tvDelete",
      "tvExpand",
      "tvExpandAll",
      "tvIsSelected",
      "tvPicture",
      "tvPictureRight",
      "tvSelection",
      "tvSetColor",
      "tvSetCurSel",
      "tvSetData",
      "tvSetPicture",
      "tvSetPictureColor",
      "tvSetPictureColorDisabled",
      "tvSetPictureColorSelected",
      "tvSetPictureRight",
      "tvSetPictureRightColor",
      "tvSetPictureRightColorDisabled",
      "tvSetPictureRightColorSelected",
      "tvSetSelectColor",
      "tvSetSelected",
      "tvSetText",
      "tvSetTooltip",
      "tvSetValue",
      "tvSort",
      "tvSortAll",
      "tvSortByValue",
      "tvSortByValueAll",
      "tvText",
      "tvTooltip",
      "tvValue",
      "type",
      "typeName",
      "typeOf",
      "UAVControl",
      "uiNamespace",
      "uiSleep",
      "unassignCurator",
      "unassignItem",
      "unassignTeam",
      "unassignVehicle",
      "underwater",
      "uniform",
      "uniformContainer",
      "uniformItems",
      "uniformMagazines",
      "uniqueUnitItems",
      "unitAddons",
      "unitAimPosition",
      "unitAimPositionVisual",
      "unitBackpack",
      "unitCombatMode",
      "unitIsUAV",
      "unitPos",
      "unitReady",
      "unitRecoilCoefficient",
      "units",
      "unitsBelowHeight",
      "unitTurret",
      "unlinkItem",
      "unlockAchievement",
      "unregisterTask",
      "updateDrawIcon",
      "updateMenuItem",
      "updateObjectTree",
      "useAIOperMapObstructionTest",
      "useAISteeringComponent",
      "useAudioTimeForMoves",
      "userInputDisabled",
      "values",
      "vectorAdd",
      "vectorCos",
      "vectorCrossProduct",
      "vectorDiff",
      "vectorDir",
      "vectorDirVisual",
      "vectorDistance",
      "vectorDistanceSqr",
      "vectorDotProduct",
      "vectorFromTo",
      "vectorLinearConversion",
      "vectorMagnitude",
      "vectorMagnitudeSqr",
      "vectorModelToWorld",
      "vectorModelToWorldVisual",
      "vectorMultiply",
      "vectorNormalized",
      "vectorUp",
      "vectorUpVisual",
      "vectorWorldToModel",
      "vectorWorldToModelVisual",
      "vehicle",
      "vehicleCargoEnabled",
      "vehicleChat",
      "vehicleMoveInfo",
      "vehicleRadio",
      "vehicleReceiveRemoteTargets",
      "vehicleReportOwnPosition",
      "vehicleReportRemoteTargets",
      "vehicles",
      "vehicleVarName",
      "velocity",
      "velocityModelSpace",
      "verifySignature",
      "vest",
      "vestContainer",
      "vestItems",
      "vestMagazines",
      "viewDistance",
      "visibleCompass",
      "visibleGps",
      "visibleMap",
      "visiblePosition",
      "visiblePositionASL",
      "visibleScoretable",
      "visibleWatch",
      "waves",
      "waypointAttachedObject",
      "waypointAttachedVehicle",
      "waypointAttachObject",
      "waypointAttachVehicle",
      "waypointBehaviour",
      "waypointCombatMode",
      "waypointCompletionRadius",
      "waypointDescription",
      "waypointForceBehaviour",
      "waypointFormation",
      "waypointHousePosition",
      "waypointLoiterAltitude",
      "waypointLoiterRadius",
      "waypointLoiterType",
      "waypointName",
      "waypointPosition",
      "waypoints",
      "waypointScript",
      "waypointsEnabledUAV",
      "waypointShow",
      "waypointSpeed",
      "waypointStatements",
      "waypointTimeout",
      "waypointTimeoutCurrent",
      "waypointType",
      "waypointVisible",
      "weaponAccessories",
      "weaponAccessoriesCargo",
      "weaponCargo",
      "weaponDirection",
      "weaponInertia",
      "weaponLowered",
      "weaponReloadingTime",
      "weapons",
      "weaponsInfo",
      "weaponsItems",
      "weaponsItemsCargo",
      "weaponState",
      "weaponsTurret",
      "weightRTD",
      "WFSideText",
      "wind",
      "windDir",
      "windRTD",
      "windStr",
      "wingsForcesRTD",
      "worldName",
      "worldSize",
      "worldToModel",
      "worldToModelVisual",
      "worldToScreen"
    ], l = {
      className: "meta",
      begin: /#\s*[a-z]+\b/,
      end: /$/,
      keywords: "define undef ifdef ifndef else endif include if",
      contains: [
        {
          begin: /\\\n/,
          relevance: 0
        },
        t.inherit(i, { className: "string" }),
        {
          begin: /<[^\n>]*>/,
          end: /$/,
          illegal: "\\n"
        },
        t.C_LINE_COMMENT_MODE,
        t.C_BLOCK_COMMENT_MODE
      ]
    };
    return {
      name: "SQF",
      case_insensitive: !0,
      keywords: {
        keyword: a,
        built_in: s,
        literal: o
      },
      contains: [
        t.C_LINE_COMMENT_MODE,
        t.C_BLOCK_COMMENT_MODE,
        t.NUMBER_MODE,
        n,
        r,
        i,
        l
      ],
      illegal: [
        //$ is only valid when used with Hex numbers (e.g. $FF)
        /\$[^a-fA-F0-9]/,
        /\w\$/,
        /\?/,
        //There's no ? in SQF
        /@/,
        //There's no @ in SQF
        // Brute-force-fixing the build error. See https://github.com/highlightjs/highlight.js/pull/3193#issuecomment-843088729
        / \| /,
        // . is only used in numbers
        /[a-zA-Z_]\./,
        /\:\=/,
        /\[\:/
      ]
    };
  }
  return vy = e, vy;
}
var by, OL;
function kee() {
  if (OL) return by;
  OL = 1;
  function e(t) {
    const n = t.regex, r = t.COMMENT("--", "$"), i = {
      className: "string",
      variants: [
        {
          begin: /'/,
          end: /'/,
          contains: [{ begin: /''/ }]
        }
      ]
    }, a = {
      begin: /"/,
      end: /"/,
      contains: [{ begin: /""/ }]
    }, o = [
      "true",
      "false",
      // Not sure it's correct to call NULL literal, and clauses like IS [NOT] NULL look strange that way.
      // "null",
      "unknown"
    ], s = [
      "double precision",
      "large object",
      "with timezone",
      "without timezone"
    ], l = [
      "bigint",
      "binary",
      "blob",
      "boolean",
      "char",
      "character",
      "clob",
      "date",
      "dec",
      "decfloat",
      "decimal",
      "float",
      "int",
      "integer",
      "interval",
      "nchar",
      "nclob",
      "national",
      "numeric",
      "real",
      "row",
      "smallint",
      "time",
      "timestamp",
      "varchar",
      "varying",
      // modifier (character varying)
      "varbinary"
    ], u = [
      "add",
      "asc",
      "collation",
      "desc",
      "final",
      "first",
      "last",
      "view"
    ], c = [
      "abs",
      "acos",
      "all",
      "allocate",
      "alter",
      "and",
      "any",
      "are",
      "array",
      "array_agg",
      "array_max_cardinality",
      "as",
      "asensitive",
      "asin",
      "asymmetric",
      "at",
      "atan",
      "atomic",
      "authorization",
      "avg",
      "begin",
      "begin_frame",
      "begin_partition",
      "between",
      "bigint",
      "binary",
      "blob",
      "boolean",
      "both",
      "by",
      "call",
      "called",
      "cardinality",
      "cascaded",
      "case",
      "cast",
      "ceil",
      "ceiling",
      "char",
      "char_length",
      "character",
      "character_length",
      "check",
      "classifier",
      "clob",
      "close",
      "coalesce",
      "collate",
      "collect",
      "column",
      "commit",
      "condition",
      "connect",
      "constraint",
      "contains",
      "convert",
      "copy",
      "corr",
      "corresponding",
      "cos",
      "cosh",
      "count",
      "covar_pop",
      "covar_samp",
      "create",
      "cross",
      "cube",
      "cume_dist",
      "current",
      "current_catalog",
      "current_date",
      "current_default_transform_group",
      "current_path",
      "current_role",
      "current_row",
      "current_schema",
      "current_time",
      "current_timestamp",
      "current_path",
      "current_role",
      "current_transform_group_for_type",
      "current_user",
      "cursor",
      "cycle",
      "date",
      "day",
      "deallocate",
      "dec",
      "decimal",
      "decfloat",
      "declare",
      "default",
      "define",
      "delete",
      "dense_rank",
      "deref",
      "describe",
      "deterministic",
      "disconnect",
      "distinct",
      "double",
      "drop",
      "dynamic",
      "each",
      "element",
      "else",
      "empty",
      "end",
      "end_frame",
      "end_partition",
      "end-exec",
      "equals",
      "escape",
      "every",
      "except",
      "exec",
      "execute",
      "exists",
      "exp",
      "external",
      "extract",
      "false",
      "fetch",
      "filter",
      "first_value",
      "float",
      "floor",
      "for",
      "foreign",
      "frame_row",
      "free",
      "from",
      "full",
      "function",
      "fusion",
      "get",
      "global",
      "grant",
      "group",
      "grouping",
      "groups",
      "having",
      "hold",
      "hour",
      "identity",
      "in",
      "indicator",
      "initial",
      "inner",
      "inout",
      "insensitive",
      "insert",
      "int",
      "integer",
      "intersect",
      "intersection",
      "interval",
      "into",
      "is",
      "join",
      "json_array",
      "json_arrayagg",
      "json_exists",
      "json_object",
      "json_objectagg",
      "json_query",
      "json_table",
      "json_table_primitive",
      "json_value",
      "lag",
      "language",
      "large",
      "last_value",
      "lateral",
      "lead",
      "leading",
      "left",
      "like",
      "like_regex",
      "listagg",
      "ln",
      "local",
      "localtime",
      "localtimestamp",
      "log",
      "log10",
      "lower",
      "match",
      "match_number",
      "match_recognize",
      "matches",
      "max",
      "member",
      "merge",
      "method",
      "min",
      "minute",
      "mod",
      "modifies",
      "module",
      "month",
      "multiset",
      "national",
      "natural",
      "nchar",
      "nclob",
      "new",
      "no",
      "none",
      "normalize",
      "not",
      "nth_value",
      "ntile",
      "null",
      "nullif",
      "numeric",
      "octet_length",
      "occurrences_regex",
      "of",
      "offset",
      "old",
      "omit",
      "on",
      "one",
      "only",
      "open",
      "or",
      "order",
      "out",
      "outer",
      "over",
      "overlaps",
      "overlay",
      "parameter",
      "partition",
      "pattern",
      "per",
      "percent",
      "percent_rank",
      "percentile_cont",
      "percentile_disc",
      "period",
      "portion",
      "position",
      "position_regex",
      "power",
      "precedes",
      "precision",
      "prepare",
      "primary",
      "procedure",
      "ptf",
      "range",
      "rank",
      "reads",
      "real",
      "recursive",
      "ref",
      "references",
      "referencing",
      "regr_avgx",
      "regr_avgy",
      "regr_count",
      "regr_intercept",
      "regr_r2",
      "regr_slope",
      "regr_sxx",
      "regr_sxy",
      "regr_syy",
      "release",
      "result",
      "return",
      "returns",
      "revoke",
      "right",
      "rollback",
      "rollup",
      "row",
      "row_number",
      "rows",
      "running",
      "savepoint",
      "scope",
      "scroll",
      "search",
      "second",
      "seek",
      "select",
      "sensitive",
      "session_user",
      "set",
      "show",
      "similar",
      "sin",
      "sinh",
      "skip",
      "smallint",
      "some",
      "specific",
      "specifictype",
      "sql",
      "sqlexception",
      "sqlstate",
      "sqlwarning",
      "sqrt",
      "start",
      "static",
      "stddev_pop",
      "stddev_samp",
      "submultiset",
      "subset",
      "substring",
      "substring_regex",
      "succeeds",
      "sum",
      "symmetric",
      "system",
      "system_time",
      "system_user",
      "table",
      "tablesample",
      "tan",
      "tanh",
      "then",
      "time",
      "timestamp",
      "timezone_hour",
      "timezone_minute",
      "to",
      "trailing",
      "translate",
      "translate_regex",
      "translation",
      "treat",
      "trigger",
      "trim",
      "trim_array",
      "true",
      "truncate",
      "uescape",
      "union",
      "unique",
      "unknown",
      "unnest",
      "update",
      "upper",
      "user",
      "using",
      "value",
      "values",
      "value_of",
      "var_pop",
      "var_samp",
      "varbinary",
      "varchar",
      "varying",
      "versioning",
      "when",
      "whenever",
      "where",
      "width_bucket",
      "window",
      "with",
      "within",
      "without",
      "year"
    ], d = [
      "abs",
      "acos",
      "array_agg",
      "asin",
      "atan",
      "avg",
      "cast",
      "ceil",
      "ceiling",
      "coalesce",
      "corr",
      "cos",
      "cosh",
      "count",
      "covar_pop",
      "covar_samp",
      "cume_dist",
      "dense_rank",
      "deref",
      "element",
      "exp",
      "extract",
      "first_value",
      "floor",
      "json_array",
      "json_arrayagg",
      "json_exists",
      "json_object",
      "json_objectagg",
      "json_query",
      "json_table",
      "json_table_primitive",
      "json_value",
      "lag",
      "last_value",
      "lead",
      "listagg",
      "ln",
      "log",
      "log10",
      "lower",
      "max",
      "min",
      "mod",
      "nth_value",
      "ntile",
      "nullif",
      "percent_rank",
      "percentile_cont",
      "percentile_disc",
      "position",
      "position_regex",
      "power",
      "rank",
      "regr_avgx",
      "regr_avgy",
      "regr_count",
      "regr_intercept",
      "regr_r2",
      "regr_slope",
      "regr_sxx",
      "regr_sxy",
      "regr_syy",
      "row_number",
      "sin",
      "sinh",
      "sqrt",
      "stddev_pop",
      "stddev_samp",
      "substring",
      "substring_regex",
      "sum",
      "tan",
      "tanh",
      "translate",
      "translate_regex",
      "treat",
      "trim",
      "trim_array",
      "unnest",
      "upper",
      "value_of",
      "var_pop",
      "var_samp",
      "width_bucket"
    ], f = [
      "current_catalog",
      "current_date",
      "current_default_transform_group",
      "current_path",
      "current_role",
      "current_schema",
      "current_transform_group_for_type",
      "current_user",
      "session_user",
      "system_time",
      "system_user",
      "current_time",
      "localtime",
      "current_timestamp",
      "localtimestamp"
    ], h = [
      "create table",
      "insert into",
      "primary key",
      "foreign key",
      "not null",
      "alter table",
      "add constraint",
      "grouping sets",
      "on overflow",
      "character set",
      "respect nulls",
      "ignore nulls",
      "nulls first",
      "nulls last",
      "depth first",
      "breadth first"
    ], m = d, v = [
      ...c,
      ...u
    ].filter((S) => !d.includes(S)), b = {
      className: "variable",
      begin: /@[a-z0-9][a-z0-9_]*/
    }, y = {
      className: "operator",
      begin: /[-+*/=%^~]|&&?|\|\|?|!=?|<(?:=>?|<|>)?|>[>=]?/,
      relevance: 0
    }, g = {
      begin: n.concat(/\b/, n.either(...m), /\s*\(/),
      relevance: 0,
      keywords: { built_in: m }
    };
    function E(S, {
      exceptions: C,
      when: T
    } = {}) {
      const O = T;
      return C = C || [], S.map((R) => R.match(/\|\d+$/) || C.includes(R) ? R : O(R) ? `${R}|0` : R);
    }
    return {
      name: "SQL",
      case_insensitive: !0,
      // does not include {} or HTML tags `</`
      illegal: /[{}]|<\//,
      keywords: {
        $pattern: /\b[\w\.]+/,
        keyword: E(v, { when: (S) => S.length < 3 }),
        literal: o,
        type: l,
        built_in: f
      },
      contains: [
        {
          begin: n.either(...h),
          relevance: 0,
          keywords: {
            $pattern: /[\w\.]+/,
            keyword: v.concat(h),
            literal: o,
            type: l
          }
        },
        {
          className: "type",
          begin: n.either(...s)
        },
        g,
        b,
        i,
        a,
        t.C_NUMBER_MODE,
        t.C_BLOCK_COMMENT_MODE,
        r,
        y
      ]
    };
  }
  return by = e, by;
}
var Ey, RL;
function Mee() {
  if (RL) return Ey;
  RL = 1;
  function e(t) {
    const n = t.regex, r = [
      "functions",
      "model",
      "data",
      "parameters",
      "quantities",
      "transformed",
      "generated"
    ], i = [
      "for",
      "in",
      "if",
      "else",
      "while",
      "break",
      "continue",
      "return"
    ], a = [
      "array",
      "tuple",
      "complex",
      "int",
      "real",
      "vector",
      "complex_vector",
      "ordered",
      "positive_ordered",
      "simplex",
      "unit_vector",
      "row_vector",
      "complex_row_vector",
      "matrix",
      "complex_matrix",
      "cholesky_factor_corr|10",
      "cholesky_factor_cov|10",
      "corr_matrix|10",
      "cov_matrix|10",
      "void"
    ], o = [
      "abs",
      "acos",
      "acosh",
      "add_diag",
      "algebra_solver",
      "algebra_solver_newton",
      "append_array",
      "append_col",
      "append_row",
      "asin",
      "asinh",
      "atan",
      "atan2",
      "atanh",
      "bessel_first_kind",
      "bessel_second_kind",
      "binary_log_loss",
      "block",
      "cbrt",
      "ceil",
      "chol2inv",
      "cholesky_decompose",
      "choose",
      "col",
      "cols",
      "columns_dot_product",
      "columns_dot_self",
      "complex_schur_decompose",
      "complex_schur_decompose_t",
      "complex_schur_decompose_u",
      "conj",
      "cos",
      "cosh",
      "cov_exp_quad",
      "crossprod",
      "csr_extract",
      "csr_extract_u",
      "csr_extract_v",
      "csr_extract_w",
      "csr_matrix_times_vector",
      "csr_to_dense_matrix",
      "cumulative_sum",
      "dae",
      "dae_tol",
      "determinant",
      "diag_matrix",
      "diagonal",
      "diag_post_multiply",
      "diag_pre_multiply",
      "digamma",
      "dims",
      "distance",
      "dot_product",
      "dot_self",
      "eigendecompose",
      "eigendecompose_sym",
      "eigenvalues",
      "eigenvalues_sym",
      "eigenvectors",
      "eigenvectors_sym",
      "erf",
      "erfc",
      "exp",
      "exp2",
      "expm1",
      "falling_factorial",
      "fdim",
      "fft",
      "fft2",
      "floor",
      "fma",
      "fmax",
      "fmin",
      "fmod",
      "gamma_p",
      "gamma_q",
      "generalized_inverse",
      "get_imag",
      "get_real",
      "head",
      "hmm_hidden_state_prob",
      "hmm_marginal",
      "hypot",
      "identity_matrix",
      "inc_beta",
      "integrate_1d",
      "integrate_ode",
      "integrate_ode_adams",
      "integrate_ode_bdf",
      "integrate_ode_rk45",
      "int_step",
      "inv",
      "inv_cloglog",
      "inv_erfc",
      "inverse",
      "inverse_spd",
      "inv_fft",
      "inv_fft2",
      "inv_inc_beta",
      "inv_logit",
      "inv_Phi",
      "inv_sqrt",
      "inv_square",
      "is_inf",
      "is_nan",
      "lambert_w0",
      "lambert_wm1",
      "lbeta",
      "lchoose",
      "ldexp",
      "lgamma",
      "linspaced_array",
      "linspaced_int_array",
      "linspaced_row_vector",
      "linspaced_vector",
      "lmgamma",
      "lmultiply",
      "log",
      "log1m",
      "log1m_exp",
      "log1m_inv_logit",
      "log1p",
      "log1p_exp",
      "log_determinant",
      "log_diff_exp",
      "log_falling_factorial",
      "log_inv_logit",
      "log_inv_logit_diff",
      "logit",
      "log_mix",
      "log_modified_bessel_first_kind",
      "log_rising_factorial",
      "log_softmax",
      "log_sum_exp",
      "machine_precision",
      "map_rect",
      "matrix_exp",
      "matrix_exp_multiply",
      "matrix_power",
      "max",
      "mdivide_left_spd",
      "mdivide_left_tri_low",
      "mdivide_right_spd",
      "mdivide_right_tri_low",
      "mean",
      "min",
      "modified_bessel_first_kind",
      "modified_bessel_second_kind",
      "multiply_lower_tri_self_transpose",
      "negative_infinity",
      "norm",
      "norm1",
      "norm2",
      "not_a_number",
      "num_elements",
      "ode_adams",
      "ode_adams_tol",
      "ode_adjoint_tol_ctl",
      "ode_bdf",
      "ode_bdf_tol",
      "ode_ckrk",
      "ode_ckrk_tol",
      "ode_rk45",
      "ode_rk45_tol",
      "one_hot_array",
      "one_hot_int_array",
      "one_hot_row_vector",
      "one_hot_vector",
      "ones_array",
      "ones_int_array",
      "ones_row_vector",
      "ones_vector",
      "owens_t",
      "Phi",
      "Phi_approx",
      "polar",
      "positive_infinity",
      "pow",
      "print",
      "prod",
      "proj",
      "qr",
      "qr_Q",
      "qr_R",
      "qr_thin",
      "qr_thin_Q",
      "qr_thin_R",
      "quad_form",
      "quad_form_diag",
      "quad_form_sym",
      "quantile",
      "rank",
      "reduce_sum",
      "reject",
      "rep_array",
      "rep_matrix",
      "rep_row_vector",
      "rep_vector",
      "reverse",
      "rising_factorial",
      "round",
      "row",
      "rows",
      "rows_dot_product",
      "rows_dot_self",
      "scale_matrix_exp_multiply",
      "sd",
      "segment",
      "sin",
      "singular_values",
      "sinh",
      "size",
      "softmax",
      "sort_asc",
      "sort_desc",
      "sort_indices_asc",
      "sort_indices_desc",
      "sqrt",
      "square",
      "squared_distance",
      "step",
      "sub_col",
      "sub_row",
      "sum",
      "svd",
      "svd_U",
      "svd_V",
      "symmetrize_from_lower_tri",
      "tail",
      "tan",
      "tanh",
      "target",
      "tcrossprod",
      "tgamma",
      "to_array_1d",
      "to_array_2d",
      "to_complex",
      "to_int",
      "to_matrix",
      "to_row_vector",
      "to_vector",
      "trace",
      "trace_gen_quad_form",
      "trace_quad_form",
      "trigamma",
      "trunc",
      "uniform_simplex",
      "variance",
      "zeros_array",
      "zeros_int_array",
      "zeros_row_vector"
    ], s = [
      "bernoulli",
      "bernoulli_logit",
      "bernoulli_logit_glm",
      "beta",
      "beta_binomial",
      "beta_proportion",
      "binomial",
      "binomial_logit",
      "categorical",
      "categorical_logit",
      "categorical_logit_glm",
      "cauchy",
      "chi_square",
      "dirichlet",
      "discrete_range",
      "double_exponential",
      "exp_mod_normal",
      "exponential",
      "frechet",
      "gamma",
      "gaussian_dlm_obs",
      "gumbel",
      "hmm_latent",
      "hypergeometric",
      "inv_chi_square",
      "inv_gamma",
      "inv_wishart",
      "inv_wishart_cholesky",
      "lkj_corr",
      "lkj_corr_cholesky",
      "logistic",
      "loglogistic",
      "lognormal",
      "multi_gp",
      "multi_gp_cholesky",
      "multinomial",
      "multinomial_logit",
      "multi_normal",
      "multi_normal_cholesky",
      "multi_normal_prec",
      "multi_student_cholesky_t",
      "multi_student_t",
      "multi_student_t_cholesky",
      "neg_binomial",
      "neg_binomial_2",
      "neg_binomial_2_log",
      "neg_binomial_2_log_glm",
      "normal",
      "normal_id_glm",
      "ordered_logistic",
      "ordered_logistic_glm",
      "ordered_probit",
      "pareto",
      "pareto_type_2",
      "poisson",
      "poisson_log",
      "poisson_log_glm",
      "rayleigh",
      "scaled_inv_chi_square",
      "skew_double_exponential",
      "skew_normal",
      "std_normal",
      "std_normal_log",
      "student_t",
      "uniform",
      "von_mises",
      "weibull",
      "wiener",
      "wishart",
      "wishart_cholesky"
    ], l = t.COMMENT(
      /\/\*/,
      /\*\//,
      {
        relevance: 0,
        contains: [
          {
            scope: "doctag",
            match: /@(return|param)/
          }
        ]
      }
    ), u = {
      scope: "meta",
      begin: /#include\b/,
      end: /$/,
      contains: [
        {
          match: /[a-z][a-z-._]+/,
          scope: "string"
        },
        t.C_LINE_COMMENT_MODE
      ]
    }, c = [
      "lower",
      "upper",
      "offset",
      "multiplier"
    ];
    return {
      name: "Stan",
      aliases: ["stanfuncs"],
      keywords: {
        $pattern: t.IDENT_RE,
        title: r,
        type: a,
        keyword: i,
        built_in: o
      },
      contains: [
        t.C_LINE_COMMENT_MODE,
        u,
        t.HASH_COMMENT_MODE,
        l,
        {
          scope: "built_in",
          match: /\s(pi|e|sqrt2|log2|log10)(?=\()/,
          relevance: 0
        },
        {
          match: n.concat(/[<,]\s*/, n.either(...c), /\s*=/),
          keywords: c
        },
        {
          scope: "keyword",
          match: /\btarget(?=\s*\+=)/
        },
        {
          // highlights the 'T' in T[,] for only Stan language distributrions
          match: [
            /~\s*/,
            n.either(...s),
            /(?:\(\))/,
            /\s*T(?=\s*\[)/
          ],
          scope: {
            2: "built_in",
            4: "keyword"
          }
        },
        {
          // highlights distributions that end with special endings
          scope: "built_in",
          keywords: s,
          begin: n.concat(/\w*/, n.either(...s), /(_lpdf|_lupdf|_lpmf|_cdf|_lcdf|_lccdf|_qf)(?=\s*[\(.*\)])/)
        },
        {
          // highlights distributions after ~
          begin: [
            /~/,
            /\s*/,
            n.concat(n.either(...s), /(?=\s*[\(.*\)])/)
          ],
          scope: { 3: "built_in" }
        },
        {
          // highlights user defined distributions after ~
          begin: [
            /~/,
            /\s*\w+(?=\s*[\(.*\)])/,
            "(?!.*/\b(" + n.either(...s) + ")\b)"
          ],
          scope: { 2: "title.function" }
        },
        {
          // highlights user defined distributions with special endings
          scope: "title.function",
          begin: /\w*(_lpdf|_lupdf|_lpmf|_cdf|_lcdf|_lccdf|_qf)(?=\s*[\(.*\)])/
        },
        {
          scope: "number",
          match: n.concat(
            // Comes from @RunDevelopment accessed 11/29/2021 at
            // https://github.com/PrismJS/prism/blob/c53ad2e65b7193ab4f03a1797506a54bbb33d5a2/components/prism-stan.js#L56
            // start of big noncapture group which
            // 1. gets numbers that are by themselves
            // 2. numbers that are separated by _
            // 3. numbers that are separted by .
            /(?:\b\d+(?:_\d+)*(?:\.(?:\d+(?:_\d+)*)?)?|\B\.\d+(?:_\d+)*)/,
            // grabs scientific notation
            // grabs complex numbers with i
            /(?:[eE][+-]?\d+(?:_\d+)*)?i?(?!\w)/
          ),
          relevance: 0
        },
        {
          scope: "string",
          begin: /"/,
          end: /"/
        }
      ]
    };
  }
  return Ey = e, Ey;
}
var Sy, wL;
function Pee() {
  if (wL) return Sy;
  wL = 1;
  function e(t) {
    return {
      name: "Stata",
      aliases: [
        "do",
        "ado"
      ],
      case_insensitive: !0,
      keywords: "if else in foreach for forv forva forval forvalu forvalue forvalues by bys bysort xi quietly qui capture about ac ac_7 acprplot acprplot_7 adjust ado adopath adoupdate alpha ameans an ano anov anova anova_estat anova_terms anovadef aorder ap app appe appen append arch arch_dr arch_estat arch_p archlm areg areg_p args arima arima_dr arima_estat arima_p as asmprobit asmprobit_estat asmprobit_lf asmprobit_mfx__dlg asmprobit_p ass asse asser assert avplot avplot_7 avplots avplots_7 bcskew0 bgodfrey bias binreg bip0_lf biplot bipp_lf bipr_lf bipr_p biprobit bitest bitesti bitowt blogit bmemsize boot bootsamp bootstrap bootstrap_8 boxco_l boxco_p boxcox boxcox_6 boxcox_p bprobit br break brier bro brow brows browse brr brrstat bs bs_7 bsampl_w bsample bsample_7 bsqreg bstat bstat_7 bstat_8 bstrap bstrap_7 bubble bubbleplot ca ca_estat ca_p cabiplot camat canon canon_8 canon_8_p canon_estat canon_p cap caprojection capt captu captur capture cat cc cchart cchart_7 cci cd censobs_table centile cf char chdir checkdlgfiles checkestimationsample checkhlpfiles checksum chelp ci cii cl class classutil clear cli clis clist clo clog clog_lf clog_p clogi clogi_sw clogit clogit_lf clogit_p clogitp clogl_sw cloglog clonevar clslistarray cluster cluster_measures cluster_stop cluster_tree cluster_tree_8 clustermat cmdlog cnr cnre cnreg cnreg_p cnreg_sw cnsreg codebook collaps4 collapse colormult_nb colormult_nw compare compress conf confi confir confirm conren cons const constr constra constrai constrain constraint continue contract copy copyright copysource cor corc corr corr2data corr_anti corr_kmo corr_smc corre correl correla correlat correlate corrgram cou coun count cox cox_p cox_sw coxbase coxhaz coxvar cprplot cprplot_7 crc cret cretu cretur creturn cross cs cscript cscript_log csi ct ct_is ctset ctst_5 ctst_st cttost cumsp cumsp_7 cumul cusum cusum_7 cutil d|0 datasig datasign datasigna datasignat datasignatu datasignatur datasignature datetof db dbeta de dec deco decod decode deff des desc descr descri describ describe destring dfbeta dfgls dfuller di di_g dir dirstats dis discard disp disp_res disp_s displ displa display distinct do doe doed doedi doedit dotplot dotplot_7 dprobit drawnorm drop ds ds_util dstdize duplicates durbina dwstat dydx e|0 ed edi edit egen eivreg emdef en enc enco encod encode eq erase ereg ereg_lf ereg_p ereg_sw ereghet ereghet_glf ereghet_glf_sh ereghet_gp ereghet_ilf ereghet_ilf_sh ereghet_ip eret eretu eretur ereturn err erro error esize est est_cfexist est_cfname est_clickable est_expand est_hold est_table est_unhold est_unholdok estat estat_default estat_summ estat_vce_only esti estimates etodow etof etomdy ex exi exit expand expandcl fac fact facto factor factor_estat factor_p factor_pca_rotated factor_rotate factormat fcast fcast_compute fcast_graph fdades fdadesc fdadescr fdadescri fdadescrib fdadescribe fdasav fdasave fdause fh_st file open file read file close file filefilter fillin find_hlp_file findfile findit findit_7 fit fl fli flis flist for5_0 forest forestplot form forma format fpredict frac_154 frac_adj frac_chk frac_cox frac_ddp frac_dis frac_dv frac_in frac_mun frac_pp frac_pq frac_pv frac_wgt frac_xo fracgen fracplot fracplot_7 fracpoly fracpred fron_ex fron_hn fron_p fron_tn fron_tn2 frontier ftodate ftoe ftomdy ftowdate funnel funnelplot g|0 gamhet_glf gamhet_gp gamhet_ilf gamhet_ip gamma gamma_d2 gamma_p gamma_sw gammahet gdi_hexagon gdi_spokes ge gen gene gener genera generat generate genrank genstd genvmean gettoken gl gladder gladder_7 glim_l01 glim_l02 glim_l03 glim_l04 glim_l05 glim_l06 glim_l07 glim_l08 glim_l09 glim_l10 glim_l11 glim_l12 glim_lf glim_mu glim_nw1 glim_nw2 glim_nw3 glim_p glim_v1 glim_v2 glim_v3 glim_v4 glim_v5 glim_v6 glim_v7 glm glm_6 glm_p glm_sw glmpred glo glob globa global glogit glogit_8 glogit_p gmeans gnbre_lf gnbreg gnbreg_5 gnbreg_p gomp_lf gompe_sw gomper_p gompertz gompertzhet gomphet_glf gomphet_glf_sh gomphet_gp gomphet_ilf gomphet_ilf_sh gomphet_ip gphdot gphpen gphprint gprefs gprobi_p gprobit gprobit_8 gr gr7 gr_copy gr_current gr_db gr_describe gr_dir gr_draw gr_draw_replay gr_drop gr_edit gr_editviewopts gr_example gr_example2 gr_export gr_print gr_qscheme gr_query gr_read gr_rename gr_replay gr_save gr_set gr_setscheme gr_table gr_undo gr_use graph graph7 grebar greigen greigen_7 greigen_8 grmeanby grmeanby_7 gs_fileinfo gs_filetype gs_graphinfo gs_stat gsort gwood h|0 hadimvo hareg hausman haver he heck_d2 heckma_p heckman heckp_lf heckpr_p heckprob hel help hereg hetpr_lf hetpr_p hetprob hettest hexdump hilite hist hist_7 histogram hlogit hlu hmeans hotel hotelling hprobit hreg hsearch icd9 icd9_ff icd9p iis impute imtest inbase include inf infi infil infile infix inp inpu input ins insheet insp inspe inspec inspect integ inten intreg intreg_7 intreg_p intrg2_ll intrg_ll intrg_ll2 ipolate iqreg ir irf irf_create irfm iri is_svy is_svysum isid istdize ivprob_1_lf ivprob_lf ivprobit ivprobit_p ivreg ivreg_footnote ivtob_1_lf ivtob_lf ivtobit ivtobit_p jackknife jacknife jknife jknife_6 jknife_8 jkstat joinby kalarma1 kap kap_3 kapmeier kappa kapwgt kdensity kdensity_7 keep ksm ksmirnov ktau kwallis l|0 la lab labbe labbeplot labe label labelbook ladder levels levelsof leverage lfit lfit_p li lincom line linktest lis list lloghet_glf lloghet_glf_sh lloghet_gp lloghet_ilf lloghet_ilf_sh lloghet_ip llogi_sw llogis_p llogist llogistic llogistichet lnorm_lf lnorm_sw lnorma_p lnormal lnormalhet lnormhet_glf lnormhet_glf_sh lnormhet_gp lnormhet_ilf lnormhet_ilf_sh lnormhet_ip lnskew0 loadingplot loc loca local log logi logis_lf logistic logistic_p logit logit_estat logit_p loglogs logrank loneway lookfor lookup lowess lowess_7 lpredict lrecomp lroc lroc_7 lrtest ls lsens lsens_7 lsens_x lstat ltable ltable_7 ltriang lv lvr2plot lvr2plot_7 m|0 ma mac macr macro makecns man manova manova_estat manova_p manovatest mantel mark markin markout marksample mat mat_capp mat_order mat_put_rr mat_rapp mata mata_clear mata_describe mata_drop mata_matdescribe mata_matsave mata_matuse mata_memory mata_mlib mata_mosave mata_rename mata_which matalabel matcproc matlist matname matr matri matrix matrix_input__dlg matstrik mcc mcci md0_ md1_ md1debug_ md2_ md2debug_ mds mds_estat mds_p mdsconfig mdslong mdsmat mdsshepard mdytoe mdytof me_derd mean means median memory memsize menl meqparse mer merg merge meta mfp mfx mhelp mhodds minbound mixed_ll mixed_ll_reparm mkassert mkdir mkmat mkspline ml ml_5 ml_adjs ml_bhhhs ml_c_d ml_check ml_clear ml_cnt ml_debug ml_defd ml_e0 ml_e0_bfgs ml_e0_cycle ml_e0_dfp ml_e0i ml_e1 ml_e1_bfgs ml_e1_bhhh ml_e1_cycle ml_e1_dfp ml_e2 ml_e2_cycle ml_ebfg0 ml_ebfr0 ml_ebfr1 ml_ebh0q ml_ebhh0 ml_ebhr0 ml_ebr0i ml_ecr0i ml_edfp0 ml_edfr0 ml_edfr1 ml_edr0i ml_eds ml_eer0i ml_egr0i ml_elf ml_elf_bfgs ml_elf_bhhh ml_elf_cycle ml_elf_dfp ml_elfi ml_elfs ml_enr0i ml_enrr0 ml_erdu0 ml_erdu0_bfgs ml_erdu0_bhhh ml_erdu0_bhhhq ml_erdu0_cycle ml_erdu0_dfp ml_erdu0_nrbfgs ml_exde ml_footnote ml_geqnr ml_grad0 ml_graph ml_hbhhh ml_hd0 ml_hold ml_init ml_inv ml_log ml_max ml_mlout ml_mlout_8 ml_model ml_nb0 ml_opt ml_p ml_plot ml_query ml_rdgrd ml_repor ml_s_e ml_score ml_searc ml_technique ml_unhold mleval mlf_ mlmatbysum mlmatsum mlog mlogi mlogit mlogit_footnote mlogit_p mlopts mlsum mlvecsum mnl0_ mor more mov move mprobit mprobit_lf mprobit_p mrdu0_ mrdu1_ mvdecode mvencode mvreg mvreg_estat n|0 nbreg nbreg_al nbreg_lf nbreg_p nbreg_sw nestreg net newey newey_7 newey_p news nl nl_7 nl_9 nl_9_p nl_p nl_p_7 nlcom nlcom_p nlexp2 nlexp2_7 nlexp2a nlexp2a_7 nlexp3 nlexp3_7 nlgom3 nlgom3_7 nlgom4 nlgom4_7 nlinit nllog3 nllog3_7 nllog4 nllog4_7 nlog_rd nlogit nlogit_p nlogitgen nlogittree nlpred no nobreak noi nois noisi noisil noisily note notes notes_dlg nptrend numlabel numlist odbc old_ver olo olog ologi ologi_sw ologit ologit_p ologitp on one onew onewa oneway op_colnm op_comp op_diff op_inv op_str opr opro oprob oprob_sw oprobi oprobi_p oprobit oprobitp opts_exclusive order orthog orthpoly ou out outf outfi outfil outfile outs outsh outshe outshee outsheet ovtest pac pac_7 palette parse parse_dissim pause pca pca_8 pca_display pca_estat pca_p pca_rotate pcamat pchart pchart_7 pchi pchi_7 pcorr pctile pentium pergram pergram_7 permute permute_8 personal peto_st pkcollapse pkcross pkequiv pkexamine pkexamine_7 pkshape pksumm pksumm_7 pl plo plot plugin pnorm pnorm_7 poisgof poiss_lf poiss_sw poisso_p poisson poisson_estat post postclose postfile postutil pperron pr prais prais_e prais_e2 prais_p predict predictnl preserve print pro prob probi probit probit_estat probit_p proc_time procoverlay procrustes procrustes_estat procrustes_p profiler prog progr progra program prop proportion prtest prtesti pwcorr pwd q\\s qby qbys qchi qchi_7 qladder qladder_7 qnorm qnorm_7 qqplot qqplot_7 qreg qreg_c qreg_p qreg_sw qu quadchk quantile quantile_7 que quer query range ranksum ratio rchart rchart_7 rcof recast reclink recode reg reg3 reg3_p regdw regr regre regre_p2 regres regres_p regress regress_estat regriv_p remap ren rena renam rename renpfix repeat replace report reshape restore ret retu retur return rm rmdir robvar roccomp roccomp_7 roccomp_8 rocf_lf rocfit rocfit_8 rocgold rocplot rocplot_7 roctab roctab_7 rolling rologit rologit_p rot rota rotat rotate rotatemat rreg rreg_p ru run runtest rvfplot rvfplot_7 rvpplot rvpplot_7 sa safesum sample sampsi sav save savedresults saveold sc sca scal scala scalar scatter scm_mine sco scob_lf scob_p scobi_sw scobit scor score scoreplot scoreplot_help scree screeplot screeplot_help sdtest sdtesti se search separate seperate serrbar serrbar_7 serset set set_defaults sfrancia sh she shel shell shewhart shewhart_7 signestimationsample signrank signtest simul simul_7 simulate simulate_8 sktest sleep slogit slogit_d2 slogit_p smooth snapspan so sor sort spearman spikeplot spikeplot_7 spikeplt spline_x split sqreg sqreg_p sret sretu sretur sreturn ssc st st_ct st_hc st_hcd st_hcd_sh st_is st_issys st_note st_promo st_set st_show st_smpl st_subid stack statsby statsby_8 stbase stci stci_7 stcox stcox_estat stcox_fr stcox_fr_ll stcox_p stcox_sw stcoxkm stcoxkm_7 stcstat stcurv stcurve stcurve_7 stdes stem stepwise stereg stfill stgen stir stjoin stmc stmh stphplot stphplot_7 stphtest stphtest_7 stptime strate strate_7 streg streg_sw streset sts sts_7 stset stsplit stsum sttocc sttoct stvary stweib su suest suest_8 sum summ summa summar summari summariz summarize sunflower sureg survcurv survsum svar svar_p svmat svy svy_disp svy_dreg svy_est svy_est_7 svy_estat svy_get svy_gnbreg_p svy_head svy_header svy_heckman_p svy_heckprob_p svy_intreg_p svy_ivreg_p svy_logistic_p svy_logit_p svy_mlogit_p svy_nbreg_p svy_ologit_p svy_oprobit_p svy_poisson_p svy_probit_p svy_regress_p svy_sub svy_sub_7 svy_x svy_x_7 svy_x_p svydes svydes_8 svygen svygnbreg svyheckman svyheckprob svyintreg svyintreg_7 svyintrg svyivreg svylc svylog_p svylogit svymarkout svymarkout_8 svymean svymlog svymlogit svynbreg svyolog svyologit svyoprob svyoprobit svyopts svypois svypois_7 svypoisson svyprobit svyprobt svyprop svyprop_7 svyratio svyreg svyreg_p svyregress svyset svyset_7 svyset_8 svytab svytab_7 svytest svytotal sw sw_8 swcnreg swcox swereg swilk swlogis swlogit swologit swoprbt swpois swprobit swqreg swtobit swweib symmetry symmi symplot symplot_7 syntax sysdescribe sysdir sysuse szroeter ta tab tab1 tab2 tab_or tabd tabdi tabdis tabdisp tabi table tabodds tabodds_7 tabstat tabu tabul tabula tabulat tabulate te tempfile tempname tempvar tes test testnl testparm teststd tetrachoric time_it timer tis tob tobi tobit tobit_p tobit_sw token tokeni tokeniz tokenize tostring total translate translator transmap treat_ll treatr_p treatreg trim trimfill trnb_cons trnb_mean trpoiss_d2 trunc_ll truncr_p truncreg tsappend tset tsfill tsline tsline_ex tsreport tsrevar tsrline tsset tssmooth tsunab ttest ttesti tut_chk tut_wait tutorial tw tware_st two twoway twoway__fpfit_serset twoway__function_gen twoway__histogram_gen twoway__ipoint_serset twoway__ipoints_serset twoway__kdensity_gen twoway__lfit_serset twoway__normgen_gen twoway__pci_serset twoway__qfit_serset twoway__scatteri_serset twoway__sunflower_gen twoway_ksm_serset ty typ type typeof u|0 unab unabbrev unabcmd update us use uselabel var var_mkcompanion var_p varbasic varfcast vargranger varirf varirf_add varirf_cgraph varirf_create varirf_ctable varirf_describe varirf_dir varirf_drop varirf_erase varirf_graph varirf_ograph varirf_rename varirf_set varirf_table varlist varlmar varnorm varsoc varstable varstable_w varstable_w2 varwle vce vec vec_fevd vec_mkphi vec_p vec_p_w vecirf_create veclmar veclmar_w vecnorm vecnorm_w vecrank vecstable verinst vers versi versio version view viewsource vif vwls wdatetof webdescribe webseek webuse weib1_lf weib2_lf weib_lf weib_lf0 weibhet_glf weibhet_glf_sh weibhet_glfa weibhet_glfa_sh weibhet_gp weibhet_ilf weibhet_ilf_sh weibhet_ilfa weibhet_ilfa_sh weibhet_ip weibu_sw weibul_p weibull weibull_c weibull_s weibullhet wh whelp whi which whil while wilc_st wilcoxon win wind windo window winexec wntestb wntestb_7 wntestq xchart xchart_7 xcorr xcorr_7 xi xi_6 xmlsav xmlsave xmluse xpose xsh xshe xshel xshell xt_iis xt_tis xtab_p xtabond xtbin_p xtclog xtcloglog xtcloglog_8 xtcloglog_d2 xtcloglog_pa_p xtcloglog_re_p xtcnt_p xtcorr xtdata xtdes xtfront_p xtfrontier xtgee xtgee_elink xtgee_estat xtgee_makeivar xtgee_p xtgee_plink xtgls xtgls_p xthaus xthausman xtht_p xthtaylor xtile xtint_p xtintreg xtintreg_8 xtintreg_d2 xtintreg_p xtivp_1 xtivp_2 xtivreg xtline xtline_ex xtlogit xtlogit_8 xtlogit_d2 xtlogit_fe_p xtlogit_pa_p xtlogit_re_p xtmixed xtmixed_estat xtmixed_p xtnb_fe xtnb_lf xtnbreg xtnbreg_pa_p xtnbreg_refe_p xtpcse xtpcse_p xtpois xtpoisson xtpoisson_d2 xtpoisson_pa_p xtpoisson_refe_p xtpred xtprobit xtprobit_8 xtprobit_d2 xtprobit_re_p xtps_fe xtps_lf xtps_ren xtps_ren_8 xtrar_p xtrc xtrc_p xtrchh xtrefe_p xtreg xtreg_be xtreg_fe xtreg_ml xtreg_pa_p xtreg_re xtregar xtrere_p xtset xtsf_ll xtsf_llti xtsum xttab xttest0 xttobit xttobit_8 xttobit_p xttrans yx yxview__barlike_draw yxview_area_draw yxview_bar_draw yxview_dot_draw yxview_dropline_draw yxview_function_draw yxview_iarrow_draw yxview_ilabels_draw yxview_normal_draw yxview_pcarrow_draw yxview_pcbarrow_draw yxview_pccapsym_draw yxview_pcscatter_draw yxview_pcspike_draw yxview_rarea_draw yxview_rbar_draw yxview_rbarm_draw yxview_rcap_draw yxview_rcapsym_draw yxview_rconnected_draw yxview_rline_draw yxview_rscatter_draw yxview_rspike_draw yxview_spike_draw yxview_sunflower_draw zap_s zinb zinb_llf zinb_plf zip zip_llf zip_p zip_plf zt_ct_5 zt_hc_5 zt_hcd_5 zt_is_5 zt_iss_5 zt_sho_5 zt_smp_5 ztbase_5 ztcox_5 ztdes_5 ztereg_5 ztfill_5 ztgen_5 ztir_5 ztjoin_5 ztnb ztnb_p ztp ztp_p zts_5 ztset_5 ztspli_5 ztsum_5 zttoct_5 ztvary_5 ztweib_5",
      contains: [
        {
          className: "symbol",
          begin: /`[a-zA-Z0-9_]+'/
        },
        {
          className: "variable",
          begin: /\$\{?[a-zA-Z0-9_]+\}?/,
          relevance: 0
        },
        {
          className: "string",
          variants: [
            { begin: `\`"[^\r
]*?"'` },
            { begin: `"[^\r
"]*"` }
          ]
        },
        {
          className: "built_in",
          variants: [{ begin: "\\b(abs|acos|asin|atan|atan2|atanh|ceil|cloglog|comb|cos|digamma|exp|floor|invcloglog|invlogit|ln|lnfact|lnfactorial|lngamma|log|log10|max|min|mod|reldif|round|sign|sin|sqrt|sum|tan|tanh|trigamma|trunc|betaden|Binomial|binorm|binormal|chi2|chi2tail|dgammapda|dgammapdada|dgammapdadx|dgammapdx|dgammapdxdx|F|Fden|Ftail|gammaden|gammap|ibeta|invbinomial|invchi2|invchi2tail|invF|invFtail|invgammap|invibeta|invnchi2|invnFtail|invnibeta|invnorm|invnormal|invttail|nbetaden|nchi2|nFden|nFtail|nibeta|norm|normal|normalden|normd|npnchi2|tden|ttail|uniform|abbrev|char|index|indexnot|length|lower|ltrim|match|plural|proper|real|regexm|regexr|regexs|reverse|rtrim|string|strlen|strlower|strltrim|strmatch|strofreal|strpos|strproper|strreverse|strrtrim|strtrim|strupper|subinstr|subinword|substr|trim|upper|word|wordcount|_caller|autocode|byteorder|chop|clip|cond|e|epsdouble|epsfloat|group|inlist|inrange|irecode|matrix|maxbyte|maxdouble|maxfloat|maxint|maxlong|mi|minbyte|mindouble|minfloat|minint|minlong|missing|r|recode|replay|return|s|scalar|d|date|day|dow|doy|halfyear|mdy|month|quarter|week|year|d|daily|dofd|dofh|dofm|dofq|dofw|dofy|h|halfyearly|hofd|m|mofd|monthly|q|qofd|quarterly|tin|twithin|w|weekly|wofd|y|yearly|yh|ym|yofd|yq|yw|cholesky|colnumb|colsof|corr|det|diag|diag0cnt|el|get|hadamard|I|inv|invsym|issym|issymmetric|J|matmissing|matuniform|mreldif|nullmat|rownumb|rowsof|sweep|syminv|trace|vec|vecdiag)(?=\\()" }]
        },
        t.COMMENT("^[ 	]*\\*.*$", !1),
        t.C_LINE_COMMENT_MODE,
        t.C_BLOCK_COMMENT_MODE
      ]
    };
  }
  return Sy = e, Sy;
}
var yy, xL;
function Fee() {
  if (xL) return yy;
  xL = 1;
  function e(t) {
    return {
      name: "STEP Part 21",
      aliases: [
        "p21",
        "step",
        "stp"
      ],
      case_insensitive: !0,
      // STEP 21 is case insensitive in theory, in practice all non-comments are capitalized.
      keywords: {
        $pattern: "[A-Z_][A-Z0-9_.]*",
        keyword: [
          "HEADER",
          "ENDSEC",
          "DATA"
        ]
      },
      contains: [
        {
          className: "meta",
          begin: "ISO-10303-21;",
          relevance: 10
        },
        {
          className: "meta",
          begin: "END-ISO-10303-21;",
          relevance: 10
        },
        t.C_LINE_COMMENT_MODE,
        t.C_BLOCK_COMMENT_MODE,
        t.COMMENT("/\\*\\*!", "\\*/"),
        t.C_NUMBER_MODE,
        t.inherit(t.APOS_STRING_MODE, { illegal: null }),
        t.inherit(t.QUOTE_STRING_MODE, { illegal: null }),
        {
          className: "string",
          begin: "'",
          end: "'"
        },
        {
          className: "symbol",
          variants: [
            {
              begin: "#",
              end: "\\d+",
              illegal: "\\W"
            }
          ]
        }
      ]
    };
  }
  return yy = e, yy;
}
var Ty, NL;
function Bee() {
  if (NL) return Ty;
  NL = 1;
  const e = (s) => ({
    IMPORTANT: {
      scope: "meta",
      begin: "!important"
    },
    BLOCK_COMMENT: s.C_BLOCK_COMMENT_MODE,
    HEXCOLOR: {
      scope: "number",
      begin: /#(([0-9a-fA-F]{3,4})|(([0-9a-fA-F]{2}){3,4}))\b/
    },
    FUNCTION_DISPATCH: {
      className: "built_in",
      begin: /[\w-]+(?=\()/
    },
    ATTRIBUTE_SELECTOR_MODE: {
      scope: "selector-attr",
      begin: /\[/,
      end: /\]/,
      illegal: "$",
      contains: [
        s.APOS_STRING_MODE,
        s.QUOTE_STRING_MODE
      ]
    },
    CSS_NUMBER_MODE: {
      scope: "number",
      begin: s.NUMBER_RE + "(%|em|ex|ch|rem|vw|vh|vmin|vmax|cm|mm|in|pt|pc|px|deg|grad|rad|turn|s|ms|Hz|kHz|dpi|dpcm|dppx)?",
      relevance: 0
    },
    CSS_VARIABLE: {
      className: "attr",
      begin: /--[A-Za-z_][A-Za-z0-9_-]*/
    }
  }), t = [
    "a",
    "abbr",
    "address",
    "article",
    "aside",
    "audio",
    "b",
    "blockquote",
    "body",
    "button",
    "canvas",
    "caption",
    "cite",
    "code",
    "dd",
    "del",
    "details",
    "dfn",
    "div",
    "dl",
    "dt",
    "em",
    "fieldset",
    "figcaption",
    "figure",
    "footer",
    "form",
    "h1",
    "h2",
    "h3",
    "h4",
    "h5",
    "h6",
    "header",
    "hgroup",
    "html",
    "i",
    "iframe",
    "img",
    "input",
    "ins",
    "kbd",
    "label",
    "legend",
    "li",
    "main",
    "mark",
    "menu",
    "nav",
    "object",
    "ol",
    "p",
    "q",
    "quote",
    "samp",
    "section",
    "span",
    "strong",
    "summary",
    "sup",
    "table",
    "tbody",
    "td",
    "textarea",
    "tfoot",
    "th",
    "thead",
    "time",
    "tr",
    "ul",
    "var",
    "video"
  ], n = [
    "any-hover",
    "any-pointer",
    "aspect-ratio",
    "color",
    "color-gamut",
    "color-index",
    "device-aspect-ratio",
    "device-height",
    "device-width",
    "display-mode",
    "forced-colors",
    "grid",
    "height",
    "hover",
    "inverted-colors",
    "monochrome",
    "orientation",
    "overflow-block",
    "overflow-inline",
    "pointer",
    "prefers-color-scheme",
    "prefers-contrast",
    "prefers-reduced-motion",
    "prefers-reduced-transparency",
    "resolution",
    "scan",
    "scripting",
    "update",
    "width",
    // TODO: find a better solution?
    "min-width",
    "max-width",
    "min-height",
    "max-height"
  ], r = [
    "active",
    "any-link",
    "blank",
    "checked",
    "current",
    "default",
    "defined",
    "dir",
    // dir()
    "disabled",
    "drop",
    "empty",
    "enabled",
    "first",
    "first-child",
    "first-of-type",
    "fullscreen",
    "future",
    "focus",
    "focus-visible",
    "focus-within",
    "has",
    // has()
    "host",
    // host or host()
    "host-context",
    // host-context()
    "hover",
    "indeterminate",
    "in-range",
    "invalid",
    "is",
    // is()
    "lang",
    // lang()
    "last-child",
    "last-of-type",
    "left",
    "link",
    "local-link",
    "not",
    // not()
    "nth-child",
    // nth-child()
    "nth-col",
    // nth-col()
    "nth-last-child",
    // nth-last-child()
    "nth-last-col",
    // nth-last-col()
    "nth-last-of-type",
    //nth-last-of-type()
    "nth-of-type",
    //nth-of-type()
    "only-child",
    "only-of-type",
    "optional",
    "out-of-range",
    "past",
    "placeholder-shown",
    "read-only",
    "read-write",
    "required",
    "right",
    "root",
    "scope",
    "target",
    "target-within",
    "user-invalid",
    "valid",
    "visited",
    "where"
    // where()
  ], i = [
    "after",
    "backdrop",
    "before",
    "cue",
    "cue-region",
    "first-letter",
    "first-line",
    "grammar-error",
    "marker",
    "part",
    "placeholder",
    "selection",
    "slotted",
    "spelling-error"
  ], a = [
    "align-content",
    "align-items",
    "align-self",
    "all",
    "animation",
    "animation-delay",
    "animation-direction",
    "animation-duration",
    "animation-fill-mode",
    "animation-iteration-count",
    "animation-name",
    "animation-play-state",
    "animation-timing-function",
    "backface-visibility",
    "background",
    "background-attachment",
    "background-blend-mode",
    "background-clip",
    "background-color",
    "background-image",
    "background-origin",
    "background-position",
    "background-repeat",
    "background-size",
    "block-size",
    "border",
    "border-block",
    "border-block-color",
    "border-block-end",
    "border-block-end-color",
    "border-block-end-style",
    "border-block-end-width",
    "border-block-start",
    "border-block-start-color",
    "border-block-start-style",
    "border-block-start-width",
    "border-block-style",
    "border-block-width",
    "border-bottom",
    "border-bottom-color",
    "border-bottom-left-radius",
    "border-bottom-right-radius",
    "border-bottom-style",
    "border-bottom-width",
    "border-collapse",
    "border-color",
    "border-image",
    "border-image-outset",
    "border-image-repeat",
    "border-image-slice",
    "border-image-source",
    "border-image-width",
    "border-inline",
    "border-inline-color",
    "border-inline-end",
    "border-inline-end-color",
    "border-inline-end-style",
    "border-inline-end-width",
    "border-inline-start",
    "border-inline-start-color",
    "border-inline-start-style",
    "border-inline-start-width",
    "border-inline-style",
    "border-inline-width",
    "border-left",
    "border-left-color",
    "border-left-style",
    "border-left-width",
    "border-radius",
    "border-right",
    "border-right-color",
    "border-right-style",
    "border-right-width",
    "border-spacing",
    "border-style",
    "border-top",
    "border-top-color",
    "border-top-left-radius",
    "border-top-right-radius",
    "border-top-style",
    "border-top-width",
    "border-width",
    "bottom",
    "box-decoration-break",
    "box-shadow",
    "box-sizing",
    "break-after",
    "break-before",
    "break-inside",
    "caption-side",
    "caret-color",
    "clear",
    "clip",
    "clip-path",
    "clip-rule",
    "color",
    "column-count",
    "column-fill",
    "column-gap",
    "column-rule",
    "column-rule-color",
    "column-rule-style",
    "column-rule-width",
    "column-span",
    "column-width",
    "columns",
    "contain",
    "content",
    "content-visibility",
    "counter-increment",
    "counter-reset",
    "cue",
    "cue-after",
    "cue-before",
    "cursor",
    "direction",
    "display",
    "empty-cells",
    "filter",
    "flex",
    "flex-basis",
    "flex-direction",
    "flex-flow",
    "flex-grow",
    "flex-shrink",
    "flex-wrap",
    "float",
    "flow",
    "font",
    "font-display",
    "font-family",
    "font-feature-settings",
    "font-kerning",
    "font-language-override",
    "font-size",
    "font-size-adjust",
    "font-smoothing",
    "font-stretch",
    "font-style",
    "font-synthesis",
    "font-variant",
    "font-variant-caps",
    "font-variant-east-asian",
    "font-variant-ligatures",
    "font-variant-numeric",
    "font-variant-position",
    "font-variation-settings",
    "font-weight",
    "gap",
    "glyph-orientation-vertical",
    "grid",
    "grid-area",
    "grid-auto-columns",
    "grid-auto-flow",
    "grid-auto-rows",
    "grid-column",
    "grid-column-end",
    "grid-column-start",
    "grid-gap",
    "grid-row",
    "grid-row-end",
    "grid-row-start",
    "grid-template",
    "grid-template-areas",
    "grid-template-columns",
    "grid-template-rows",
    "hanging-punctuation",
    "height",
    "hyphens",
    "icon",
    "image-orientation",
    "image-rendering",
    "image-resolution",
    "ime-mode",
    "inline-size",
    "isolation",
    "justify-content",
    "left",
    "letter-spacing",
    "line-break",
    "line-height",
    "list-style",
    "list-style-image",
    "list-style-position",
    "list-style-type",
    "margin",
    "margin-block",
    "margin-block-end",
    "margin-block-start",
    "margin-bottom",
    "margin-inline",
    "margin-inline-end",
    "margin-inline-start",
    "margin-left",
    "margin-right",
    "margin-top",
    "marks",
    "mask",
    "mask-border",
    "mask-border-mode",
    "mask-border-outset",
    "mask-border-repeat",
    "mask-border-slice",
    "mask-border-source",
    "mask-border-width",
    "mask-clip",
    "mask-composite",
    "mask-image",
    "mask-mode",
    "mask-origin",
    "mask-position",
    "mask-repeat",
    "mask-size",
    "mask-type",
    "max-block-size",
    "max-height",
    "max-inline-size",
    "max-width",
    "min-block-size",
    "min-height",
    "min-inline-size",
    "min-width",
    "mix-blend-mode",
    "nav-down",
    "nav-index",
    "nav-left",
    "nav-right",
    "nav-up",
    "none",
    "normal",
    "object-fit",
    "object-position",
    "opacity",
    "order",
    "orphans",
    "outline",
    "outline-color",
    "outline-offset",
    "outline-style",
    "outline-width",
    "overflow",
    "overflow-wrap",
    "overflow-x",
    "overflow-y",
    "padding",
    "padding-block",
    "padding-block-end",
    "padding-block-start",
    "padding-bottom",
    "padding-inline",
    "padding-inline-end",
    "padding-inline-start",
    "padding-left",
    "padding-right",
    "padding-top",
    "page-break-after",
    "page-break-before",
    "page-break-inside",
    "pause",
    "pause-after",
    "pause-before",
    "perspective",
    "perspective-origin",
    "pointer-events",
    "position",
    "quotes",
    "resize",
    "rest",
    "rest-after",
    "rest-before",
    "right",
    "row-gap",
    "scroll-margin",
    "scroll-margin-block",
    "scroll-margin-block-end",
    "scroll-margin-block-start",
    "scroll-margin-bottom",
    "scroll-margin-inline",
    "scroll-margin-inline-end",
    "scroll-margin-inline-start",
    "scroll-margin-left",
    "scroll-margin-right",
    "scroll-margin-top",
    "scroll-padding",
    "scroll-padding-block",
    "scroll-padding-block-end",
    "scroll-padding-block-start",
    "scroll-padding-bottom",
    "scroll-padding-inline",
    "scroll-padding-inline-end",
    "scroll-padding-inline-start",
    "scroll-padding-left",
    "scroll-padding-right",
    "scroll-padding-top",
    "scroll-snap-align",
    "scroll-snap-stop",
    "scroll-snap-type",
    "scrollbar-color",
    "scrollbar-gutter",
    "scrollbar-width",
    "shape-image-threshold",
    "shape-margin",
    "shape-outside",
    "speak",
    "speak-as",
    "src",
    // @font-face
    "tab-size",
    "table-layout",
    "text-align",
    "text-align-all",
    "text-align-last",
    "text-combine-upright",
    "text-decoration",
    "text-decoration-color",
    "text-decoration-line",
    "text-decoration-style",
    "text-emphasis",
    "text-emphasis-color",
    "text-emphasis-position",
    "text-emphasis-style",
    "text-indent",
    "text-justify",
    "text-orientation",
    "text-overflow",
    "text-rendering",
    "text-shadow",
    "text-transform",
    "text-underline-position",
    "top",
    "transform",
    "transform-box",
    "transform-origin",
    "transform-style",
    "transition",
    "transition-delay",
    "transition-duration",
    "transition-property",
    "transition-timing-function",
    "unicode-bidi",
    "vertical-align",
    "visibility",
    "voice-balance",
    "voice-duration",
    "voice-family",
    "voice-pitch",
    "voice-range",
    "voice-rate",
    "voice-stress",
    "voice-volume",
    "white-space",
    "widows",
    "width",
    "will-change",
    "word-break",
    "word-spacing",
    "word-wrap",
    "writing-mode",
    "z-index"
    // reverse makes sure longer attributes `font-weight` are matched fully
    // instead of getting false positives on say `font`
  ].reverse();
  function o(s) {
    const l = e(s), u = "and or not only", c = {
      className: "variable",
      begin: "\\$" + s.IDENT_RE
    }, d = [
      "charset",
      "css",
      "debug",
      "extend",
      "font-face",
      "for",
      "import",
      "include",
      "keyframes",
      "media",
      "mixin",
      "page",
      "warn",
      "while"
    ], f = "(?=[.\\s\\n[:,(])";
    return {
      name: "Stylus",
      aliases: ["styl"],
      case_insensitive: !1,
      keywords: "if else for in",
      illegal: "(" + [
        "\\?",
        "(\\bReturn\\b)",
        // monkey
        "(\\bEnd\\b)",
        // monkey
        "(\\bend\\b)",
        // vbscript
        "(\\bdef\\b)",
        // gradle
        ";",
        // a whole lot of languages
        "#\\s",
        // markdown
        "\\*\\s",
        // markdown
        "===\\s",
        // markdown
        "\\|",
        "%"
        // prolog
      ].join("|") + ")",
      contains: [
        // strings
        s.QUOTE_STRING_MODE,
        s.APOS_STRING_MODE,
        // comments
        s.C_LINE_COMMENT_MODE,
        s.C_BLOCK_COMMENT_MODE,
        // hex colors
        l.HEXCOLOR,
        // class tag
        {
          begin: "\\.[a-zA-Z][a-zA-Z0-9_-]*" + f,
          className: "selector-class"
        },
        // id tag
        {
          begin: "#[a-zA-Z][a-zA-Z0-9_-]*" + f,
          className: "selector-id"
        },
        // tags
        {
          begin: "\\b(" + t.join("|") + ")" + f,
          className: "selector-tag"
        },
        // psuedo selectors
        {
          className: "selector-pseudo",
          begin: "&?:(" + r.join("|") + ")" + f
        },
        {
          className: "selector-pseudo",
          begin: "&?:(:)?(" + i.join("|") + ")" + f
        },
        l.ATTRIBUTE_SELECTOR_MODE,
        {
          className: "keyword",
          begin: /@media/,
          starts: {
            end: /[{;}]/,
            keywords: {
              $pattern: /[a-z-]+/,
              keyword: u,
              attribute: n.join(" ")
            },
            contains: [l.CSS_NUMBER_MODE]
          }
        },
        // @ keywords
        {
          className: "keyword",
          begin: "@((-(o|moz|ms|webkit)-)?(" + d.join("|") + "))\\b"
        },
        // variables
        c,
        // dimension
        l.CSS_NUMBER_MODE,
        // functions
        //  - only from beginning of line + whitespace
        {
          className: "function",
          begin: "^[a-zA-Z][a-zA-Z0-9_-]*\\(.*\\)",
          illegal: "[\\n]",
          returnBegin: !0,
          contains: [
            {
              className: "title",
              begin: "\\b[a-zA-Z][a-zA-Z0-9_-]*"
            },
            {
              className: "params",
              begin: /\(/,
              end: /\)/,
              contains: [
                l.HEXCOLOR,
                c,
                s.APOS_STRING_MODE,
                l.CSS_NUMBER_MODE,
                s.QUOTE_STRING_MODE
              ]
            }
          ]
        },
        // css variables
        l.CSS_VARIABLE,
        // attributes
        //  - only from beginning of line + whitespace
        //  - must have whitespace after it
        {
          className: "attribute",
          begin: "\\b(" + a.join("|") + ")\\b",
          starts: {
            // value container
            end: /;|$/,
            contains: [
              l.HEXCOLOR,
              c,
              s.APOS_STRING_MODE,
              s.QUOTE_STRING_MODE,
              l.CSS_NUMBER_MODE,
              s.C_BLOCK_COMMENT_MODE,
              l.IMPORTANT,
              l.FUNCTION_DISPATCH
            ],
            illegal: /\./,
            relevance: 0
          }
        },
        l.FUNCTION_DISPATCH
      ]
    };
  }
  return Ty = o, Ty;
}
var Cy, DL;
function $ee() {
  if (DL) return Cy;
  DL = 1;
  function e(t) {
    return {
      name: "SubUnit",
      case_insensitive: !0,
      contains: [
        {
          className: "string",
          begin: `\\[
(multipart)?`,
          end: `\\]
`
        },
        {
          className: "string",
          begin: "\\d{4}-\\d{2}-\\d{2}(\\s+)\\d{2}:\\d{2}:\\d{2}.\\d+Z"
        },
        {
          className: "string",
          begin: "(\\+|-)\\d+"
        },
        {
          className: "keyword",
          relevance: 10,
          variants: [
            { begin: "^(test|testing|success|successful|failure|error|skip|xfail|uxsuccess)(:?)\\s+(test)?" },
            { begin: "^progress(:?)(\\s+)?(pop|push)?" },
            { begin: "^tags:" },
            { begin: "^time:" }
          ]
        }
      ]
    };
  }
  return Cy = e, Cy;
}
var Ay, IL;
function Uee() {
  if (IL) return Ay;
  IL = 1;
  function e(R) {
    return R ? typeof R == "string" ? R : R.source : null;
  }
  function t(R) {
    return n("(?=", R, ")");
  }
  function n(...R) {
    return R.map((q) => e(q)).join("");
  }
  function r(R) {
    const D = R[R.length - 1];
    return typeof D == "object" && D.constructor === Object ? (R.splice(R.length - 1, 1), D) : {};
  }
  function i(...R) {
    return "(" + (r(R).capture ? "" : "?:") + R.map(($) => e($)).join("|") + ")";
  }
  const a = (R) => n(
    /\b/,
    R,
    /\w$/.test(R) ? /\b/ : /\B/
  ), o = [
    "Protocol",
    // contextual
    "Type"
    // contextual
  ].map(a), s = [
    "init",
    "self"
  ].map(a), l = [
    "Any",
    "Self"
  ], u = [
    // strings below will be fed into the regular `keywords` engine while regex
    // will result in additional modes being created to scan for those keywords to
    // avoid conflicts with other rules
    "actor",
    "any",
    // contextual
    "associatedtype",
    "async",
    "await",
    /as\?/,
    // operator
    /as!/,
    // operator
    "as",
    // operator
    "borrowing",
    // contextual
    "break",
    "case",
    "catch",
    "class",
    "consume",
    // contextual
    "consuming",
    // contextual
    "continue",
    "convenience",
    // contextual
    "copy",
    // contextual
    "default",
    "defer",
    "deinit",
    "didSet",
    // contextual
    "distributed",
    "do",
    "dynamic",
    // contextual
    "each",
    "else",
    "enum",
    "extension",
    "fallthrough",
    /fileprivate\(set\)/,
    "fileprivate",
    "final",
    // contextual
    "for",
    "func",
    "get",
    // contextual
    "guard",
    "if",
    "import",
    "indirect",
    // contextual
    "infix",
    // contextual
    /init\?/,
    /init!/,
    "inout",
    /internal\(set\)/,
    "internal",
    "in",
    "is",
    // operator
    "isolated",
    // contextual
    "nonisolated",
    // contextual
    "lazy",
    // contextual
    "let",
    "macro",
    "mutating",
    // contextual
    "nonmutating",
    // contextual
    /open\(set\)/,
    // contextual
    "open",
    // contextual
    "operator",
    "optional",
    // contextual
    "override",
    // contextual
    "postfix",
    // contextual
    "precedencegroup",
    "prefix",
    // contextual
    /private\(set\)/,
    "private",
    "protocol",
    /public\(set\)/,
    "public",
    "repeat",
    "required",
    // contextual
    "rethrows",
    "return",
    "set",
    // contextual
    "some",
    // contextual
    "static",
    "struct",
    "subscript",
    "super",
    "switch",
    "throws",
    "throw",
    /try\?/,
    // operator
    /try!/,
    // operator
    "try",
    // operator
    "typealias",
    /unowned\(safe\)/,
    // contextual
    /unowned\(unsafe\)/,
    // contextual
    "unowned",
    // contextual
    "var",
    "weak",
    // contextual
    "where",
    "while",
    "willSet"
    // contextual
  ], c = [
    "false",
    "nil",
    "true"
  ], d = [
    "assignment",
    "associativity",
    "higherThan",
    "left",
    "lowerThan",
    "none",
    "right"
  ], f = [
    "#colorLiteral",
    "#column",
    "#dsohandle",
    "#else",
    "#elseif",
    "#endif",
    "#error",
    "#file",
    "#fileID",
    "#fileLiteral",
    "#filePath",
    "#function",
    "#if",
    "#imageLiteral",
    "#keyPath",
    "#line",
    "#selector",
    "#sourceLocation",
    "#warning"
  ], h = [
    "abs",
    "all",
    "any",
    "assert",
    "assertionFailure",
    "debugPrint",
    "dump",
    "fatalError",
    "getVaList",
    "isKnownUniquelyReferenced",
    "max",
    "min",
    "numericCast",
    "pointwiseMax",
    "pointwiseMin",
    "precondition",
    "preconditionFailure",
    "print",
    "readLine",
    "repeatElement",
    "sequence",
    "stride",
    "swap",
    "swift_unboxFromSwiftValueWithType",
    "transcode",
    "type",
    "unsafeBitCast",
    "unsafeDowncast",
    "withExtendedLifetime",
    "withUnsafeMutablePointer",
    "withUnsafePointer",
    "withVaList",
    "withoutActuallyEscaping",
    "zip"
  ], m = i(
    /[/=\-+!*%<>&|^~?]/,
    /[\u00A1-\u00A7]/,
    /[\u00A9\u00AB]/,
    /[\u00AC\u00AE]/,
    /[\u00B0\u00B1]/,
    /[\u00B6\u00BB\u00BF\u00D7\u00F7]/,
    /[\u2016-\u2017]/,
    /[\u2020-\u2027]/,
    /[\u2030-\u203E]/,
    /[\u2041-\u2053]/,
    /[\u2055-\u205E]/,
    /[\u2190-\u23FF]/,
    /[\u2500-\u2775]/,
    /[\u2794-\u2BFF]/,
    /[\u2E00-\u2E7F]/,
    /[\u3001-\u3003]/,
    /[\u3008-\u3020]/,
    /[\u3030]/
  ), v = i(
    m,
    /[\u0300-\u036F]/,
    /[\u1DC0-\u1DFF]/,
    /[\u20D0-\u20FF]/,
    /[\uFE00-\uFE0F]/,
    /[\uFE20-\uFE2F]/
    // TODO: The following characters are also allowed, but the regex isn't supported yet.
    // /[\u{E0100}-\u{E01EF}]/u
  ), b = n(m, v, "*"), y = i(
    /[a-zA-Z_]/,
    /[\u00A8\u00AA\u00AD\u00AF\u00B2-\u00B5\u00B7-\u00BA]/,
    /[\u00BC-\u00BE\u00C0-\u00D6\u00D8-\u00F6\u00F8-\u00FF]/,
    /[\u0100-\u02FF\u0370-\u167F\u1681-\u180D\u180F-\u1DBF]/,
    /[\u1E00-\u1FFF]/,
    /[\u200B-\u200D\u202A-\u202E\u203F-\u2040\u2054\u2060-\u206F]/,
    /[\u2070-\u20CF\u2100-\u218F\u2460-\u24FF\u2776-\u2793]/,
    /[\u2C00-\u2DFF\u2E80-\u2FFF]/,
    /[\u3004-\u3007\u3021-\u302F\u3031-\u303F\u3040-\uD7FF]/,
    /[\uF900-\uFD3D\uFD40-\uFDCF\uFDF0-\uFE1F\uFE30-\uFE44]/,
    /[\uFE47-\uFEFE\uFF00-\uFFFD]/
    // Should be /[\uFE47-\uFFFD]/, but we have to exclude FEFF.
    // The following characters are also allowed, but the regexes aren't supported yet.
    // /[\u{10000}-\u{1FFFD}\u{20000-\u{2FFFD}\u{30000}-\u{3FFFD}\u{40000}-\u{4FFFD}]/u,
    // /[\u{50000}-\u{5FFFD}\u{60000-\u{6FFFD}\u{70000}-\u{7FFFD}\u{80000}-\u{8FFFD}]/u,
    // /[\u{90000}-\u{9FFFD}\u{A0000-\u{AFFFD}\u{B0000}-\u{BFFFD}\u{C0000}-\u{CFFFD}]/u,
    // /[\u{D0000}-\u{DFFFD}\u{E0000-\u{EFFFD}]/u
  ), g = i(
    y,
    /\d/,
    /[\u0300-\u036F\u1DC0-\u1DFF\u20D0-\u20FF\uFE20-\uFE2F]/
  ), E = n(y, g, "*"), S = n(/[A-Z]/, g, "*"), C = [
    "attached",
    "autoclosure",
    n(/convention\(/, i("swift", "block", "c"), /\)/),
    "discardableResult",
    "dynamicCallable",
    "dynamicMemberLookup",
    "escaping",
    "freestanding",
    "frozen",
    "GKInspectable",
    "IBAction",
    "IBDesignable",
    "IBInspectable",
    "IBOutlet",
    "IBSegueAction",
    "inlinable",
    "main",
    "nonobjc",
    "NSApplicationMain",
    "NSCopying",
    "NSManaged",
    n(/objc\(/, E, /\)/),
    "objc",
    "objcMembers",
    "propertyWrapper",
    "requires_stored_property_inits",
    "resultBuilder",
    "Sendable",
    "testable",
    "UIApplicationMain",
    "unchecked",
    "unknown",
    "usableFromInline",
    "warn_unqualified_access"
  ], T = [
    "iOS",
    "iOSApplicationExtension",
    "macOS",
    "macOSApplicationExtension",
    "macCatalyst",
    "macCatalystApplicationExtension",
    "watchOS",
    "watchOSApplicationExtension",
    "tvOS",
    "tvOSApplicationExtension",
    "swift"
  ];
  function O(R) {
    const D = {
      match: /\s+/,
      relevance: 0
    }, q = R.COMMENT(
      "/\\*",
      "\\*/",
      { contains: ["self"] }
    ), $ = [
      R.C_LINE_COMMENT_MODE,
      q
    ], P = {
      match: [
        /\./,
        i(...o, ...s)
      ],
      className: { 2: "keyword" }
    }, Y = {
      // Consume .keyword to prevent highlighting properties and methods as keywords.
      match: n(/\./, i(...u)),
      relevance: 0
    }, L = u.filter((kt) => typeof kt == "string").concat(["_|0"]), x = u.filter((kt) => typeof kt != "string").concat(l).map(a), I = { variants: [
      {
        className: "keyword",
        match: i(...x, ...s)
      }
    ] }, k = {
      $pattern: i(
        /\b\w+/,
        // regular keywords
        /#\w+/
        // number keywords
      ),
      keyword: L.concat(f),
      literal: c
    }, B = [
      P,
      Y,
      I
    ], W = {
      // Consume .built_in to prevent highlighting properties and methods.
      match: n(/\./, i(...h)),
      relevance: 0
    }, Z = {
      className: "built_in",
      match: n(/\b/, i(...h), /(?=\()/)
    }, V = [
      W,
      Z
    ], K = {
      // Prevent -> from being highlighting as an operator.
      match: /->/,
      relevance: 0
    }, ne = {
      className: "operator",
      relevance: 0,
      variants: [
        { match: b },
        {
          // dot-operator: only operators that start with a dot are allowed to use dots as
          // characters (..., ...<, .*, etc). So there rule here is: a dot followed by one or more
          // characters that may also include dots.
          match: `\\.(\\.|${v})+`
        }
      ]
    }, Ee = [
      K,
      ne
    ], oe = "([0-9]_*)+", ae = "([0-9a-fA-F]_*)+", pe = {
      className: "number",
      relevance: 0,
      variants: [
        // decimal floating-point-literal (subsumes decimal-literal)
        { match: `\\b(${oe})(\\.(${oe}))?([eE][+-]?(${oe}))?\\b` },
        // hexadecimal floating-point-literal (subsumes hexadecimal-literal)
        { match: `\\b0x(${ae})(\\.(${ae}))?([pP][+-]?(${oe}))?\\b` },
        // octal-literal
        { match: /\b0o([0-7]_*)+\b/ },
        // binary-literal
        { match: /\b0b([01]_*)+\b/ }
      ]
    }, Se = (kt = "") => ({
      className: "subst",
      variants: [
        { match: n(/\\/, kt, /[0\\tnr"']/) },
        { match: n(/\\/, kt, /u\{[0-9a-fA-F]{1,8}\}/) }
      ]
    }), Re = (kt = "") => ({
      className: "subst",
      match: n(/\\/, kt, /[\t ]*(?:[\r\n]|\r\n)/)
    }), Ye = (kt = "") => ({
      className: "subst",
      label: "interpol",
      begin: n(/\\/, kt, /\(/),
      end: /\)/
    }), nt = (kt = "") => ({
      begin: n(kt, /"""/),
      end: n(/"""/, kt),
      contains: [
        Se(kt),
        Re(kt),
        Ye(kt)
      ]
    }), ut = (kt = "") => ({
      begin: n(kt, /"/),
      end: n(/"/, kt),
      contains: [
        Se(kt),
        Ye(kt)
      ]
    }), Tt = {
      className: "string",
      variants: [
        nt(),
        nt("#"),
        nt("##"),
        nt("###"),
        ut(),
        ut("#"),
        ut("##"),
        ut("###")
      ]
    }, Ot = [
      R.BACKSLASH_ESCAPE,
      {
        begin: /\[/,
        end: /\]/,
        relevance: 0,
        contains: [R.BACKSLASH_ESCAPE]
      }
    ], Xt = {
      begin: /\/[^\s](?=[^/\n]*\/)/,
      end: /\//,
      contains: Ot
    }, We = (kt) => {
      const Dn = n(kt, /\//), gn = n(/\//, kt);
      return {
        begin: Dn,
        end: gn,
        contains: [
          ...Ot,
          {
            scope: "comment",
            begin: `#(?!.*${gn})`,
            end: /$/
          }
        ]
      };
    }, st = {
      scope: "regexp",
      variants: [
        We("###"),
        We("##"),
        We("#"),
        Xt
      ]
    }, Pt = { match: n(/`/, E, /`/) }, Ke = {
      className: "variable",
      match: /\$\d+/
    }, Je = {
      className: "variable",
      match: `\\$${g}+`
    }, Be = [
      Pt,
      Ke,
      Je
    ], pt = {
      match: /(@|#(un)?)available/,
      scope: "keyword",
      starts: { contains: [
        {
          begin: /\(/,
          end: /\)/,
          keywords: T,
          contains: [
            ...Ee,
            pe,
            Tt
          ]
        }
      ] }
    }, ft = {
      scope: "keyword",
      match: n(/@/, i(...C))
    }, Ze = {
      scope: "meta",
      match: n(/@/, E)
    }, _t = [
      pt,
      ft,
      Ze
    ], St = {
      match: t(/\b[A-Z]/),
      relevance: 0,
      contains: [
        {
          // Common Apple frameworks, for relevance boost
          className: "type",
          match: n(/(AV|CA|CF|CG|CI|CL|CM|CN|CT|MK|MP|MTK|MTL|NS|SCN|SK|UI|WK|XC)/, g, "+")
        },
        {
          // Type identifier
          className: "type",
          match: S,
          relevance: 0
        },
        {
          // Optional type
          match: /[?!]+/,
          relevance: 0
        },
        {
          // Variadic parameter
          match: /\.\.\./,
          relevance: 0
        },
        {
          // Protocol composition
          match: n(/\s+&\s+/, t(S)),
          relevance: 0
        }
      ]
    }, we = {
      begin: /</,
      end: />/,
      keywords: k,
      contains: [
        ...$,
        ...B,
        ..._t,
        K,
        St
      ]
    };
    St.contains.push(we);
    const je = {
      match: n(E, /\s*:/),
      keywords: "_|0",
      relevance: 0
    }, yt = {
      begin: /\(/,
      end: /\)/,
      relevance: 0,
      keywords: k,
      contains: [
        "self",
        je,
        ...$,
        st,
        ...B,
        ...V,
        ...Ee,
        pe,
        Tt,
        ...Be,
        ..._t,
        St
      ]
    }, Rt = {
      begin: /</,
      end: />/,
      keywords: "repeat each",
      contains: [
        ...$,
        St
      ]
    }, sn = {
      begin: i(
        t(n(E, /\s*:/)),
        t(n(E, /\s+/, E, /\s*:/))
      ),
      end: /:/,
      relevance: 0,
      contains: [
        {
          className: "keyword",
          match: /\b_\b/
        },
        {
          className: "params",
          match: E
        }
      ]
    }, me = {
      begin: /\(/,
      end: /\)/,
      keywords: k,
      contains: [
        sn,
        ...$,
        ...B,
        ...Ee,
        pe,
        Tt,
        ..._t,
        St,
        yt
      ],
      endsParent: !0,
      illegal: /["']/
    }, He = {
      match: [
        /(func|macro)/,
        /\s+/,
        i(Pt.match, E, b)
      ],
      className: {
        1: "keyword",
        3: "title.function"
      },
      contains: [
        Rt,
        me,
        D
      ],
      illegal: [
        /\[/,
        /%/
      ]
    }, tt = {
      match: [
        /\b(?:subscript|init[?!]?)/,
        /\s*(?=[<(])/
      ],
      className: { 1: "keyword" },
      contains: [
        Rt,
        me,
        D
      ],
      illegal: /\[|%/
    }, ot = {
      match: [
        /operator/,
        /\s+/,
        b
      ],
      className: {
        1: "keyword",
        3: "title"
      }
    }, xn = {
      begin: [
        /precedencegroup/,
        /\s+/,
        S
      ],
      className: {
        1: "keyword",
        3: "title"
      },
      contains: [St],
      keywords: [
        ...d,
        ...c
      ],
      end: /}/
    };
    for (const kt of Tt.variants) {
      const Dn = kt.contains.find((Vn) => Vn.label === "interpol");
      Dn.keywords = k;
      const gn = [
        ...B,
        ...V,
        ...Ee,
        pe,
        Tt,
        ...Be
      ];
      Dn.contains = [
        ...gn,
        {
          begin: /\(/,
          end: /\)/,
          contains: [
            "self",
            ...gn
          ]
        }
      ];
    }
    return {
      name: "Swift",
      keywords: k,
      contains: [
        ...$,
        He,
        tt,
        {
          beginKeywords: "struct protocol class extension enum actor",
          end: "\\{",
          excludeEnd: !0,
          keywords: k,
          contains: [
            R.inherit(R.TITLE_MODE, {
              className: "title.class",
              begin: /[A-Za-z$_][\u00C0-\u02B80-9A-Za-z$_]*/
            }),
            ...B
          ]
        },
        ot,
        xn,
        {
          beginKeywords: "import",
          end: /$/,
          contains: [...$],
          relevance: 0
        },
        st,
        ...B,
        ...V,
        ...Ee,
        pe,
        Tt,
        ...Be,
        ..._t,
        St,
        yt
      ]
    };
  }
  return Ay = O, Ay;
}
var Oy, LL;
function qee() {
  if (LL) return Oy;
  LL = 1;
  function e(t) {
    return {
      name: "Tagger Script",
      contains: [
        {
          className: "comment",
          begin: /\$noop\(/,
          end: /\)/,
          contains: [
            { begin: /\\[()]/ },
            {
              begin: /\(/,
              end: /\)/,
              contains: [
                { begin: /\\[()]/ },
                "self"
              ]
            }
          ],
          relevance: 10
        },
        {
          className: "keyword",
          begin: /\$[_a-zA-Z0-9]+(?=\()/
        },
        {
          className: "variable",
          begin: /%[_a-zA-Z0-9:]+%/
        },
        {
          className: "symbol",
          begin: /\\[\\nt$%,()]/
        },
        {
          className: "symbol",
          begin: /\\u[a-fA-F0-9]{4}/
        }
      ]
    };
  }
  return Oy = e, Oy;
}
var Ry, kL;
function Gee() {
  if (kL) return Ry;
  kL = 1;
  function e(t) {
    const n = "true false yes no null", r = "[\\w#;/?:@&=+$,.~*'()[\\]]+", i = {
      className: "attr",
      variants: [
        { begin: "\\w[\\w :\\/.-]*:(?=[ 	]|$)" },
        {
          // double quoted keys
          begin: '"\\w[\\w :\\/.-]*":(?=[ 	]|$)'
        },
        {
          // single quoted keys
          begin: "'\\w[\\w :\\/.-]*':(?=[ 	]|$)"
        }
      ]
    }, a = {
      className: "template-variable",
      variants: [
        {
          // jinja templates Ansible
          begin: /\{\{/,
          end: /\}\}/
        },
        {
          // Ruby i18n
          begin: /%\{/,
          end: /\}/
        }
      ]
    }, o = {
      className: "string",
      relevance: 0,
      variants: [
        {
          begin: /'/,
          end: /'/
        },
        {
          begin: /"/,
          end: /"/
        },
        { begin: /\S+/ }
      ],
      contains: [
        t.BACKSLASH_ESCAPE,
        a
      ]
    }, s = t.inherit(o, { variants: [
      {
        begin: /'/,
        end: /'/
      },
      {
        begin: /"/,
        end: /"/
      },
      { begin: /[^\s,{}[\]]+/ }
    ] }), f = {
      className: "number",
      begin: "\\b" + "[0-9]{4}(-[0-9][0-9]){0,2}" + "([Tt \\t][0-9][0-9]?(:[0-9][0-9]){2})?" + "(\\.[0-9]*)?" + "([ \\t])*(Z|[-+][0-9][0-9]?(:[0-9][0-9])?)?" + "\\b"
    }, h = {
      end: ",",
      endsWithParent: !0,
      excludeEnd: !0,
      keywords: n,
      relevance: 0
    }, m = {
      begin: /\{/,
      end: /\}/,
      contains: [h],
      illegal: "\\n",
      relevance: 0
    }, v = {
      begin: "\\[",
      end: "\\]",
      contains: [h],
      illegal: "\\n",
      relevance: 0
    }, b = [
      i,
      {
        className: "meta",
        begin: "^---\\s*$",
        relevance: 10
      },
      {
        // multi line string
        // Blocks start with a | or > followed by a newline
        //
        // Indentation of subsequent lines must be the same to
        // be considered part of the block
        className: "string",
        begin: "[\\|>]([1-9]?[+-])?[ ]*\\n( +)[^ ][^\\n]*\\n(\\2[^\\n]+\\n?)*"
      },
      {
        // Ruby/Rails erb
        begin: "<%[%=-]?",
        end: "[%-]?%>",
        subLanguage: "ruby",
        excludeBegin: !0,
        excludeEnd: !0,
        relevance: 0
      },
      {
        // named tags
        className: "type",
        begin: "!\\w+!" + r
      },
      // https://yaml.org/spec/1.2/spec.html#id2784064
      {
        // verbatim tags
        className: "type",
        begin: "!<" + r + ">"
      },
      {
        // primary tags
        className: "type",
        begin: "!" + r
      },
      {
        // secondary tags
        className: "type",
        begin: "!!" + r
      },
      {
        // fragment id &ref
        className: "meta",
        begin: "&" + t.UNDERSCORE_IDENT_RE + "$"
      },
      {
        // fragment reference *ref
        className: "meta",
        begin: "\\*" + t.UNDERSCORE_IDENT_RE + "$"
      },
      {
        // array listing
        className: "bullet",
        // TODO: remove |$ hack when we have proper look-ahead support
        begin: "-(?=[ ]|$)",
        relevance: 0
      },
      t.HASH_COMMENT_MODE,
      {
        beginKeywords: n,
        keywords: { literal: n }
      },
      f,
      // numbers are any valid C-style number that
      // sit isolated from other words
      {
        className: "number",
        begin: t.C_NUMBER_RE + "\\b",
        relevance: 0
      },
      m,
      v,
      o
    ], y = [...b];
    return y.pop(), y.push(s), h.contains = y, {
      name: "YAML",
      case_insensitive: !0,
      aliases: ["yml"],
      contains: b
    };
  }
  return Ry = e, Ry;
}
var wy, ML;
function Yee() {
  if (ML) return wy;
  ML = 1;
  function e(t) {
    return {
      name: "Test Anything Protocol",
      case_insensitive: !0,
      contains: [
        t.HASH_COMMENT_MODE,
        // version of format and total amount of testcases
        {
          className: "meta",
          variants: [
            { begin: "^TAP version (\\d+)$" },
            { begin: "^1\\.\\.(\\d+)$" }
          ]
        },
        // YAML block
        {
          begin: /---$/,
          end: "\\.\\.\\.$",
          subLanguage: "yaml",
          relevance: 0
        },
        // testcase number
        {
          className: "number",
          begin: " (\\d+) "
        },
        // testcase status and description
        {
          className: "symbol",
          variants: [
            { begin: "^ok" },
            { begin: "^not ok" }
          ]
        }
      ]
    };
  }
  return wy = e, wy;
}
var xy, PL;
function Hee() {
  if (PL) return xy;
  PL = 1;
  function e(t) {
    const n = t.regex, r = /[a-zA-Z_][a-zA-Z0-9_]*/, i = {
      className: "number",
      variants: [
        t.BINARY_NUMBER_MODE,
        t.C_NUMBER_MODE
      ]
    };
    return {
      name: "Tcl",
      aliases: ["tk"],
      keywords: [
        "after",
        "append",
        "apply",
        "array",
        "auto_execok",
        "auto_import",
        "auto_load",
        "auto_mkindex",
        "auto_mkindex_old",
        "auto_qualify",
        "auto_reset",
        "bgerror",
        "binary",
        "break",
        "catch",
        "cd",
        "chan",
        "clock",
        "close",
        "concat",
        "continue",
        "dde",
        "dict",
        "encoding",
        "eof",
        "error",
        "eval",
        "exec",
        "exit",
        "expr",
        "fblocked",
        "fconfigure",
        "fcopy",
        "file",
        "fileevent",
        "filename",
        "flush",
        "for",
        "foreach",
        "format",
        "gets",
        "glob",
        "global",
        "history",
        "http",
        "if",
        "incr",
        "info",
        "interp",
        "join",
        "lappend|10",
        "lassign|10",
        "lindex|10",
        "linsert|10",
        "list",
        "llength|10",
        "load",
        "lrange|10",
        "lrepeat|10",
        "lreplace|10",
        "lreverse|10",
        "lsearch|10",
        "lset|10",
        "lsort|10",
        "mathfunc",
        "mathop",
        "memory",
        "msgcat",
        "namespace",
        "open",
        "package",
        "parray",
        "pid",
        "pkg::create",
        "pkg_mkIndex",
        "platform",
        "platform::shell",
        "proc",
        "puts",
        "pwd",
        "read",
        "refchan",
        "regexp",
        "registry",
        "regsub|10",
        "rename",
        "return",
        "safe",
        "scan",
        "seek",
        "set",
        "socket",
        "source",
        "split",
        "string",
        "subst",
        "switch",
        "tcl_endOfWord",
        "tcl_findLibrary",
        "tcl_startOfNextWord",
        "tcl_startOfPreviousWord",
        "tcl_wordBreakAfter",
        "tcl_wordBreakBefore",
        "tcltest",
        "tclvars",
        "tell",
        "time",
        "tm",
        "trace",
        "unknown",
        "unload",
        "unset",
        "update",
        "uplevel",
        "upvar",
        "variable",
        "vwait",
        "while"
      ],
      contains: [
        t.COMMENT(";[ \\t]*#", "$"),
        t.COMMENT("^[ \\t]*#", "$"),
        {
          beginKeywords: "proc",
          end: "[\\{]",
          excludeEnd: !0,
          contains: [
            {
              className: "title",
              begin: "[ \\t\\n\\r]+(::)?[a-zA-Z_]((::)?[a-zA-Z0-9_])*",
              end: "[ \\t\\n\\r]",
              endsWithParent: !0,
              excludeEnd: !0
            }
          ]
        },
        {
          className: "variable",
          variants: [
            { begin: n.concat(
              /\$/,
              n.optional(/::/),
              r,
              "(::",
              r,
              ")*"
            ) },
            {
              begin: "\\$\\{(::)?[a-zA-Z_]((::)?[a-zA-Z0-9_])*",
              end: "\\}",
              contains: [i]
            }
          ]
        },
        {
          className: "string",
          contains: [t.BACKSLASH_ESCAPE],
          variants: [t.inherit(t.QUOTE_STRING_MODE, { illegal: null })]
        },
        i
      ]
    };
  }
  return xy = e, xy;
}
var Ny, FL;
function zee() {
  if (FL) return Ny;
  FL = 1;
  function e(t) {
    const n = [
      "bool",
      "byte",
      "i16",
      "i32",
      "i64",
      "double",
      "string",
      "binary"
    ];
    return {
      name: "Thrift",
      keywords: {
        keyword: [
          "namespace",
          "const",
          "typedef",
          "struct",
          "enum",
          "service",
          "exception",
          "void",
          "oneway",
          "set",
          "list",
          "map",
          "required",
          "optional"
        ],
        type: n,
        literal: "true false"
      },
      contains: [
        t.QUOTE_STRING_MODE,
        t.NUMBER_MODE,
        t.C_LINE_COMMENT_MODE,
        t.C_BLOCK_COMMENT_MODE,
        {
          className: "class",
          beginKeywords: "struct enum service exception",
          end: /\{/,
          illegal: /\n/,
          contains: [
            t.inherit(t.TITLE_MODE, {
              // hack: eating everything after the first title
              starts: {
                endsWithParent: !0,
                excludeEnd: !0
              }
            })
          ]
        },
        {
          begin: "\\b(set|list|map)\\s*<",
          keywords: { type: [
            ...n,
            "set",
            "list",
            "map"
          ] },
          end: ">",
          contains: ["self"]
        }
      ]
    };
  }
  return Ny = e, Ny;
}
var Dy, BL;
function Vee() {
  if (BL) return Dy;
  BL = 1;
  function e(t) {
    const n = {
      className: "number",
      begin: "[1-9][0-9]*",
      /* no leading zeros */
      relevance: 0
    }, r = {
      className: "symbol",
      begin: ":[^\\]]+"
    }, i = {
      className: "built_in",
      begin: "(AR|P|PAYLOAD|PR|R|SR|RSR|LBL|VR|UALM|MESSAGE|UTOOL|UFRAME|TIMER|TIMER_OVERFLOW|JOINT_MAX_SPEED|RESUME_PROG|DIAG_REC)\\[",
      end: "\\]",
      contains: [
        "self",
        n,
        r
      ]
    }, a = {
      className: "built_in",
      begin: "(AI|AO|DI|DO|F|RI|RO|UI|UO|GI|GO|SI|SO)\\[",
      end: "\\]",
      contains: [
        "self",
        n,
        t.QUOTE_STRING_MODE,
        /* for pos section at bottom */
        r
      ]
    };
    return {
      name: "TP",
      keywords: {
        keyword: [
          "ABORT",
          "ACC",
          "ADJUST",
          "AND",
          "AP_LD",
          "BREAK",
          "CALL",
          "CNT",
          "COL",
          "CONDITION",
          "CONFIG",
          "DA",
          "DB",
          "DIV",
          "DETECT",
          "ELSE",
          "END",
          "ENDFOR",
          "ERR_NUM",
          "ERROR_PROG",
          "FINE",
          "FOR",
          "GP",
          "GUARD",
          "INC",
          "IF",
          "JMP",
          "LINEAR_MAX_SPEED",
          "LOCK",
          "MOD",
          "MONITOR",
          "OFFSET",
          "Offset",
          "OR",
          "OVERRIDE",
          "PAUSE",
          "PREG",
          "PTH",
          "RT_LD",
          "RUN",
          "SELECT",
          "SKIP",
          "Skip",
          "TA",
          "TB",
          "TO",
          "TOOL_OFFSET",
          "Tool_Offset",
          "UF",
          "UT",
          "UFRAME_NUM",
          "UTOOL_NUM",
          "UNLOCK",
          "WAIT",
          "X",
          "Y",
          "Z",
          "W",
          "P",
          "R",
          "STRLEN",
          "SUBSTR",
          "FINDSTR",
          "VOFFSET",
          "PROG",
          "ATTR",
          "MN",
          "POS"
        ],
        literal: [
          "ON",
          "OFF",
          "max_speed",
          "LPOS",
          "JPOS",
          "ENABLE",
          "DISABLE",
          "START",
          "STOP",
          "RESET"
        ]
      },
      contains: [
        i,
        a,
        {
          className: "keyword",
          begin: "/(PROG|ATTR|MN|POS|END)\\b"
        },
        {
          /* this is for cases like ,CALL */
          className: "keyword",
          begin: "(CALL|RUN|POINT_LOGIC|LBL)\\b"
        },
        {
          /* this is for cases like CNT100 where the default lexemes do not
           * separate the keyword and the number */
          className: "keyword",
          begin: "\\b(ACC|CNT|Skip|Offset|PSPD|RT_LD|AP_LD|Tool_Offset)"
        },
        {
          /* to catch numbers that do not have a word boundary on the left */
          className: "number",
          begin: "\\d+(sec|msec|mm/sec|cm/min|inch/min|deg/sec|mm|in|cm)?\\b",
          relevance: 0
        },
        t.COMMENT("//", "[;$]"),
        t.COMMENT("!", "[;$]"),
        t.COMMENT("--eg:", "$"),
        t.QUOTE_STRING_MODE,
        {
          className: "string",
          begin: "'",
          end: "'"
        },
        t.C_NUMBER_MODE,
        {
          className: "variable",
          begin: "\\$[A-Za-z0-9_]+"
        }
      ]
    };
  }
  return Dy = e, Dy;
}
var Iy, $L;
function Wee() {
  if ($L) return Iy;
  $L = 1;
  function e(t) {
    const n = t.regex, r = [
      "absolute_url",
      "asset|0",
      "asset_version",
      "attribute",
      "block",
      "constant",
      "controller|0",
      "country_timezones",
      "csrf_token",
      "cycle",
      "date",
      "dump",
      "expression",
      "form|0",
      "form_end",
      "form_errors",
      "form_help",
      "form_label",
      "form_rest",
      "form_row",
      "form_start",
      "form_widget",
      "html_classes",
      "include",
      "is_granted",
      "logout_path",
      "logout_url",
      "max",
      "min",
      "parent",
      "path|0",
      "random",
      "range",
      "relative_path",
      "render",
      "render_esi",
      "source",
      "template_from_string",
      "url|0"
    ], i = [
      "abs",
      "abbr_class",
      "abbr_method",
      "batch",
      "capitalize",
      "column",
      "convert_encoding",
      "country_name",
      "currency_name",
      "currency_symbol",
      "data_uri",
      "date",
      "date_modify",
      "default",
      "escape",
      "file_excerpt",
      "file_link",
      "file_relative",
      "filter",
      "first",
      "format",
      "format_args",
      "format_args_as_text",
      "format_currency",
      "format_date",
      "format_datetime",
      "format_file",
      "format_file_from_text",
      "format_number",
      "format_time",
      "html_to_markdown",
      "humanize",
      "inky_to_html",
      "inline_css",
      "join",
      "json_encode",
      "keys",
      "language_name",
      "last",
      "length",
      "locale_name",
      "lower",
      "map",
      "markdown",
      "markdown_to_html",
      "merge",
      "nl2br",
      "number_format",
      "raw",
      "reduce",
      "replace",
      "reverse",
      "round",
      "slice",
      "slug",
      "sort",
      "spaceless",
      "split",
      "striptags",
      "timezone_name",
      "title",
      "trans",
      "transchoice",
      "trim",
      "u|0",
      "upper",
      "url_encode",
      "yaml_dump",
      "yaml_encode"
    ];
    let a = [
      "apply",
      "autoescape",
      "block",
      "cache",
      "deprecated",
      "do",
      "embed",
      "extends",
      "filter",
      "flush",
      "for",
      "form_theme",
      "from",
      "if",
      "import",
      "include",
      "macro",
      "sandbox",
      "set",
      "stopwatch",
      "trans",
      "trans_default_domain",
      "transchoice",
      "use",
      "verbatim",
      "with"
    ];
    a = a.concat(a.map((v) => `end${v}`));
    const o = {
      scope: "string",
      variants: [
        {
          begin: /'/,
          end: /'/
        },
        {
          begin: /"/,
          end: /"/
        }
      ]
    }, s = {
      scope: "number",
      match: /\d+/
    }, l = {
      begin: /\(/,
      end: /\)/,
      excludeBegin: !0,
      excludeEnd: !0,
      contains: [
        o,
        s
      ]
    }, u = {
      beginKeywords: r.join(" "),
      keywords: { name: r },
      relevance: 0,
      contains: [l]
    }, c = {
      match: /\|(?=[A-Za-z_]+:?)/,
      beginScope: "punctuation",
      relevance: 0,
      contains: [
        {
          match: /[A-Za-z_]+:?/,
          keywords: i
        }
      ]
    }, d = (v, { relevance: b }) => ({
      beginScope: {
        1: "template-tag",
        3: "name"
      },
      relevance: b || 2,
      endScope: "template-tag",
      begin: [
        /\{%/,
        /\s*/,
        n.either(...v)
      ],
      end: /%\}/,
      keywords: "in",
      contains: [
        c,
        u,
        o,
        s
      ]
    }), f = /[a-z_]+/, h = d(a, { relevance: 2 }), m = d([f], { relevance: 1 });
    return {
      name: "Twig",
      aliases: ["craftcms"],
      case_insensitive: !0,
      subLanguage: "xml",
      contains: [
        t.COMMENT(/\{#/, /#\}/),
        h,
        m,
        {
          className: "template-variable",
          begin: /\{\{/,
          end: /\}\}/,
          contains: [
            "self",
            c,
            u,
            o,
            s
          ]
        }
      ]
    };
  }
  return Iy = e, Iy;
}
var Ly, UL;
function Kee() {
  if (UL) return Ly;
  UL = 1;
  const e = "[A-Za-z$_][0-9A-Za-z$_]*", t = [
    "as",
    // for exports
    "in",
    "of",
    "if",
    "for",
    "while",
    "finally",
    "var",
    "new",
    "function",
    "do",
    "return",
    "void",
    "else",
    "break",
    "catch",
    "instanceof",
    "with",
    "throw",
    "case",
    "default",
    "try",
    "switch",
    "continue",
    "typeof",
    "delete",
    "let",
    "yield",
    "const",
    "class",
    // JS handles these with a special rule
    // "get",
    // "set",
    "debugger",
    "async",
    "await",
    "static",
    "import",
    "from",
    "export",
    "extends"
  ], n = [
    "true",
    "false",
    "null",
    "undefined",
    "NaN",
    "Infinity"
  ], r = [
    // Fundamental objects
    "Object",
    "Function",
    "Boolean",
    "Symbol",
    // numbers and dates
    "Math",
    "Date",
    "Number",
    "BigInt",
    // text
    "String",
    "RegExp",
    // Indexed collections
    "Array",
    "Float32Array",
    "Float64Array",
    "Int8Array",
    "Uint8Array",
    "Uint8ClampedArray",
    "Int16Array",
    "Int32Array",
    "Uint16Array",
    "Uint32Array",
    "BigInt64Array",
    "BigUint64Array",
    // Keyed collections
    "Set",
    "Map",
    "WeakSet",
    "WeakMap",
    // Structured data
    "ArrayBuffer",
    "SharedArrayBuffer",
    "Atomics",
    "DataView",
    "JSON",
    // Control abstraction objects
    "Promise",
    "Generator",
    "GeneratorFunction",
    "AsyncFunction",
    // Reflection
    "Reflect",
    "Proxy",
    // Internationalization
    "Intl",
    // WebAssembly
    "WebAssembly"
  ], i = [
    "Error",
    "EvalError",
    "InternalError",
    "RangeError",
    "ReferenceError",
    "SyntaxError",
    "TypeError",
    "URIError"
  ], a = [
    "setInterval",
    "setTimeout",
    "clearInterval",
    "clearTimeout",
    "require",
    "exports",
    "eval",
    "isFinite",
    "isNaN",
    "parseFloat",
    "parseInt",
    "decodeURI",
    "decodeURIComponent",
    "encodeURI",
    "encodeURIComponent",
    "escape",
    "unescape"
  ], o = [
    "arguments",
    "this",
    "super",
    "console",
    "window",
    "document",
    "localStorage",
    "sessionStorage",
    "module",
    "global"
    // Node.js
  ], s = [].concat(
    a,
    r,
    i
  );
  function l(c) {
    const d = c.regex, f = (Se, { after: Re }) => {
      const Ye = "</" + Se[0].slice(1);
      return Se.input.indexOf(Ye, Re) !== -1;
    }, h = e, m = {
      begin: "<>",
      end: "</>"
    }, v = /<[A-Za-z0-9\\._:-]+\s*\/>/, b = {
      begin: /<[A-Za-z0-9\\._:-]+/,
      end: /\/[A-Za-z0-9\\._:-]+>|\/>/,
      /**
       * @param {RegExpMatchArray} match
       * @param {CallbackResponse} response
       */
      isTrulyOpeningTag: (Se, Re) => {
        const Ye = Se[0].length + Se.index, nt = Se.input[Ye];
        if (
          // HTML should not include another raw `<` inside a tag
          // nested type?
          // `<Array<Array<number>>`, etc.
          nt === "<" || // the , gives away that this is not HTML
          // `<T, A extends keyof T, V>`
          nt === ","
        ) {
          Re.ignoreMatch();
          return;
        }
        nt === ">" && (f(Se, { after: Ye }) || Re.ignoreMatch());
        let ut;
        const Tt = Se.input.substring(Ye);
        if (ut = Tt.match(/^\s*=/)) {
          Re.ignoreMatch();
          return;
        }
        if ((ut = Tt.match(/^\s+extends\s+/)) && ut.index === 0) {
          Re.ignoreMatch();
          return;
        }
      }
    }, y = {
      $pattern: e,
      keyword: t,
      literal: n,
      built_in: s,
      "variable.language": o
    }, g = "[0-9](_?[0-9])*", E = `\\.(${g})`, S = "0|[1-9](_?[0-9])*|0[0-7]*[89][0-9]*", C = {
      className: "number",
      variants: [
        // DecimalLiteral
        { begin: `(\\b(${S})((${E})|\\.)?|(${E}))[eE][+-]?(${g})\\b` },
        { begin: `\\b(${S})\\b((${E})\\b|\\.)?|(${E})\\b` },
        // DecimalBigIntegerLiteral
        { begin: "\\b(0|[1-9](_?[0-9])*)n\\b" },
        // NonDecimalIntegerLiteral
        { begin: "\\b0[xX][0-9a-fA-F](_?[0-9a-fA-F])*n?\\b" },
        { begin: "\\b0[bB][0-1](_?[0-1])*n?\\b" },
        { begin: "\\b0[oO][0-7](_?[0-7])*n?\\b" },
        // LegacyOctalIntegerLiteral (does not include underscore separators)
        // https://tc39.es/ecma262/#sec-additional-syntax-numeric-literals
        { begin: "\\b0[0-7]+n?\\b" }
      ],
      relevance: 0
    }, T = {
      className: "subst",
      begin: "\\$\\{",
      end: "\\}",
      keywords: y,
      contains: []
      // defined later
    }, O = {
      begin: "html`",
      end: "",
      starts: {
        end: "`",
        returnEnd: !1,
        contains: [
          c.BACKSLASH_ESCAPE,
          T
        ],
        subLanguage: "xml"
      }
    }, R = {
      begin: "css`",
      end: "",
      starts: {
        end: "`",
        returnEnd: !1,
        contains: [
          c.BACKSLASH_ESCAPE,
          T
        ],
        subLanguage: "css"
      }
    }, D = {
      begin: "gql`",
      end: "",
      starts: {
        end: "`",
        returnEnd: !1,
        contains: [
          c.BACKSLASH_ESCAPE,
          T
        ],
        subLanguage: "graphql"
      }
    }, q = {
      className: "string",
      begin: "`",
      end: "`",
      contains: [
        c.BACKSLASH_ESCAPE,
        T
      ]
    }, P = {
      className: "comment",
      variants: [
        c.COMMENT(
          /\/\*\*(?!\/)/,
          "\\*/",
          {
            relevance: 0,
            contains: [
              {
                begin: "(?=@[A-Za-z]+)",
                relevance: 0,
                contains: [
                  {
                    className: "doctag",
                    begin: "@[A-Za-z]+"
                  },
                  {
                    className: "type",
                    begin: "\\{",
                    end: "\\}",
                    excludeEnd: !0,
                    excludeBegin: !0,
                    relevance: 0
                  },
                  {
                    className: "variable",
                    begin: h + "(?=\\s*(-)|$)",
                    endsParent: !0,
                    relevance: 0
                  },
                  // eat spaces (not newlines) so we can find
                  // types or variables
                  {
                    begin: /(?=[^\n])\s/,
                    relevance: 0
                  }
                ]
              }
            ]
          }
        ),
        c.C_BLOCK_COMMENT_MODE,
        c.C_LINE_COMMENT_MODE
      ]
    }, Y = [
      c.APOS_STRING_MODE,
      c.QUOTE_STRING_MODE,
      O,
      R,
      D,
      q,
      // Skip numbers when they are part of a variable name
      { match: /\$\d+/ },
      C
      // This is intentional:
      // See https://github.com/highlightjs/highlight.js/issues/3288
      // hljs.REGEXP_MODE
    ];
    T.contains = Y.concat({
      // we need to pair up {} inside our subst to prevent
      // it from ending too early by matching another }
      begin: /\{/,
      end: /\}/,
      keywords: y,
      contains: [
        "self"
      ].concat(Y)
    });
    const L = [].concat(P, T.contains), x = L.concat([
      // eat recursive parens in sub expressions
      {
        begin: /\(/,
        end: /\)/,
        keywords: y,
        contains: ["self"].concat(L)
      }
    ]), I = {
      className: "params",
      begin: /\(/,
      end: /\)/,
      excludeBegin: !0,
      excludeEnd: !0,
      keywords: y,
      contains: x
    }, k = {
      variants: [
        // class Car extends vehicle
        {
          match: [
            /class/,
            /\s+/,
            h,
            /\s+/,
            /extends/,
            /\s+/,
            d.concat(h, "(", d.concat(/\./, h), ")*")
          ],
          scope: {
            1: "keyword",
            3: "title.class",
            5: "keyword",
            7: "title.class.inherited"
          }
        },
        // class Car
        {
          match: [
            /class/,
            /\s+/,
            h
          ],
          scope: {
            1: "keyword",
            3: "title.class"
          }
        }
      ]
    }, B = {
      relevance: 0,
      match: d.either(
        // Hard coded exceptions
        /\bJSON/,
        // Float32Array, OutT
        /\b[A-Z][a-z]+([A-Z][a-z]*|\d)*/,
        // CSSFactory, CSSFactoryT
        /\b[A-Z]{2,}([A-Z][a-z]+|\d)+([A-Z][a-z]*)*/,
        // FPs, FPsT
        /\b[A-Z]{2,}[a-z]+([A-Z][a-z]+|\d)*([A-Z][a-z]*)*/
        // P
        // single letters are not highlighted
        // BLAH
        // this will be flagged as a UPPER_CASE_CONSTANT instead
      ),
      className: "title.class",
      keywords: {
        _: [
          // se we still get relevance credit for JS library classes
          ...r,
          ...i
        ]
      }
    }, W = {
      label: "use_strict",
      className: "meta",
      relevance: 10,
      begin: /^\s*['"]use (strict|asm)['"]/
    }, Z = {
      variants: [
        {
          match: [
            /function/,
            /\s+/,
            h,
            /(?=\s*\()/
          ]
        },
        // anonymous function
        {
          match: [
            /function/,
            /\s*(?=\()/
          ]
        }
      ],
      className: {
        1: "keyword",
        3: "title.function"
      },
      label: "func.def",
      contains: [I],
      illegal: /%/
    }, V = {
      relevance: 0,
      match: /\b[A-Z][A-Z_0-9]+\b/,
      className: "variable.constant"
    };
    function K(Se) {
      return d.concat("(?!", Se.join("|"), ")");
    }
    const ne = {
      match: d.concat(
        /\b/,
        K([
          ...a,
          "super",
          "import"
        ]),
        h,
        d.lookahead(/\(/)
      ),
      className: "title.function",
      relevance: 0
    }, Ee = {
      begin: d.concat(/\./, d.lookahead(
        d.concat(h, /(?![0-9A-Za-z$_(])/)
      )),
      end: h,
      excludeBegin: !0,
      keywords: "prototype",
      className: "property",
      relevance: 0
    }, oe = {
      match: [
        /get|set/,
        /\s+/,
        h,
        /(?=\()/
      ],
      className: {
        1: "keyword",
        3: "title.function"
      },
      contains: [
        {
          // eat to avoid empty params
          begin: /\(\)/
        },
        I
      ]
    }, ae = "(\\([^()]*(\\([^()]*(\\([^()]*\\)[^()]*)*\\)[^()]*)*\\)|" + c.UNDERSCORE_IDENT_RE + ")\\s*=>", pe = {
      match: [
        /const|var|let/,
        /\s+/,
        h,
        /\s*/,
        /=\s*/,
        /(async\s*)?/,
        // async is optional
        d.lookahead(ae)
      ],
      keywords: "async",
      className: {
        1: "keyword",
        3: "title.function"
      },
      contains: [
        I
      ]
    };
    return {
      name: "JavaScript",
      aliases: ["js", "jsx", "mjs", "cjs"],
      keywords: y,
      // this will be extended by TypeScript
      exports: { PARAMS_CONTAINS: x, CLASS_REFERENCE: B },
      illegal: /#(?![$_A-z])/,
      contains: [
        c.SHEBANG({
          label: "shebang",
          binary: "node",
          relevance: 5
        }),
        W,
        c.APOS_STRING_MODE,
        c.QUOTE_STRING_MODE,
        O,
        R,
        D,
        q,
        P,
        // Skip numbers when they are part of a variable name
        { match: /\$\d+/ },
        C,
        B,
        {
          className: "attr",
          begin: h + d.lookahead(":"),
          relevance: 0
        },
        pe,
        {
          // "value" container
          begin: "(" + c.RE_STARTERS_RE + "|\\b(case|return|throw)\\b)\\s*",
          keywords: "return throw case",
          relevance: 0,
          contains: [
            P,
            c.REGEXP_MODE,
            {
              className: "function",
              // we have to count the parens to make sure we actually have the
              // correct bounding ( ) before the =>.  There could be any number of
              // sub-expressions inside also surrounded by parens.
              begin: ae,
              returnBegin: !0,
              end: "\\s*=>",
              contains: [
                {
                  className: "params",
                  variants: [
                    {
                      begin: c.UNDERSCORE_IDENT_RE,
                      relevance: 0
                    },
                    {
                      className: null,
                      begin: /\(\s*\)/,
                      skip: !0
                    },
                    {
                      begin: /\(/,
                      end: /\)/,
                      excludeBegin: !0,
                      excludeEnd: !0,
                      keywords: y,
                      contains: x
                    }
                  ]
                }
              ]
            },
            {
              // could be a comma delimited list of params to a function call
              begin: /,/,
              relevance: 0
            },
            {
              match: /\s+/,
              relevance: 0
            },
            {
              // JSX
              variants: [
                { begin: m.begin, end: m.end },
                { match: v },
                {
                  begin: b.begin,
                  // we carefully check the opening tag to see if it truly
                  // is a tag and not a false positive
                  "on:begin": b.isTrulyOpeningTag,
                  end: b.end
                }
              ],
              subLanguage: "xml",
              contains: [
                {
                  begin: b.begin,
                  end: b.end,
                  skip: !0,
                  contains: ["self"]
                }
              ]
            }
          ]
        },
        Z,
        {
          // prevent this from getting swallowed up by function
          // since they appear "function like"
          beginKeywords: "while if switch catch for"
        },
        {
          // we have to count the parens to make sure we actually have the correct
          // bounding ( ).  There could be any number of sub-expressions inside
          // also surrounded by parens.
          begin: "\\b(?!function)" + c.UNDERSCORE_IDENT_RE + "\\([^()]*(\\([^()]*(\\([^()]*\\)[^()]*)*\\)[^()]*)*\\)\\s*\\{",
          // end parens
          returnBegin: !0,
          label: "func.def",
          contains: [
            I,
            c.inherit(c.TITLE_MODE, { begin: h, className: "title.function" })
          ]
        },
        // catch ... so it won't trigger the property rule below
        {
          match: /\.\.\./,
          relevance: 0
        },
        Ee,
        // hack: prevents detection of keywords in some circumstances
        // .keyword()
        // $keyword = x
        {
          match: "\\$" + h,
          relevance: 0
        },
        {
          match: [/\bconstructor(?=\s*\()/],
          className: { 1: "title.function" },
          contains: [I]
        },
        ne,
        V,
        k,
        oe,
        {
          match: /\$[(.]/
          // relevance booster for a pattern common to JS libs: `$(something)` and `$.something`
        }
      ]
    };
  }
  function u(c) {
    const d = l(c), f = e, h = [
      "any",
      "void",
      "number",
      "boolean",
      "string",
      "object",
      "never",
      "symbol",
      "bigint",
      "unknown"
    ], m = {
      beginKeywords: "namespace",
      end: /\{/,
      excludeEnd: !0,
      contains: [d.exports.CLASS_REFERENCE]
    }, v = {
      beginKeywords: "interface",
      end: /\{/,
      excludeEnd: !0,
      keywords: {
        keyword: "interface extends",
        built_in: h
      },
      contains: [d.exports.CLASS_REFERENCE]
    }, b = {
      className: "meta",
      relevance: 10,
      begin: /^\s*['"]use strict['"]/
    }, y = [
      "type",
      "namespace",
      "interface",
      "public",
      "private",
      "protected",
      "implements",
      "declare",
      "abstract",
      "readonly",
      "enum",
      "override"
    ], g = {
      $pattern: e,
      keyword: t.concat(y),
      literal: n,
      built_in: s.concat(h),
      "variable.language": o
    }, E = {
      className: "meta",
      begin: "@" + f
    }, S = (T, O, R) => {
      const D = T.contains.findIndex((q) => q.label === O);
      if (D === -1)
        throw new Error("can not find mode to replace");
      T.contains.splice(D, 1, R);
    };
    Object.assign(d.keywords, g), d.exports.PARAMS_CONTAINS.push(E), d.contains = d.contains.concat([
      E,
      m,
      v
    ]), S(d, "shebang", c.SHEBANG()), S(d, "use_strict", b);
    const C = d.contains.find((T) => T.label === "func.def");
    return C.relevance = 0, Object.assign(d, {
      name: "TypeScript",
      aliases: [
        "ts",
        "tsx",
        "mts",
        "cts"
      ]
    }), d;
  }
  return Ly = u, Ly;
}
var ky, qL;
function jee() {
  if (qL) return ky;
  qL = 1;
  function e(t) {
    return {
      name: "Vala",
      keywords: {
        keyword: (
          // Value types
          "char uchar unichar int uint long ulong short ushort int8 int16 int32 int64 uint8 uint16 uint32 uint64 float double bool struct enum string void weak unowned owned async signal static abstract interface override virtual delegate if while do for foreach else switch case break default return try catch public private protected internal using new this get set const stdout stdin stderr var"
        ),
        built_in: "DBus GLib CCode Gee Object Gtk Posix",
        literal: "false true null"
      },
      contains: [
        {
          className: "class",
          beginKeywords: "class interface namespace",
          end: /\{/,
          excludeEnd: !0,
          illegal: "[^,:\\n\\s\\.]",
          contains: [t.UNDERSCORE_TITLE_MODE]
        },
        t.C_LINE_COMMENT_MODE,
        t.C_BLOCK_COMMENT_MODE,
        {
          className: "string",
          begin: '"""',
          end: '"""',
          relevance: 5
        },
        t.APOS_STRING_MODE,
        t.QUOTE_STRING_MODE,
        t.C_NUMBER_MODE,
        {
          className: "meta",
          begin: "^#",
          end: "$"
        }
      ]
    };
  }
  return ky = e, ky;
}
var My, GL;
function Qee() {
  if (GL) return My;
  GL = 1;
  function e(t) {
    const n = t.regex, r = {
      className: "string",
      begin: /"(""|[^/n])"C\b/
    }, i = {
      className: "string",
      begin: /"/,
      end: /"/,
      illegal: /\n/,
      contains: [
        {
          // double quote escape
          begin: /""/
        }
      ]
    }, a = /\d{1,2}\/\d{1,2}\/\d{4}/, o = /\d{4}-\d{1,2}-\d{1,2}/, s = /(\d|1[012])(:\d+){0,2} *(AM|PM)/, l = /\d{1,2}(:\d{1,2}){1,2}/, u = {
      className: "literal",
      variants: [
        {
          // #YYYY-MM-DD# (ISO-Date) or #M/D/YYYY# (US-Date)
          begin: n.concat(/# */, n.either(o, a), / *#/)
        },
        {
          // #H:mm[:ss]# (24h Time)
          begin: n.concat(/# */, l, / *#/)
        },
        {
          // #h[:mm[:ss]] A# (12h Time)
          begin: n.concat(/# */, s, / *#/)
        },
        {
          // date plus time
          begin: n.concat(
            /# */,
            n.either(o, a),
            / +/,
            n.either(s, l),
            / *#/
          )
        }
      ]
    }, c = {
      className: "number",
      relevance: 0,
      variants: [
        {
          // Float
          begin: /\b\d[\d_]*((\.[\d_]+(E[+-]?[\d_]+)?)|(E[+-]?[\d_]+))[RFD@!#]?/
        },
        {
          // Integer (base 10)
          begin: /\b\d[\d_]*((U?[SIL])|[%&])?/
        },
        {
          // Integer (base 16)
          begin: /&H[\dA-F_]+((U?[SIL])|[%&])?/
        },
        {
          // Integer (base 8)
          begin: /&O[0-7_]+((U?[SIL])|[%&])?/
        },
        {
          // Integer (base 2)
          begin: /&B[01_]+((U?[SIL])|[%&])?/
        }
      ]
    }, d = {
      className: "label",
      begin: /^\w+:/
    }, f = t.COMMENT(/'''/, /$/, { contains: [
      {
        className: "doctag",
        begin: /<\/?/,
        end: />/
      }
    ] }), h = t.COMMENT(null, /$/, { variants: [
      { begin: /'/ },
      {
        // TODO: Use multi-class for leading spaces
        begin: /([\t ]|^)REM(?=\s)/
      }
    ] });
    return {
      name: "Visual Basic .NET",
      aliases: ["vb"],
      case_insensitive: !0,
      classNameAliases: { label: "symbol" },
      keywords: {
        keyword: "addhandler alias aggregate ansi as async assembly auto binary by byref byval call case catch class compare const continue custom declare default delegate dim distinct do each equals else elseif end enum erase error event exit explicit finally for friend from function get global goto group handles if implements imports in inherits interface into iterator join key let lib loop me mid module mustinherit mustoverride mybase myclass namespace narrowing new next notinheritable notoverridable of off on operator option optional order overloads overridable overrides paramarray partial preserve private property protected public raiseevent readonly redim removehandler resume return select set shadows shared skip static step stop structure strict sub synclock take text then throw to try unicode until using when where while widening with withevents writeonly yield",
        built_in: (
          // Operators https://docs.microsoft.com/dotnet/visual-basic/language-reference/operators
          "addressof and andalso await directcast gettype getxmlnamespace is isfalse isnot istrue like mod nameof new not or orelse trycast typeof xor cbool cbyte cchar cdate cdbl cdec cint clng cobj csbyte cshort csng cstr cuint culng cushort"
        ),
        type: (
          // Data types https://docs.microsoft.com/dotnet/visual-basic/language-reference/data-types
          "boolean byte char date decimal double integer long object sbyte short single string uinteger ulong ushort"
        ),
        literal: "true false nothing"
      },
      illegal: "//|\\{|\\}|endif|gosub|variant|wend|^\\$ ",
      contains: [
        r,
        i,
        u,
        c,
        d,
        f,
        h,
        {
          className: "meta",
          // TODO: Use multi-class for indentation once available
          begin: /[\t ]*#(const|disable|else|elseif|enable|end|externalsource|if|region)\b/,
          end: /$/,
          keywords: { keyword: "const disable else elseif enable end externalsource if region then" },
          contains: [h]
        }
      ]
    };
  }
  return My = e, My;
}
var Py, YL;
function Xee() {
  if (YL) return Py;
  YL = 1;
  function e(t) {
    const n = t.regex, r = [
      "lcase",
      "month",
      "vartype",
      "instrrev",
      "ubound",
      "setlocale",
      "getobject",
      "rgb",
      "getref",
      "string",
      "weekdayname",
      "rnd",
      "dateadd",
      "monthname",
      "now",
      "day",
      "minute",
      "isarray",
      "cbool",
      "round",
      "formatcurrency",
      "conversions",
      "csng",
      "timevalue",
      "second",
      "year",
      "space",
      "abs",
      "clng",
      "timeserial",
      "fixs",
      "len",
      "asc",
      "isempty",
      "maths",
      "dateserial",
      "atn",
      "timer",
      "isobject",
      "filter",
      "weekday",
      "datevalue",
      "ccur",
      "isdate",
      "instr",
      "datediff",
      "formatdatetime",
      "replace",
      "isnull",
      "right",
      "sgn",
      "array",
      "snumeric",
      "log",
      "cdbl",
      "hex",
      "chr",
      "lbound",
      "msgbox",
      "ucase",
      "getlocale",
      "cos",
      "cdate",
      "cbyte",
      "rtrim",
      "join",
      "hour",
      "oct",
      "typename",
      "trim",
      "strcomp",
      "int",
      "createobject",
      "loadpicture",
      "tan",
      "formatnumber",
      "mid",
      "split",
      "cint",
      "sin",
      "datepart",
      "ltrim",
      "sqr",
      "time",
      "derived",
      "eval",
      "date",
      "formatpercent",
      "exp",
      "inputbox",
      "left",
      "ascw",
      "chrw",
      "regexp",
      "cstr",
      "err"
    ], i = [
      "server",
      "response",
      "request",
      // take no arguments so can be called without ()
      "scriptengine",
      "scriptenginebuildversion",
      "scriptengineminorversion",
      "scriptenginemajorversion"
    ], a = {
      begin: n.concat(n.either(...r), "\\s*\\("),
      // relevance 0 because this is acting as a beginKeywords really
      relevance: 0,
      keywords: { built_in: r }
    };
    return {
      name: "VBScript",
      aliases: ["vbs"],
      case_insensitive: !0,
      keywords: {
        keyword: [
          "call",
          "class",
          "const",
          "dim",
          "do",
          "loop",
          "erase",
          "execute",
          "executeglobal",
          "exit",
          "for",
          "each",
          "next",
          "function",
          "if",
          "then",
          "else",
          "on",
          "error",
          "option",
          "explicit",
          "new",
          "private",
          "property",
          "let",
          "get",
          "public",
          "randomize",
          "redim",
          "rem",
          "select",
          "case",
          "set",
          "stop",
          "sub",
          "while",
          "wend",
          "with",
          "end",
          "to",
          "elseif",
          "is",
          "or",
          "xor",
          "and",
          "not",
          "class_initialize",
          "class_terminate",
          "default",
          "preserve",
          "in",
          "me",
          "byval",
          "byref",
          "step",
          "resume",
          "goto"
        ],
        built_in: i,
        literal: [
          "true",
          "false",
          "null",
          "nothing",
          "empty"
        ]
      },
      illegal: "//",
      contains: [
        a,
        t.inherit(t.QUOTE_STRING_MODE, { contains: [{ begin: '""' }] }),
        t.COMMENT(
          /'/,
          /$/,
          { relevance: 0 }
        ),
        t.C_NUMBER_MODE
      ]
    };
  }
  return Py = e, Py;
}
var Fy, HL;
function Zee() {
  if (HL) return Fy;
  HL = 1;
  function e(t) {
    return {
      name: "VBScript in HTML",
      subLanguage: "xml",
      contains: [
        {
          begin: "<%",
          end: "%>",
          subLanguage: "vbscript"
        }
      ]
    };
  }
  return Fy = e, Fy;
}
var By, zL;
function Jee() {
  if (zL) return By;
  zL = 1;
  function e(t) {
    const n = t.regex, r = {
      $pattern: /\$?[\w]+(\$[\w]+)*/,
      keyword: [
        "accept_on",
        "alias",
        "always",
        "always_comb",
        "always_ff",
        "always_latch",
        "and",
        "assert",
        "assign",
        "assume",
        "automatic",
        "before",
        "begin",
        "bind",
        "bins",
        "binsof",
        "bit",
        "break",
        "buf|0",
        "bufif0",
        "bufif1",
        "byte",
        "case",
        "casex",
        "casez",
        "cell",
        "chandle",
        "checker",
        "class",
        "clocking",
        "cmos",
        "config",
        "const",
        "constraint",
        "context",
        "continue",
        "cover",
        "covergroup",
        "coverpoint",
        "cross",
        "deassign",
        "default",
        "defparam",
        "design",
        "disable",
        "dist",
        "do",
        "edge",
        "else",
        "end",
        "endcase",
        "endchecker",
        "endclass",
        "endclocking",
        "endconfig",
        "endfunction",
        "endgenerate",
        "endgroup",
        "endinterface",
        "endmodule",
        "endpackage",
        "endprimitive",
        "endprogram",
        "endproperty",
        "endspecify",
        "endsequence",
        "endtable",
        "endtask",
        "enum",
        "event",
        "eventually",
        "expect",
        "export",
        "extends",
        "extern",
        "final",
        "first_match",
        "for",
        "force",
        "foreach",
        "forever",
        "fork",
        "forkjoin",
        "function",
        "generate|5",
        "genvar",
        "global",
        "highz0",
        "highz1",
        "if",
        "iff",
        "ifnone",
        "ignore_bins",
        "illegal_bins",
        "implements",
        "implies",
        "import",
        "incdir",
        "include",
        "initial",
        "inout",
        "input",
        "inside",
        "instance",
        "int",
        "integer",
        "interconnect",
        "interface",
        "intersect",
        "join",
        "join_any",
        "join_none",
        "large",
        "let",
        "liblist",
        "library",
        "local",
        "localparam",
        "logic",
        "longint",
        "macromodule",
        "matches",
        "medium",
        "modport",
        "module",
        "nand",
        "negedge",
        "nettype",
        "new",
        "nexttime",
        "nmos",
        "nor",
        "noshowcancelled",
        "not",
        "notif0",
        "notif1",
        "or",
        "output",
        "package",
        "packed",
        "parameter",
        "pmos",
        "posedge",
        "primitive",
        "priority",
        "program",
        "property",
        "protected",
        "pull0",
        "pull1",
        "pulldown",
        "pullup",
        "pulsestyle_ondetect",
        "pulsestyle_onevent",
        "pure",
        "rand",
        "randc",
        "randcase",
        "randsequence",
        "rcmos",
        "real",
        "realtime",
        "ref",
        "reg",
        "reject_on",
        "release",
        "repeat",
        "restrict",
        "return",
        "rnmos",
        "rpmos",
        "rtran",
        "rtranif0",
        "rtranif1",
        "s_always",
        "s_eventually",
        "s_nexttime",
        "s_until",
        "s_until_with",
        "scalared",
        "sequence",
        "shortint",
        "shortreal",
        "showcancelled",
        "signed",
        "small",
        "soft",
        "solve",
        "specify",
        "specparam",
        "static",
        "string",
        "strong",
        "strong0",
        "strong1",
        "struct",
        "super",
        "supply0",
        "supply1",
        "sync_accept_on",
        "sync_reject_on",
        "table",
        "tagged",
        "task",
        "this",
        "throughout",
        "time",
        "timeprecision",
        "timeunit",
        "tran",
        "tranif0",
        "tranif1",
        "tri",
        "tri0",
        "tri1",
        "triand",
        "trior",
        "trireg",
        "type",
        "typedef",
        "union",
        "unique",
        "unique0",
        "unsigned",
        "until",
        "until_with",
        "untyped",
        "use",
        "uwire",
        "var",
        "vectored",
        "virtual",
        "void",
        "wait",
        "wait_order",
        "wand",
        "weak",
        "weak0",
        "weak1",
        "while",
        "wildcard",
        "wire",
        "with",
        "within",
        "wor",
        "xnor",
        "xor"
      ],
      literal: ["null"],
      built_in: [
        "$finish",
        "$stop",
        "$exit",
        "$fatal",
        "$error",
        "$warning",
        "$info",
        "$realtime",
        "$time",
        "$printtimescale",
        "$bitstoreal",
        "$bitstoshortreal",
        "$itor",
        "$signed",
        "$cast",
        "$bits",
        "$stime",
        "$timeformat",
        "$realtobits",
        "$shortrealtobits",
        "$rtoi",
        "$unsigned",
        "$asserton",
        "$assertkill",
        "$assertpasson",
        "$assertfailon",
        "$assertnonvacuouson",
        "$assertoff",
        "$assertcontrol",
        "$assertpassoff",
        "$assertfailoff",
        "$assertvacuousoff",
        "$isunbounded",
        "$sampled",
        "$fell",
        "$changed",
        "$past_gclk",
        "$fell_gclk",
        "$changed_gclk",
        "$rising_gclk",
        "$steady_gclk",
        "$coverage_control",
        "$coverage_get",
        "$coverage_save",
        "$set_coverage_db_name",
        "$rose",
        "$stable",
        "$past",
        "$rose_gclk",
        "$stable_gclk",
        "$future_gclk",
        "$falling_gclk",
        "$changing_gclk",
        "$display",
        "$coverage_get_max",
        "$coverage_merge",
        "$get_coverage",
        "$load_coverage_db",
        "$typename",
        "$unpacked_dimensions",
        "$left",
        "$low",
        "$increment",
        "$clog2",
        "$ln",
        "$log10",
        "$exp",
        "$sqrt",
        "$pow",
        "$floor",
        "$ceil",
        "$sin",
        "$cos",
        "$tan",
        "$countbits",
        "$onehot",
        "$isunknown",
        "$fatal",
        "$warning",
        "$dimensions",
        "$right",
        "$high",
        "$size",
        "$asin",
        "$acos",
        "$atan",
        "$atan2",
        "$hypot",
        "$sinh",
        "$cosh",
        "$tanh",
        "$asinh",
        "$acosh",
        "$atanh",
        "$countones",
        "$onehot0",
        "$error",
        "$info",
        "$random",
        "$dist_chi_square",
        "$dist_erlang",
        "$dist_exponential",
        "$dist_normal",
        "$dist_poisson",
        "$dist_t",
        "$dist_uniform",
        "$q_initialize",
        "$q_remove",
        "$q_exam",
        "$async$and$array",
        "$async$nand$array",
        "$async$or$array",
        "$async$nor$array",
        "$sync$and$array",
        "$sync$nand$array",
        "$sync$or$array",
        "$sync$nor$array",
        "$q_add",
        "$q_full",
        "$psprintf",
        "$async$and$plane",
        "$async$nand$plane",
        "$async$or$plane",
        "$async$nor$plane",
        "$sync$and$plane",
        "$sync$nand$plane",
        "$sync$or$plane",
        "$sync$nor$plane",
        "$system",
        "$display",
        "$displayb",
        "$displayh",
        "$displayo",
        "$strobe",
        "$strobeb",
        "$strobeh",
        "$strobeo",
        "$write",
        "$readmemb",
        "$readmemh",
        "$writememh",
        "$value$plusargs",
        "$dumpvars",
        "$dumpon",
        "$dumplimit",
        "$dumpports",
        "$dumpportson",
        "$dumpportslimit",
        "$writeb",
        "$writeh",
        "$writeo",
        "$monitor",
        "$monitorb",
        "$monitorh",
        "$monitoro",
        "$writememb",
        "$dumpfile",
        "$dumpoff",
        "$dumpall",
        "$dumpflush",
        "$dumpportsoff",
        "$dumpportsall",
        "$dumpportsflush",
        "$fclose",
        "$fdisplay",
        "$fdisplayb",
        "$fdisplayh",
        "$fdisplayo",
        "$fstrobe",
        "$fstrobeb",
        "$fstrobeh",
        "$fstrobeo",
        "$swrite",
        "$swriteb",
        "$swriteh",
        "$swriteo",
        "$fscanf",
        "$fread",
        "$fseek",
        "$fflush",
        "$feof",
        "$fopen",
        "$fwrite",
        "$fwriteb",
        "$fwriteh",
        "$fwriteo",
        "$fmonitor",
        "$fmonitorb",
        "$fmonitorh",
        "$fmonitoro",
        "$sformat",
        "$sformatf",
        "$fgetc",
        "$ungetc",
        "$fgets",
        "$sscanf",
        "$rewind",
        "$ftell",
        "$ferror"
      ]
    }, i = [
      "__FILE__",
      "__LINE__"
    ], a = [
      "begin_keywords",
      "celldefine",
      "default_nettype",
      "default_decay_time",
      "default_trireg_strength",
      "define",
      "delay_mode_distributed",
      "delay_mode_path",
      "delay_mode_unit",
      "delay_mode_zero",
      "else",
      "elsif",
      "end_keywords",
      "endcelldefine",
      "endif",
      "ifdef",
      "ifndef",
      "include",
      "line",
      "nounconnected_drive",
      "pragma",
      "resetall",
      "timescale",
      "unconnected_drive",
      "undef",
      "undefineall"
    ];
    return {
      name: "Verilog",
      aliases: [
        "v",
        "sv",
        "svh"
      ],
      case_insensitive: !1,
      keywords: r,
      contains: [
        t.C_BLOCK_COMMENT_MODE,
        t.C_LINE_COMMENT_MODE,
        t.QUOTE_STRING_MODE,
        {
          scope: "number",
          contains: [t.BACKSLASH_ESCAPE],
          variants: [
            { begin: /\b((\d+'([bhodBHOD]))[0-9xzXZa-fA-F_]+)/ },
            { begin: /\B(('([bhodBHOD]))[0-9xzXZa-fA-F_]+)/ },
            {
              // decimal
              begin: /\b[0-9][0-9_]*/,
              relevance: 0
            }
          ]
        },
        /* parameters to instances */
        {
          scope: "variable",
          variants: [
            { begin: "#\\((?!parameter).+\\)" },
            {
              begin: "\\.\\w+",
              relevance: 0
            }
          ]
        },
        {
          scope: "variable.constant",
          match: n.concat(/`/, n.either(...i))
        },
        {
          scope: "meta",
          begin: n.concat(/`/, n.either(...a)),
          end: /$|\/\/|\/\*/,
          returnEnd: !0,
          keywords: a
        }
      ]
    };
  }
  return By = e, By;
}
var $y, VL;
function ete() {
  if (VL) return $y;
  VL = 1;
  function e(t) {
    const n = "\\d(_|\\d)*", r = "[eE][-+]?" + n, i = n + "(\\." + n + ")?(" + r + ")?", a = "\\w+", s = "\\b(" + (n + "#" + a + "(\\." + a + ")?#(" + r + ")?") + "|" + i + ")";
    return {
      name: "VHDL",
      case_insensitive: !0,
      keywords: {
        keyword: [
          "abs",
          "access",
          "after",
          "alias",
          "all",
          "and",
          "architecture",
          "array",
          "assert",
          "assume",
          "assume_guarantee",
          "attribute",
          "begin",
          "block",
          "body",
          "buffer",
          "bus",
          "case",
          "component",
          "configuration",
          "constant",
          "context",
          "cover",
          "disconnect",
          "downto",
          "default",
          "else",
          "elsif",
          "end",
          "entity",
          "exit",
          "fairness",
          "file",
          "for",
          "force",
          "function",
          "generate",
          "generic",
          "group",
          "guarded",
          "if",
          "impure",
          "in",
          "inertial",
          "inout",
          "is",
          "label",
          "library",
          "linkage",
          "literal",
          "loop",
          "map",
          "mod",
          "nand",
          "new",
          "next",
          "nor",
          "not",
          "null",
          "of",
          "on",
          "open",
          "or",
          "others",
          "out",
          "package",
          "parameter",
          "port",
          "postponed",
          "procedure",
          "process",
          "property",
          "protected",
          "pure",
          "range",
          "record",
          "register",
          "reject",
          "release",
          "rem",
          "report",
          "restrict",
          "restrict_guarantee",
          "return",
          "rol",
          "ror",
          "select",
          "sequence",
          "severity",
          "shared",
          "signal",
          "sla",
          "sll",
          "sra",
          "srl",
          "strong",
          "subtype",
          "then",
          "to",
          "transport",
          "type",
          "unaffected",
          "units",
          "until",
          "use",
          "variable",
          "view",
          "vmode",
          "vprop",
          "vunit",
          "wait",
          "when",
          "while",
          "with",
          "xnor",
          "xor"
        ],
        built_in: [
          "boolean",
          "bit",
          "character",
          "integer",
          "time",
          "delay_length",
          "natural",
          "positive",
          "string",
          "bit_vector",
          "file_open_kind",
          "file_open_status",
          "std_logic",
          "std_logic_vector",
          "unsigned",
          "signed",
          "boolean_vector",
          "integer_vector",
          "std_ulogic",
          "std_ulogic_vector",
          "unresolved_unsigned",
          "u_unsigned",
          "unresolved_signed",
          "u_signed",
          "real_vector",
          "time_vector"
        ],
        literal: [
          // severity_level
          "false",
          "true",
          "note",
          "warning",
          "error",
          "failure",
          // textio
          "line",
          "text",
          "side",
          "width"
        ]
      },
      illegal: /\{/,
      contains: [
        t.C_BLOCK_COMMENT_MODE,
        // VHDL-2008 block commenting.
        t.COMMENT("--", "$"),
        t.QUOTE_STRING_MODE,
        {
          className: "number",
          begin: s,
          relevance: 0
        },
        {
          className: "string",
          begin: "'(U|X|0|1|Z|W|L|H|-)'",
          contains: [t.BACKSLASH_ESCAPE]
        },
        {
          className: "symbol",
          begin: "'[A-Za-z](_?[A-Za-z0-9])*",
          contains: [t.BACKSLASH_ESCAPE]
        }
      ]
    };
  }
  return $y = e, $y;
}
var Uy, WL;
function tte() {
  if (WL) return Uy;
  WL = 1;
  function e(t) {
    return {
      name: "Vim Script",
      keywords: {
        $pattern: /[!#@\w]+/,
        keyword: (
          // express version except: ! & * < = > !! # @ @@
          "N|0 P|0 X|0 a|0 ab abc abo al am an|0 ar arga argd arge argdo argg argl argu as au aug aun b|0 bN ba bad bd be bel bf bl bm bn bo bp br brea breaka breakd breakl bro bufdo buffers bun bw c|0 cN cNf ca cabc caddb cad caddf cal cat cb cc ccl cd ce cex cf cfir cgetb cgete cg changes chd che checkt cl cla clo cm cmapc cme cn cnew cnf cno cnorea cnoreme co col colo com comc comp con conf cope cp cpf cq cr cs cst cu cuna cunme cw delm deb debugg delc delf dif diffg diffo diffp diffpu diffs diffthis dig di dl dell dj dli do doautoa dp dr ds dsp e|0 ea ec echoe echoh echom echon el elsei em en endfo endf endt endw ene ex exe exi exu f|0 files filet fin fina fini fir fix fo foldc foldd folddoc foldo for fu go gr grepa gu gv ha helpf helpg helpt hi hid his ia iabc if ij il im imapc ime ino inorea inoreme int is isp iu iuna iunme j|0 ju k|0 keepa kee keepj lN lNf l|0 lad laddb laddf la lan lat lb lc lch lcl lcs le lefta let lex lf lfir lgetb lgete lg lgr lgrepa lh ll lla lli lmak lm lmapc lne lnew lnf ln loadk lo loc lockv lol lope lp lpf lr ls lt lu lua luad luaf lv lvimgrepa lw m|0 ma mak map mapc marks mat me menut mes mk mks mksp mkv mkvie mod mz mzf nbc nb nbs new nm nmapc nme nn nnoreme noa no noh norea noreme norm nu nun nunme ol o|0 om omapc ome on ono onoreme opt ou ounme ow p|0 profd prof pro promptr pc ped pe perld po popu pp pre prev ps pt ptN ptf ptj ptl ptn ptp ptr pts pu pw py3 python3 py3d py3f py pyd pyf quita qa rec red redi redr redraws reg res ret retu rew ri rightb rub rubyd rubyf rund ru rv sN san sa sal sav sb sbN sba sbf sbl sbm sbn sbp sbr scrip scripte scs se setf setg setl sf sfir sh sim sig sil sl sla sm smap smapc sme sn sni sno snor snoreme sor so spelld spe spelli spellr spellu spellw sp spr sre st sta startg startr star stopi stj sts sun sunm sunme sus sv sw sy synti sync tN tabN tabc tabdo tabe tabf tabfir tabl tabm tabnew tabn tabo tabp tabr tabs tab ta tags tc tcld tclf te tf th tj tl tm tn to tp tr try ts tu u|0 undoj undol una unh unl unlo unm unme uns up ve verb vert vim vimgrepa vi viu vie vm vmapc vme vne vn vnoreme vs vu vunme windo w|0 wN wa wh wi winc winp wn wp wq wqa ws wu wv x|0 xa xmapc xm xme xn xnoreme xu xunme y|0 z|0 ~ Next Print append abbreviate abclear aboveleft all amenu anoremenu args argadd argdelete argedit argglobal arglocal argument ascii autocmd augroup aunmenu buffer bNext ball badd bdelete behave belowright bfirst blast bmodified bnext botright bprevious brewind break breakadd breakdel breaklist browse bunload bwipeout change cNext cNfile cabbrev cabclear caddbuffer caddexpr caddfile call catch cbuffer cclose center cexpr cfile cfirst cgetbuffer cgetexpr cgetfile chdir checkpath checktime clist clast close cmap cmapclear cmenu cnext cnewer cnfile cnoremap cnoreabbrev cnoremenu copy colder colorscheme command comclear compiler continue confirm copen cprevious cpfile cquit crewind cscope cstag cunmap cunabbrev cunmenu cwindow delete delmarks debug debuggreedy delcommand delfunction diffupdate diffget diffoff diffpatch diffput diffsplit digraphs display deletel djump dlist doautocmd doautoall deletep drop dsearch dsplit edit earlier echo echoerr echohl echomsg else elseif emenu endif endfor endfunction endtry endwhile enew execute exit exusage file filetype find finally finish first fixdel fold foldclose folddoopen folddoclosed foldopen function global goto grep grepadd gui gvim hardcopy help helpfind helpgrep helptags highlight hide history insert iabbrev iabclear ijump ilist imap imapclear imenu inoremap inoreabbrev inoremenu intro isearch isplit iunmap iunabbrev iunmenu join jumps keepalt keepmarks keepjumps lNext lNfile list laddexpr laddbuffer laddfile last language later lbuffer lcd lchdir lclose lcscope left leftabove lexpr lfile lfirst lgetbuffer lgetexpr lgetfile lgrep lgrepadd lhelpgrep llast llist lmake lmap lmapclear lnext lnewer lnfile lnoremap loadkeymap loadview lockmarks lockvar lolder lopen lprevious lpfile lrewind ltag lunmap luado luafile lvimgrep lvimgrepadd lwindow move mark make mapclear match menu menutranslate messages mkexrc mksession mkspell mkvimrc mkview mode mzscheme mzfile nbclose nbkey nbsart next nmap nmapclear nmenu nnoremap nnoremenu noautocmd noremap nohlsearch noreabbrev noremenu normal number nunmap nunmenu oldfiles open omap omapclear omenu only onoremap onoremenu options ounmap ounmenu ownsyntax print profdel profile promptfind promptrepl pclose pedit perl perldo pop popup ppop preserve previous psearch ptag ptNext ptfirst ptjump ptlast ptnext ptprevious ptrewind ptselect put pwd py3do py3file python pydo pyfile quit quitall qall read recover redo redir redraw redrawstatus registers resize retab return rewind right rightbelow ruby rubydo rubyfile rundo runtime rviminfo substitute sNext sandbox sargument sall saveas sbuffer sbNext sball sbfirst sblast sbmodified sbnext sbprevious sbrewind scriptnames scriptencoding scscope set setfiletype setglobal setlocal sfind sfirst shell simalt sign silent sleep slast smagic smapclear smenu snext sniff snomagic snoremap snoremenu sort source spelldump spellgood spellinfo spellrepall spellundo spellwrong split sprevious srewind stop stag startgreplace startreplace startinsert stopinsert stjump stselect sunhide sunmap sunmenu suspend sview swapname syntax syntime syncbind tNext tabNext tabclose tabedit tabfind tabfirst tablast tabmove tabnext tabonly tabprevious tabrewind tag tcl tcldo tclfile tearoff tfirst throw tjump tlast tmenu tnext topleft tprevious trewind tselect tunmenu undo undojoin undolist unabbreviate unhide unlet unlockvar unmap unmenu unsilent update vglobal version verbose vertical vimgrep vimgrepadd visual viusage view vmap vmapclear vmenu vnew vnoremap vnoremenu vsplit vunmap vunmenu write wNext wall while winsize wincmd winpos wnext wprevious wqall wsverb wundo wviminfo xit xall xmapclear xmap xmenu xnoremap xnoremenu xunmap xunmenu yank"
        ),
        built_in: (
          // built in func
          "synIDtrans atan2 range matcharg did_filetype asin feedkeys xor argv complete_check add getwinposx getqflist getwinposy screencol clearmatches empty extend getcmdpos mzeval garbagecollect setreg ceil sqrt diff_hlID inputsecret get getfperm getpid filewritable shiftwidth max sinh isdirectory synID system inputrestore winline atan visualmode inputlist tabpagewinnr round getregtype mapcheck hasmapto histdel argidx findfile sha256 exists toupper getcmdline taglist string getmatches bufnr strftime winwidth bufexists strtrans tabpagebuflist setcmdpos remote_read printf setloclist getpos getline bufwinnr float2nr len getcmdtype diff_filler luaeval resolve libcallnr foldclosedend reverse filter has_key bufname str2float strlen setline getcharmod setbufvar index searchpos shellescape undofile foldclosed setqflist buflisted strchars str2nr virtcol floor remove undotree remote_expr winheight gettabwinvar reltime cursor tabpagenr finddir localtime acos getloclist search tanh matchend rename gettabvar strdisplaywidth type abs py3eval setwinvar tolower wildmenumode log10 spellsuggest bufloaded synconcealed nextnonblank server2client complete settabwinvar executable input wincol setmatches getftype hlID inputsave searchpair or screenrow line settabvar histadd deepcopy strpart remote_peek and eval getftime submatch screenchar winsaveview matchadd mkdir screenattr getfontname libcall reltimestr getfsize winnr invert pow getbufline byte2line soundfold repeat fnameescape tagfiles sin strwidth spellbadword trunc maparg log lispindent hostname setpos globpath remote_foreground getchar synIDattr fnamemodify cscope_connection stridx winbufnr indent min complete_add nr2char searchpairpos inputdialog values matchlist items hlexists strridx browsedir expand fmod pathshorten line2byte argc count getwinvar glob foldtextresult getreg foreground cosh matchdelete has char2nr simplify histget searchdecl iconv winrestcmd pumvisible writefile foldlevel haslocaldir keys cos matchstr foldtext histnr tan tempname getcwd byteidx getbufvar islocked escape eventhandler remote_send serverlist winrestview synstack pyeval prevnonblank readfile cindent filereadable changenr exp"
        )
      },
      illegal: /;/,
      contains: [
        t.NUMBER_MODE,
        {
          className: "string",
          begin: "'",
          end: "'",
          illegal: "\\n"
        },
        /*
        	      A double quote can start either a string or a line comment. Strings are
        	      ended before the end of a line by another double quote and can contain
        	      escaped double-quotes and post-escaped line breaks.
        
        	      Also, any double quote at the beginning of a line is a comment but we
        	      don't handle that properly at the moment: any double quote inside will
        	      turn them into a string. Handling it properly will require a smarter
        	      parser.
        	      */
        {
          className: "string",
          begin: /"(\\"|\n\\|[^"\n])*"/
        },
        t.COMMENT('"', "$"),
        {
          className: "variable",
          begin: /[bwtglsav]:[\w\d_]+/
        },
        {
          begin: [
            /\b(?:function|function!)/,
            /\s+/,
            t.IDENT_RE
          ],
          className: {
            1: "keyword",
            3: "title"
          },
          end: "$",
          relevance: 0,
          contains: [
            {
              className: "params",
              begin: "\\(",
              end: "\\)"
            }
          ]
        },
        {
          className: "symbol",
          begin: /<[\w-]+>/
        }
      ]
    };
  }
  return Uy = e, Uy;
}
var qy, KL;
function nte() {
  if (KL) return qy;
  KL = 1;
  function e(t) {
    t.regex;
    const n = t.COMMENT(/\(;/, /;\)/);
    n.contains.push("self");
    const r = t.COMMENT(/;;/, /$/), i = [
      "anyfunc",
      "block",
      "br",
      "br_if",
      "br_table",
      "call",
      "call_indirect",
      "data",
      "drop",
      "elem",
      "else",
      "end",
      "export",
      "func",
      "global.get",
      "global.set",
      "local.get",
      "local.set",
      "local.tee",
      "get_global",
      "get_local",
      "global",
      "if",
      "import",
      "local",
      "loop",
      "memory",
      "memory.grow",
      "memory.size",
      "module",
      "mut",
      "nop",
      "offset",
      "param",
      "result",
      "return",
      "select",
      "set_global",
      "set_local",
      "start",
      "table",
      "tee_local",
      "then",
      "type",
      "unreachable"
    ], a = {
      begin: [
        /(?:func|call|call_indirect)/,
        /\s+/,
        /\$[^\s)]+/
      ],
      className: {
        1: "keyword",
        3: "title.function"
      }
    }, o = {
      className: "variable",
      begin: /\$[\w_]+/
    }, s = {
      match: /(\((?!;)|\))+/,
      className: "punctuation",
      relevance: 0
    }, l = {
      className: "number",
      relevance: 0,
      // borrowed from Prism, TODO: split out into variants
      match: /[+-]?\b(?:\d(?:_?\d)*(?:\.\d(?:_?\d)*)?(?:[eE][+-]?\d(?:_?\d)*)?|0x[\da-fA-F](?:_?[\da-fA-F])*(?:\.[\da-fA-F](?:_?[\da-fA-D])*)?(?:[pP][+-]?\d(?:_?\d)*)?)\b|\binf\b|\bnan(?::0x[\da-fA-F](?:_?[\da-fA-D])*)?\b/
    }, u = {
      // look-ahead prevents us from gobbling up opcodes
      match: /(i32|i64|f32|f64)(?!\.)/,
      className: "type"
    }, c = {
      className: "keyword",
      // borrowed from Prism, TODO: split out into variants
      match: /\b(f32|f64|i32|i64)(?:\.(?:abs|add|and|ceil|clz|const|convert_[su]\/i(?:32|64)|copysign|ctz|demote\/f64|div(?:_[su])?|eqz?|extend_[su]\/i32|floor|ge(?:_[su])?|gt(?:_[su])?|le(?:_[su])?|load(?:(?:8|16|32)_[su])?|lt(?:_[su])?|max|min|mul|nearest|neg?|or|popcnt|promote\/f32|reinterpret\/[fi](?:32|64)|rem_[su]|rot[lr]|shl|shr_[su]|store(?:8|16|32)?|sqrt|sub|trunc(?:_[su]\/f(?:32|64))?|wrap\/i64|xor))\b/
    };
    return {
      name: "WebAssembly",
      keywords: {
        $pattern: /[\w.]+/,
        keyword: i
      },
      contains: [
        r,
        n,
        {
          match: [
            /(?:offset|align)/,
            /\s*/,
            /=/
          ],
          className: {
            1: "keyword",
            3: "operator"
          }
        },
        o,
        s,
        a,
        t.QUOTE_STRING_MODE,
        u,
        c,
        l
      ]
    };
  }
  return qy = e, qy;
}
var Gy, jL;
function rte() {
  if (jL) return Gy;
  jL = 1;
  function e(t) {
    const n = t.regex, r = /[a-zA-Z]\w*/, i = [
      "as",
      "break",
      "class",
      "construct",
      "continue",
      "else",
      "for",
      "foreign",
      "if",
      "import",
      "in",
      "is",
      "return",
      "static",
      "var",
      "while"
    ], a = [
      "true",
      "false",
      "null"
    ], o = [
      "this",
      "super"
    ], s = [
      "Bool",
      "Class",
      "Fiber",
      "Fn",
      "List",
      "Map",
      "Null",
      "Num",
      "Object",
      "Range",
      "Sequence",
      "String",
      "System"
    ], l = [
      "-",
      "~",
      /\*/,
      "%",
      /\.\.\./,
      /\.\./,
      /\+/,
      "<<",
      ">>",
      ">=",
      "<=",
      "<",
      ">",
      /\^/,
      /!=/,
      /!/,
      /\bis\b/,
      "==",
      "&&",
      "&",
      /\|\|/,
      /\|/,
      /\?:/,
      "="
    ], u = {
      relevance: 0,
      match: n.concat(/\b(?!(if|while|for|else|super)\b)/, r, /(?=\s*[({])/),
      className: "title.function"
    }, c = {
      match: n.concat(
        n.either(
          n.concat(/\b(?!(if|while|for|else|super)\b)/, r),
          n.either(...l)
        ),
        /(?=\s*\([^)]+\)\s*\{)/
      ),
      className: "title.function",
      starts: { contains: [
        {
          begin: /\(/,
          end: /\)/,
          contains: [
            {
              relevance: 0,
              scope: "params",
              match: r
            }
          ]
        }
      ] }
    }, d = {
      variants: [
        { match: [
          /class\s+/,
          r,
          /\s+is\s+/,
          r
        ] },
        { match: [
          /class\s+/,
          r
        ] }
      ],
      scope: {
        2: "title.class",
        4: "title.class.inherited"
      },
      keywords: i
    }, f = {
      relevance: 0,
      match: n.either(...l),
      className: "operator"
    }, h = {
      className: "string",
      begin: /"""/,
      end: /"""/
    }, m = {
      className: "property",
      begin: n.concat(/\./, n.lookahead(r)),
      end: r,
      excludeBegin: !0,
      relevance: 0
    }, v = {
      relevance: 0,
      match: n.concat(/\b_/, r),
      scope: "variable"
    }, b = {
      relevance: 0,
      match: /\b[A-Z]+[a-z]+([A-Z]+[a-z]+)*/,
      scope: "title.class",
      keywords: { _: s }
    }, y = t.C_NUMBER_MODE, g = {
      match: [
        r,
        /\s*/,
        /=/,
        /\s*/,
        /\(/,
        r,
        /\)\s*\{/
      ],
      scope: {
        1: "title.function",
        3: "operator",
        6: "params"
      }
    }, E = t.COMMENT(
      /\/\*\*/,
      /\*\//,
      { contains: [
        {
          match: /@[a-z]+/,
          scope: "doctag"
        },
        "self"
      ] }
    ), S = {
      scope: "subst",
      begin: /%\(/,
      end: /\)/,
      contains: [
        y,
        b,
        u,
        v,
        f
      ]
    }, C = {
      scope: "string",
      begin: /"/,
      end: /"/,
      contains: [
        S,
        {
          scope: "char.escape",
          variants: [
            { match: /\\\\|\\["0%abefnrtv]/ },
            { match: /\\x[0-9A-F]{2}/ },
            { match: /\\u[0-9A-F]{4}/ },
            { match: /\\U[0-9A-F]{8}/ }
          ]
        }
      ]
    };
    S.contains.push(C);
    const T = [
      ...i,
      ...o,
      ...a
    ], O = {
      relevance: 0,
      match: n.concat(
        "\\b(?!",
        T.join("|"),
        "\\b)",
        /[a-zA-Z_]\w*(?:[?!]|\b)/
      ),
      className: "variable"
    };
    return {
      name: "Wren",
      keywords: {
        keyword: i,
        "variable.language": o,
        literal: a
      },
      contains: [
        {
          // scope: "meta",
          scope: "comment",
          variants: [
            {
              begin: [
                /#!?/,
                /[A-Za-z_]+(?=\()/
              ],
              beginScope: {
                // 2: "attr"
              },
              keywords: { literal: a },
              contains: [
                // NUMBER,
                // VARIABLE
              ],
              end: /\)/
            },
            {
              begin: [
                /#!?/,
                /[A-Za-z_]+/
              ],
              beginScope: {
                // 2: "attr"
              },
              end: /$/
            }
          ]
        },
        y,
        C,
        h,
        E,
        t.C_LINE_COMMENT_MODE,
        t.C_BLOCK_COMMENT_MODE,
        b,
        d,
        g,
        c,
        u,
        f,
        v,
        m,
        O
      ]
    };
  }
  return Gy = e, Gy;
}
var Yy, QL;
function ite() {
  if (QL) return Yy;
  QL = 1;
  function e(t) {
    return {
      name: "Intel x86 Assembly",
      case_insensitive: !0,
      keywords: {
        $pattern: "[.%]?" + t.IDENT_RE,
        keyword: "lock rep repe repz repne repnz xaquire xrelease bnd nobnd aaa aad aam aas adc add and arpl bb0_reset bb1_reset bound bsf bsr bswap bt btc btr bts call cbw cdq cdqe clc cld cli clts cmc cmp cmpsb cmpsd cmpsq cmpsw cmpxchg cmpxchg486 cmpxchg8b cmpxchg16b cpuid cpu_read cpu_write cqo cwd cwde daa das dec div dmint emms enter equ f2xm1 fabs fadd faddp fbld fbstp fchs fclex fcmovb fcmovbe fcmove fcmovnb fcmovnbe fcmovne fcmovnu fcmovu fcom fcomi fcomip fcomp fcompp fcos fdecstp fdisi fdiv fdivp fdivr fdivrp femms feni ffree ffreep fiadd ficom ficomp fidiv fidivr fild fimul fincstp finit fist fistp fisttp fisub fisubr fld fld1 fldcw fldenv fldl2e fldl2t fldlg2 fldln2 fldpi fldz fmul fmulp fnclex fndisi fneni fninit fnop fnsave fnstcw fnstenv fnstsw fpatan fprem fprem1 fptan frndint frstor fsave fscale fsetpm fsin fsincos fsqrt fst fstcw fstenv fstp fstsw fsub fsubp fsubr fsubrp ftst fucom fucomi fucomip fucomp fucompp fxam fxch fxtract fyl2x fyl2xp1 hlt ibts icebp idiv imul in inc incbin insb insd insw int int01 int1 int03 int3 into invd invpcid invlpg invlpga iret iretd iretq iretw jcxz jecxz jrcxz jmp jmpe lahf lar lds lea leave les lfence lfs lgdt lgs lidt lldt lmsw loadall loadall286 lodsb lodsd lodsq lodsw loop loope loopne loopnz loopz lsl lss ltr mfence monitor mov movd movq movsb movsd movsq movsw movsx movsxd movzx mul mwait neg nop not or out outsb outsd outsw packssdw packsswb packuswb paddb paddd paddsb paddsiw paddsw paddusb paddusw paddw pand pandn pause paveb pavgusb pcmpeqb pcmpeqd pcmpeqw pcmpgtb pcmpgtd pcmpgtw pdistib pf2id pfacc pfadd pfcmpeq pfcmpge pfcmpgt pfmax pfmin pfmul pfrcp pfrcpit1 pfrcpit2 pfrsqit1 pfrsqrt pfsub pfsubr pi2fd pmachriw pmaddwd pmagw pmulhriw pmulhrwa pmulhrwc pmulhw pmullw pmvgezb pmvlzb pmvnzb pmvzb pop popa popad popaw popf popfd popfq popfw por prefetch prefetchw pslld psllq psllw psrad psraw psrld psrlq psrlw psubb psubd psubsb psubsiw psubsw psubusb psubusw psubw punpckhbw punpckhdq punpckhwd punpcklbw punpckldq punpcklwd push pusha pushad pushaw pushf pushfd pushfq pushfw pxor rcl rcr rdshr rdmsr rdpmc rdtsc rdtscp ret retf retn rol ror rdm rsdc rsldt rsm rsts sahf sal salc sar sbb scasb scasd scasq scasw sfence sgdt shl shld shr shrd sidt sldt skinit smi smint smintold smsw stc std sti stosb stosd stosq stosw str sub svdc svldt svts swapgs syscall sysenter sysexit sysret test ud0 ud1 ud2b ud2 ud2a umov verr verw fwait wbinvd wrshr wrmsr xadd xbts xchg xlatb xlat xor cmove cmovz cmovne cmovnz cmova cmovnbe cmovae cmovnb cmovb cmovnae cmovbe cmovna cmovg cmovnle cmovge cmovnl cmovl cmovnge cmovle cmovng cmovc cmovnc cmovo cmovno cmovs cmovns cmovp cmovpe cmovnp cmovpo je jz jne jnz ja jnbe jae jnb jb jnae jbe jna jg jnle jge jnl jl jnge jle jng jc jnc jo jno js jns jpo jnp jpe jp sete setz setne setnz seta setnbe setae setnb setnc setb setnae setcset setbe setna setg setnle setge setnl setl setnge setle setng sets setns seto setno setpe setp setpo setnp addps addss andnps andps cmpeqps cmpeqss cmpleps cmpless cmpltps cmpltss cmpneqps cmpneqss cmpnleps cmpnless cmpnltps cmpnltss cmpordps cmpordss cmpunordps cmpunordss cmpps cmpss comiss cvtpi2ps cvtps2pi cvtsi2ss cvtss2si cvttps2pi cvttss2si divps divss ldmxcsr maxps maxss minps minss movaps movhps movlhps movlps movhlps movmskps movntps movss movups mulps mulss orps rcpps rcpss rsqrtps rsqrtss shufps sqrtps sqrtss stmxcsr subps subss ucomiss unpckhps unpcklps xorps fxrstor fxrstor64 fxsave fxsave64 xgetbv xsetbv xsave xsave64 xsaveopt xsaveopt64 xrstor xrstor64 prefetchnta prefetcht0 prefetcht1 prefetcht2 maskmovq movntq pavgb pavgw pextrw pinsrw pmaxsw pmaxub pminsw pminub pmovmskb pmulhuw psadbw pshufw pf2iw pfnacc pfpnacc pi2fw pswapd maskmovdqu clflush movntdq movnti movntpd movdqa movdqu movdq2q movq2dq paddq pmuludq pshufd pshufhw pshuflw pslldq psrldq psubq punpckhqdq punpcklqdq addpd addsd andnpd andpd cmpeqpd cmpeqsd cmplepd cmplesd cmpltpd cmpltsd cmpneqpd cmpneqsd cmpnlepd cmpnlesd cmpnltpd cmpnltsd cmpordpd cmpordsd cmpunordpd cmpunordsd cmppd comisd cvtdq2pd cvtdq2ps cvtpd2dq cvtpd2pi cvtpd2ps cvtpi2pd cvtps2dq cvtps2pd cvtsd2si cvtsd2ss cvtsi2sd cvtss2sd cvttpd2pi cvttpd2dq cvttps2dq cvttsd2si divpd divsd maxpd maxsd minpd minsd movapd movhpd movlpd movmskpd movupd mulpd mulsd orpd shufpd sqrtpd sqrtsd subpd subsd ucomisd unpckhpd unpcklpd xorpd addsubpd addsubps haddpd haddps hsubpd hsubps lddqu movddup movshdup movsldup clgi stgi vmcall vmclear vmfunc vmlaunch vmload vmmcall vmptrld vmptrst vmread vmresume vmrun vmsave vmwrite vmxoff vmxon invept invvpid pabsb pabsw pabsd palignr phaddw phaddd phaddsw phsubw phsubd phsubsw pmaddubsw pmulhrsw pshufb psignb psignw psignd extrq insertq movntsd movntss lzcnt blendpd blendps blendvpd blendvps dppd dpps extractps insertps movntdqa mpsadbw packusdw pblendvb pblendw pcmpeqq pextrb pextrd pextrq phminposuw pinsrb pinsrd pinsrq pmaxsb pmaxsd pmaxud pmaxuw pminsb pminsd pminud pminuw pmovsxbw pmovsxbd pmovsxbq pmovsxwd pmovsxwq pmovsxdq pmovzxbw pmovzxbd pmovzxbq pmovzxwd pmovzxwq pmovzxdq pmuldq pmulld ptest roundpd roundps roundsd roundss crc32 pcmpestri pcmpestrm pcmpistri pcmpistrm pcmpgtq popcnt getsec pfrcpv pfrsqrtv movbe aesenc aesenclast aesdec aesdeclast aesimc aeskeygenassist vaesenc vaesenclast vaesdec vaesdeclast vaesimc vaeskeygenassist vaddpd vaddps vaddsd vaddss vaddsubpd vaddsubps vandpd vandps vandnpd vandnps vblendpd vblendps vblendvpd vblendvps vbroadcastss vbroadcastsd vbroadcastf128 vcmpeq_ospd vcmpeqpd vcmplt_ospd vcmpltpd vcmple_ospd vcmplepd vcmpunord_qpd vcmpunordpd vcmpneq_uqpd vcmpneqpd vcmpnlt_uspd vcmpnltpd vcmpnle_uspd vcmpnlepd vcmpord_qpd vcmpordpd vcmpeq_uqpd vcmpnge_uspd vcmpngepd vcmpngt_uspd vcmpngtpd vcmpfalse_oqpd vcmpfalsepd vcmpneq_oqpd vcmpge_ospd vcmpgepd vcmpgt_ospd vcmpgtpd vcmptrue_uqpd vcmptruepd vcmplt_oqpd vcmple_oqpd vcmpunord_spd vcmpneq_uspd vcmpnlt_uqpd vcmpnle_uqpd vcmpord_spd vcmpeq_uspd vcmpnge_uqpd vcmpngt_uqpd vcmpfalse_ospd vcmpneq_ospd vcmpge_oqpd vcmpgt_oqpd vcmptrue_uspd vcmppd vcmpeq_osps vcmpeqps vcmplt_osps vcmpltps vcmple_osps vcmpleps vcmpunord_qps vcmpunordps vcmpneq_uqps vcmpneqps vcmpnlt_usps vcmpnltps vcmpnle_usps vcmpnleps vcmpord_qps vcmpordps vcmpeq_uqps vcmpnge_usps vcmpngeps vcmpngt_usps vcmpngtps vcmpfalse_oqps vcmpfalseps vcmpneq_oqps vcmpge_osps vcmpgeps vcmpgt_osps vcmpgtps vcmptrue_uqps vcmptrueps vcmplt_oqps vcmple_oqps vcmpunord_sps vcmpneq_usps vcmpnlt_uqps vcmpnle_uqps vcmpord_sps vcmpeq_usps vcmpnge_uqps vcmpngt_uqps vcmpfalse_osps vcmpneq_osps vcmpge_oqps vcmpgt_oqps vcmptrue_usps vcmpps vcmpeq_ossd vcmpeqsd vcmplt_ossd vcmpltsd vcmple_ossd vcmplesd vcmpunord_qsd vcmpunordsd vcmpneq_uqsd vcmpneqsd vcmpnlt_ussd vcmpnltsd vcmpnle_ussd vcmpnlesd vcmpord_qsd vcmpordsd vcmpeq_uqsd vcmpnge_ussd vcmpngesd vcmpngt_ussd vcmpngtsd vcmpfalse_oqsd vcmpfalsesd vcmpneq_oqsd vcmpge_ossd vcmpgesd vcmpgt_ossd vcmpgtsd vcmptrue_uqsd vcmptruesd vcmplt_oqsd vcmple_oqsd vcmpunord_ssd vcmpneq_ussd vcmpnlt_uqsd vcmpnle_uqsd vcmpord_ssd vcmpeq_ussd vcmpnge_uqsd vcmpngt_uqsd vcmpfalse_ossd vcmpneq_ossd vcmpge_oqsd vcmpgt_oqsd vcmptrue_ussd vcmpsd vcmpeq_osss vcmpeqss vcmplt_osss vcmpltss vcmple_osss vcmpless vcmpunord_qss vcmpunordss vcmpneq_uqss vcmpneqss vcmpnlt_usss vcmpnltss vcmpnle_usss vcmpnless vcmpord_qss vcmpordss vcmpeq_uqss vcmpnge_usss vcmpngess vcmpngt_usss vcmpngtss vcmpfalse_oqss vcmpfalsess vcmpneq_oqss vcmpge_osss vcmpgess vcmpgt_osss vcmpgtss vcmptrue_uqss vcmptruess vcmplt_oqss vcmple_oqss vcmpunord_sss vcmpneq_usss vcmpnlt_uqss vcmpnle_uqss vcmpord_sss vcmpeq_usss vcmpnge_uqss vcmpngt_uqss vcmpfalse_osss vcmpneq_osss vcmpge_oqss vcmpgt_oqss vcmptrue_usss vcmpss vcomisd vcomiss vcvtdq2pd vcvtdq2ps vcvtpd2dq vcvtpd2ps vcvtps2dq vcvtps2pd vcvtsd2si vcvtsd2ss vcvtsi2sd vcvtsi2ss vcvtss2sd vcvtss2si vcvttpd2dq vcvttps2dq vcvttsd2si vcvttss2si vdivpd vdivps vdivsd vdivss vdppd vdpps vextractf128 vextractps vhaddpd vhaddps vhsubpd vhsubps vinsertf128 vinsertps vlddqu vldqqu vldmxcsr vmaskmovdqu vmaskmovps vmaskmovpd vmaxpd vmaxps vmaxsd vmaxss vminpd vminps vminsd vminss vmovapd vmovaps vmovd vmovq vmovddup vmovdqa vmovqqa vmovdqu vmovqqu vmovhlps vmovhpd vmovhps vmovlhps vmovlpd vmovlps vmovmskpd vmovmskps vmovntdq vmovntqq vmovntdqa vmovntpd vmovntps vmovsd vmovshdup vmovsldup vmovss vmovupd vmovups vmpsadbw vmulpd vmulps vmulsd vmulss vorpd vorps vpabsb vpabsw vpabsd vpacksswb vpackssdw vpackuswb vpackusdw vpaddb vpaddw vpaddd vpaddq vpaddsb vpaddsw vpaddusb vpaddusw vpalignr vpand vpandn vpavgb vpavgw vpblendvb vpblendw vpcmpestri vpcmpestrm vpcmpistri vpcmpistrm vpcmpeqb vpcmpeqw vpcmpeqd vpcmpeqq vpcmpgtb vpcmpgtw vpcmpgtd vpcmpgtq vpermilpd vpermilps vperm2f128 vpextrb vpextrw vpextrd vpextrq vphaddw vphaddd vphaddsw vphminposuw vphsubw vphsubd vphsubsw vpinsrb vpinsrw vpinsrd vpinsrq vpmaddwd vpmaddubsw vpmaxsb vpmaxsw vpmaxsd vpmaxub vpmaxuw vpmaxud vpminsb vpminsw vpminsd vpminub vpminuw vpminud vpmovmskb vpmovsxbw vpmovsxbd vpmovsxbq vpmovsxwd vpmovsxwq vpmovsxdq vpmovzxbw vpmovzxbd vpmovzxbq vpmovzxwd vpmovzxwq vpmovzxdq vpmulhuw vpmulhrsw vpmulhw vpmullw vpmulld vpmuludq vpmuldq vpor vpsadbw vpshufb vpshufd vpshufhw vpshuflw vpsignb vpsignw vpsignd vpslldq vpsrldq vpsllw vpslld vpsllq vpsraw vpsrad vpsrlw vpsrld vpsrlq vptest vpsubb vpsubw vpsubd vpsubq vpsubsb vpsubsw vpsubusb vpsubusw vpunpckhbw vpunpckhwd vpunpckhdq vpunpckhqdq vpunpcklbw vpunpcklwd vpunpckldq vpunpcklqdq vpxor vrcpps vrcpss vrsqrtps vrsqrtss vroundpd vroundps vroundsd vroundss vshufpd vshufps vsqrtpd vsqrtps vsqrtsd vsqrtss vstmxcsr vsubpd vsubps vsubsd vsubss vtestps vtestpd vucomisd vucomiss vunpckhpd vunpckhps vunpcklpd vunpcklps vxorpd vxorps vzeroall vzeroupper pclmullqlqdq pclmulhqlqdq pclmullqhqdq pclmulhqhqdq pclmulqdq vpclmullqlqdq vpclmulhqlqdq vpclmullqhqdq vpclmulhqhqdq vpclmulqdq vfmadd132ps vfmadd132pd vfmadd312ps vfmadd312pd vfmadd213ps vfmadd213pd vfmadd123ps vfmadd123pd vfmadd231ps vfmadd231pd vfmadd321ps vfmadd321pd vfmaddsub132ps vfmaddsub132pd vfmaddsub312ps vfmaddsub312pd vfmaddsub213ps vfmaddsub213pd vfmaddsub123ps vfmaddsub123pd vfmaddsub231ps vfmaddsub231pd vfmaddsub321ps vfmaddsub321pd vfmsub132ps vfmsub132pd vfmsub312ps vfmsub312pd vfmsub213ps vfmsub213pd vfmsub123ps vfmsub123pd vfmsub231ps vfmsub231pd vfmsub321ps vfmsub321pd vfmsubadd132ps vfmsubadd132pd vfmsubadd312ps vfmsubadd312pd vfmsubadd213ps vfmsubadd213pd vfmsubadd123ps vfmsubadd123pd vfmsubadd231ps vfmsubadd231pd vfmsubadd321ps vfmsubadd321pd vfnmadd132ps vfnmadd132pd vfnmadd312ps vfnmadd312pd vfnmadd213ps vfnmadd213pd vfnmadd123ps vfnmadd123pd vfnmadd231ps vfnmadd231pd vfnmadd321ps vfnmadd321pd vfnmsub132ps vfnmsub132pd vfnmsub312ps vfnmsub312pd vfnmsub213ps vfnmsub213pd vfnmsub123ps vfnmsub123pd vfnmsub231ps vfnmsub231pd vfnmsub321ps vfnmsub321pd vfmadd132ss vfmadd132sd vfmadd312ss vfmadd312sd vfmadd213ss vfmadd213sd vfmadd123ss vfmadd123sd vfmadd231ss vfmadd231sd vfmadd321ss vfmadd321sd vfmsub132ss vfmsub132sd vfmsub312ss vfmsub312sd vfmsub213ss vfmsub213sd vfmsub123ss vfmsub123sd vfmsub231ss vfmsub231sd vfmsub321ss vfmsub321sd vfnmadd132ss vfnmadd132sd vfnmadd312ss vfnmadd312sd vfnmadd213ss vfnmadd213sd vfnmadd123ss vfnmadd123sd vfnmadd231ss vfnmadd231sd vfnmadd321ss vfnmadd321sd vfnmsub132ss vfnmsub132sd vfnmsub312ss vfnmsub312sd vfnmsub213ss vfnmsub213sd vfnmsub123ss vfnmsub123sd vfnmsub231ss vfnmsub231sd vfnmsub321ss vfnmsub321sd rdfsbase rdgsbase rdrand wrfsbase wrgsbase vcvtph2ps vcvtps2ph adcx adox rdseed clac stac xstore xcryptecb xcryptcbc xcryptctr xcryptcfb xcryptofb montmul xsha1 xsha256 llwpcb slwpcb lwpval lwpins vfmaddpd vfmaddps vfmaddsd vfmaddss vfmaddsubpd vfmaddsubps vfmsubaddpd vfmsubaddps vfmsubpd vfmsubps vfmsubsd vfmsubss vfnmaddpd vfnmaddps vfnmaddsd vfnmaddss vfnmsubpd vfnmsubps vfnmsubsd vfnmsubss vfrczpd vfrczps vfrczsd vfrczss vpcmov vpcomb vpcomd vpcomq vpcomub vpcomud vpcomuq vpcomuw vpcomw vphaddbd vphaddbq vphaddbw vphadddq vphaddubd vphaddubq vphaddubw vphaddudq vphadduwd vphadduwq vphaddwd vphaddwq vphsubbw vphsubdq vphsubwd vpmacsdd vpmacsdqh vpmacsdql vpmacssdd vpmacssdqh vpmacssdql vpmacsswd vpmacssww vpmacswd vpmacsww vpmadcsswd vpmadcswd vpperm vprotb vprotd vprotq vprotw vpshab vpshad vpshaq vpshaw vpshlb vpshld vpshlq vpshlw vbroadcasti128 vpblendd vpbroadcastb vpbroadcastw vpbroadcastd vpbroadcastq vpermd vpermpd vpermps vpermq vperm2i128 vextracti128 vinserti128 vpmaskmovd vpmaskmovq vpsllvd vpsllvq vpsravd vpsrlvd vpsrlvq vgatherdpd vgatherqpd vgatherdps vgatherqps vpgatherdd vpgatherqd vpgatherdq vpgatherqq xabort xbegin xend xtest andn bextr blci blcic blsi blsic blcfill blsfill blcmsk blsmsk blsr blcs bzhi mulx pdep pext rorx sarx shlx shrx tzcnt tzmsk t1mskc valignd valignq vblendmpd vblendmps vbroadcastf32x4 vbroadcastf64x4 vbroadcasti32x4 vbroadcasti64x4 vcompresspd vcompressps vcvtpd2udq vcvtps2udq vcvtsd2usi vcvtss2usi vcvttpd2udq vcvttps2udq vcvttsd2usi vcvttss2usi vcvtudq2pd vcvtudq2ps vcvtusi2sd vcvtusi2ss vexpandpd vexpandps vextractf32x4 vextractf64x4 vextracti32x4 vextracti64x4 vfixupimmpd vfixupimmps vfixupimmsd vfixupimmss vgetexppd vgetexpps vgetexpsd vgetexpss vgetmantpd vgetmantps vgetmantsd vgetmantss vinsertf32x4 vinsertf64x4 vinserti32x4 vinserti64x4 vmovdqa32 vmovdqa64 vmovdqu32 vmovdqu64 vpabsq vpandd vpandnd vpandnq vpandq vpblendmd vpblendmq vpcmpltd vpcmpled vpcmpneqd vpcmpnltd vpcmpnled vpcmpd vpcmpltq vpcmpleq vpcmpneqq vpcmpnltq vpcmpnleq vpcmpq vpcmpequd vpcmpltud vpcmpleud vpcmpnequd vpcmpnltud vpcmpnleud vpcmpud vpcmpequq vpcmpltuq vpcmpleuq vpcmpnequq vpcmpnltuq vpcmpnleuq vpcmpuq vpcompressd vpcompressq vpermi2d vpermi2pd vpermi2ps vpermi2q vpermt2d vpermt2pd vpermt2ps vpermt2q vpexpandd vpexpandq vpmaxsq vpmaxuq vpminsq vpminuq vpmovdb vpmovdw vpmovqb vpmovqd vpmovqw vpmovsdb vpmovsdw vpmovsqb vpmovsqd vpmovsqw vpmovusdb vpmovusdw vpmovusqb vpmovusqd vpmovusqw vpord vporq vprold vprolq vprolvd vprolvq vprord vprorq vprorvd vprorvq vpscatterdd vpscatterdq vpscatterqd vpscatterqq vpsraq vpsravq vpternlogd vpternlogq vptestmd vptestmq vptestnmd vptestnmq vpxord vpxorq vrcp14pd vrcp14ps vrcp14sd vrcp14ss vrndscalepd vrndscaleps vrndscalesd vrndscaless vrsqrt14pd vrsqrt14ps vrsqrt14sd vrsqrt14ss vscalefpd vscalefps vscalefsd vscalefss vscatterdpd vscatterdps vscatterqpd vscatterqps vshuff32x4 vshuff64x2 vshufi32x4 vshufi64x2 kandnw kandw kmovw knotw kortestw korw kshiftlw kshiftrw kunpckbw kxnorw kxorw vpbroadcastmb2q vpbroadcastmw2d vpconflictd vpconflictq vplzcntd vplzcntq vexp2pd vexp2ps vrcp28pd vrcp28ps vrcp28sd vrcp28ss vrsqrt28pd vrsqrt28ps vrsqrt28sd vrsqrt28ss vgatherpf0dpd vgatherpf0dps vgatherpf0qpd vgatherpf0qps vgatherpf1dpd vgatherpf1dps vgatherpf1qpd vgatherpf1qps vscatterpf0dpd vscatterpf0dps vscatterpf0qpd vscatterpf0qps vscatterpf1dpd vscatterpf1dps vscatterpf1qpd vscatterpf1qps prefetchwt1 bndmk bndcl bndcu bndcn bndmov bndldx bndstx sha1rnds4 sha1nexte sha1msg1 sha1msg2 sha256rnds2 sha256msg1 sha256msg2 hint_nop0 hint_nop1 hint_nop2 hint_nop3 hint_nop4 hint_nop5 hint_nop6 hint_nop7 hint_nop8 hint_nop9 hint_nop10 hint_nop11 hint_nop12 hint_nop13 hint_nop14 hint_nop15 hint_nop16 hint_nop17 hint_nop18 hint_nop19 hint_nop20 hint_nop21 hint_nop22 hint_nop23 hint_nop24 hint_nop25 hint_nop26 hint_nop27 hint_nop28 hint_nop29 hint_nop30 hint_nop31 hint_nop32 hint_nop33 hint_nop34 hint_nop35 hint_nop36 hint_nop37 hint_nop38 hint_nop39 hint_nop40 hint_nop41 hint_nop42 hint_nop43 hint_nop44 hint_nop45 hint_nop46 hint_nop47 hint_nop48 hint_nop49 hint_nop50 hint_nop51 hint_nop52 hint_nop53 hint_nop54 hint_nop55 hint_nop56 hint_nop57 hint_nop58 hint_nop59 hint_nop60 hint_nop61 hint_nop62 hint_nop63",
        built_in: (
          // Instruction pointer
          "ip eip rip al ah bl bh cl ch dl dh sil dil bpl spl r8b r9b r10b r11b r12b r13b r14b r15b ax bx cx dx si di bp sp r8w r9w r10w r11w r12w r13w r14w r15w eax ebx ecx edx esi edi ebp esp eip r8d r9d r10d r11d r12d r13d r14d r15d rax rbx rcx rdx rsi rdi rbp rsp r8 r9 r10 r11 r12 r13 r14 r15 cs ds es fs gs ss st st0 st1 st2 st3 st4 st5 st6 st7 mm0 mm1 mm2 mm3 mm4 mm5 mm6 mm7 xmm0  xmm1  xmm2  xmm3  xmm4  xmm5  xmm6  xmm7  xmm8  xmm9 xmm10  xmm11 xmm12 xmm13 xmm14 xmm15 xmm16 xmm17 xmm18 xmm19 xmm20 xmm21 xmm22 xmm23 xmm24 xmm25 xmm26 xmm27 xmm28 xmm29 xmm30 xmm31 ymm0  ymm1  ymm2  ymm3  ymm4  ymm5  ymm6  ymm7  ymm8  ymm9 ymm10  ymm11 ymm12 ymm13 ymm14 ymm15 ymm16 ymm17 ymm18 ymm19 ymm20 ymm21 ymm22 ymm23 ymm24 ymm25 ymm26 ymm27 ymm28 ymm29 ymm30 ymm31 zmm0  zmm1  zmm2  zmm3  zmm4  zmm5  zmm6  zmm7  zmm8  zmm9 zmm10  zmm11 zmm12 zmm13 zmm14 zmm15 zmm16 zmm17 zmm18 zmm19 zmm20 zmm21 zmm22 zmm23 zmm24 zmm25 zmm26 zmm27 zmm28 zmm29 zmm30 zmm31 k0 k1 k2 k3 k4 k5 k6 k7 bnd0 bnd1 bnd2 bnd3 cr0 cr1 cr2 cr3 cr4 cr8 dr0 dr1 dr2 dr3 dr8 tr3 tr4 tr5 tr6 tr7 r0 r1 r2 r3 r4 r5 r6 r7 r0b r1b r2b r3b r4b r5b r6b r7b r0w r1w r2w r3w r4w r5w r6w r7w r0d r1d r2d r3d r4d r5d r6d r7d r0h r1h r2h r3h r0l r1l r2l r3l r4l r5l r6l r7l r8l r9l r10l r11l r12l r13l r14l r15l db dw dd dq dt ddq do dy dz resb resw resd resq rest resdq reso resy resz incbin equ times byte word dword qword nosplit rel abs seg wrt strict near far a32 ptr"
        ),
        meta: "%define %xdefine %+ %undef %defstr %deftok %assign %strcat %strlen %substr %rotate %elif %else %endif %if %ifmacro %ifctx %ifidn %ifidni %ifid %ifnum %ifstr %iftoken %ifempty %ifenv %error %warning %fatal %rep %endrep %include %push %pop %repl %pathsearch %depend %use %arg %stacksize %local %line %comment %endcomment .nolist __FILE__ __LINE__ __SECT__  __BITS__ __OUTPUT_FORMAT__ __DATE__ __TIME__ __DATE_NUM__ __TIME_NUM__ __UTC_DATE__ __UTC_TIME__ __UTC_DATE_NUM__ __UTC_TIME_NUM__  __PASS__ struc endstruc istruc at iend align alignb sectalign daz nodaz up down zero default option assume public bits use16 use32 use64 default section segment absolute extern global common cpu float __utf16__ __utf16le__ __utf16be__ __utf32__ __utf32le__ __utf32be__ __float8__ __float16__ __float32__ __float64__ __float80m__ __float80e__ __float128l__ __float128h__ __Infinity__ __QNaN__ __SNaN__ Inf NaN QNaN SNaN float8 float16 float32 float64 float80m float80e float128l float128h __FLOAT_DAZ__ __FLOAT_ROUND__ __FLOAT__"
      },
      contains: [
        t.COMMENT(
          ";",
          "$",
          { relevance: 0 }
        ),
        {
          className: "number",
          variants: [
            // Float number and x87 BCD
            {
              begin: "\\b(?:([0-9][0-9_]*)?\\.[0-9_]*(?:[eE][+-]?[0-9_]+)?|(0[Xx])?[0-9][0-9_]*(\\.[0-9_]*)?(?:[pP](?:[+-]?[0-9_]+)?)?)\\b",
              relevance: 0
            },
            // Hex number in $
            {
              begin: "\\$[0-9][0-9A-Fa-f]*",
              relevance: 0
            },
            // Number in H,D,T,Q,O,B,Y suffix
            { begin: "\\b(?:[0-9A-Fa-f][0-9A-Fa-f_]*[Hh]|[0-9][0-9_]*[DdTt]?|[0-7][0-7_]*[QqOo]|[0-1][0-1_]*[BbYy])\\b" },
            // Number in X,D,T,Q,O,B,Y prefix
            { begin: "\\b(?:0[Xx][0-9A-Fa-f_]+|0[DdTt][0-9_]+|0[QqOo][0-7_]+|0[BbYy][0-1_]+)\\b" }
          ]
        },
        // Double quote string
        t.QUOTE_STRING_MODE,
        {
          className: "string",
          variants: [
            // Single-quoted string
            {
              begin: "'",
              end: "[^\\\\]'"
            },
            // Backquoted string
            {
              begin: "`",
              end: "[^\\\\]`"
            }
          ],
          relevance: 0
        },
        {
          className: "symbol",
          variants: [
            // Global label and local label
            { begin: "^\\s*[A-Za-z._?][A-Za-z0-9_$#@~.?]*(:|\\s+label)" },
            // Macro-local label
            { begin: "^\\s*%%[A-Za-z0-9_$#@~.?]*:" }
          ],
          relevance: 0
        },
        // Macro parameter
        {
          className: "subst",
          begin: "%[0-9]+",
          relevance: 0
        },
        // Macro parameter
        {
          className: "subst",
          begin: "%!S+",
          relevance: 0
        },
        {
          className: "meta",
          begin: /^\s*\.[\w_-]+/
        }
      ]
    };
  }
  return Yy = e, Yy;
}
var Hy, XL;
function ate() {
  if (XL) return Hy;
  XL = 1;
  function e(t) {
    const n = [
      "if",
      "then",
      "else",
      "do",
      "while",
      "until",
      "for",
      "loop",
      "import",
      "with",
      "is",
      "as",
      "where",
      "when",
      "by",
      "data",
      "constant",
      "integer",
      "real",
      "text",
      "name",
      "boolean",
      "symbol",
      "infix",
      "prefix",
      "postfix",
      "block",
      "tree"
    ], r = [
      "in",
      "mod",
      "rem",
      "and",
      "or",
      "xor",
      "not",
      "abs",
      "sign",
      "floor",
      "ceil",
      "sqrt",
      "sin",
      "cos",
      "tan",
      "asin",
      "acos",
      "atan",
      "exp",
      "expm1",
      "log",
      "log2",
      "log10",
      "log1p",
      "pi",
      "at",
      "text_length",
      "text_range",
      "text_find",
      "text_replace",
      "contains",
      "page",
      "slide",
      "basic_slide",
      "title_slide",
      "title",
      "subtitle",
      "fade_in",
      "fade_out",
      "fade_at",
      "clear_color",
      "color",
      "line_color",
      "line_width",
      "texture_wrap",
      "texture_transform",
      "texture",
      "scale_?x",
      "scale_?y",
      "scale_?z?",
      "translate_?x",
      "translate_?y",
      "translate_?z?",
      "rotate_?x",
      "rotate_?y",
      "rotate_?z?",
      "rectangle",
      "circle",
      "ellipse",
      "sphere",
      "path",
      "line_to",
      "move_to",
      "quad_to",
      "curve_to",
      "theme",
      "background",
      "contents",
      "locally",
      "time",
      "mouse_?x",
      "mouse_?y",
      "mouse_buttons"
    ], i = [
      "ObjectLoader",
      "Animate",
      "MovieCredits",
      "Slides",
      "Filters",
      "Shading",
      "Materials",
      "LensFlare",
      "Mapping",
      "VLCAudioVideo",
      "StereoDecoder",
      "PointCloud",
      "NetworkAccess",
      "RemoteControl",
      "RegExp",
      "ChromaKey",
      "Snowfall",
      "NodeJS",
      "Speech",
      "Charts"
    ], o = {
      $pattern: /[a-zA-Z][a-zA-Z0-9_?]*/,
      keyword: n,
      literal: [
        "true",
        "false",
        "nil"
      ],
      built_in: r.concat(i)
    }, s = {
      className: "string",
      begin: '"',
      end: '"',
      illegal: "\\n"
    }, l = {
      className: "string",
      begin: "'",
      end: "'",
      illegal: "\\n"
    }, u = {
      className: "string",
      begin: "<<",
      end: ">>"
    }, c = {
      className: "number",
      begin: "[0-9]+#[0-9A-Z_]+(\\.[0-9-A-Z_]+)?#?([Ee][+-]?[0-9]+)?"
    }, d = {
      beginKeywords: "import",
      end: "$",
      keywords: o,
      contains: [s]
    }, f = {
      className: "function",
      begin: /[a-z][^\n]*->/,
      returnBegin: !0,
      end: /->/,
      contains: [
        t.inherit(t.TITLE_MODE, { starts: {
          endsWithParent: !0,
          keywords: o
        } })
      ]
    };
    return {
      name: "XL",
      aliases: ["tao"],
      keywords: o,
      contains: [
        t.C_LINE_COMMENT_MODE,
        t.C_BLOCK_COMMENT_MODE,
        s,
        l,
        u,
        f,
        d,
        c,
        t.NUMBER_MODE
      ]
    };
  }
  return Hy = e, Hy;
}
var zy, ZL;
function ote() {
  if (ZL) return zy;
  ZL = 1;
  function e(t) {
    return {
      name: "XQuery",
      aliases: [
        "xpath",
        "xq",
        "xqm"
      ],
      case_insensitive: !1,
      illegal: /(proc)|(abstract)|(extends)|(until)|(#)/,
      keywords: {
        $pattern: /[a-zA-Z$][a-zA-Z0-9_:-]*/,
        keyword: [
          "module",
          "schema",
          "namespace",
          "boundary-space",
          "preserve",
          "no-preserve",
          "strip",
          "default",
          "collation",
          "base-uri",
          "ordering",
          "context",
          "decimal-format",
          "decimal-separator",
          "copy-namespaces",
          "empty-sequence",
          "except",
          "exponent-separator",
          "external",
          "grouping-separator",
          "inherit",
          "no-inherit",
          "lax",
          "minus-sign",
          "per-mille",
          "percent",
          "schema-attribute",
          "schema-element",
          "strict",
          "unordered",
          "zero-digit",
          "declare",
          "import",
          "option",
          "function",
          "validate",
          "variable",
          "for",
          "at",
          "in",
          "let",
          "where",
          "order",
          "group",
          "by",
          "return",
          "if",
          "then",
          "else",
          "tumbling",
          "sliding",
          "window",
          "start",
          "when",
          "only",
          "end",
          "previous",
          "next",
          "stable",
          "ascending",
          "descending",
          "allowing",
          "empty",
          "greatest",
          "least",
          "some",
          "every",
          "satisfies",
          "switch",
          "case",
          "typeswitch",
          "try",
          "catch",
          "and",
          "or",
          "to",
          "union",
          "intersect",
          "instance",
          "of",
          "treat",
          "as",
          "castable",
          "cast",
          "map",
          "array",
          "delete",
          "insert",
          "into",
          "replace",
          "value",
          "rename",
          "copy",
          "modify",
          "update"
        ],
        type: [
          "item",
          "document-node",
          "node",
          "attribute",
          "document",
          "element",
          "comment",
          "namespace",
          "namespace-node",
          "processing-instruction",
          "text",
          "construction",
          "xs:anyAtomicType",
          "xs:untypedAtomic",
          "xs:duration",
          "xs:time",
          "xs:decimal",
          "xs:float",
          "xs:double",
          "xs:gYearMonth",
          "xs:gYear",
          "xs:gMonthDay",
          "xs:gMonth",
          "xs:gDay",
          "xs:boolean",
          "xs:base64Binary",
          "xs:hexBinary",
          "xs:anyURI",
          "xs:QName",
          "xs:NOTATION",
          "xs:dateTime",
          "xs:dateTimeStamp",
          "xs:date",
          "xs:string",
          "xs:normalizedString",
          "xs:token",
          "xs:language",
          "xs:NMTOKEN",
          "xs:Name",
          "xs:NCName",
          "xs:ID",
          "xs:IDREF",
          "xs:ENTITY",
          "xs:integer",
          "xs:nonPositiveInteger",
          "xs:negativeInteger",
          "xs:long",
          "xs:int",
          "xs:short",
          "xs:byte",
          "xs:nonNegativeInteger",
          "xs:unisignedLong",
          "xs:unsignedInt",
          "xs:unsignedShort",
          "xs:unsignedByte",
          "xs:positiveInteger",
          "xs:yearMonthDuration",
          "xs:dayTimeDuration"
        ],
        literal: [
          "eq",
          "ne",
          "lt",
          "le",
          "gt",
          "ge",
          "is",
          "self::",
          "child::",
          "descendant::",
          "descendant-or-self::",
          "attribute::",
          "following::",
          "following-sibling::",
          "parent::",
          "ancestor::",
          "ancestor-or-self::",
          "preceding::",
          "preceding-sibling::",
          "NaN"
        ]
      },
      contains: [
        {
          className: "variable",
          begin: /[$][\w\-:]+/
        },
        {
          className: "built_in",
          variants: [
            {
              begin: /\barray:/,
              end: /(?:append|filter|flatten|fold-(?:left|right)|for-each(?:-pair)?|get|head|insert-before|join|put|remove|reverse|size|sort|subarray|tail)\b/
            },
            {
              begin: /\bmap:/,
              end: /(?:contains|entry|find|for-each|get|keys|merge|put|remove|size)\b/
            },
            {
              begin: /\bmath:/,
              end: /(?:a(?:cos|sin|tan[2]?)|cos|exp(?:10)?|log(?:10)?|pi|pow|sin|sqrt|tan)\b/
            },
            {
              begin: /\bop:/,
              end: /\(/,
              excludeEnd: !0
            },
            {
              begin: /\bfn:/,
              end: /\(/,
              excludeEnd: !0
            },
            // do not highlight inbuilt strings as variable or xml element names
            { begin: /[^</$:'"-]\b(?:abs|accumulator-(?:after|before)|adjust-(?:date(?:Time)?|time)-to-timezone|analyze-string|apply|available-(?:environment-variables|system-properties)|avg|base-uri|boolean|ceiling|codepoints?-(?:equal|to-string)|collation-key|collection|compare|concat|contains(?:-token)?|copy-of|count|current(?:-)?(?:date(?:Time)?|time|group(?:ing-key)?|output-uri|merge-(?:group|key))?data|dateTime|days?-from-(?:date(?:Time)?|duration)|deep-equal|default-(?:collation|language)|distinct-values|document(?:-uri)?|doc(?:-available)?|element-(?:available|with-id)|empty|encode-for-uri|ends-with|environment-variable|error|escape-html-uri|exactly-one|exists|false|filter|floor|fold-(?:left|right)|for-each(?:-pair)?|format-(?:date(?:Time)?|time|integer|number)|function-(?:arity|available|lookup|name)|generate-id|has-children|head|hours-from-(?:dateTime|duration|time)|id(?:ref)?|implicit-timezone|in-scope-prefixes|index-of|innermost|insert-before|iri-to-uri|json-(?:doc|to-xml)|key|lang|last|load-xquery-module|local-name(?:-from-QName)?|(?:lower|upper)-case|matches|max|minutes-from-(?:dateTime|duration|time)|min|months?-from-(?:date(?:Time)?|duration)|name(?:space-uri-?(?:for-prefix|from-QName)?)?|nilled|node-name|normalize-(?:space|unicode)|not|number|one-or-more|outermost|parse-(?:ietf-date|json)|path|position|(?:prefix-from-)?QName|random-number-generator|regex-group|remove|replace|resolve-(?:QName|uri)|reverse|root|round(?:-half-to-even)?|seconds-from-(?:dateTime|duration|time)|snapshot|sort|starts-with|static-base-uri|stream-available|string-?(?:join|length|to-codepoints)?|subsequence|substring-?(?:after|before)?|sum|system-property|tail|timezone-from-(?:date(?:Time)?|time)|tokenize|trace|trans(?:form|late)|true|type-available|unordered|unparsed-(?:entity|text)?-?(?:public-id|uri|available|lines)?|uri-collection|xml-to-json|years?-from-(?:date(?:Time)?|duration)|zero-or-one)\b/ },
            {
              begin: /\blocal:/,
              end: /\(/,
              excludeEnd: !0
            },
            {
              begin: /\bzip:/,
              end: /(?:zip-file|(?:xml|html|text|binary)-entry| (?:update-)?entries)\b/
            },
            {
              begin: /\b(?:util|db|functx|app|xdmp|xmldb):/,
              end: /\(/,
              excludeEnd: !0
            }
          ]
        },
        {
          className: "string",
          variants: [
            {
              begin: /"/,
              end: /"/,
              contains: [
                {
                  begin: /""/,
                  relevance: 0
                }
              ]
            },
            {
              begin: /'/,
              end: /'/,
              contains: [
                {
                  begin: /''/,
                  relevance: 0
                }
              ]
            }
          ]
        },
        {
          className: "number",
          begin: /(\b0[0-7_]+)|(\b0x[0-9a-fA-F_]+)|(\b[1-9][0-9_]*(\.[0-9_]+)?)|[0_]\b/,
          relevance: 0
        },
        {
          className: "comment",
          begin: /\(:/,
          end: /:\)/,
          relevance: 10,
          contains: [
            {
              className: "doctag",
              begin: /@\w+/
            }
          ]
        },
        {
          className: "meta",
          begin: /%[\w\-:]+/
        },
        {
          className: "title",
          begin: /\bxquery version "[13]\.[01]"\s?(?:encoding ".+")?/,
          end: /;/
        },
        {
          beginKeywords: "element attribute comment document processing-instruction",
          end: /\{/,
          excludeEnd: !0
        },
        {
          begin: /<([\w._:-]+)(\s+\S*=('|").*('|"))?>/,
          end: /(\/[\w._:-]+>)/,
          subLanguage: "xml",
          contains: [
            {
              begin: /\{/,
              end: /\}/,
              subLanguage: "xquery"
            },
            "self"
          ]
        }
      ]
    };
  }
  return zy = e, zy;
}
var Vy, JL;
function ste() {
  if (JL) return Vy;
  JL = 1;
  function e(t) {
    const n = {
      className: "string",
      contains: [t.BACKSLASH_ESCAPE],
      variants: [
        t.inherit(t.APOS_STRING_MODE, { illegal: null }),
        t.inherit(t.QUOTE_STRING_MODE, { illegal: null })
      ]
    }, r = t.UNDERSCORE_TITLE_MODE, i = { variants: [
      t.BINARY_NUMBER_MODE,
      t.C_NUMBER_MODE
    ] }, a = (
      // classes and objects
      "namespace class interface use extends function return abstract final public protected private static deprecated throw try catch Exception echo empty isset instanceof unset let var new const self require if else elseif switch case default do while loop for continue break likely unlikely __LINE__ __FILE__ __DIR__ __FUNCTION__ __CLASS__ __TRAIT__ __METHOD__ __NAMESPACE__ array boolean float double integer object resource string char long unsigned bool int uint ulong uchar true false null undefined"
    );
    return {
      name: "Zephir",
      aliases: ["zep"],
      keywords: a,
      contains: [
        t.C_LINE_COMMENT_MODE,
        t.COMMENT(
          /\/\*/,
          /\*\//,
          { contains: [
            {
              className: "doctag",
              begin: /@[A-Za-z]+/
            }
          ] }
        ),
        {
          className: "string",
          begin: /<<<['"]?\w+['"]?$/,
          end: /^\w+;/,
          contains: [t.BACKSLASH_ESCAPE]
        },
        {
          // swallow composed identifiers to avoid parsing them as keywords
          begin: /(::|->)+[a-zA-Z_\x7f-\xff][a-zA-Z0-9_\x7f-\xff]*/
        },
        {
          className: "function",
          beginKeywords: "function fn",
          end: /[;{]/,
          excludeEnd: !0,
          illegal: /\$|\[|%/,
          contains: [
            r,
            {
              className: "params",
              begin: /\(/,
              end: /\)/,
              keywords: a,
              contains: [
                "self",
                t.C_BLOCK_COMMENT_MODE,
                n,
                i
              ]
            }
          ]
        },
        {
          className: "class",
          beginKeywords: "class interface",
          end: /\{/,
          excludeEnd: !0,
          illegal: /[:($"]/,
          contains: [
            { beginKeywords: "extends implements" },
            r
          ]
        },
        {
          beginKeywords: "namespace",
          end: /;/,
          illegal: /[.']/,
          contains: [r]
        },
        {
          beginKeywords: "use",
          end: /;/,
          contains: [r]
        },
        {
          begin: /=>/
          // No markup, just a relevance booster
        },
        n,
        i
      ]
    };
  }
  return Vy = e, Vy;
}
var le = DX;
le.registerLanguage("1c", IX());
le.registerLanguage("abnf", LX());
le.registerLanguage("accesslog", kX());
le.registerLanguage("actionscript", MX());
le.registerLanguage("ada", PX());
le.registerLanguage("angelscript", FX());
le.registerLanguage("apache", BX());
le.registerLanguage("applescript", $X());
le.registerLanguage("arcade", UX());
le.registerLanguage("arduino", qX());
le.registerLanguage("armasm", GX());
le.registerLanguage("xml", YX());
le.registerLanguage("asciidoc", HX());
le.registerLanguage("aspectj", zX());
le.registerLanguage("autohotkey", VX());
le.registerLanguage("autoit", WX());
le.registerLanguage("avrasm", KX());
le.registerLanguage("awk", jX());
le.registerLanguage("axapta", QX());
le.registerLanguage("bash", XX());
le.registerLanguage("basic", ZX());
le.registerLanguage("bnf", JX());
le.registerLanguage("brainfuck", eZ());
le.registerLanguage("c", tZ());
le.registerLanguage("cal", nZ());
le.registerLanguage("capnproto", rZ());
le.registerLanguage("ceylon", iZ());
le.registerLanguage("clean", aZ());
le.registerLanguage("clojure", oZ());
le.registerLanguage("clojure-repl", sZ());
le.registerLanguage("cmake", lZ());
le.registerLanguage("coffeescript", uZ());
le.registerLanguage("coq", cZ());
le.registerLanguage("cos", dZ());
le.registerLanguage("cpp", fZ());
le.registerLanguage("crmsh", pZ());
le.registerLanguage("crystal", mZ());
le.registerLanguage("csharp", hZ());
le.registerLanguage("csp", gZ());
le.registerLanguage("css", _Z());
le.registerLanguage("d", vZ());
le.registerLanguage("markdown", bZ());
le.registerLanguage("dart", EZ());
le.registerLanguage("delphi", SZ());
le.registerLanguage("diff", yZ());
le.registerLanguage("django", TZ());
le.registerLanguage("dns", CZ());
le.registerLanguage("dockerfile", AZ());
le.registerLanguage("dos", OZ());
le.registerLanguage("dsconfig", RZ());
le.registerLanguage("dts", wZ());
le.registerLanguage("dust", xZ());
le.registerLanguage("ebnf", NZ());
le.registerLanguage("elixir", DZ());
le.registerLanguage("elm", IZ());
le.registerLanguage("ruby", LZ());
le.registerLanguage("erb", kZ());
le.registerLanguage("erlang-repl", MZ());
le.registerLanguage("erlang", PZ());
le.registerLanguage("excel", FZ());
le.registerLanguage("fix", BZ());
le.registerLanguage("flix", $Z());
le.registerLanguage("fortran", UZ());
le.registerLanguage("fsharp", qZ());
le.registerLanguage("gams", GZ());
le.registerLanguage("gauss", YZ());
le.registerLanguage("gcode", HZ());
le.registerLanguage("gherkin", zZ());
le.registerLanguage("glsl", VZ());
le.registerLanguage("gml", WZ());
le.registerLanguage("go", KZ());
le.registerLanguage("golo", jZ());
le.registerLanguage("gradle", QZ());
le.registerLanguage("graphql", XZ());
le.registerLanguage("groovy", ZZ());
le.registerLanguage("haml", JZ());
le.registerLanguage("handlebars", eJ());
le.registerLanguage("haskell", tJ());
le.registerLanguage("haxe", nJ());
le.registerLanguage("hsp", rJ());
le.registerLanguage("http", iJ());
le.registerLanguage("hy", aJ());
le.registerLanguage("inform7", oJ());
le.registerLanguage("ini", sJ());
le.registerLanguage("irpf90", lJ());
le.registerLanguage("isbl", uJ());
le.registerLanguage("java", cJ());
le.registerLanguage("javascript", dJ());
le.registerLanguage("jboss-cli", fJ());
le.registerLanguage("json", pJ());
le.registerLanguage("julia", mJ());
le.registerLanguage("julia-repl", hJ());
le.registerLanguage("kotlin", gJ());
le.registerLanguage("lasso", _J());
le.registerLanguage("latex", vJ());
le.registerLanguage("ldif", bJ());
le.registerLanguage("leaf", EJ());
le.registerLanguage("less", SJ());
le.registerLanguage("lisp", yJ());
le.registerLanguage("livecodeserver", TJ());
le.registerLanguage("livescript", CJ());
le.registerLanguage("llvm", AJ());
le.registerLanguage("lsl", OJ());
le.registerLanguage("lua", RJ());
le.registerLanguage("makefile", wJ());
le.registerLanguage("mathematica", xJ());
le.registerLanguage("matlab", NJ());
le.registerLanguage("maxima", DJ());
le.registerLanguage("mel", IJ());
le.registerLanguage("mercury", LJ());
le.registerLanguage("mipsasm", kJ());
le.registerLanguage("mizar", MJ());
le.registerLanguage("perl", PJ());
le.registerLanguage("mojolicious", FJ());
le.registerLanguage("monkey", BJ());
le.registerLanguage("moonscript", $J());
le.registerLanguage("n1ql", UJ());
le.registerLanguage("nestedtext", qJ());
le.registerLanguage("nginx", GJ());
le.registerLanguage("nim", YJ());
le.registerLanguage("nix", HJ());
le.registerLanguage("node-repl", zJ());
le.registerLanguage("nsis", VJ());
le.registerLanguage("objectivec", WJ());
le.registerLanguage("ocaml", KJ());
le.registerLanguage("openscad", jJ());
le.registerLanguage("oxygene", QJ());
le.registerLanguage("parser3", XJ());
le.registerLanguage("pf", ZJ());
le.registerLanguage("pgsql", JJ());
le.registerLanguage("php", eee());
le.registerLanguage("php-template", tee());
le.registerLanguage("plaintext", nee());
le.registerLanguage("pony", ree());
le.registerLanguage("powershell", iee());
le.registerLanguage("processing", aee());
le.registerLanguage("profile", oee());
le.registerLanguage("prolog", see());
le.registerLanguage("properties", lee());
le.registerLanguage("protobuf", uee());
le.registerLanguage("puppet", cee());
le.registerLanguage("purebasic", dee());
le.registerLanguage("python", fee());
le.registerLanguage("python-repl", pee());
le.registerLanguage("q", mee());
le.registerLanguage("qml", hee());
le.registerLanguage("r", gee());
le.registerLanguage("reasonml", _ee());
le.registerLanguage("rib", vee());
le.registerLanguage("roboconf", bee());
le.registerLanguage("routeros", Eee());
le.registerLanguage("rsl", See());
le.registerLanguage("ruleslanguage", yee());
le.registerLanguage("rust", Tee());
le.registerLanguage("sas", Cee());
le.registerLanguage("scala", Aee());
le.registerLanguage("scheme", Oee());
le.registerLanguage("scilab", Ree());
le.registerLanguage("scss", wee());
le.registerLanguage("shell", xee());
le.registerLanguage("smali", Nee());
le.registerLanguage("smalltalk", Dee());
le.registerLanguage("sml", Iee());
le.registerLanguage("sqf", Lee());
le.registerLanguage("sql", kee());
le.registerLanguage("stan", Mee());
le.registerLanguage("stata", Pee());
le.registerLanguage("step21", Fee());
le.registerLanguage("stylus", Bee());
le.registerLanguage("subunit", $ee());
le.registerLanguage("swift", Uee());
le.registerLanguage("taggerscript", qee());
le.registerLanguage("yaml", Gee());
le.registerLanguage("tap", Yee());
le.registerLanguage("tcl", Hee());
le.registerLanguage("thrift", zee());
le.registerLanguage("tp", Vee());
le.registerLanguage("twig", Wee());
le.registerLanguage("typescript", Kee());
le.registerLanguage("vala", jee());
le.registerLanguage("vbnet", Qee());
le.registerLanguage("vbscript", Xee());
le.registerLanguage("vbscript-html", Zee());
le.registerLanguage("verilog", Jee());
le.registerLanguage("vhdl", ete());
le.registerLanguage("vim", tte());
le.registerLanguage("wasm", nte());
le.registerLanguage("wren", rte());
le.registerLanguage("x86asm", ite());
le.registerLanguage("xl", ate());
le.registerLanguage("xquery", ote());
le.registerLanguage("zephir", ste());
le.HighlightJS = le;
le.default = le;
var lte = le;
const tC = /* @__PURE__ */ E1(lte);
function ute(e) {
  const t = e.regex, n = new RegExp("[\\p{XID_Start}_]\\p{XID_Continue}*", "u"), r = [
    "and",
    "as",
    "assert",
    "async",
    "await",
    "break",
    "case",
    "class",
    "continue",
    "def",
    "del",
    "elif",
    "else",
    "except",
    "finally",
    "for",
    "from",
    "global",
    "if",
    "import",
    "in",
    "is",
    "lambda",
    "match",
    "nonlocal|10",
    "not",
    "or",
    "pass",
    "raise",
    "return",
    "try",
    "while",
    "with",
    "yield"
  ], s = {
    $pattern: /[A-Za-z]\w+|__\w+__/,
    keyword: r,
    built_in: [
      "__import__",
      "abs",
      "all",
      "any",
      "ascii",
      "bin",
      "bool",
      "breakpoint",
      "bytearray",
      "bytes",
      "callable",
      "chr",
      "classmethod",
      "compile",
      "complex",
      "delattr",
      "dict",
      "dir",
      "divmod",
      "enumerate",
      "eval",
      "exec",
      "filter",
      "float",
      "format",
      "frozenset",
      "getattr",
      "globals",
      "hasattr",
      "hash",
      "help",
      "hex",
      "id",
      "input",
      "int",
      "isinstance",
      "issubclass",
      "iter",
      "len",
      "list",
      "locals",
      "map",
      "max",
      "memoryview",
      "min",
      "next",
      "object",
      "oct",
      "open",
      "ord",
      "pow",
      "print",
      "property",
      "range",
      "repr",
      "reversed",
      "round",
      "set",
      "setattr",
      "slice",
      "sorted",
      "staticmethod",
      "str",
      "sum",
      "super",
      "tuple",
      "type",
      "vars",
      "zip"
    ],
    literal: [
      "__debug__",
      "Ellipsis",
      "False",
      "None",
      "NotImplemented",
      "True"
    ],
    type: [
      "Any",
      "Callable",
      "Coroutine",
      "Dict",
      "List",
      "Literal",
      "Generic",
      "Optional",
      "Sequence",
      "Set",
      "Tuple",
      "Type",
      "Union"
    ]
  }, l = {
    className: "meta",
    begin: /^(>>>|\.\.\.) /
  }, u = {
    className: "subst",
    begin: /\{/,
    end: /\}/,
    keywords: s,
    illegal: /#/
  }, c = {
    begin: /\{\{/,
    relevance: 0
  }, d = {
    className: "string",
    contains: [e.BACKSLASH_ESCAPE],
    variants: [
      {
        begin: /([uU]|[bB]|[rR]|[bB][rR]|[rR][bB])?'''/,
        end: /'''/,
        contains: [
          e.BACKSLASH_ESCAPE,
          l
        ],
        relevance: 10
      },
      {
        begin: /([uU]|[bB]|[rR]|[bB][rR]|[rR][bB])?"""/,
        end: /"""/,
        contains: [
          e.BACKSLASH_ESCAPE,
          l
        ],
        relevance: 10
      },
      {
        begin: /([fF][rR]|[rR][fF]|[fF])'''/,
        end: /'''/,
        contains: [
          e.BACKSLASH_ESCAPE,
          l,
          c,
          u
        ]
      },
      {
        begin: /([fF][rR]|[rR][fF]|[fF])"""/,
        end: /"""/,
        contains: [
          e.BACKSLASH_ESCAPE,
          l,
          c,
          u
        ]
      },
      {
        begin: /([uU]|[rR])'/,
        end: /'/,
        relevance: 10
      },
      {
        begin: /([uU]|[rR])"/,
        end: /"/,
        relevance: 10
      },
      {
        begin: /([bB]|[bB][rR]|[rR][bB])'/,
        end: /'/
      },
      {
        begin: /([bB]|[bB][rR]|[rR][bB])"/,
        end: /"/
      },
      {
        begin: /([fF][rR]|[rR][fF]|[fF])'/,
        end: /'/,
        contains: [
          e.BACKSLASH_ESCAPE,
          c,
          u
        ]
      },
      {
        begin: /([fF][rR]|[rR][fF]|[fF])"/,
        end: /"/,
        contains: [
          e.BACKSLASH_ESCAPE,
          c,
          u
        ]
      },
      e.APOS_STRING_MODE,
      e.QUOTE_STRING_MODE
    ]
  }, f = "[0-9](_?[0-9])*", h = `(\\b(${f}))?\\.(${f})|\\b(${f})\\.`, m = `\\b|${r.join("|")}`, v = {
    className: "number",
    relevance: 0,
    variants: [
      // exponentfloat, pointfloat
      // https://docs.python.org/3.9/reference/lexical_analysis.html#floating-point-literals
      // optionally imaginary
      // https://docs.python.org/3.9/reference/lexical_analysis.html#imaginary-literals
      // Note: no leading \b because floats can start with a decimal point
      // and we don't want to mishandle e.g. `fn(.5)`,
      // no trailing \b for pointfloat because it can end with a decimal point
      // and we don't want to mishandle e.g. `0..hex()`; this should be safe
      // because both MUST contain a decimal point and so cannot be confused with
      // the interior part of an identifier
      {
        begin: `(\\b(${f})|(${h}))[eE][+-]?(${f})[jJ]?(?=${m})`
      },
      {
        begin: `(${h})[jJ]?`
      },
      // decinteger, bininteger, octinteger, hexinteger
      // https://docs.python.org/3.9/reference/lexical_analysis.html#integer-literals
      // optionally "long" in Python 2
      // https://docs.python.org/2.7/reference/lexical_analysis.html#integer-and-long-integer-literals
      // decinteger is optionally imaginary
      // https://docs.python.org/3.9/reference/lexical_analysis.html#imaginary-literals
      {
        begin: `\\b([1-9](_?[0-9])*|0+(_?0)*)[lLjJ]?(?=${m})`
      },
      {
        begin: `\\b0[bB](_?[01])+[lL]?(?=${m})`
      },
      {
        begin: `\\b0[oO](_?[0-7])+[lL]?(?=${m})`
      },
      {
        begin: `\\b0[xX](_?[0-9a-fA-F])+[lL]?(?=${m})`
      },
      // imagnumber (digitpart-based)
      // https://docs.python.org/3.9/reference/lexical_analysis.html#imaginary-literals
      {
        begin: `\\b(${f})[jJ](?=${m})`
      }
    ]
  }, b = {
    className: "comment",
    begin: t.lookahead(/# type:/),
    end: /$/,
    keywords: s,
    contains: [
      {
        // prevent keywords from coloring `type`
        begin: /# type:/
      },
      // comment within a datatype comment includes no keywords
      {
        begin: /#/,
        end: /\b\B/,
        endsWithParent: !0
      }
    ]
  }, y = {
    className: "params",
    variants: [
      // Exclude params in functions without params
      {
        className: "",
        begin: /\(\s*\)/,
        skip: !0
      },
      {
        begin: /\(/,
        end: /\)/,
        excludeBegin: !0,
        excludeEnd: !0,
        keywords: s,
        contains: [
          "self",
          l,
          v,
          d,
          e.HASH_COMMENT_MODE
        ]
      }
    ]
  };
  return u.contains = [
    d,
    v,
    l
  ], {
    name: "Python",
    aliases: [
      "py",
      "gyp",
      "ipython"
    ],
    unicodeRegex: !0,
    keywords: s,
    illegal: /(<\/|\?)|=>/,
    contains: [
      l,
      v,
      {
        // very common convention
        begin: /\bself\b/
      },
      {
        // eat "if" prior to string so that it won't accidentally be
        // labeled as an f-string
        beginKeywords: "if",
        relevance: 0
      },
      d,
      b,
      e.HASH_COMMENT_MODE,
      {
        match: [
          /\bdef/,
          /\s+/,
          n
        ],
        scope: {
          1: "keyword",
          3: "title.function"
        },
        contains: [y]
      },
      {
        variants: [
          {
            match: [
              /\bclass/,
              /\s+/,
              n,
              /\s*/,
              /\(\s*/,
              n,
              /\s*\)/
            ]
          },
          {
            match: [
              /\bclass/,
              /\s+/,
              n
            ]
          }
        ],
        scope: {
          1: "keyword",
          3: "title.class",
          6: "title.class.inherited"
        }
      },
      {
        className: "meta",
        begin: /^[\t ]*@/,
        end: /(?=#)|$/,
        contains: [
          v,
          y,
          d
        ]
      }
    ]
  };
}
function cte(e) {
  for (var t = [], n = 1; n < arguments.length; n++)
    t[n - 1] = arguments[n];
  var r = Array.from(typeof e == "string" ? [e] : e);
  r[r.length - 1] = r[r.length - 1].replace(/\r?\n([\t ]*)$/, "");
  var i = r.reduce(function(s, l) {
    var u = l.match(/\n([\t ]+|(?!\s).)/g);
    return u ? s.concat(u.map(function(c) {
      var d, f;
      return (f = (d = c.match(/[\t ]/g)) === null || d === void 0 ? void 0 : d.length) !== null && f !== void 0 ? f : 0;
    })) : s;
  }, []);
  if (i.length) {
    var a = new RegExp(`
[	 ]{` + Math.min.apply(Math, i) + "}", "g");
    r = r.map(function(s) {
      return s.replace(a, `
`);
    });
  }
  r[0] = r[0].replace(/^\r?\n/, "");
  var o = r[0];
  return t.forEach(function(s, l) {
    var u = o.match(/(?:^|\n)( *)$/), c = u ? u[1] : "", d = s;
    typeof s == "string" && s.includes(`
`) && (d = String(s).split(`
`).map(function(f, h) {
      return h === 0 ? f : "" + c + f;
    }).join(`
`)), o += d + r[l + 1];
  }), o;
}
var QF = { exports: {} };
(function(e, t) {
  (function(n, r) {
    e.exports = r();
  })(Pc, function() {
    var n = 1e3, r = 6e4, i = 36e5, a = "millisecond", o = "second", s = "minute", l = "hour", u = "day", c = "week", d = "month", f = "quarter", h = "year", m = "date", v = "Invalid Date", b = /^(\d{4})[-/]?(\d{1,2})?[-/]?(\d{0,2})[Tt\s]*(\d{1,2})?:?(\d{1,2})?:?(\d{1,2})?[.:]?(\d+)?$/, y = /\[([^\]]+)]|Y{1,4}|M{1,4}|D{1,2}|d{1,4}|H{1,2}|h{1,2}|a|A|m{1,2}|s{1,2}|Z{1,2}|SSS/g, g = { name: "en", weekdays: "Sunday_Monday_Tuesday_Wednesday_Thursday_Friday_Saturday".split("_"), months: "January_February_March_April_May_June_July_August_September_October_November_December".split("_"), ordinal: function(L) {
      var x = ["th", "st", "nd", "rd"], I = L % 100;
      return "[" + L + (x[(I - 20) % 10] || x[I] || x[0]) + "]";
    } }, E = function(L, x, I) {
      var k = String(L);
      return !k || k.length >= x ? L : "" + Array(x + 1 - k.length).join(I) + L;
    }, S = { s: E, z: function(L) {
      var x = -L.utcOffset(), I = Math.abs(x), k = Math.floor(I / 60), B = I % 60;
      return (x <= 0 ? "+" : "-") + E(k, 2, "0") + ":" + E(B, 2, "0");
    }, m: function L(x, I) {
      if (x.date() < I.date()) return -L(I, x);
      var k = 12 * (I.year() - x.year()) + (I.month() - x.month()), B = x.clone().add(k, d), W = I - B < 0, Z = x.clone().add(k + (W ? -1 : 1), d);
      return +(-(k + (I - B) / (W ? B - Z : Z - B)) || 0);
    }, a: function(L) {
      return L < 0 ? Math.ceil(L) || 0 : Math.floor(L);
    }, p: function(L) {
      return { M: d, y: h, w: c, d: u, D: m, h: l, m: s, s: o, ms: a, Q: f }[L] || String(L || "").toLowerCase().replace(/s$/, "");
    }, u: function(L) {
      return L === void 0;
    } }, C = "en", T = {};
    T[C] = g;
    var O = "$isDayjsObject", R = function(L) {
      return L instanceof P || !(!L || !L[O]);
    }, D = function L(x, I, k) {
      var B;
      if (!x) return C;
      if (typeof x == "string") {
        var W = x.toLowerCase();
        T[W] && (B = W), I && (T[W] = I, B = W);
        var Z = x.split("-");
        if (!B && Z.length > 1) return L(Z[0]);
      } else {
        var V = x.name;
        T[V] = x, B = V;
      }
      return !k && B && (C = B), B || !k && C;
    }, q = function(L, x) {
      if (R(L)) return L.clone();
      var I = typeof x == "object" ? x : {};
      return I.date = L, I.args = arguments, new P(I);
    }, $ = S;
    $.l = D, $.i = R, $.w = function(L, x) {
      return q(L, { locale: x.$L, utc: x.$u, x: x.$x, $offset: x.$offset });
    };
    var P = function() {
      function L(I) {
        this.$L = D(I.locale, null, !0), this.parse(I), this.$x = this.$x || I.x || {}, this[O] = !0;
      }
      var x = L.prototype;
      return x.parse = function(I) {
        this.$d = function(k) {
          var B = k.date, W = k.utc;
          if (B === null) return /* @__PURE__ */ new Date(NaN);
          if ($.u(B)) return /* @__PURE__ */ new Date();
          if (B instanceof Date) return new Date(B);
          if (typeof B == "string" && !/Z$/i.test(B)) {
            var Z = B.match(b);
            if (Z) {
              var V = Z[2] - 1 || 0, K = (Z[7] || "0").substring(0, 3);
              return W ? new Date(Date.UTC(Z[1], V, Z[3] || 1, Z[4] || 0, Z[5] || 0, Z[6] || 0, K)) : new Date(Z[1], V, Z[3] || 1, Z[4] || 0, Z[5] || 0, Z[6] || 0, K);
            }
          }
          return new Date(B);
        }(I), this.init();
      }, x.init = function() {
        var I = this.$d;
        this.$y = I.getFullYear(), this.$M = I.getMonth(), this.$D = I.getDate(), this.$W = I.getDay(), this.$H = I.getHours(), this.$m = I.getMinutes(), this.$s = I.getSeconds(), this.$ms = I.getMilliseconds();
      }, x.$utils = function() {
        return $;
      }, x.isValid = function() {
        return this.$d.toString() !== v;
      }, x.isSame = function(I, k) {
        var B = q(I);
        return this.startOf(k) <= B && B <= this.endOf(k);
      }, x.isAfter = function(I, k) {
        return q(I) < this.startOf(k);
      }, x.isBefore = function(I, k) {
        return this.endOf(k) < q(I);
      }, x.$g = function(I, k, B) {
        return $.u(I) ? this[k] : this.set(B, I);
      }, x.unix = function() {
        return Math.floor(this.valueOf() / 1e3);
      }, x.valueOf = function() {
        return this.$d.getTime();
      }, x.startOf = function(I, k) {
        var B = this, W = !!$.u(k) || k, Z = $.p(I), V = function(Re, Ye) {
          var nt = $.w(B.$u ? Date.UTC(B.$y, Ye, Re) : new Date(B.$y, Ye, Re), B);
          return W ? nt : nt.endOf(u);
        }, K = function(Re, Ye) {
          return $.w(B.toDate()[Re].apply(B.toDate("s"), (W ? [0, 0, 0, 0] : [23, 59, 59, 999]).slice(Ye)), B);
        }, ne = this.$W, Ee = this.$M, oe = this.$D, ae = "set" + (this.$u ? "UTC" : "");
        switch (Z) {
          case h:
            return W ? V(1, 0) : V(31, 11);
          case d:
            return W ? V(1, Ee) : V(0, Ee + 1);
          case c:
            var pe = this.$locale().weekStart || 0, Se = (ne < pe ? ne + 7 : ne) - pe;
            return V(W ? oe - Se : oe + (6 - Se), Ee);
          case u:
          case m:
            return K(ae + "Hours", 0);
          case l:
            return K(ae + "Minutes", 1);
          case s:
            return K(ae + "Seconds", 2);
          case o:
            return K(ae + "Milliseconds", 3);
          default:
            return this.clone();
        }
      }, x.endOf = function(I) {
        return this.startOf(I, !1);
      }, x.$set = function(I, k) {
        var B, W = $.p(I), Z = "set" + (this.$u ? "UTC" : ""), V = (B = {}, B[u] = Z + "Date", B[m] = Z + "Date", B[d] = Z + "Month", B[h] = Z + "FullYear", B[l] = Z + "Hours", B[s] = Z + "Minutes", B[o] = Z + "Seconds", B[a] = Z + "Milliseconds", B)[W], K = W === u ? this.$D + (k - this.$W) : k;
        if (W === d || W === h) {
          var ne = this.clone().set(m, 1);
          ne.$d[V](K), ne.init(), this.$d = ne.set(m, Math.min(this.$D, ne.daysInMonth())).$d;
        } else V && this.$d[V](K);
        return this.init(), this;
      }, x.set = function(I, k) {
        return this.clone().$set(I, k);
      }, x.get = function(I) {
        return this[$.p(I)]();
      }, x.add = function(I, k) {
        var B, W = this;
        I = Number(I);
        var Z = $.p(k), V = function(Ee) {
          var oe = q(W);
          return $.w(oe.date(oe.date() + Math.round(Ee * I)), W);
        };
        if (Z === d) return this.set(d, this.$M + I);
        if (Z === h) return this.set(h, this.$y + I);
        if (Z === u) return V(1);
        if (Z === c) return V(7);
        var K = (B = {}, B[s] = r, B[l] = i, B[o] = n, B)[Z] || 1, ne = this.$d.getTime() + I * K;
        return $.w(ne, this);
      }, x.subtract = function(I, k) {
        return this.add(-1 * I, k);
      }, x.format = function(I) {
        var k = this, B = this.$locale();
        if (!this.isValid()) return B.invalidDate || v;
        var W = I || "YYYY-MM-DDTHH:mm:ssZ", Z = $.z(this), V = this.$H, K = this.$m, ne = this.$M, Ee = B.weekdays, oe = B.months, ae = B.meridiem, pe = function(Ye, nt, ut, Tt) {
          return Ye && (Ye[nt] || Ye(k, W)) || ut[nt].slice(0, Tt);
        }, Se = function(Ye) {
          return $.s(V % 12 || 12, Ye, "0");
        }, Re = ae || function(Ye, nt, ut) {
          var Tt = Ye < 12 ? "AM" : "PM";
          return ut ? Tt.toLowerCase() : Tt;
        };
        return W.replace(y, function(Ye, nt) {
          return nt || function(ut) {
            switch (ut) {
              case "YY":
                return String(k.$y).slice(-2);
              case "YYYY":
                return $.s(k.$y, 4, "0");
              case "M":
                return ne + 1;
              case "MM":
                return $.s(ne + 1, 2, "0");
              case "MMM":
                return pe(B.monthsShort, ne, oe, 3);
              case "MMMM":
                return pe(oe, ne);
              case "D":
                return k.$D;
              case "DD":
                return $.s(k.$D, 2, "0");
              case "d":
                return String(k.$W);
              case "dd":
                return pe(B.weekdaysMin, k.$W, Ee, 2);
              case "ddd":
                return pe(B.weekdaysShort, k.$W, Ee, 3);
              case "dddd":
                return Ee[k.$W];
              case "H":
                return String(V);
              case "HH":
                return $.s(V, 2, "0");
              case "h":
                return Se(1);
              case "hh":
                return Se(2);
              case "a":
                return Re(V, K, !0);
              case "A":
                return Re(V, K, !1);
              case "m":
                return String(K);
              case "mm":
                return $.s(K, 2, "0");
              case "s":
                return String(k.$s);
              case "ss":
                return $.s(k.$s, 2, "0");
              case "SSS":
                return $.s(k.$ms, 3, "0");
              case "Z":
                return Z;
            }
            return null;
          }(Ye) || Z.replace(":", "");
        });
      }, x.utcOffset = function() {
        return 15 * -Math.round(this.$d.getTimezoneOffset() / 15);
      }, x.diff = function(I, k, B) {
        var W, Z = this, V = $.p(k), K = q(I), ne = (K.utcOffset() - this.utcOffset()) * r, Ee = this - K, oe = function() {
          return $.m(Z, K);
        };
        switch (V) {
          case h:
            W = oe() / 12;
            break;
          case d:
            W = oe();
            break;
          case f:
            W = oe() / 3;
            break;
          case c:
            W = (Ee - ne) / 6048e5;
            break;
          case u:
            W = (Ee - ne) / 864e5;
            break;
          case l:
            W = Ee / i;
            break;
          case s:
            W = Ee / r;
            break;
          case o:
            W = Ee / n;
            break;
          default:
            W = Ee;
        }
        return B ? W : $.a(W);
      }, x.daysInMonth = function() {
        return this.endOf(d).$D;
      }, x.$locale = function() {
        return T[this.$L];
      }, x.locale = function(I, k) {
        if (!I) return this.$L;
        var B = this.clone(), W = D(I, k, !0);
        return W && (B.$L = W), B;
      }, x.clone = function() {
        return $.w(this.$d, this);
      }, x.toDate = function() {
        return new Date(this.valueOf());
      }, x.toJSON = function() {
        return this.isValid() ? this.toISOString() : null;
      }, x.toISOString = function() {
        return this.$d.toISOString();
      }, x.toString = function() {
        return this.$d.toUTCString();
      }, L;
    }(), Y = P.prototype;
    return q.prototype = Y, [["$ms", a], ["$s", o], ["$m", s], ["$H", l], ["$W", u], ["$M", d], ["$y", h], ["$D", m]].forEach(function(L) {
      Y[L[1]] = function(x) {
        return this.$g(x, L[0], L[1]);
      };
    }), q.extend = function(L, x) {
      return L.$i || (L(x, P, q), L.$i = !0), q;
    }, q.locale = D, q.isDayjs = R, q.unix = function(L) {
      return q(1e3 * L);
    }, q.en = T[C], q.Ls = T, q.p = {}, q;
  });
})(QF);
var dte = QF.exports;
const fte = /* @__PURE__ */ E1(dte);
var XF = {};
(function(e) {
  Object.defineProperty(e, "__esModule", { value: !0 }), e.sanitizeUrl = e.BLANK_URL = void 0;
  var t = /^([^\w]*)(javascript|data|vbscript)/im, n = /&#(\w+)(^\w|;)?/g, r = /&(newline|tab);/gi, i = /[\u0000-\u001F\u007F-\u009F\u2000-\u200D\uFEFF]/gim, a = /^.+(:|&colon;)/gim, o = [".", "/"];
  e.BLANK_URL = "about:blank";
  function s(c) {
    return o.indexOf(c[0]) > -1;
  }
  function l(c) {
    var d = c.replace(i, "");
    return d.replace(n, function(f, h) {
      return String.fromCharCode(h);
    });
  }
  function u(c) {
    if (!c)
      return e.BLANK_URL;
    var d = l(c).replace(r, "").replace(i, "").trim();
    if (!d)
      return e.BLANK_URL;
    if (s(d))
      return d;
    var f = d.match(a);
    if (!f)
      return d;
    var h = f[0];
    return t.test(h) ? e.BLANK_URL : d;
  }
  e.sanitizeUrl = u;
})(XF);
var pte = { value: () => {
} };
function ZF() {
  for (var e = 0, t = arguments.length, n = {}, r; e < t; ++e) {
    if (!(r = arguments[e] + "") || r in n || /[\s.]/.test(r)) throw new Error("illegal type: " + r);
    n[r] = [];
  }
  return new og(n);
}
function og(e) {
  this._ = e;
}
function mte(e, t) {
  return e.trim().split(/^|\s+/).map(function(n) {
    var r = "", i = n.indexOf(".");
    if (i >= 0 && (r = n.slice(i + 1), n = n.slice(0, i)), n && !t.hasOwnProperty(n)) throw new Error("unknown type: " + n);
    return { type: n, name: r };
  });
}
og.prototype = ZF.prototype = {
  constructor: og,
  on: function(e, t) {
    var n = this._, r = mte(e + "", n), i, a = -1, o = r.length;
    if (arguments.length < 2) {
      for (; ++a < o; ) if ((i = (e = r[a]).type) && (i = hte(n[i], e.name))) return i;
      return;
    }
    if (t != null && typeof t != "function") throw new Error("invalid callback: " + t);
    for (; ++a < o; )
      if (i = (e = r[a]).type) n[i] = ek(n[i], e.name, t);
      else if (t == null) for (i in n) n[i] = ek(n[i], e.name, null);
    return this;
  },
  copy: function() {
    var e = {}, t = this._;
    for (var n in t) e[n] = t[n].slice();
    return new og(e);
  },
  call: function(e, t) {
    if ((i = arguments.length - 2) > 0) for (var n = new Array(i), r = 0, i, a; r < i; ++r) n[r] = arguments[r + 2];
    if (!this._.hasOwnProperty(e)) throw new Error("unknown type: " + e);
    for (a = this._[e], r = 0, i = a.length; r < i; ++r) a[r].value.apply(t, n);
  },
  apply: function(e, t, n) {
    if (!this._.hasOwnProperty(e)) throw new Error("unknown type: " + e);
    for (var r = this._[e], i = 0, a = r.length; i < a; ++i) r[i].value.apply(t, n);
  }
};
function hte(e, t) {
  for (var n = 0, r = e.length, i; n < r; ++n)
    if ((i = e[n]).name === t)
      return i.value;
}
function ek(e, t, n) {
  for (var r = 0, i = e.length; r < i; ++r)
    if (e[r].name === t) {
      e[r] = pte, e = e.slice(0, r).concat(e.slice(r + 1));
      break;
    }
  return n != null && e.push({ name: t, value: n }), e;
}
var nC = "http://www.w3.org/1999/xhtml";
const tk = {
  svg: "http://www.w3.org/2000/svg",
  xhtml: nC,
  xlink: "http://www.w3.org/1999/xlink",
  xml: "http://www.w3.org/XML/1998/namespace",
  xmlns: "http://www.w3.org/2000/xmlns/"
};
function G_(e) {
  var t = e += "", n = t.indexOf(":");
  return n >= 0 && (t = e.slice(0, n)) !== "xmlns" && (e = e.slice(n + 1)), tk.hasOwnProperty(t) ? { space: tk[t], local: e } : e;
}
function gte(e) {
  return function() {
    var t = this.ownerDocument, n = this.namespaceURI;
    return n === nC && t.documentElement.namespaceURI === nC ? t.createElement(e) : t.createElementNS(n, e);
  };
}
function _te(e) {
  return function() {
    return this.ownerDocument.createElementNS(e.space, e.local);
  };
}
function JF(e) {
  var t = G_(e);
  return (t.local ? _te : gte)(t);
}
function vte() {
}
function A1(e) {
  return e == null ? vte : function() {
    return this.querySelector(e);
  };
}
function bte(e) {
  typeof e != "function" && (e = A1(e));
  for (var t = this._groups, n = t.length, r = new Array(n), i = 0; i < n; ++i)
    for (var a = t[i], o = a.length, s = r[i] = new Array(o), l, u, c = 0; c < o; ++c)
      (l = a[c]) && (u = e.call(l, l.__data__, c, a)) && ("__data__" in l && (u.__data__ = l.__data__), s[c] = u);
  return new Na(r, this._parents);
}
function Ete(e) {
  return e == null ? [] : Array.isArray(e) ? e : Array.from(e);
}
function Ste() {
  return [];
}
function e3(e) {
  return e == null ? Ste : function() {
    return this.querySelectorAll(e);
  };
}
function yte(e) {
  return function() {
    return Ete(e.apply(this, arguments));
  };
}
function Tte(e) {
  typeof e == "function" ? e = yte(e) : e = e3(e);
  for (var t = this._groups, n = t.length, r = [], i = [], a = 0; a < n; ++a)
    for (var o = t[a], s = o.length, l, u = 0; u < s; ++u)
      (l = o[u]) && (r.push(e.call(l, l.__data__, u, o)), i.push(l));
  return new Na(r, i);
}
function t3(e) {
  return function() {
    return this.matches(e);
  };
}
function n3(e) {
  return function(t) {
    return t.matches(e);
  };
}
var Cte = Array.prototype.find;
function Ate(e) {
  return function() {
    return Cte.call(this.children, e);
  };
}
function Ote() {
  return this.firstElementChild;
}
function Rte(e) {
  return this.select(e == null ? Ote : Ate(typeof e == "function" ? e : n3(e)));
}
var wte = Array.prototype.filter;
function xte() {
  return Array.from(this.children);
}
function Nte(e) {
  return function() {
    return wte.call(this.children, e);
  };
}
function Dte(e) {
  return this.selectAll(e == null ? xte : Nte(typeof e == "function" ? e : n3(e)));
}
function Ite(e) {
  typeof e != "function" && (e = t3(e));
  for (var t = this._groups, n = t.length, r = new Array(n), i = 0; i < n; ++i)
    for (var a = t[i], o = a.length, s = r[i] = [], l, u = 0; u < o; ++u)
      (l = a[u]) && e.call(l, l.__data__, u, a) && s.push(l);
  return new Na(r, this._parents);
}
function r3(e) {
  return new Array(e.length);
}
function Lte() {
  return new Na(this._enter || this._groups.map(r3), this._parents);
}
function Pg(e, t) {
  this.ownerDocument = e.ownerDocument, this.namespaceURI = e.namespaceURI, this._next = null, this._parent = e, this.__data__ = t;
}
Pg.prototype = {
  constructor: Pg,
  appendChild: function(e) {
    return this._parent.insertBefore(e, this._next);
  },
  insertBefore: function(e, t) {
    return this._parent.insertBefore(e, t);
  },
  querySelector: function(e) {
    return this._parent.querySelector(e);
  },
  querySelectorAll: function(e) {
    return this._parent.querySelectorAll(e);
  }
};
function kte(e) {
  return function() {
    return e;
  };
}
function Mte(e, t, n, r, i, a) {
  for (var o = 0, s, l = t.length, u = a.length; o < u; ++o)
    (s = t[o]) ? (s.__data__ = a[o], r[o] = s) : n[o] = new Pg(e, a[o]);
  for (; o < l; ++o)
    (s = t[o]) && (i[o] = s);
}
function Pte(e, t, n, r, i, a, o) {
  var s, l, u = /* @__PURE__ */ new Map(), c = t.length, d = a.length, f = new Array(c), h;
  for (s = 0; s < c; ++s)
    (l = t[s]) && (f[s] = h = o.call(l, l.__data__, s, t) + "", u.has(h) ? i[s] = l : u.set(h, l));
  for (s = 0; s < d; ++s)
    h = o.call(e, a[s], s, a) + "", (l = u.get(h)) ? (r[s] = l, l.__data__ = a[s], u.delete(h)) : n[s] = new Pg(e, a[s]);
  for (s = 0; s < c; ++s)
    (l = t[s]) && u.get(f[s]) === l && (i[s] = l);
}
function Fte(e) {
  return e.__data__;
}
function Bte(e, t) {
  if (!arguments.length) return Array.from(this, Fte);
  var n = t ? Pte : Mte, r = this._parents, i = this._groups;
  typeof e != "function" && (e = kte(e));
  for (var a = i.length, o = new Array(a), s = new Array(a), l = new Array(a), u = 0; u < a; ++u) {
    var c = r[u], d = i[u], f = d.length, h = $te(e.call(c, c && c.__data__, u, r)), m = h.length, v = s[u] = new Array(m), b = o[u] = new Array(m), y = l[u] = new Array(f);
    n(c, d, v, b, y, h, t);
    for (var g = 0, E = 0, S, C; g < m; ++g)
      if (S = v[g]) {
        for (g >= E && (E = g + 1); !(C = b[E]) && ++E < m; ) ;
        S._next = C || null;
      }
  }
  return o = new Na(o, r), o._enter = s, o._exit = l, o;
}
function $te(e) {
  return typeof e == "object" && "length" in e ? e : Array.from(e);
}
function Ute() {
  return new Na(this._exit || this._groups.map(r3), this._parents);
}
function qte(e, t, n) {
  var r = this.enter(), i = this, a = this.exit();
  return typeof e == "function" ? (r = e(r), r && (r = r.selection())) : r = r.append(e + ""), t != null && (i = t(i), i && (i = i.selection())), n == null ? a.remove() : n(a), r && i ? r.merge(i).order() : i;
}
function Gte(e) {
  for (var t = e.selection ? e.selection() : e, n = this._groups, r = t._groups, i = n.length, a = r.length, o = Math.min(i, a), s = new Array(i), l = 0; l < o; ++l)
    for (var u = n[l], c = r[l], d = u.length, f = s[l] = new Array(d), h, m = 0; m < d; ++m)
      (h = u[m] || c[m]) && (f[m] = h);
  for (; l < i; ++l)
    s[l] = n[l];
  return new Na(s, this._parents);
}
function Yte() {
  for (var e = this._groups, t = -1, n = e.length; ++t < n; )
    for (var r = e[t], i = r.length - 1, a = r[i], o; --i >= 0; )
      (o = r[i]) && (a && o.compareDocumentPosition(a) ^ 4 && a.parentNode.insertBefore(o, a), a = o);
  return this;
}
function Hte(e) {
  e || (e = zte);
  function t(d, f) {
    return d && f ? e(d.__data__, f.__data__) : !d - !f;
  }
  for (var n = this._groups, r = n.length, i = new Array(r), a = 0; a < r; ++a) {
    for (var o = n[a], s = o.length, l = i[a] = new Array(s), u, c = 0; c < s; ++c)
      (u = o[c]) && (l[c] = u);
    l.sort(t);
  }
  return new Na(i, this._parents).order();
}
function zte(e, t) {
  return e < t ? -1 : e > t ? 1 : e >= t ? 0 : NaN;
}
function Vte() {
  var e = arguments[0];
  return arguments[0] = this, e.apply(null, arguments), this;
}
function Wte() {
  return Array.from(this);
}
function Kte() {
  for (var e = this._groups, t = 0, n = e.length; t < n; ++t)
    for (var r = e[t], i = 0, a = r.length; i < a; ++i) {
      var o = r[i];
      if (o) return o;
    }
  return null;
}
function jte() {
  let e = 0;
  for (const t of this) ++e;
  return e;
}
function Qte() {
  return !this.node();
}
function Xte(e) {
  for (var t = this._groups, n = 0, r = t.length; n < r; ++n)
    for (var i = t[n], a = 0, o = i.length, s; a < o; ++a)
      (s = i[a]) && e.call(s, s.__data__, a, i);
  return this;
}
function Zte(e) {
  return function() {
    this.removeAttribute(e);
  };
}
function Jte(e) {
  return function() {
    this.removeAttributeNS(e.space, e.local);
  };
}
function ene(e, t) {
  return function() {
    this.setAttribute(e, t);
  };
}
function tne(e, t) {
  return function() {
    this.setAttributeNS(e.space, e.local, t);
  };
}
function nne(e, t) {
  return function() {
    var n = t.apply(this, arguments);
    n == null ? this.removeAttribute(e) : this.setAttribute(e, n);
  };
}
function rne(e, t) {
  return function() {
    var n = t.apply(this, arguments);
    n == null ? this.removeAttributeNS(e.space, e.local) : this.setAttributeNS(e.space, e.local, n);
  };
}
function ine(e, t) {
  var n = G_(e);
  if (arguments.length < 2) {
    var r = this.node();
    return n.local ? r.getAttributeNS(n.space, n.local) : r.getAttribute(n);
  }
  return this.each((t == null ? n.local ? Jte : Zte : typeof t == "function" ? n.local ? rne : nne : n.local ? tne : ene)(n, t));
}
function i3(e) {
  return e.ownerDocument && e.ownerDocument.defaultView || e.document && e || e.defaultView;
}
function ane(e) {
  return function() {
    this.style.removeProperty(e);
  };
}
function one(e, t, n) {
  return function() {
    this.style.setProperty(e, t, n);
  };
}
function sne(e, t, n) {
  return function() {
    var r = t.apply(this, arguments);
    r == null ? this.style.removeProperty(e) : this.style.setProperty(e, r, n);
  };
}
function lne(e, t, n) {
  return arguments.length > 1 ? this.each((t == null ? ane : typeof t == "function" ? sne : one)(e, t, n ?? "")) : ud(this.node(), e);
}
function ud(e, t) {
  return e.style.getPropertyValue(t) || i3(e).getComputedStyle(e, null).getPropertyValue(t);
}
function une(e) {
  return function() {
    delete this[e];
  };
}
function cne(e, t) {
  return function() {
    this[e] = t;
  };
}
function dne(e, t) {
  return function() {
    var n = t.apply(this, arguments);
    n == null ? delete this[e] : this[e] = n;
  };
}
function fne(e, t) {
  return arguments.length > 1 ? this.each((t == null ? une : typeof t == "function" ? dne : cne)(e, t)) : this.node()[e];
}
function a3(e) {
  return e.trim().split(/^|\s+/);
}
function O1(e) {
  return e.classList || new o3(e);
}
function o3(e) {
  this._node = e, this._names = a3(e.getAttribute("class") || "");
}
o3.prototype = {
  add: function(e) {
    var t = this._names.indexOf(e);
    t < 0 && (this._names.push(e), this._node.setAttribute("class", this._names.join(" ")));
  },
  remove: function(e) {
    var t = this._names.indexOf(e);
    t >= 0 && (this._names.splice(t, 1), this._node.setAttribute("class", this._names.join(" ")));
  },
  contains: function(e) {
    return this._names.indexOf(e) >= 0;
  }
};
function s3(e, t) {
  for (var n = O1(e), r = -1, i = t.length; ++r < i; ) n.add(t[r]);
}
function l3(e, t) {
  for (var n = O1(e), r = -1, i = t.length; ++r < i; ) n.remove(t[r]);
}
function pne(e) {
  return function() {
    s3(this, e);
  };
}
function mne(e) {
  return function() {
    l3(this, e);
  };
}
function hne(e, t) {
  return function() {
    (t.apply(this, arguments) ? s3 : l3)(this, e);
  };
}
function gne(e, t) {
  var n = a3(e + "");
  if (arguments.length < 2) {
    for (var r = O1(this.node()), i = -1, a = n.length; ++i < a; ) if (!r.contains(n[i])) return !1;
    return !0;
  }
  return this.each((typeof t == "function" ? hne : t ? pne : mne)(n, t));
}
function _ne() {
  this.textContent = "";
}
function vne(e) {
  return function() {
    this.textContent = e;
  };
}
function bne(e) {
  return function() {
    var t = e.apply(this, arguments);
    this.textContent = t ?? "";
  };
}
function Ene(e) {
  return arguments.length ? this.each(e == null ? _ne : (typeof e == "function" ? bne : vne)(e)) : this.node().textContent;
}
function Sne() {
  this.innerHTML = "";
}
function yne(e) {
  return function() {
    this.innerHTML = e;
  };
}
function Tne(e) {
  return function() {
    var t = e.apply(this, arguments);
    this.innerHTML = t ?? "";
  };
}
function Cne(e) {
  return arguments.length ? this.each(e == null ? Sne : (typeof e == "function" ? Tne : yne)(e)) : this.node().innerHTML;
}
function Ane() {
  this.nextSibling && this.parentNode.appendChild(this);
}
function One() {
  return this.each(Ane);
}
function Rne() {
  this.previousSibling && this.parentNode.insertBefore(this, this.parentNode.firstChild);
}
function wne() {
  return this.each(Rne);
}
function xne(e) {
  var t = typeof e == "function" ? e : JF(e);
  return this.select(function() {
    return this.appendChild(t.apply(this, arguments));
  });
}
function Nne() {
  return null;
}
function Dne(e, t) {
  var n = typeof e == "function" ? e : JF(e), r = t == null ? Nne : typeof t == "function" ? t : A1(t);
  return this.select(function() {
    return this.insertBefore(n.apply(this, arguments), r.apply(this, arguments) || null);
  });
}
function Ine() {
  var e = this.parentNode;
  e && e.removeChild(this);
}
function Lne() {
  return this.each(Ine);
}
function kne() {
  var e = this.cloneNode(!1), t = this.parentNode;
  return t ? t.insertBefore(e, this.nextSibling) : e;
}
function Mne() {
  var e = this.cloneNode(!0), t = this.parentNode;
  return t ? t.insertBefore(e, this.nextSibling) : e;
}
function Pne(e) {
  return this.select(e ? Mne : kne);
}
function Fne(e) {
  return arguments.length ? this.property("__data__", e) : this.node().__data__;
}
function Bne(e) {
  return function(t) {
    e.call(this, t, this.__data__);
  };
}
function $ne(e) {
  return e.trim().split(/^|\s+/).map(function(t) {
    var n = "", r = t.indexOf(".");
    return r >= 0 && (n = t.slice(r + 1), t = t.slice(0, r)), { type: t, name: n };
  });
}
function Une(e) {
  return function() {
    var t = this.__on;
    if (t) {
      for (var n = 0, r = -1, i = t.length, a; n < i; ++n)
        a = t[n], (!e.type || a.type === e.type) && a.name === e.name ? this.removeEventListener(a.type, a.listener, a.options) : t[++r] = a;
      ++r ? t.length = r : delete this.__on;
    }
  };
}
function qne(e, t, n) {
  return function() {
    var r = this.__on, i, a = Bne(t);
    if (r) {
      for (var o = 0, s = r.length; o < s; ++o)
        if ((i = r[o]).type === e.type && i.name === e.name) {
          this.removeEventListener(i.type, i.listener, i.options), this.addEventListener(i.type, i.listener = a, i.options = n), i.value = t;
          return;
        }
    }
    this.addEventListener(e.type, a, n), i = { type: e.type, name: e.name, value: t, listener: a, options: n }, r ? r.push(i) : this.__on = [i];
  };
}
function Gne(e, t, n) {
  var r = $ne(e + ""), i, a = r.length, o;
  if (arguments.length < 2) {
    var s = this.node().__on;
    if (s) {
      for (var l = 0, u = s.length, c; l < u; ++l)
        for (i = 0, c = s[l]; i < a; ++i)
          if ((o = r[i]).type === c.type && o.name === c.name)
            return c.value;
    }
    return;
  }
  for (s = t ? qne : Une, i = 0; i < a; ++i) this.each(s(r[i], t, n));
  return this;
}
function u3(e, t, n) {
  var r = i3(e), i = r.CustomEvent;
  typeof i == "function" ? i = new i(t, n) : (i = r.document.createEvent("Event"), n ? (i.initEvent(t, n.bubbles, n.cancelable), i.detail = n.detail) : i.initEvent(t, !1, !1)), e.dispatchEvent(i);
}
function Yne(e, t) {
  return function() {
    return u3(this, e, t);
  };
}
function Hne(e, t) {
  return function() {
    return u3(this, e, t.apply(this, arguments));
  };
}
function zne(e, t) {
  return this.each((typeof t == "function" ? Hne : Yne)(e, t));
}
function* Vne() {
  for (var e = this._groups, t = 0, n = e.length; t < n; ++t)
    for (var r = e[t], i = 0, a = r.length, o; i < a; ++i)
      (o = r[i]) && (yield o);
}
var c3 = [null];
function Na(e, t) {
  this._groups = e, this._parents = t;
}
function um() {
  return new Na([[document.documentElement]], c3);
}
function Wne() {
  return this;
}
Na.prototype = um.prototype = {
  constructor: Na,
  select: bte,
  selectAll: Tte,
  selectChild: Rte,
  selectChildren: Dte,
  filter: Ite,
  data: Bte,
  enter: Lte,
  exit: Ute,
  join: qte,
  merge: Gte,
  selection: Wne,
  order: Yte,
  sort: Hte,
  call: Vte,
  nodes: Wte,
  node: Kte,
  size: jte,
  empty: Qte,
  each: Xte,
  attr: ine,
  style: lne,
  property: fne,
  classed: gne,
  text: Ene,
  html: Cne,
  raise: One,
  lower: wne,
  append: xne,
  insert: Dne,
  remove: Lne,
  clone: Pne,
  datum: Fne,
  on: Gne,
  dispatch: zne,
  [Symbol.iterator]: Vne
};
function ja(e) {
  return typeof e == "string" ? new Na([[document.querySelector(e)]], [document.documentElement]) : new Na([[e]], c3);
}
function R1(e, t, n) {
  e.prototype = t.prototype = n, n.constructor = e;
}
function d3(e, t) {
  var n = Object.create(e.prototype);
  for (var r in t) n[r] = t[r];
  return n;
}
function cm() {
}
var Ap = 0.7, Fg = 1 / Ap, Jc = "\\s*([+-]?\\d+)\\s*", Op = "\\s*([+-]?(?:\\d*\\.)?\\d+(?:[eE][+-]?\\d+)?)\\s*", Go = "\\s*([+-]?(?:\\d*\\.)?\\d+(?:[eE][+-]?\\d+)?)%\\s*", Kne = /^#([0-9a-f]{3,8})$/, jne = new RegExp(`^rgb\\(${Jc},${Jc},${Jc}\\)$`), Qne = new RegExp(`^rgb\\(${Go},${Go},${Go}\\)$`), Xne = new RegExp(`^rgba\\(${Jc},${Jc},${Jc},${Op}\\)$`), Zne = new RegExp(`^rgba\\(${Go},${Go},${Go},${Op}\\)$`), Jne = new RegExp(`^hsl\\(${Op},${Go},${Go}\\)$`), ere = new RegExp(`^hsla\\(${Op},${Go},${Go},${Op}\\)$`), nk = {
  aliceblue: 15792383,
  antiquewhite: 16444375,
  aqua: 65535,
  aquamarine: 8388564,
  azure: 15794175,
  beige: 16119260,
  bisque: 16770244,
  black: 0,
  blanchedalmond: 16772045,
  blue: 255,
  blueviolet: 9055202,
  brown: 10824234,
  burlywood: 14596231,
  cadetblue: 6266528,
  chartreuse: 8388352,
  chocolate: 13789470,
  coral: 16744272,
  cornflowerblue: 6591981,
  cornsilk: 16775388,
  crimson: 14423100,
  cyan: 65535,
  darkblue: 139,
  darkcyan: 35723,
  darkgoldenrod: 12092939,
  darkgray: 11119017,
  darkgreen: 25600,
  darkgrey: 11119017,
  darkkhaki: 12433259,
  darkmagenta: 9109643,
  darkolivegreen: 5597999,
  darkorange: 16747520,
  darkorchid: 10040012,
  darkred: 9109504,
  darksalmon: 15308410,
  darkseagreen: 9419919,
  darkslateblue: 4734347,
  darkslategray: 3100495,
  darkslategrey: 3100495,
  darkturquoise: 52945,
  darkviolet: 9699539,
  deeppink: 16716947,
  deepskyblue: 49151,
  dimgray: 6908265,
  dimgrey: 6908265,
  dodgerblue: 2003199,
  firebrick: 11674146,
  floralwhite: 16775920,
  forestgreen: 2263842,
  fuchsia: 16711935,
  gainsboro: 14474460,
  ghostwhite: 16316671,
  gold: 16766720,
  goldenrod: 14329120,
  gray: 8421504,
  green: 32768,
  greenyellow: 11403055,
  grey: 8421504,
  honeydew: 15794160,
  hotpink: 16738740,
  indianred: 13458524,
  indigo: 4915330,
  ivory: 16777200,
  khaki: 15787660,
  lavender: 15132410,
  lavenderblush: 16773365,
  lawngreen: 8190976,
  lemonchiffon: 16775885,
  lightblue: 11393254,
  lightcoral: 15761536,
  lightcyan: 14745599,
  lightgoldenrodyellow: 16448210,
  lightgray: 13882323,
  lightgreen: 9498256,
  lightgrey: 13882323,
  lightpink: 16758465,
  lightsalmon: 16752762,
  lightseagreen: 2142890,
  lightskyblue: 8900346,
  lightslategray: 7833753,
  lightslategrey: 7833753,
  lightsteelblue: 11584734,
  lightyellow: 16777184,
  lime: 65280,
  limegreen: 3329330,
  linen: 16445670,
  magenta: 16711935,
  maroon: 8388608,
  mediumaquamarine: 6737322,
  mediumblue: 205,
  mediumorchid: 12211667,
  mediumpurple: 9662683,
  mediumseagreen: 3978097,
  mediumslateblue: 8087790,
  mediumspringgreen: 64154,
  mediumturquoise: 4772300,
  mediumvioletred: 13047173,
  midnightblue: 1644912,
  mintcream: 16121850,
  mistyrose: 16770273,
  moccasin: 16770229,
  navajowhite: 16768685,
  navy: 128,
  oldlace: 16643558,
  olive: 8421376,
  olivedrab: 7048739,
  orange: 16753920,
  orangered: 16729344,
  orchid: 14315734,
  palegoldenrod: 15657130,
  palegreen: 10025880,
  paleturquoise: 11529966,
  palevioletred: 14381203,
  papayawhip: 16773077,
  peachpuff: 16767673,
  peru: 13468991,
  pink: 16761035,
  plum: 14524637,
  powderblue: 11591910,
  purple: 8388736,
  rebeccapurple: 6697881,
  red: 16711680,
  rosybrown: 12357519,
  royalblue: 4286945,
  saddlebrown: 9127187,
  salmon: 16416882,
  sandybrown: 16032864,
  seagreen: 3050327,
  seashell: 16774638,
  sienna: 10506797,
  silver: 12632256,
  skyblue: 8900331,
  slateblue: 6970061,
  slategray: 7372944,
  slategrey: 7372944,
  snow: 16775930,
  springgreen: 65407,
  steelblue: 4620980,
  tan: 13808780,
  teal: 32896,
  thistle: 14204888,
  tomato: 16737095,
  turquoise: 4251856,
  violet: 15631086,
  wheat: 16113331,
  white: 16777215,
  whitesmoke: 16119285,
  yellow: 16776960,
  yellowgreen: 10145074
};
R1(cm, Rp, {
  copy(e) {
    return Object.assign(new this.constructor(), this, e);
  },
  displayable() {
    return this.rgb().displayable();
  },
  hex: rk,
  // Deprecated! Use color.formatHex.
  formatHex: rk,
  formatHex8: tre,
  formatHsl: nre,
  formatRgb: ik,
  toString: ik
});
function rk() {
  return this.rgb().formatHex();
}
function tre() {
  return this.rgb().formatHex8();
}
function nre() {
  return f3(this).formatHsl();
}
function ik() {
  return this.rgb().formatRgb();
}
function Rp(e) {
  var t, n;
  return e = (e + "").trim().toLowerCase(), (t = Kne.exec(e)) ? (n = t[1].length, t = parseInt(t[1], 16), n === 6 ? ak(t) : n === 3 ? new la(t >> 8 & 15 | t >> 4 & 240, t >> 4 & 15 | t & 240, (t & 15) << 4 | t & 15, 1) : n === 8 ? Fh(t >> 24 & 255, t >> 16 & 255, t >> 8 & 255, (t & 255) / 255) : n === 4 ? Fh(t >> 12 & 15 | t >> 8 & 240, t >> 8 & 15 | t >> 4 & 240, t >> 4 & 15 | t & 240, ((t & 15) << 4 | t & 15) / 255) : null) : (t = jne.exec(e)) ? new la(t[1], t[2], t[3], 1) : (t = Qne.exec(e)) ? new la(t[1] * 255 / 100, t[2] * 255 / 100, t[3] * 255 / 100, 1) : (t = Xne.exec(e)) ? Fh(t[1], t[2], t[3], t[4]) : (t = Zne.exec(e)) ? Fh(t[1] * 255 / 100, t[2] * 255 / 100, t[3] * 255 / 100, t[4]) : (t = Jne.exec(e)) ? lk(t[1], t[2] / 100, t[3] / 100, 1) : (t = ere.exec(e)) ? lk(t[1], t[2] / 100, t[3] / 100, t[4]) : nk.hasOwnProperty(e) ? ak(nk[e]) : e === "transparent" ? new la(NaN, NaN, NaN, 0) : null;
}
function ak(e) {
  return new la(e >> 16 & 255, e >> 8 & 255, e & 255, 1);
}
function Fh(e, t, n, r) {
  return r <= 0 && (e = t = n = NaN), new la(e, t, n, r);
}
function rre(e) {
  return e instanceof cm || (e = Rp(e)), e ? (e = e.rgb(), new la(e.r, e.g, e.b, e.opacity)) : new la();
}
function rC(e, t, n, r) {
  return arguments.length === 1 ? rre(e) : new la(e, t, n, r ?? 1);
}
function la(e, t, n, r) {
  this.r = +e, this.g = +t, this.b = +n, this.opacity = +r;
}
R1(la, rC, d3(cm, {
  brighter(e) {
    return e = e == null ? Fg : Math.pow(Fg, e), new la(this.r * e, this.g * e, this.b * e, this.opacity);
  },
  darker(e) {
    return e = e == null ? Ap : Math.pow(Ap, e), new la(this.r * e, this.g * e, this.b * e, this.opacity);
  },
  rgb() {
    return this;
  },
  clamp() {
    return new la(ku(this.r), ku(this.g), ku(this.b), Bg(this.opacity));
  },
  displayable() {
    return -0.5 <= this.r && this.r < 255.5 && -0.5 <= this.g && this.g < 255.5 && -0.5 <= this.b && this.b < 255.5 && 0 <= this.opacity && this.opacity <= 1;
  },
  hex: ok,
  // Deprecated! Use color.formatHex.
  formatHex: ok,
  formatHex8: ire,
  formatRgb: sk,
  toString: sk
}));
function ok() {
  return `#${xu(this.r)}${xu(this.g)}${xu(this.b)}`;
}
function ire() {
  return `#${xu(this.r)}${xu(this.g)}${xu(this.b)}${xu((isNaN(this.opacity) ? 1 : this.opacity) * 255)}`;
}
function sk() {
  const e = Bg(this.opacity);
  return `${e === 1 ? "rgb(" : "rgba("}${ku(this.r)}, ${ku(this.g)}, ${ku(this.b)}${e === 1 ? ")" : `, ${e})`}`;
}
function Bg(e) {
  return isNaN(e) ? 1 : Math.max(0, Math.min(1, e));
}
function ku(e) {
  return Math.max(0, Math.min(255, Math.round(e) || 0));
}
function xu(e) {
  return e = ku(e), (e < 16 ? "0" : "") + e.toString(16);
}
function lk(e, t, n, r) {
  return r <= 0 ? e = t = n = NaN : n <= 0 || n >= 1 ? e = t = NaN : t <= 0 && (e = NaN), new _o(e, t, n, r);
}
function f3(e) {
  if (e instanceof _o) return new _o(e.h, e.s, e.l, e.opacity);
  if (e instanceof cm || (e = Rp(e)), !e) return new _o();
  if (e instanceof _o) return e;
  e = e.rgb();
  var t = e.r / 255, n = e.g / 255, r = e.b / 255, i = Math.min(t, n, r), a = Math.max(t, n, r), o = NaN, s = a - i, l = (a + i) / 2;
  return s ? (t === a ? o = (n - r) / s + (n < r) * 6 : n === a ? o = (r - t) / s + 2 : o = (t - n) / s + 4, s /= l < 0.5 ? a + i : 2 - a - i, o *= 60) : s = l > 0 && l < 1 ? 0 : o, new _o(o, s, l, e.opacity);
}
function are(e, t, n, r) {
  return arguments.length === 1 ? f3(e) : new _o(e, t, n, r ?? 1);
}
function _o(e, t, n, r) {
  this.h = +e, this.s = +t, this.l = +n, this.opacity = +r;
}
R1(_o, are, d3(cm, {
  brighter(e) {
    return e = e == null ? Fg : Math.pow(Fg, e), new _o(this.h, this.s, this.l * e, this.opacity);
  },
  darker(e) {
    return e = e == null ? Ap : Math.pow(Ap, e), new _o(this.h, this.s, this.l * e, this.opacity);
  },
  rgb() {
    var e = this.h % 360 + (this.h < 0) * 360, t = isNaN(e) || isNaN(this.s) ? 0 : this.s, n = this.l, r = n + (n < 0.5 ? n : 1 - n) * t, i = 2 * n - r;
    return new la(
      Wy(e >= 240 ? e - 240 : e + 120, i, r),
      Wy(e, i, r),
      Wy(e < 120 ? e + 240 : e - 120, i, r),
      this.opacity
    );
  },
  clamp() {
    return new _o(uk(this.h), Bh(this.s), Bh(this.l), Bg(this.opacity));
  },
  displayable() {
    return (0 <= this.s && this.s <= 1 || isNaN(this.s)) && 0 <= this.l && this.l <= 1 && 0 <= this.opacity && this.opacity <= 1;
  },
  formatHsl() {
    const e = Bg(this.opacity);
    return `${e === 1 ? "hsl(" : "hsla("}${uk(this.h)}, ${Bh(this.s) * 100}%, ${Bh(this.l) * 100}%${e === 1 ? ")" : `, ${e})`}`;
  }
}));
function uk(e) {
  return e = (e || 0) % 360, e < 0 ? e + 360 : e;
}
function Bh(e) {
  return Math.max(0, Math.min(1, e || 0));
}
function Wy(e, t, n) {
  return (e < 60 ? t + (n - t) * e / 60 : e < 180 ? n : e < 240 ? t + (n - t) * (240 - e) / 60 : t) * 255;
}
const w1 = (e) => () => e;
function p3(e, t) {
  return function(n) {
    return e + n * t;
  };
}
function ore(e, t, n) {
  return e = Math.pow(e, n), t = Math.pow(t, n) - e, n = 1 / n, function(r) {
    return Math.pow(e + r * t, n);
  };
}
function o7e(e, t) {
  var n = t - e;
  return n ? p3(e, n > 180 || n < -180 ? n - 360 * Math.round(n / 360) : n) : w1(isNaN(e) ? t : e);
}
function sre(e) {
  return (e = +e) == 1 ? m3 : function(t, n) {
    return n - t ? ore(t, n, e) : w1(isNaN(t) ? n : t);
  };
}
function m3(e, t) {
  var n = t - e;
  return n ? p3(e, n) : w1(isNaN(e) ? t : e);
}
const ck = function e(t) {
  var n = sre(t);
  function r(i, a) {
    var o = n((i = rC(i)).r, (a = rC(a)).r), s = n(i.g, a.g), l = n(i.b, a.b), u = m3(i.opacity, a.opacity);
    return function(c) {
      return i.r = o(c), i.g = s(c), i.b = l(c), i.opacity = u(c), i + "";
    };
  }
  return r.gamma = e, r;
}(1);
function yl(e, t) {
  return e = +e, t = +t, function(n) {
    return e * (1 - n) + t * n;
  };
}
var iC = /[-+]?(?:\d+\.?\d*|\.?\d+)(?:[eE][-+]?\d+)?/g, Ky = new RegExp(iC.source, "g");
function lre(e) {
  return function() {
    return e;
  };
}
function ure(e) {
  return function(t) {
    return e(t) + "";
  };
}
function cre(e, t) {
  var n = iC.lastIndex = Ky.lastIndex = 0, r, i, a, o = -1, s = [], l = [];
  for (e = e + "", t = t + ""; (r = iC.exec(e)) && (i = Ky.exec(t)); )
    (a = i.index) > n && (a = t.slice(n, a), s[o] ? s[o] += a : s[++o] = a), (r = r[0]) === (i = i[0]) ? s[o] ? s[o] += i : s[++o] = i : (s[++o] = null, l.push({ i: o, x: yl(r, i) })), n = Ky.lastIndex;
  return n < t.length && (a = t.slice(n), s[o] ? s[o] += a : s[++o] = a), s.length < 2 ? l[0] ? ure(l[0].x) : lre(t) : (t = l.length, function(u) {
    for (var c = 0, d; c < t; ++c) s[(d = l[c]).i] = d.x(u);
    return s.join("");
  });
}
var dk = 180 / Math.PI, aC = {
  translateX: 0,
  translateY: 0,
  rotate: 0,
  skewX: 0,
  scaleX: 1,
  scaleY: 1
};
function h3(e, t, n, r, i, a) {
  var o, s, l;
  return (o = Math.sqrt(e * e + t * t)) && (e /= o, t /= o), (l = e * n + t * r) && (n -= e * l, r -= t * l), (s = Math.sqrt(n * n + r * r)) && (n /= s, r /= s, l /= s), e * r < t * n && (e = -e, t = -t, l = -l, o = -o), {
    translateX: i,
    translateY: a,
    rotate: Math.atan2(t, e) * dk,
    skewX: Math.atan(l) * dk,
    scaleX: o,
    scaleY: s
  };
}
var $h;
function dre(e) {
  const t = new (typeof DOMMatrix == "function" ? DOMMatrix : WebKitCSSMatrix)(e + "");
  return t.isIdentity ? aC : h3(t.a, t.b, t.c, t.d, t.e, t.f);
}
function fre(e) {
  return e == null || ($h || ($h = document.createElementNS("http://www.w3.org/2000/svg", "g")), $h.setAttribute("transform", e), !(e = $h.transform.baseVal.consolidate())) ? aC : (e = e.matrix, h3(e.a, e.b, e.c, e.d, e.e, e.f));
}
function g3(e, t, n, r) {
  function i(u) {
    return u.length ? u.pop() + " " : "";
  }
  function a(u, c, d, f, h, m) {
    if (u !== d || c !== f) {
      var v = h.push("translate(", null, t, null, n);
      m.push({ i: v - 4, x: yl(u, d) }, { i: v - 2, x: yl(c, f) });
    } else (d || f) && h.push("translate(" + d + t + f + n);
  }
  function o(u, c, d, f) {
    u !== c ? (u - c > 180 ? c += 360 : c - u > 180 && (u += 360), f.push({ i: d.push(i(d) + "rotate(", null, r) - 2, x: yl(u, c) })) : c && d.push(i(d) + "rotate(" + c + r);
  }
  function s(u, c, d, f) {
    u !== c ? f.push({ i: d.push(i(d) + "skewX(", null, r) - 2, x: yl(u, c) }) : c && d.push(i(d) + "skewX(" + c + r);
  }
  function l(u, c, d, f, h, m) {
    if (u !== d || c !== f) {
      var v = h.push(i(h) + "scale(", null, ",", null, ")");
      m.push({ i: v - 4, x: yl(u, d) }, { i: v - 2, x: yl(c, f) });
    } else (d !== 1 || f !== 1) && h.push(i(h) + "scale(" + d + "," + f + ")");
  }
  return function(u, c) {
    var d = [], f = [];
    return u = e(u), c = e(c), a(u.translateX, u.translateY, c.translateX, c.translateY, d, f), o(u.rotate, c.rotate, d, f), s(u.skewX, c.skewX, d, f), l(u.scaleX, u.scaleY, c.scaleX, c.scaleY, d, f), u = c = null, function(h) {
      for (var m = -1, v = f.length, b; ++m < v; ) d[(b = f[m]).i] = b.x(h);
      return d.join("");
    };
  };
}
var pre = g3(dre, "px, ", "px)", "deg)"), mre = g3(fre, ", ", ")", ")"), cd = 0, Ff = 0, Ef = 0, _3 = 1e3, $g, Bf, Ug = 0, Yu = 0, Y_ = 0, wp = typeof performance == "object" && performance.now ? performance : Date, v3 = typeof window == "object" && window.requestAnimationFrame ? window.requestAnimationFrame.bind(window) : function(e) {
  setTimeout(e, 17);
};
function x1() {
  return Yu || (v3(hre), Yu = wp.now() + Y_);
}
function hre() {
  Yu = 0;
}
function qg() {
  this._call = this._time = this._next = null;
}
qg.prototype = b3.prototype = {
  constructor: qg,
  restart: function(e, t, n) {
    if (typeof e != "function") throw new TypeError("callback is not a function");
    n = (n == null ? x1() : +n) + (t == null ? 0 : +t), !this._next && Bf !== this && (Bf ? Bf._next = this : $g = this, Bf = this), this._call = e, this._time = n, oC();
  },
  stop: function() {
    this._call && (this._call = null, this._time = 1 / 0, oC());
  }
};
function b3(e, t, n) {
  var r = new qg();
  return r.restart(e, t, n), r;
}
function gre() {
  x1(), ++cd;
  for (var e = $g, t; e; )
    (t = Yu - e._time) >= 0 && e._call.call(void 0, t), e = e._next;
  --cd;
}
function fk() {
  Yu = (Ug = wp.now()) + Y_, cd = Ff = 0;
  try {
    gre();
  } finally {
    cd = 0, vre(), Yu = 0;
  }
}
function _re() {
  var e = wp.now(), t = e - Ug;
  t > _3 && (Y_ -= t, Ug = e);
}
function vre() {
  for (var e, t = $g, n, r = 1 / 0; t; )
    t._call ? (r > t._time && (r = t._time), e = t, t = t._next) : (n = t._next, t._next = null, t = e ? e._next = n : $g = n);
  Bf = e, oC(r);
}
function oC(e) {
  if (!cd) {
    Ff && (Ff = clearTimeout(Ff));
    var t = e - Yu;
    t > 24 ? (e < 1 / 0 && (Ff = setTimeout(fk, e - wp.now() - Y_)), Ef && (Ef = clearInterval(Ef))) : (Ef || (Ug = wp.now(), Ef = setInterval(_re, _3)), cd = 1, v3(fk));
  }
}
function pk(e, t, n) {
  var r = new qg();
  return t = t == null ? 0 : +t, r.restart((i) => {
    r.stop(), e(i + t);
  }, t, n), r;
}
var bre = ZF("start", "end", "cancel", "interrupt"), Ere = [], E3 = 0, mk = 1, sC = 2, sg = 3, hk = 4, lC = 5, lg = 6;
function H_(e, t, n, r, i, a) {
  var o = e.__transition;
  if (!o) e.__transition = {};
  else if (n in o) return;
  Sre(e, n, {
    name: t,
    index: r,
    // For context during callback.
    group: i,
    // For context during callback.
    on: bre,
    tween: Ere,
    time: a.time,
    delay: a.delay,
    duration: a.duration,
    ease: a.ease,
    timer: null,
    state: E3
  });
}
function N1(e, t) {
  var n = Oo(e, t);
  if (n.state > E3) throw new Error("too late; already scheduled");
  return n;
}
function ns(e, t) {
  var n = Oo(e, t);
  if (n.state > sg) throw new Error("too late; already running");
  return n;
}
function Oo(e, t) {
  var n = e.__transition;
  if (!n || !(n = n[t])) throw new Error("transition not found");
  return n;
}
function Sre(e, t, n) {
  var r = e.__transition, i;
  r[t] = n, n.timer = b3(a, 0, n.time);
  function a(u) {
    n.state = mk, n.timer.restart(o, n.delay, n.time), n.delay <= u && o(u - n.delay);
  }
  function o(u) {
    var c, d, f, h;
    if (n.state !== mk) return l();
    for (c in r)
      if (h = r[c], h.name === n.name) {
        if (h.state === sg) return pk(o);
        h.state === hk ? (h.state = lg, h.timer.stop(), h.on.call("interrupt", e, e.__data__, h.index, h.group), delete r[c]) : +c < t && (h.state = lg, h.timer.stop(), h.on.call("cancel", e, e.__data__, h.index, h.group), delete r[c]);
      }
    if (pk(function() {
      n.state === sg && (n.state = hk, n.timer.restart(s, n.delay, n.time), s(u));
    }), n.state = sC, n.on.call("start", e, e.__data__, n.index, n.group), n.state === sC) {
      for (n.state = sg, i = new Array(f = n.tween.length), c = 0, d = -1; c < f; ++c)
        (h = n.tween[c].value.call(e, e.__data__, n.index, n.group)) && (i[++d] = h);
      i.length = d + 1;
    }
  }
  function s(u) {
    for (var c = u < n.duration ? n.ease.call(null, u / n.duration) : (n.timer.restart(l), n.state = lC, 1), d = -1, f = i.length; ++d < f; )
      i[d].call(e, c);
    n.state === lC && (n.on.call("end", e, e.__data__, n.index, n.group), l());
  }
  function l() {
    n.state = lg, n.timer.stop(), delete r[t];
    for (var u in r) return;
    delete e.__transition;
  }
}
function yre(e, t) {
  var n = e.__transition, r, i, a = !0, o;
  if (n) {
    t = t == null ? null : t + "";
    for (o in n) {
      if ((r = n[o]).name !== t) {
        a = !1;
        continue;
      }
      i = r.state > sC && r.state < lC, r.state = lg, r.timer.stop(), r.on.call(i ? "interrupt" : "cancel", e, e.__data__, r.index, r.group), delete n[o];
    }
    a && delete e.__transition;
  }
}
function Tre(e) {
  return this.each(function() {
    yre(this, e);
  });
}
function Cre(e, t) {
  var n, r;
  return function() {
    var i = ns(this, e), a = i.tween;
    if (a !== n) {
      r = n = a;
      for (var o = 0, s = r.length; o < s; ++o)
        if (r[o].name === t) {
          r = r.slice(), r.splice(o, 1);
          break;
        }
    }
    i.tween = r;
  };
}
function Are(e, t, n) {
  var r, i;
  if (typeof n != "function") throw new Error();
  return function() {
    var a = ns(this, e), o = a.tween;
    if (o !== r) {
      i = (r = o).slice();
      for (var s = { name: t, value: n }, l = 0, u = i.length; l < u; ++l)
        if (i[l].name === t) {
          i[l] = s;
          break;
        }
      l === u && i.push(s);
    }
    a.tween = i;
  };
}
function Ore(e, t) {
  var n = this._id;
  if (e += "", arguments.length < 2) {
    for (var r = Oo(this.node(), n).tween, i = 0, a = r.length, o; i < a; ++i)
      if ((o = r[i]).name === e)
        return o.value;
    return null;
  }
  return this.each((t == null ? Cre : Are)(n, e, t));
}
function D1(e, t, n) {
  var r = e._id;
  return e.each(function() {
    var i = ns(this, r);
    (i.value || (i.value = {}))[t] = n.apply(this, arguments);
  }), function(i) {
    return Oo(i, r).value[t];
  };
}
function S3(e, t) {
  var n;
  return (typeof t == "number" ? yl : t instanceof Rp ? ck : (n = Rp(t)) ? (t = n, ck) : cre)(e, t);
}
function Rre(e) {
  return function() {
    this.removeAttribute(e);
  };
}
function wre(e) {
  return function() {
    this.removeAttributeNS(e.space, e.local);
  };
}
function xre(e, t, n) {
  var r, i = n + "", a;
  return function() {
    var o = this.getAttribute(e);
    return o === i ? null : o === r ? a : a = t(r = o, n);
  };
}
function Nre(e, t, n) {
  var r, i = n + "", a;
  return function() {
    var o = this.getAttributeNS(e.space, e.local);
    return o === i ? null : o === r ? a : a = t(r = o, n);
  };
}
function Dre(e, t, n) {
  var r, i, a;
  return function() {
    var o, s = n(this), l;
    return s == null ? void this.removeAttribute(e) : (o = this.getAttribute(e), l = s + "", o === l ? null : o === r && l === i ? a : (i = l, a = t(r = o, s)));
  };
}
function Ire(e, t, n) {
  var r, i, a;
  return function() {
    var o, s = n(this), l;
    return s == null ? void this.removeAttributeNS(e.space, e.local) : (o = this.getAttributeNS(e.space, e.local), l = s + "", o === l ? null : o === r && l === i ? a : (i = l, a = t(r = o, s)));
  };
}
function Lre(e, t) {
  var n = G_(e), r = n === "transform" ? mre : S3;
  return this.attrTween(e, typeof t == "function" ? (n.local ? Ire : Dre)(n, r, D1(this, "attr." + e, t)) : t == null ? (n.local ? wre : Rre)(n) : (n.local ? Nre : xre)(n, r, t));
}
function kre(e, t) {
  return function(n) {
    this.setAttribute(e, t.call(this, n));
  };
}
function Mre(e, t) {
  return function(n) {
    this.setAttributeNS(e.space, e.local, t.call(this, n));
  };
}
function Pre(e, t) {
  var n, r;
  function i() {
    var a = t.apply(this, arguments);
    return a !== r && (n = (r = a) && Mre(e, a)), n;
  }
  return i._value = t, i;
}
function Fre(e, t) {
  var n, r;
  function i() {
    var a = t.apply(this, arguments);
    return a !== r && (n = (r = a) && kre(e, a)), n;
  }
  return i._value = t, i;
}
function Bre(e, t) {
  var n = "attr." + e;
  if (arguments.length < 2) return (n = this.tween(n)) && n._value;
  if (t == null) return this.tween(n, null);
  if (typeof t != "function") throw new Error();
  var r = G_(e);
  return this.tween(n, (r.local ? Pre : Fre)(r, t));
}
function $re(e, t) {
  return function() {
    N1(this, e).delay = +t.apply(this, arguments);
  };
}
function Ure(e, t) {
  return t = +t, function() {
    N1(this, e).delay = t;
  };
}
function qre(e) {
  var t = this._id;
  return arguments.length ? this.each((typeof e == "function" ? $re : Ure)(t, e)) : Oo(this.node(), t).delay;
}
function Gre(e, t) {
  return function() {
    ns(this, e).duration = +t.apply(this, arguments);
  };
}
function Yre(e, t) {
  return t = +t, function() {
    ns(this, e).duration = t;
  };
}
function Hre(e) {
  var t = this._id;
  return arguments.length ? this.each((typeof e == "function" ? Gre : Yre)(t, e)) : Oo(this.node(), t).duration;
}
function zre(e, t) {
  if (typeof t != "function") throw new Error();
  return function() {
    ns(this, e).ease = t;
  };
}
function Vre(e) {
  var t = this._id;
  return arguments.length ? this.each(zre(t, e)) : Oo(this.node(), t).ease;
}
function Wre(e, t) {
  return function() {
    var n = t.apply(this, arguments);
    if (typeof n != "function") throw new Error();
    ns(this, e).ease = n;
  };
}
function Kre(e) {
  if (typeof e != "function") throw new Error();
  return this.each(Wre(this._id, e));
}
function jre(e) {
  typeof e != "function" && (e = t3(e));
  for (var t = this._groups, n = t.length, r = new Array(n), i = 0; i < n; ++i)
    for (var a = t[i], o = a.length, s = r[i] = [], l, u = 0; u < o; ++u)
      (l = a[u]) && e.call(l, l.__data__, u, a) && s.push(l);
  return new Us(r, this._parents, this._name, this._id);
}
function Qre(e) {
  if (e._id !== this._id) throw new Error();
  for (var t = this._groups, n = e._groups, r = t.length, i = n.length, a = Math.min(r, i), o = new Array(r), s = 0; s < a; ++s)
    for (var l = t[s], u = n[s], c = l.length, d = o[s] = new Array(c), f, h = 0; h < c; ++h)
      (f = l[h] || u[h]) && (d[h] = f);
  for (; s < r; ++s)
    o[s] = t[s];
  return new Us(o, this._parents, this._name, this._id);
}
function Xre(e) {
  return (e + "").trim().split(/^|\s+/).every(function(t) {
    var n = t.indexOf(".");
    return n >= 0 && (t = t.slice(0, n)), !t || t === "start";
  });
}
function Zre(e, t, n) {
  var r, i, a = Xre(t) ? N1 : ns;
  return function() {
    var o = a(this, e), s = o.on;
    s !== r && (i = (r = s).copy()).on(t, n), o.on = i;
  };
}
function Jre(e, t) {
  var n = this._id;
  return arguments.length < 2 ? Oo(this.node(), n).on.on(e) : this.each(Zre(n, e, t));
}
function eie(e) {
  return function() {
    var t = this.parentNode;
    for (var n in this.__transition) if (+n !== e) return;
    t && t.removeChild(this);
  };
}
function tie() {
  return this.on("end.remove", eie(this._id));
}
function nie(e) {
  var t = this._name, n = this._id;
  typeof e != "function" && (e = A1(e));
  for (var r = this._groups, i = r.length, a = new Array(i), o = 0; o < i; ++o)
    for (var s = r[o], l = s.length, u = a[o] = new Array(l), c, d, f = 0; f < l; ++f)
      (c = s[f]) && (d = e.call(c, c.__data__, f, s)) && ("__data__" in c && (d.__data__ = c.__data__), u[f] = d, H_(u[f], t, n, f, u, Oo(c, n)));
  return new Us(a, this._parents, t, n);
}
function rie(e) {
  var t = this._name, n = this._id;
  typeof e != "function" && (e = e3(e));
  for (var r = this._groups, i = r.length, a = [], o = [], s = 0; s < i; ++s)
    for (var l = r[s], u = l.length, c, d = 0; d < u; ++d)
      if (c = l[d]) {
        for (var f = e.call(c, c.__data__, d, l), h, m = Oo(c, n), v = 0, b = f.length; v < b; ++v)
          (h = f[v]) && H_(h, t, n, v, f, m);
        a.push(f), o.push(c);
      }
  return new Us(a, o, t, n);
}
var iie = um.prototype.constructor;
function aie() {
  return new iie(this._groups, this._parents);
}
function oie(e, t) {
  var n, r, i;
  return function() {
    var a = ud(this, e), o = (this.style.removeProperty(e), ud(this, e));
    return a === o ? null : a === n && o === r ? i : i = t(n = a, r = o);
  };
}
function y3(e) {
  return function() {
    this.style.removeProperty(e);
  };
}
function sie(e, t, n) {
  var r, i = n + "", a;
  return function() {
    var o = ud(this, e);
    return o === i ? null : o === r ? a : a = t(r = o, n);
  };
}
function lie(e, t, n) {
  var r, i, a;
  return function() {
    var o = ud(this, e), s = n(this), l = s + "";
    return s == null && (l = s = (this.style.removeProperty(e), ud(this, e))), o === l ? null : o === r && l === i ? a : (i = l, a = t(r = o, s));
  };
}
function uie(e, t) {
  var n, r, i, a = "style." + t, o = "end." + a, s;
  return function() {
    var l = ns(this, e), u = l.on, c = l.value[a] == null ? s || (s = y3(t)) : void 0;
    (u !== n || i !== c) && (r = (n = u).copy()).on(o, i = c), l.on = r;
  };
}
function cie(e, t, n) {
  var r = (e += "") == "transform" ? pre : S3;
  return t == null ? this.styleTween(e, oie(e, r)).on("end.style." + e, y3(e)) : typeof t == "function" ? this.styleTween(e, lie(e, r, D1(this, "style." + e, t))).each(uie(this._id, e)) : this.styleTween(e, sie(e, r, t), n).on("end.style." + e, null);
}
function die(e, t, n) {
  return function(r) {
    this.style.setProperty(e, t.call(this, r), n);
  };
}
function fie(e, t, n) {
  var r, i;
  function a() {
    var o = t.apply(this, arguments);
    return o !== i && (r = (i = o) && die(e, o, n)), r;
  }
  return a._value = t, a;
}
function pie(e, t, n) {
  var r = "style." + (e += "");
  if (arguments.length < 2) return (r = this.tween(r)) && r._value;
  if (t == null) return this.tween(r, null);
  if (typeof t != "function") throw new Error();
  return this.tween(r, fie(e, t, n ?? ""));
}
function mie(e) {
  return function() {
    this.textContent = e;
  };
}
function hie(e) {
  return function() {
    var t = e(this);
    this.textContent = t ?? "";
  };
}
function gie(e) {
  return this.tween("text", typeof e == "function" ? hie(D1(this, "text", e)) : mie(e == null ? "" : e + ""));
}
function _ie(e) {
  return function(t) {
    this.textContent = e.call(this, t);
  };
}
function vie(e) {
  var t, n;
  function r() {
    var i = e.apply(this, arguments);
    return i !== n && (t = (n = i) && _ie(i)), t;
  }
  return r._value = e, r;
}
function bie(e) {
  var t = "text";
  if (arguments.length < 1) return (t = this.tween(t)) && t._value;
  if (e == null) return this.tween(t, null);
  if (typeof e != "function") throw new Error();
  return this.tween(t, vie(e));
}
function Eie() {
  for (var e = this._name, t = this._id, n = T3(), r = this._groups, i = r.length, a = 0; a < i; ++a)
    for (var o = r[a], s = o.length, l, u = 0; u < s; ++u)
      if (l = o[u]) {
        var c = Oo(l, t);
        H_(l, e, n, u, o, {
          time: c.time + c.delay + c.duration,
          delay: 0,
          duration: c.duration,
          ease: c.ease
        });
      }
  return new Us(r, this._parents, e, n);
}
function Sie() {
  var e, t, n = this, r = n._id, i = n.size();
  return new Promise(function(a, o) {
    var s = { value: o }, l = { value: function() {
      --i === 0 && a();
    } };
    n.each(function() {
      var u = ns(this, r), c = u.on;
      c !== e && (t = (e = c).copy(), t._.cancel.push(s), t._.interrupt.push(s), t._.end.push(l)), u.on = t;
    }), i === 0 && a();
  });
}
var yie = 0;
function Us(e, t, n, r) {
  this._groups = e, this._parents = t, this._name = n, this._id = r;
}
function T3() {
  return ++yie;
}
var Ss = um.prototype;
Us.prototype = {
  constructor: Us,
  select: nie,
  selectAll: rie,
  selectChild: Ss.selectChild,
  selectChildren: Ss.selectChildren,
  filter: jre,
  merge: Qre,
  selection: aie,
  transition: Eie,
  call: Ss.call,
  nodes: Ss.nodes,
  node: Ss.node,
  size: Ss.size,
  empty: Ss.empty,
  each: Ss.each,
  on: Jre,
  attr: Lre,
  attrTween: Bre,
  style: cie,
  styleTween: pie,
  text: gie,
  textTween: bie,
  remove: tie,
  tween: Ore,
  delay: qre,
  duration: Hre,
  ease: Vre,
  easeVarying: Kre,
  end: Sie,
  [Symbol.iterator]: Ss[Symbol.iterator]
};
function Tie(e) {
  return ((e *= 2) <= 1 ? e * e * e : (e -= 2) * e * e + 2) / 2;
}
var Cie = {
  time: null,
  // Set on use.
  delay: 0,
  duration: 250,
  ease: Tie
};
function Aie(e, t) {
  for (var n; !(n = e.__transition) || !(n = n[t]); )
    if (!(e = e.parentNode))
      throw new Error(`transition ${t} not found`);
  return n;
}
function Oie(e) {
  var t, n;
  e instanceof Us ? (t = e._id, e = e._name) : (t = T3(), (n = Cie).time = x1(), e = e == null ? null : e + "");
  for (var r = this._groups, i = r.length, a = 0; a < i; ++a)
    for (var o = r[a], s = o.length, l, u = 0; u < s; ++u)
      (l = o[u]) && H_(l, e, t, u, o, n || Aie(l, t));
  return new Us(r, this._parents, e, t);
}
um.prototype.interrupt = Tre;
um.prototype.transition = Oie;
const s7e = Math.abs, l7e = Math.atan2, u7e = Math.cos, c7e = Math.max, d7e = Math.min, f7e = Math.sin, p7e = Math.sqrt, gk = 1e-12, I1 = Math.PI, _k = I1 / 2, m7e = 2 * I1;
function h7e(e) {
  return e > 1 ? 0 : e < -1 ? I1 : Math.acos(e);
}
function g7e(e) {
  return e >= 1 ? _k : e <= -1 ? -_k : Math.asin(e);
}
function C3(e) {
  this._context = e;
}
C3.prototype = {
  areaStart: function() {
    this._line = 0;
  },
  areaEnd: function() {
    this._line = NaN;
  },
  lineStart: function() {
    this._point = 0;
  },
  lineEnd: function() {
    (this._line || this._line !== 0 && this._point === 1) && this._context.closePath(), this._line = 1 - this._line;
  },
  point: function(e, t) {
    switch (e = +e, t = +t, this._point) {
      case 0:
        this._point = 1, this._line ? this._context.lineTo(e, t) : this._context.moveTo(e, t);
        break;
      case 1:
        this._point = 2;
      default:
        this._context.lineTo(e, t);
        break;
    }
  }
};
function Rie(e) {
  return new C3(e);
}
class A3 {
  constructor(t, n) {
    this._context = t, this._x = n;
  }
  areaStart() {
    this._line = 0;
  }
  areaEnd() {
    this._line = NaN;
  }
  lineStart() {
    this._point = 0;
  }
  lineEnd() {
    (this._line || this._line !== 0 && this._point === 1) && this._context.closePath(), this._line = 1 - this._line;
  }
  point(t, n) {
    switch (t = +t, n = +n, this._point) {
      case 0: {
        this._point = 1, this._line ? this._context.lineTo(t, n) : this._context.moveTo(t, n);
        break;
      }
      case 1:
        this._point = 2;
      default: {
        this._x ? this._context.bezierCurveTo(this._x0 = (this._x0 + t) / 2, this._y0, this._x0, n, t, n) : this._context.bezierCurveTo(this._x0, this._y0 = (this._y0 + n) / 2, t, this._y0, t, n);
        break;
      }
    }
    this._x0 = t, this._y0 = n;
  }
}
function wie(e) {
  return new A3(e, !0);
}
function xie(e) {
  return new A3(e, !1);
}
function $l() {
}
function Gg(e, t, n) {
  e._context.bezierCurveTo(
    (2 * e._x0 + e._x1) / 3,
    (2 * e._y0 + e._y1) / 3,
    (e._x0 + 2 * e._x1) / 3,
    (e._y0 + 2 * e._y1) / 3,
    (e._x0 + 4 * e._x1 + t) / 6,
    (e._y0 + 4 * e._y1 + n) / 6
  );
}
function z_(e) {
  this._context = e;
}
z_.prototype = {
  areaStart: function() {
    this._line = 0;
  },
  areaEnd: function() {
    this._line = NaN;
  },
  lineStart: function() {
    this._x0 = this._x1 = this._y0 = this._y1 = NaN, this._point = 0;
  },
  lineEnd: function() {
    switch (this._point) {
      case 3:
        Gg(this, this._x1, this._y1);
      case 2:
        this._context.lineTo(this._x1, this._y1);
        break;
    }
    (this._line || this._line !== 0 && this._point === 1) && this._context.closePath(), this._line = 1 - this._line;
  },
  point: function(e, t) {
    switch (e = +e, t = +t, this._point) {
      case 0:
        this._point = 1, this._line ? this._context.lineTo(e, t) : this._context.moveTo(e, t);
        break;
      case 1:
        this._point = 2;
        break;
      case 2:
        this._point = 3, this._context.lineTo((5 * this._x0 + this._x1) / 6, (5 * this._y0 + this._y1) / 6);
      default:
        Gg(this, e, t);
        break;
    }
    this._x0 = this._x1, this._x1 = e, this._y0 = this._y1, this._y1 = t;
  }
};
function Nie(e) {
  return new z_(e);
}
function O3(e) {
  this._context = e;
}
O3.prototype = {
  areaStart: $l,
  areaEnd: $l,
  lineStart: function() {
    this._x0 = this._x1 = this._x2 = this._x3 = this._x4 = this._y0 = this._y1 = this._y2 = this._y3 = this._y4 = NaN, this._point = 0;
  },
  lineEnd: function() {
    switch (this._point) {
      case 1: {
        this._context.moveTo(this._x2, this._y2), this._context.closePath();
        break;
      }
      case 2: {
        this._context.moveTo((this._x2 + 2 * this._x3) / 3, (this._y2 + 2 * this._y3) / 3), this._context.lineTo((this._x3 + 2 * this._x2) / 3, (this._y3 + 2 * this._y2) / 3), this._context.closePath();
        break;
      }
      case 3: {
        this.point(this._x2, this._y2), this.point(this._x3, this._y3), this.point(this._x4, this._y4);
        break;
      }
    }
  },
  point: function(e, t) {
    switch (e = +e, t = +t, this._point) {
      case 0:
        this._point = 1, this._x2 = e, this._y2 = t;
        break;
      case 1:
        this._point = 2, this._x3 = e, this._y3 = t;
        break;
      case 2:
        this._point = 3, this._x4 = e, this._y4 = t, this._context.moveTo((this._x0 + 4 * this._x1 + e) / 6, (this._y0 + 4 * this._y1 + t) / 6);
        break;
      default:
        Gg(this, e, t);
        break;
    }
    this._x0 = this._x1, this._x1 = e, this._y0 = this._y1, this._y1 = t;
  }
};
function Die(e) {
  return new O3(e);
}
function R3(e) {
  this._context = e;
}
R3.prototype = {
  areaStart: function() {
    this._line = 0;
  },
  areaEnd: function() {
    this._line = NaN;
  },
  lineStart: function() {
    this._x0 = this._x1 = this._y0 = this._y1 = NaN, this._point = 0;
  },
  lineEnd: function() {
    (this._line || this._line !== 0 && this._point === 3) && this._context.closePath(), this._line = 1 - this._line;
  },
  point: function(e, t) {
    switch (e = +e, t = +t, this._point) {
      case 0:
        this._point = 1;
        break;
      case 1:
        this._point = 2;
        break;
      case 2:
        this._point = 3;
        var n = (this._x0 + 4 * this._x1 + e) / 6, r = (this._y0 + 4 * this._y1 + t) / 6;
        this._line ? this._context.lineTo(n, r) : this._context.moveTo(n, r);
        break;
      case 3:
        this._point = 4;
      default:
        Gg(this, e, t);
        break;
    }
    this._x0 = this._x1, this._x1 = e, this._y0 = this._y1, this._y1 = t;
  }
};
function Iie(e) {
  return new R3(e);
}
function w3(e, t) {
  this._basis = new z_(e), this._beta = t;
}
w3.prototype = {
  lineStart: function() {
    this._x = [], this._y = [], this._basis.lineStart();
  },
  lineEnd: function() {
    var e = this._x, t = this._y, n = e.length - 1;
    if (n > 0)
      for (var r = e[0], i = t[0], a = e[n] - r, o = t[n] - i, s = -1, l; ++s <= n; )
        l = s / n, this._basis.point(
          this._beta * e[s] + (1 - this._beta) * (r + l * a),
          this._beta * t[s] + (1 - this._beta) * (i + l * o)
        );
    this._x = this._y = null, this._basis.lineEnd();
  },
  point: function(e, t) {
    this._x.push(+e), this._y.push(+t);
  }
};
const Lie = function e(t) {
  function n(r) {
    return t === 1 ? new z_(r) : new w3(r, t);
  }
  return n.beta = function(r) {
    return e(+r);
  }, n;
}(0.85);
function Yg(e, t, n) {
  e._context.bezierCurveTo(
    e._x1 + e._k * (e._x2 - e._x0),
    e._y1 + e._k * (e._y2 - e._y0),
    e._x2 + e._k * (e._x1 - t),
    e._y2 + e._k * (e._y1 - n),
    e._x2,
    e._y2
  );
}
function L1(e, t) {
  this._context = e, this._k = (1 - t) / 6;
}
L1.prototype = {
  areaStart: function() {
    this._line = 0;
  },
  areaEnd: function() {
    this._line = NaN;
  },
  lineStart: function() {
    this._x0 = this._x1 = this._x2 = this._y0 = this._y1 = this._y2 = NaN, this._point = 0;
  },
  lineEnd: function() {
    switch (this._point) {
      case 2:
        this._context.lineTo(this._x2, this._y2);
        break;
      case 3:
        Yg(this, this._x1, this._y1);
        break;
    }
    (this._line || this._line !== 0 && this._point === 1) && this._context.closePath(), this._line = 1 - this._line;
  },
  point: function(e, t) {
    switch (e = +e, t = +t, this._point) {
      case 0:
        this._point = 1, this._line ? this._context.lineTo(e, t) : this._context.moveTo(e, t);
        break;
      case 1:
        this._point = 2, this._x1 = e, this._y1 = t;
        break;
      case 2:
        this._point = 3;
      default:
        Yg(this, e, t);
        break;
    }
    this._x0 = this._x1, this._x1 = this._x2, this._x2 = e, this._y0 = this._y1, this._y1 = this._y2, this._y2 = t;
  }
};
const kie = function e(t) {
  function n(r) {
    return new L1(r, t);
  }
  return n.tension = function(r) {
    return e(+r);
  }, n;
}(0);
function k1(e, t) {
  this._context = e, this._k = (1 - t) / 6;
}
k1.prototype = {
  areaStart: $l,
  areaEnd: $l,
  lineStart: function() {
    this._x0 = this._x1 = this._x2 = this._x3 = this._x4 = this._x5 = this._y0 = this._y1 = this._y2 = this._y3 = this._y4 = this._y5 = NaN, this._point = 0;
  },
  lineEnd: function() {
    switch (this._point) {
      case 1: {
        this._context.moveTo(this._x3, this._y3), this._context.closePath();
        break;
      }
      case 2: {
        this._context.lineTo(this._x3, this._y3), this._context.closePath();
        break;
      }
      case 3: {
        this.point(this._x3, this._y3), this.point(this._x4, this._y4), this.point(this._x5, this._y5);
        break;
      }
    }
  },
  point: function(e, t) {
    switch (e = +e, t = +t, this._point) {
      case 0:
        this._point = 1, this._x3 = e, this._y3 = t;
        break;
      case 1:
        this._point = 2, this._context.moveTo(this._x4 = e, this._y4 = t);
        break;
      case 2:
        this._point = 3, this._x5 = e, this._y5 = t;
        break;
      default:
        Yg(this, e, t);
        break;
    }
    this._x0 = this._x1, this._x1 = this._x2, this._x2 = e, this._y0 = this._y1, this._y1 = this._y2, this._y2 = t;
  }
};
const Mie = function e(t) {
  function n(r) {
    return new k1(r, t);
  }
  return n.tension = function(r) {
    return e(+r);
  }, n;
}(0);
function M1(e, t) {
  this._context = e, this._k = (1 - t) / 6;
}
M1.prototype = {
  areaStart: function() {
    this._line = 0;
  },
  areaEnd: function() {
    this._line = NaN;
  },
  lineStart: function() {
    this._x0 = this._x1 = this._x2 = this._y0 = this._y1 = this._y2 = NaN, this._point = 0;
  },
  lineEnd: function() {
    (this._line || this._line !== 0 && this._point === 3) && this._context.closePath(), this._line = 1 - this._line;
  },
  point: function(e, t) {
    switch (e = +e, t = +t, this._point) {
      case 0:
        this._point = 1;
        break;
      case 1:
        this._point = 2;
        break;
      case 2:
        this._point = 3, this._line ? this._context.lineTo(this._x2, this._y2) : this._context.moveTo(this._x2, this._y2);
        break;
      case 3:
        this._point = 4;
      default:
        Yg(this, e, t);
        break;
    }
    this._x0 = this._x1, this._x1 = this._x2, this._x2 = e, this._y0 = this._y1, this._y1 = this._y2, this._y2 = t;
  }
};
const Pie = function e(t) {
  function n(r) {
    return new M1(r, t);
  }
  return n.tension = function(r) {
    return e(+r);
  }, n;
}(0);
function P1(e, t, n) {
  var r = e._x1, i = e._y1, a = e._x2, o = e._y2;
  if (e._l01_a > gk) {
    var s = 2 * e._l01_2a + 3 * e._l01_a * e._l12_a + e._l12_2a, l = 3 * e._l01_a * (e._l01_a + e._l12_a);
    r = (r * s - e._x0 * e._l12_2a + e._x2 * e._l01_2a) / l, i = (i * s - e._y0 * e._l12_2a + e._y2 * e._l01_2a) / l;
  }
  if (e._l23_a > gk) {
    var u = 2 * e._l23_2a + 3 * e._l23_a * e._l12_a + e._l12_2a, c = 3 * e._l23_a * (e._l23_a + e._l12_a);
    a = (a * u + e._x1 * e._l23_2a - t * e._l12_2a) / c, o = (o * u + e._y1 * e._l23_2a - n * e._l12_2a) / c;
  }
  e._context.bezierCurveTo(r, i, a, o, e._x2, e._y2);
}
function x3(e, t) {
  this._context = e, this._alpha = t;
}
x3.prototype = {
  areaStart: function() {
    this._line = 0;
  },
  areaEnd: function() {
    this._line = NaN;
  },
  lineStart: function() {
    this._x0 = this._x1 = this._x2 = this._y0 = this._y1 = this._y2 = NaN, this._l01_a = this._l12_a = this._l23_a = this._l01_2a = this._l12_2a = this._l23_2a = this._point = 0;
  },
  lineEnd: function() {
    switch (this._point) {
      case 2:
        this._context.lineTo(this._x2, this._y2);
        break;
      case 3:
        this.point(this._x2, this._y2);
        break;
    }
    (this._line || this._line !== 0 && this._point === 1) && this._context.closePath(), this._line = 1 - this._line;
  },
  point: function(e, t) {
    if (e = +e, t = +t, this._point) {
      var n = this._x2 - e, r = this._y2 - t;
      this._l23_a = Math.sqrt(this._l23_2a = Math.pow(n * n + r * r, this._alpha));
    }
    switch (this._point) {
      case 0:
        this._point = 1, this._line ? this._context.lineTo(e, t) : this._context.moveTo(e, t);
        break;
      case 1:
        this._point = 2;
        break;
      case 2:
        this._point = 3;
      default:
        P1(this, e, t);
        break;
    }
    this._l01_a = this._l12_a, this._l12_a = this._l23_a, this._l01_2a = this._l12_2a, this._l12_2a = this._l23_2a, this._x0 = this._x1, this._x1 = this._x2, this._x2 = e, this._y0 = this._y1, this._y1 = this._y2, this._y2 = t;
  }
};
const Fie = function e(t) {
  function n(r) {
    return t ? new x3(r, t) : new L1(r, 0);
  }
  return n.alpha = function(r) {
    return e(+r);
  }, n;
}(0.5);
function N3(e, t) {
  this._context = e, this._alpha = t;
}
N3.prototype = {
  areaStart: $l,
  areaEnd: $l,
  lineStart: function() {
    this._x0 = this._x1 = this._x2 = this._x3 = this._x4 = this._x5 = this._y0 = this._y1 = this._y2 = this._y3 = this._y4 = this._y5 = NaN, this._l01_a = this._l12_a = this._l23_a = this._l01_2a = this._l12_2a = this._l23_2a = this._point = 0;
  },
  lineEnd: function() {
    switch (this._point) {
      case 1: {
        this._context.moveTo(this._x3, this._y3), this._context.closePath();
        break;
      }
      case 2: {
        this._context.lineTo(this._x3, this._y3), this._context.closePath();
        break;
      }
      case 3: {
        this.point(this._x3, this._y3), this.point(this._x4, this._y4), this.point(this._x5, this._y5);
        break;
      }
    }
  },
  point: function(e, t) {
    if (e = +e, t = +t, this._point) {
      var n = this._x2 - e, r = this._y2 - t;
      this._l23_a = Math.sqrt(this._l23_2a = Math.pow(n * n + r * r, this._alpha));
    }
    switch (this._point) {
      case 0:
        this._point = 1, this._x3 = e, this._y3 = t;
        break;
      case 1:
        this._point = 2, this._context.moveTo(this._x4 = e, this._y4 = t);
        break;
      case 2:
        this._point = 3, this._x5 = e, this._y5 = t;
        break;
      default:
        P1(this, e, t);
        break;
    }
    this._l01_a = this._l12_a, this._l12_a = this._l23_a, this._l01_2a = this._l12_2a, this._l12_2a = this._l23_2a, this._x0 = this._x1, this._x1 = this._x2, this._x2 = e, this._y0 = this._y1, this._y1 = this._y2, this._y2 = t;
  }
};
const Bie = function e(t) {
  function n(r) {
    return t ? new N3(r, t) : new k1(r, 0);
  }
  return n.alpha = function(r) {
    return e(+r);
  }, n;
}(0.5);
function D3(e, t) {
  this._context = e, this._alpha = t;
}
D3.prototype = {
  areaStart: function() {
    this._line = 0;
  },
  areaEnd: function() {
    this._line = NaN;
  },
  lineStart: function() {
    this._x0 = this._x1 = this._x2 = this._y0 = this._y1 = this._y2 = NaN, this._l01_a = this._l12_a = this._l23_a = this._l01_2a = this._l12_2a = this._l23_2a = this._point = 0;
  },
  lineEnd: function() {
    (this._line || this._line !== 0 && this._point === 3) && this._context.closePath(), this._line = 1 - this._line;
  },
  point: function(e, t) {
    if (e = +e, t = +t, this._point) {
      var n = this._x2 - e, r = this._y2 - t;
      this._l23_a = Math.sqrt(this._l23_2a = Math.pow(n * n + r * r, this._alpha));
    }
    switch (this._point) {
      case 0:
        this._point = 1;
        break;
      case 1:
        this._point = 2;
        break;
      case 2:
        this._point = 3, this._line ? this._context.lineTo(this._x2, this._y2) : this._context.moveTo(this._x2, this._y2);
        break;
      case 3:
        this._point = 4;
      default:
        P1(this, e, t);
        break;
    }
    this._l01_a = this._l12_a, this._l12_a = this._l23_a, this._l01_2a = this._l12_2a, this._l12_2a = this._l23_2a, this._x0 = this._x1, this._x1 = this._x2, this._x2 = e, this._y0 = this._y1, this._y1 = this._y2, this._y2 = t;
  }
};
const $ie = function e(t) {
  function n(r) {
    return t ? new D3(r, t) : new M1(r, 0);
  }
  return n.alpha = function(r) {
    return e(+r);
  }, n;
}(0.5);
function I3(e) {
  this._context = e;
}
I3.prototype = {
  areaStart: $l,
  areaEnd: $l,
  lineStart: function() {
    this._point = 0;
  },
  lineEnd: function() {
    this._point && this._context.closePath();
  },
  point: function(e, t) {
    e = +e, t = +t, this._point ? this._context.lineTo(e, t) : (this._point = 1, this._context.moveTo(e, t));
  }
};
function Uie(e) {
  return new I3(e);
}
function vk(e) {
  return e < 0 ? -1 : 1;
}
function bk(e, t, n) {
  var r = e._x1 - e._x0, i = t - e._x1, a = (e._y1 - e._y0) / (r || i < 0 && -0), o = (n - e._y1) / (i || r < 0 && -0), s = (a * i + o * r) / (r + i);
  return (vk(a) + vk(o)) * Math.min(Math.abs(a), Math.abs(o), 0.5 * Math.abs(s)) || 0;
}
function Ek(e, t) {
  var n = e._x1 - e._x0;
  return n ? (3 * (e._y1 - e._y0) / n - t) / 2 : t;
}
function jy(e, t, n) {
  var r = e._x0, i = e._y0, a = e._x1, o = e._y1, s = (a - r) / 3;
  e._context.bezierCurveTo(r + s, i + s * t, a - s, o - s * n, a, o);
}
function Hg(e) {
  this._context = e;
}
Hg.prototype = {
  areaStart: function() {
    this._line = 0;
  },
  areaEnd: function() {
    this._line = NaN;
  },
  lineStart: function() {
    this._x0 = this._x1 = this._y0 = this._y1 = this._t0 = NaN, this._point = 0;
  },
  lineEnd: function() {
    switch (this._point) {
      case 2:
        this._context.lineTo(this._x1, this._y1);
        break;
      case 3:
        jy(this, this._t0, Ek(this, this._t0));
        break;
    }
    (this._line || this._line !== 0 && this._point === 1) && this._context.closePath(), this._line = 1 - this._line;
  },
  point: function(e, t) {
    var n = NaN;
    if (e = +e, t = +t, !(e === this._x1 && t === this._y1)) {
      switch (this._point) {
        case 0:
          this._point = 1, this._line ? this._context.lineTo(e, t) : this._context.moveTo(e, t);
          break;
        case 1:
          this._point = 2;
          break;
        case 2:
          this._point = 3, jy(this, Ek(this, n = bk(this, e, t)), n);
          break;
        default:
          jy(this, this._t0, n = bk(this, e, t));
          break;
      }
      this._x0 = this._x1, this._x1 = e, this._y0 = this._y1, this._y1 = t, this._t0 = n;
    }
  }
};
function L3(e) {
  this._context = new k3(e);
}
(L3.prototype = Object.create(Hg.prototype)).point = function(e, t) {
  Hg.prototype.point.call(this, t, e);
};
function k3(e) {
  this._context = e;
}
k3.prototype = {
  moveTo: function(e, t) {
    this._context.moveTo(t, e);
  },
  closePath: function() {
    this._context.closePath();
  },
  lineTo: function(e, t) {
    this._context.lineTo(t, e);
  },
  bezierCurveTo: function(e, t, n, r, i, a) {
    this._context.bezierCurveTo(t, e, r, n, a, i);
  }
};
function qie(e) {
  return new Hg(e);
}
function Gie(e) {
  return new L3(e);
}
function M3(e) {
  this._context = e;
}
M3.prototype = {
  areaStart: function() {
    this._line = 0;
  },
  areaEnd: function() {
    this._line = NaN;
  },
  lineStart: function() {
    this._x = [], this._y = [];
  },
  lineEnd: function() {
    var e = this._x, t = this._y, n = e.length;
    if (n)
      if (this._line ? this._context.lineTo(e[0], t[0]) : this._context.moveTo(e[0], t[0]), n === 2)
        this._context.lineTo(e[1], t[1]);
      else
        for (var r = Sk(e), i = Sk(t), a = 0, o = 1; o < n; ++a, ++o)
          this._context.bezierCurveTo(r[0][a], i[0][a], r[1][a], i[1][a], e[o], t[o]);
    (this._line || this._line !== 0 && n === 1) && this._context.closePath(), this._line = 1 - this._line, this._x = this._y = null;
  },
  point: function(e, t) {
    this._x.push(+e), this._y.push(+t);
  }
};
function Sk(e) {
  var t, n = e.length - 1, r, i = new Array(n), a = new Array(n), o = new Array(n);
  for (i[0] = 0, a[0] = 2, o[0] = e[0] + 2 * e[1], t = 1; t < n - 1; ++t) i[t] = 1, a[t] = 4, o[t] = 4 * e[t] + 2 * e[t + 1];
  for (i[n - 1] = 2, a[n - 1] = 7, o[n - 1] = 8 * e[n - 1] + e[n], t = 1; t < n; ++t) r = i[t] / a[t - 1], a[t] -= r, o[t] -= r * o[t - 1];
  for (i[n - 1] = o[n - 1] / a[n - 1], t = n - 2; t >= 0; --t) i[t] = (o[t] - i[t + 1]) / a[t];
  for (a[n - 1] = (e[n] + i[n - 1]) / 2, t = 0; t < n - 1; ++t) a[t] = 2 * e[t + 1] - i[t + 1];
  return [i, a];
}
function Yie(e) {
  return new M3(e);
}
function V_(e, t) {
  this._context = e, this._t = t;
}
V_.prototype = {
  areaStart: function() {
    this._line = 0;
  },
  areaEnd: function() {
    this._line = NaN;
  },
  lineStart: function() {
    this._x = this._y = NaN, this._point = 0;
  },
  lineEnd: function() {
    0 < this._t && this._t < 1 && this._point === 2 && this._context.lineTo(this._x, this._y), (this._line || this._line !== 0 && this._point === 1) && this._context.closePath(), this._line >= 0 && (this._t = 1 - this._t, this._line = 1 - this._line);
  },
  point: function(e, t) {
    switch (e = +e, t = +t, this._point) {
      case 0:
        this._point = 1, this._line ? this._context.lineTo(e, t) : this._context.moveTo(e, t);
        break;
      case 1:
        this._point = 2;
      default: {
        if (this._t <= 0)
          this._context.lineTo(this._x, t), this._context.lineTo(e, t);
        else {
          var n = this._x * (1 - this._t) + e * this._t;
          this._context.lineTo(n, this._y), this._context.lineTo(n, t);
        }
        break;
      }
    }
    this._x = e, this._y = t;
  }
};
function Hie(e) {
  return new V_(e, 0.5);
}
function zie(e) {
  return new V_(e, 0);
}
function Vie(e) {
  return new V_(e, 1);
}
function $f(e, t, n) {
  this.k = e, this.x = t, this.y = n;
}
$f.prototype = {
  constructor: $f,
  scale: function(e) {
    return e === 1 ? this : new $f(this.k * e, this.x, this.y);
  },
  translate: function(e, t) {
    return e === 0 & t === 0 ? this : new $f(this.k, this.x + this.k * e, this.y + this.k * t);
  },
  apply: function(e) {
    return [e[0] * this.k + this.x, e[1] * this.k + this.y];
  },
  applyX: function(e) {
    return e * this.k + this.x;
  },
  applyY: function(e) {
    return e * this.k + this.y;
  },
  invert: function(e) {
    return [(e[0] - this.x) / this.k, (e[1] - this.y) / this.k];
  },
  invertX: function(e) {
    return (e - this.x) / this.k;
  },
  invertY: function(e) {
    return (e - this.y) / this.k;
  },
  rescaleX: function(e) {
    return e.copy().domain(e.range().map(this.invertX, this).map(e.invert, e));
  },
  rescaleY: function(e) {
    return e.copy().domain(e.range().map(this.invertY, this).map(e.invert, e));
  },
  toString: function() {
    return "translate(" + this.x + "," + this.y + ") scale(" + this.k + ")";
  }
};
$f.prototype;
/*! @license DOMPurify 3.1.6 | (c) Cure53 and other contributors | Released under the Apache license 2.0 and Mozilla Public License 2.0 | github.com/cure53/DOMPurify/blob/3.1.6/LICENSE */
const {
  entries: P3,
  setPrototypeOf: yk,
  isFrozen: Wie,
  getPrototypeOf: Kie,
  getOwnPropertyDescriptor: jie
} = Object;
let {
  freeze: Ki,
  seal: Ja,
  create: F3
} = Object, {
  apply: uC,
  construct: cC
} = typeof Reflect < "u" && Reflect;
Ki || (Ki = function(t) {
  return t;
});
Ja || (Ja = function(t) {
  return t;
});
uC || (uC = function(t, n, r) {
  return t.apply(n, r);
});
cC || (cC = function(t, n) {
  return new t(...n);
});
const Uh = Da(Array.prototype.forEach), Tk = Da(Array.prototype.pop), Sf = Da(Array.prototype.push), ug = Da(String.prototype.toLowerCase), Qy = Da(String.prototype.toString), Ck = Da(String.prototype.match), yf = Da(String.prototype.replace), Qie = Da(String.prototype.indexOf), Xie = Da(String.prototype.trim), mo = Da(Object.prototype.hasOwnProperty), Ui = Da(RegExp.prototype.test), Tf = Zie(TypeError);
function Da(e) {
  return function(t) {
    for (var n = arguments.length, r = new Array(n > 1 ? n - 1 : 0), i = 1; i < n; i++)
      r[i - 1] = arguments[i];
    return uC(e, t, r);
  };
}
function Zie(e) {
  return function() {
    for (var t = arguments.length, n = new Array(t), r = 0; r < t; r++)
      n[r] = arguments[r];
    return cC(e, n);
  };
}
function bn(e, t) {
  let n = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : ug;
  yk && yk(e, null);
  let r = t.length;
  for (; r--; ) {
    let i = t[r];
    if (typeof i == "string") {
      const a = n(i);
      a !== i && (Wie(t) || (t[r] = a), i = a);
    }
    e[i] = !0;
  }
  return e;
}
function Jie(e) {
  for (let t = 0; t < e.length; t++)
    mo(e, t) || (e[t] = null);
  return e;
}
function Tu(e) {
  const t = F3(null);
  for (const [n, r] of P3(e))
    mo(e, n) && (Array.isArray(r) ? t[n] = Jie(r) : r && typeof r == "object" && r.constructor === Object ? t[n] = Tu(r) : t[n] = r);
  return t;
}
function Cf(e, t) {
  for (; e !== null; ) {
    const r = jie(e, t);
    if (r) {
      if (r.get)
        return Da(r.get);
      if (typeof r.value == "function")
        return Da(r.value);
    }
    e = Kie(e);
  }
  function n() {
    return null;
  }
  return n;
}
const Ak = Ki(["a", "abbr", "acronym", "address", "area", "article", "aside", "audio", "b", "bdi", "bdo", "big", "blink", "blockquote", "body", "br", "button", "canvas", "caption", "center", "cite", "code", "col", "colgroup", "content", "data", "datalist", "dd", "decorator", "del", "details", "dfn", "dialog", "dir", "div", "dl", "dt", "element", "em", "fieldset", "figcaption", "figure", "font", "footer", "form", "h1", "h2", "h3", "h4", "h5", "h6", "head", "header", "hgroup", "hr", "html", "i", "img", "input", "ins", "kbd", "label", "legend", "li", "main", "map", "mark", "marquee", "menu", "menuitem", "meter", "nav", "nobr", "ol", "optgroup", "option", "output", "p", "picture", "pre", "progress", "q", "rp", "rt", "ruby", "s", "samp", "section", "select", "shadow", "small", "source", "spacer", "span", "strike", "strong", "style", "sub", "summary", "sup", "table", "tbody", "td", "template", "textarea", "tfoot", "th", "thead", "time", "tr", "track", "tt", "u", "ul", "var", "video", "wbr"]), Xy = Ki(["svg", "a", "altglyph", "altglyphdef", "altglyphitem", "animatecolor", "animatemotion", "animatetransform", "circle", "clippath", "defs", "desc", "ellipse", "filter", "font", "g", "glyph", "glyphref", "hkern", "image", "line", "lineargradient", "marker", "mask", "metadata", "mpath", "path", "pattern", "polygon", "polyline", "radialgradient", "rect", "stop", "style", "switch", "symbol", "text", "textpath", "title", "tref", "tspan", "view", "vkern"]), Zy = Ki(["feBlend", "feColorMatrix", "feComponentTransfer", "feComposite", "feConvolveMatrix", "feDiffuseLighting", "feDisplacementMap", "feDistantLight", "feDropShadow", "feFlood", "feFuncA", "feFuncB", "feFuncG", "feFuncR", "feGaussianBlur", "feImage", "feMerge", "feMergeNode", "feMorphology", "feOffset", "fePointLight", "feSpecularLighting", "feSpotLight", "feTile", "feTurbulence"]), eae = Ki(["animate", "color-profile", "cursor", "discard", "font-face", "font-face-format", "font-face-name", "font-face-src", "font-face-uri", "foreignobject", "hatch", "hatchpath", "mesh", "meshgradient", "meshpatch", "meshrow", "missing-glyph", "script", "set", "solidcolor", "unknown", "use"]), Jy = Ki(["math", "menclose", "merror", "mfenced", "mfrac", "mglyph", "mi", "mlabeledtr", "mmultiscripts", "mn", "mo", "mover", "mpadded", "mphantom", "mroot", "mrow", "ms", "mspace", "msqrt", "mstyle", "msub", "msup", "msubsup", "mtable", "mtd", "mtext", "mtr", "munder", "munderover", "mprescripts"]), tae = Ki(["maction", "maligngroup", "malignmark", "mlongdiv", "mscarries", "mscarry", "msgroup", "mstack", "msline", "msrow", "semantics", "annotation", "annotation-xml", "mprescripts", "none"]), Ok = Ki(["#text"]), Rk = Ki(["accept", "action", "align", "alt", "autocapitalize", "autocomplete", "autopictureinpicture", "autoplay", "background", "bgcolor", "border", "capture", "cellpadding", "cellspacing", "checked", "cite", "class", "clear", "color", "cols", "colspan", "controls", "controlslist", "coords", "crossorigin", "datetime", "decoding", "default", "dir", "disabled", "disablepictureinpicture", "disableremoteplayback", "download", "draggable", "enctype", "enterkeyhint", "face", "for", "headers", "height", "hidden", "high", "href", "hreflang", "id", "inputmode", "integrity", "ismap", "kind", "label", "lang", "list", "loading", "loop", "low", "max", "maxlength", "media", "method", "min", "minlength", "multiple", "muted", "name", "nonce", "noshade", "novalidate", "nowrap", "open", "optimum", "pattern", "placeholder", "playsinline", "popover", "popovertarget", "popovertargetaction", "poster", "preload", "pubdate", "radiogroup", "readonly", "rel", "required", "rev", "reversed", "role", "rows", "rowspan", "spellcheck", "scope", "selected", "shape", "size", "sizes", "span", "srclang", "start", "src", "srcset", "step", "style", "summary", "tabindex", "title", "translate", "type", "usemap", "valign", "value", "width", "wrap", "xmlns", "slot"]), eT = Ki(["accent-height", "accumulate", "additive", "alignment-baseline", "ascent", "attributename", "attributetype", "azimuth", "basefrequency", "baseline-shift", "begin", "bias", "by", "class", "clip", "clippathunits", "clip-path", "clip-rule", "color", "color-interpolation", "color-interpolation-filters", "color-profile", "color-rendering", "cx", "cy", "d", "dx", "dy", "diffuseconstant", "direction", "display", "divisor", "dur", "edgemode", "elevation", "end", "fill", "fill-opacity", "fill-rule", "filter", "filterunits", "flood-color", "flood-opacity", "font-family", "font-size", "font-size-adjust", "font-stretch", "font-style", "font-variant", "font-weight", "fx", "fy", "g1", "g2", "glyph-name", "glyphref", "gradientunits", "gradienttransform", "height", "href", "id", "image-rendering", "in", "in2", "k", "k1", "k2", "k3", "k4", "kerning", "keypoints", "keysplines", "keytimes", "lang", "lengthadjust", "letter-spacing", "kernelmatrix", "kernelunitlength", "lighting-color", "local", "marker-end", "marker-mid", "marker-start", "markerheight", "markerunits", "markerwidth", "maskcontentunits", "maskunits", "max", "mask", "media", "method", "mode", "min", "name", "numoctaves", "offset", "operator", "opacity", "order", "orient", "orientation", "origin", "overflow", "paint-order", "path", "pathlength", "patterncontentunits", "patterntransform", "patternunits", "points", "preservealpha", "preserveaspectratio", "primitiveunits", "r", "rx", "ry", "radius", "refx", "refy", "repeatcount", "repeatdur", "restart", "result", "rotate", "scale", "seed", "shape-rendering", "specularconstant", "specularexponent", "spreadmethod", "startoffset", "stddeviation", "stitchtiles", "stop-color", "stop-opacity", "stroke-dasharray", "stroke-dashoffset", "stroke-linecap", "stroke-linejoin", "stroke-miterlimit", "stroke-opacity", "stroke", "stroke-width", "style", "surfacescale", "systemlanguage", "tabindex", "targetx", "targety", "transform", "transform-origin", "text-anchor", "text-decoration", "text-rendering", "textlength", "type", "u1", "u2", "unicode", "values", "viewbox", "visibility", "version", "vert-adv-y", "vert-origin-x", "vert-origin-y", "width", "word-spacing", "wrap", "writing-mode", "xchannelselector", "ychannelselector", "x", "x1", "x2", "xmlns", "y", "y1", "y2", "z", "zoomandpan"]), wk = Ki(["accent", "accentunder", "align", "bevelled", "close", "columnsalign", "columnlines", "columnspan", "denomalign", "depth", "dir", "display", "displaystyle", "encoding", "fence", "frame", "height", "href", "id", "largeop", "length", "linethickness", "lspace", "lquote", "mathbackground", "mathcolor", "mathsize", "mathvariant", "maxsize", "minsize", "movablelimits", "notation", "numalign", "open", "rowalign", "rowlines", "rowspacing", "rowspan", "rspace", "rquote", "scriptlevel", "scriptminsize", "scriptsizemultiplier", "selection", "separator", "separators", "stretchy", "subscriptshift", "supscriptshift", "symmetric", "voffset", "width", "xmlns"]), qh = Ki(["xlink:href", "xml:id", "xlink:title", "xml:space", "xmlns:xlink"]), nae = Ja(/\{\{[\w\W]*|[\w\W]*\}\}/gm), rae = Ja(/<%[\w\W]*|[\w\W]*%>/gm), iae = Ja(/\${[\w\W]*}/gm), aae = Ja(/^data-[\-\w.\u00B7-\uFFFF]/), oae = Ja(/^aria-[\-\w]+$/), B3 = Ja(
  /^(?:(?:(?:f|ht)tps?|mailto|tel|callto|sms|cid|xmpp):|[^a-z]|[a-z+.\-]+(?:[^a-z+.\-:]|$))/i
  // eslint-disable-line no-useless-escape
), sae = Ja(/^(?:\w+script|data):/i), lae = Ja(
  /[\u0000-\u0020\u00A0\u1680\u180E\u2000-\u2029\u205F\u3000]/g
  // eslint-disable-line no-control-regex
), $3 = Ja(/^html$/i), uae = Ja(/^[a-z][.\w]*(-[.\w]+)+$/i);
var xk = /* @__PURE__ */ Object.freeze({
  __proto__: null,
  MUSTACHE_EXPR: nae,
  ERB_EXPR: rae,
  TMPLIT_EXPR: iae,
  DATA_ATTR: aae,
  ARIA_ATTR: oae,
  IS_ALLOWED_URI: B3,
  IS_SCRIPT_OR_DATA: sae,
  ATTR_WHITESPACE: lae,
  DOCTYPE_NAME: $3,
  CUSTOM_ELEMENT: uae
});
const Af = {
  element: 1,
  attribute: 2,
  text: 3,
  cdataSection: 4,
  entityReference: 5,
  // Deprecated
  entityNode: 6,
  // Deprecated
  progressingInstruction: 7,
  comment: 8,
  document: 9,
  documentType: 10,
  documentFragment: 11,
  notation: 12
  // Deprecated
}, cae = function() {
  return typeof window > "u" ? null : window;
}, dae = function(t, n) {
  if (typeof t != "object" || typeof t.createPolicy != "function")
    return null;
  let r = null;
  const i = "data-tt-policy-suffix";
  n && n.hasAttribute(i) && (r = n.getAttribute(i));
  const a = "dompurify" + (r ? "#" + r : "");
  try {
    return t.createPolicy(a, {
      createHTML(o) {
        return o;
      },
      createScriptURL(o) {
        return o;
      }
    });
  } catch {
    return console.warn("TrustedTypes policy " + a + " could not be created."), null;
  }
};
function U3() {
  let e = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : cae();
  const t = (vt) => U3(vt);
  if (t.version = "3.1.6", t.removed = [], !e || !e.document || e.document.nodeType !== Af.document)
    return t.isSupported = !1, t;
  let {
    document: n
  } = e;
  const r = n, i = r.currentScript, {
    DocumentFragment: a,
    HTMLTemplateElement: o,
    Node: s,
    Element: l,
    NodeFilter: u,
    NamedNodeMap: c = e.NamedNodeMap || e.MozNamedAttrMap,
    HTMLFormElement: d,
    DOMParser: f,
    trustedTypes: h
  } = e, m = l.prototype, v = Cf(m, "cloneNode"), b = Cf(m, "remove"), y = Cf(m, "nextSibling"), g = Cf(m, "childNodes"), E = Cf(m, "parentNode");
  if (typeof o == "function") {
    const vt = n.createElement("template");
    vt.content && vt.content.ownerDocument && (n = vt.content.ownerDocument);
  }
  let S, C = "";
  const {
    implementation: T,
    createNodeIterator: O,
    createDocumentFragment: R,
    getElementsByTagName: D
  } = n, {
    importNode: q
  } = r;
  let $ = {};
  t.isSupported = typeof P3 == "function" && typeof E == "function" && T && T.createHTMLDocument !== void 0;
  const {
    MUSTACHE_EXPR: P,
    ERB_EXPR: Y,
    TMPLIT_EXPR: L,
    DATA_ATTR: x,
    ARIA_ATTR: I,
    IS_SCRIPT_OR_DATA: k,
    ATTR_WHITESPACE: B,
    CUSTOM_ELEMENT: W
  } = xk;
  let {
    IS_ALLOWED_URI: Z
  } = xk, V = null;
  const K = bn({}, [...Ak, ...Xy, ...Zy, ...Jy, ...Ok]);
  let ne = null;
  const Ee = bn({}, [...Rk, ...eT, ...wk, ...qh]);
  let oe = Object.seal(F3(null, {
    tagNameCheck: {
      writable: !0,
      configurable: !1,
      enumerable: !0,
      value: null
    },
    attributeNameCheck: {
      writable: !0,
      configurable: !1,
      enumerable: !0,
      value: null
    },
    allowCustomizedBuiltInElements: {
      writable: !0,
      configurable: !1,
      enumerable: !0,
      value: !1
    }
  })), ae = null, pe = null, Se = !0, Re = !0, Ye = !1, nt = !0, ut = !1, Tt = !0, Ot = !1, Xt = !1, We = !1, st = !1, Pt = !1, Ke = !1, Je = !0, Be = !1;
  const pt = "user-content-";
  let ft = !0, Ze = !1, _t = {}, St = null;
  const we = bn({}, ["annotation-xml", "audio", "colgroup", "desc", "foreignobject", "head", "iframe", "math", "mi", "mn", "mo", "ms", "mtext", "noembed", "noframes", "noscript", "plaintext", "script", "style", "svg", "template", "thead", "title", "video", "xmp"]);
  let je = null;
  const yt = bn({}, ["audio", "video", "img", "source", "image", "track"]);
  let Rt = null;
  const sn = bn({}, ["alt", "class", "for", "id", "label", "name", "pattern", "placeholder", "role", "summary", "title", "value", "style", "xmlns"]), me = "http://www.w3.org/1998/Math/MathML", He = "http://www.w3.org/2000/svg", tt = "http://www.w3.org/1999/xhtml";
  let ot = tt, xn = !1, kt = null;
  const Dn = bn({}, [me, He, tt], Qy);
  let gn = null;
  const Vn = ["application/xhtml+xml", "text/html"], X = "text/html";
  let te = null, _e = null;
  const M = n.createElement("form"), G = function(ue) {
    return ue instanceof RegExp || ue instanceof Function;
  }, j = function() {
    let ue = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : {};
    if (!(_e && _e === ue)) {
      if ((!ue || typeof ue != "object") && (ue = {}), ue = Tu(ue), gn = // eslint-disable-next-line unicorn/prefer-includes
      Vn.indexOf(ue.PARSER_MEDIA_TYPE) === -1 ? X : ue.PARSER_MEDIA_TYPE, te = gn === "application/xhtml+xml" ? Qy : ug, V = mo(ue, "ALLOWED_TAGS") ? bn({}, ue.ALLOWED_TAGS, te) : K, ne = mo(ue, "ALLOWED_ATTR") ? bn({}, ue.ALLOWED_ATTR, te) : Ee, kt = mo(ue, "ALLOWED_NAMESPACES") ? bn({}, ue.ALLOWED_NAMESPACES, Qy) : Dn, Rt = mo(ue, "ADD_URI_SAFE_ATTR") ? bn(
        Tu(sn),
        // eslint-disable-line indent
        ue.ADD_URI_SAFE_ATTR,
        // eslint-disable-line indent
        te
        // eslint-disable-line indent
      ) : sn, je = mo(ue, "ADD_DATA_URI_TAGS") ? bn(
        Tu(yt),
        // eslint-disable-line indent
        ue.ADD_DATA_URI_TAGS,
        // eslint-disable-line indent
        te
        // eslint-disable-line indent
      ) : yt, St = mo(ue, "FORBID_CONTENTS") ? bn({}, ue.FORBID_CONTENTS, te) : we, ae = mo(ue, "FORBID_TAGS") ? bn({}, ue.FORBID_TAGS, te) : {}, pe = mo(ue, "FORBID_ATTR") ? bn({}, ue.FORBID_ATTR, te) : {}, _t = mo(ue, "USE_PROFILES") ? ue.USE_PROFILES : !1, Se = ue.ALLOW_ARIA_ATTR !== !1, Re = ue.ALLOW_DATA_ATTR !== !1, Ye = ue.ALLOW_UNKNOWN_PROTOCOLS || !1, nt = ue.ALLOW_SELF_CLOSE_IN_ATTR !== !1, ut = ue.SAFE_FOR_TEMPLATES || !1, Tt = ue.SAFE_FOR_XML !== !1, Ot = ue.WHOLE_DOCUMENT || !1, st = ue.RETURN_DOM || !1, Pt = ue.RETURN_DOM_FRAGMENT || !1, Ke = ue.RETURN_TRUSTED_TYPE || !1, We = ue.FORCE_BODY || !1, Je = ue.SANITIZE_DOM !== !1, Be = ue.SANITIZE_NAMED_PROPS || !1, ft = ue.KEEP_CONTENT !== !1, Ze = ue.IN_PLACE || !1, Z = ue.ALLOWED_URI_REGEXP || B3, ot = ue.NAMESPACE || tt, oe = ue.CUSTOM_ELEMENT_HANDLING || {}, ue.CUSTOM_ELEMENT_HANDLING && G(ue.CUSTOM_ELEMENT_HANDLING.tagNameCheck) && (oe.tagNameCheck = ue.CUSTOM_ELEMENT_HANDLING.tagNameCheck), ue.CUSTOM_ELEMENT_HANDLING && G(ue.CUSTOM_ELEMENT_HANDLING.attributeNameCheck) && (oe.attributeNameCheck = ue.CUSTOM_ELEMENT_HANDLING.attributeNameCheck), ue.CUSTOM_ELEMENT_HANDLING && typeof ue.CUSTOM_ELEMENT_HANDLING.allowCustomizedBuiltInElements == "boolean" && (oe.allowCustomizedBuiltInElements = ue.CUSTOM_ELEMENT_HANDLING.allowCustomizedBuiltInElements), ut && (Re = !1), Pt && (st = !0), _t && (V = bn({}, Ok), ne = [], _t.html === !0 && (bn(V, Ak), bn(ne, Rk)), _t.svg === !0 && (bn(V, Xy), bn(ne, eT), bn(ne, qh)), _t.svgFilters === !0 && (bn(V, Zy), bn(ne, eT), bn(ne, qh)), _t.mathMl === !0 && (bn(V, Jy), bn(ne, wk), bn(ne, qh))), ue.ADD_TAGS && (V === K && (V = Tu(V)), bn(V, ue.ADD_TAGS, te)), ue.ADD_ATTR && (ne === Ee && (ne = Tu(ne)), bn(ne, ue.ADD_ATTR, te)), ue.ADD_URI_SAFE_ATTR && bn(Rt, ue.ADD_URI_SAFE_ATTR, te), ue.FORBID_CONTENTS && (St === we && (St = Tu(St)), bn(St, ue.FORBID_CONTENTS, te)), ft && (V["#text"] = !0), Ot && bn(V, ["html", "head", "body"]), V.table && (bn(V, ["tbody"]), delete ae.tbody), ue.TRUSTED_TYPES_POLICY) {
        if (typeof ue.TRUSTED_TYPES_POLICY.createHTML != "function")
          throw Tf('TRUSTED_TYPES_POLICY configuration option must provide a "createHTML" hook.');
        if (typeof ue.TRUSTED_TYPES_POLICY.createScriptURL != "function")
          throw Tf('TRUSTED_TYPES_POLICY configuration option must provide a "createScriptURL" hook.');
        S = ue.TRUSTED_TYPES_POLICY, C = S.createHTML("");
      } else
        S === void 0 && (S = dae(h, i)), S !== null && typeof C == "string" && (C = S.createHTML(""));
      Ki && Ki(ue), _e = ue;
    }
  }, ce = bn({}, ["mi", "mo", "mn", "ms", "mtext"]), be = bn({}, ["foreignobject", "annotation-xml"]), Ie = bn({}, ["title", "style", "font", "a", "script"]), Ue = bn({}, [...Xy, ...Zy, ...eae]), Ve = bn({}, [...Jy, ...tae]), dt = function(ue) {
    let Q = E(ue);
    (!Q || !Q.tagName) && (Q = {
      namespaceURI: ot,
      tagName: "template"
    });
    const ye = ug(ue.tagName), ct = ug(Q.tagName);
    return kt[ue.namespaceURI] ? ue.namespaceURI === He ? Q.namespaceURI === tt ? ye === "svg" : Q.namespaceURI === me ? ye === "svg" && (ct === "annotation-xml" || ce[ct]) : !!Ue[ye] : ue.namespaceURI === me ? Q.namespaceURI === tt ? ye === "math" : Q.namespaceURI === He ? ye === "math" && be[ct] : !!Ve[ye] : ue.namespaceURI === tt ? Q.namespaceURI === He && !be[ct] || Q.namespaceURI === me && !ce[ct] ? !1 : !Ve[ye] && (Ie[ye] || !Ue[ye]) : !!(gn === "application/xhtml+xml" && kt[ue.namespaceURI]) : !1;
  }, Pe = function(ue) {
    Sf(t.removed, {
      element: ue
    });
    try {
      E(ue).removeChild(ue);
    } catch {
      b(ue);
    }
  }, xe = function(ue, Q) {
    try {
      Sf(t.removed, {
        attribute: Q.getAttributeNode(ue),
        from: Q
      });
    } catch {
      Sf(t.removed, {
        attribute: null,
        from: Q
      });
    }
    if (Q.removeAttribute(ue), ue === "is" && !ne[ue])
      if (st || Pt)
        try {
          Pe(Q);
        } catch {
        }
      else
        try {
          Q.setAttribute(ue, "");
        } catch {
        }
  }, Mt = function(ue) {
    let Q = null, ye = null;
    if (We)
      ue = "<remove></remove>" + ue;
    else {
      const Rn = Ck(ue, /^[\r\n\t ]+/);
      ye = Rn && Rn[0];
    }
    gn === "application/xhtml+xml" && ot === tt && (ue = '<html xmlns="http://www.w3.org/1999/xhtml"><head></head><body>' + ue + "</body></html>");
    const ct = S ? S.createHTML(ue) : ue;
    if (ot === tt)
      try {
        Q = new f().parseFromString(ct, gn);
      } catch {
      }
    if (!Q || !Q.documentElement) {
      Q = T.createDocument(ot, "template", null);
      try {
        Q.documentElement.innerHTML = xn ? C : ct;
      } catch {
      }
    }
    const en = Q.body || Q.documentElement;
    return ue && ye && en.insertBefore(n.createTextNode(ye), en.childNodes[0] || null), ot === tt ? D.call(Q, Ot ? "html" : "body")[0] : Ot ? Q.documentElement : en;
  }, Zt = function(ue) {
    return O.call(
      ue.ownerDocument || ue,
      ue,
      // eslint-disable-next-line no-bitwise
      u.SHOW_ELEMENT | u.SHOW_COMMENT | u.SHOW_TEXT | u.SHOW_PROCESSING_INSTRUCTION | u.SHOW_CDATA_SECTION,
      null
    );
  }, Jt = function(ue) {
    return ue instanceof d && (typeof ue.nodeName != "string" || typeof ue.textContent != "string" || typeof ue.removeChild != "function" || !(ue.attributes instanceof c) || typeof ue.removeAttribute != "function" || typeof ue.setAttribute != "function" || typeof ue.namespaceURI != "string" || typeof ue.insertBefore != "function" || typeof ue.hasChildNodes != "function");
  }, xr = function(ue) {
    return typeof s == "function" && ue instanceof s;
  }, Un = function(ue, Q, ye) {
    $[ue] && Uh($[ue], (ct) => {
      ct.call(t, Q, ye, _e);
    });
  }, pi = function(ue) {
    let Q = null;
    if (Un("beforeSanitizeElements", ue, null), Jt(ue))
      return Pe(ue), !0;
    const ye = te(ue.nodeName);
    if (Un("uponSanitizeElement", ue, {
      tagName: ye,
      allowedTags: V
    }), ue.hasChildNodes() && !xr(ue.firstElementChild) && Ui(/<[/\w]/g, ue.innerHTML) && Ui(/<[/\w]/g, ue.textContent) || ue.nodeType === Af.progressingInstruction || Tt && ue.nodeType === Af.comment && Ui(/<[/\w]/g, ue.data))
      return Pe(ue), !0;
    if (!V[ye] || ae[ye]) {
      if (!ae[ye] && ti(ye) && (oe.tagNameCheck instanceof RegExp && Ui(oe.tagNameCheck, ye) || oe.tagNameCheck instanceof Function && oe.tagNameCheck(ye)))
        return !1;
      if (ft && !St[ye]) {
        const ct = E(ue) || ue.parentNode, en = g(ue) || ue.childNodes;
        if (en && ct) {
          const Rn = en.length;
          for (let Nr = Rn - 1; Nr >= 0; --Nr) {
            const mi = v(en[Nr], !0);
            mi.__removalCount = (ue.__removalCount || 0) + 1, ct.insertBefore(mi, y(ue));
          }
        }
      }
      return Pe(ue), !0;
    }
    return ue instanceof l && !dt(ue) || (ye === "noscript" || ye === "noembed" || ye === "noframes") && Ui(/<\/no(script|embed|frames)/i, ue.innerHTML) ? (Pe(ue), !0) : (ut && ue.nodeType === Af.text && (Q = ue.textContent, Uh([P, Y, L], (ct) => {
      Q = yf(Q, ct, " ");
    }), ue.textContent !== Q && (Sf(t.removed, {
      element: ue.cloneNode()
    }), ue.textContent = Q)), Un("afterSanitizeElements", ue, null), !1);
  }, Cr = function(ue, Q, ye) {
    if (Je && (Q === "id" || Q === "name") && (ye in n || ye in M))
      return !1;
    if (!(Re && !pe[Q] && Ui(x, Q))) {
      if (!(Se && Ui(I, Q))) {
        if (!ne[Q] || pe[Q]) {
          if (
            // First condition does a very basic check if a) it's basically a valid custom element tagname AND
            // b) if the tagName passes whatever the user has configured for CUSTOM_ELEMENT_HANDLING.tagNameCheck
            // and c) if the attribute name passes whatever the user has configured for CUSTOM_ELEMENT_HANDLING.attributeNameCheck
            !(ti(ue) && (oe.tagNameCheck instanceof RegExp && Ui(oe.tagNameCheck, ue) || oe.tagNameCheck instanceof Function && oe.tagNameCheck(ue)) && (oe.attributeNameCheck instanceof RegExp && Ui(oe.attributeNameCheck, Q) || oe.attributeNameCheck instanceof Function && oe.attributeNameCheck(Q)) || // Alternative, second condition checks if it's an `is`-attribute, AND
            // the value passes whatever the user has configured for CUSTOM_ELEMENT_HANDLING.tagNameCheck
            Q === "is" && oe.allowCustomizedBuiltInElements && (oe.tagNameCheck instanceof RegExp && Ui(oe.tagNameCheck, ye) || oe.tagNameCheck instanceof Function && oe.tagNameCheck(ye)))
          ) return !1;
        } else if (!Rt[Q]) {
          if (!Ui(Z, yf(ye, B, ""))) {
            if (!((Q === "src" || Q === "xlink:href" || Q === "href") && ue !== "script" && Qie(ye, "data:") === 0 && je[ue])) {
              if (!(Ye && !Ui(k, yf(ye, B, "")))) {
                if (ye)
                  return !1;
              }
            }
          }
        }
      }
    }
    return !0;
  }, ti = function(ue) {
    return ue !== "annotation-xml" && Ck(ue, W);
  }, Si = function(ue) {
    Un("beforeSanitizeAttributes", ue, null);
    const {
      attributes: Q
    } = ue;
    if (!Q)
      return;
    const ye = {
      attrName: "",
      attrValue: "",
      keepAttr: !0,
      allowedAttributes: ne
    };
    let ct = Q.length;
    for (; ct--; ) {
      const en = Q[ct], {
        name: Rn,
        namespaceURI: Nr,
        value: mi
      } = en, ha = te(Rn);
      let Er = Rn === "value" ? mi : Xie(mi);
      if (ye.attrName = ha, ye.attrValue = Er, ye.keepAttr = !0, ye.forceKeepAttr = void 0, Un("uponSanitizeAttribute", ue, ye), Er = ye.attrValue, Tt && Ui(/((--!?|])>)|<\/(style|title)/i, Er)) {
        xe(Rn, ue);
        continue;
      }
      if (ye.forceKeepAttr || (xe(Rn, ue), !ye.keepAttr))
        continue;
      if (!nt && Ui(/\/>/i, Er)) {
        xe(Rn, ue);
        continue;
      }
      ut && Uh([P, Y, L], (Js) => {
        Er = yf(Er, Js, " ");
      });
      const ds = te(ue.nodeName);
      if (Cr(ds, ha, Er)) {
        if (Be && (ha === "id" || ha === "name") && (xe(Rn, ue), Er = pt + Er), S && typeof h == "object" && typeof h.getAttributeType == "function" && !Nr)
          switch (h.getAttributeType(ds, ha)) {
            case "TrustedHTML": {
              Er = S.createHTML(Er);
              break;
            }
            case "TrustedScriptURL": {
              Er = S.createScriptURL(Er);
              break;
            }
          }
        try {
          Nr ? ue.setAttributeNS(Nr, Rn, Er) : ue.setAttribute(Rn, Er), Jt(ue) ? Pe(ue) : Tk(t.removed);
        } catch {
        }
      }
    }
    Un("afterSanitizeAttributes", ue, null);
  }, yi = function vt(ue) {
    let Q = null;
    const ye = Zt(ue);
    for (Un("beforeSanitizeShadowDOM", ue, null); Q = ye.nextNode(); )
      Un("uponSanitizeShadowNode", Q, null), !pi(Q) && (Q.content instanceof a && vt(Q.content), Si(Q));
    Un("afterSanitizeShadowDOM", ue, null);
  };
  return t.sanitize = function(vt) {
    let ue = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : {}, Q = null, ye = null, ct = null, en = null;
    if (xn = !vt, xn && (vt = "<!-->"), typeof vt != "string" && !xr(vt))
      if (typeof vt.toString == "function") {
        if (vt = vt.toString(), typeof vt != "string")
          throw Tf("dirty is not a string, aborting");
      } else
        throw Tf("toString is not a function");
    if (!t.isSupported)
      return vt;
    if (Xt || j(ue), t.removed = [], typeof vt == "string" && (Ze = !1), Ze) {
      if (vt.nodeName) {
        const mi = te(vt.nodeName);
        if (!V[mi] || ae[mi])
          throw Tf("root node is forbidden and cannot be sanitized in-place");
      }
    } else if (vt instanceof s)
      Q = Mt("<!---->"), ye = Q.ownerDocument.importNode(vt, !0), ye.nodeType === Af.element && ye.nodeName === "BODY" || ye.nodeName === "HTML" ? Q = ye : Q.appendChild(ye);
    else {
      if (!st && !ut && !Ot && // eslint-disable-next-line unicorn/prefer-includes
      vt.indexOf("<") === -1)
        return S && Ke ? S.createHTML(vt) : vt;
      if (Q = Mt(vt), !Q)
        return st ? null : Ke ? C : "";
    }
    Q && We && Pe(Q.firstChild);
    const Rn = Zt(Ze ? vt : Q);
    for (; ct = Rn.nextNode(); )
      pi(ct) || (ct.content instanceof a && yi(ct.content), Si(ct));
    if (Ze)
      return vt;
    if (st) {
      if (Pt)
        for (en = R.call(Q.ownerDocument); Q.firstChild; )
          en.appendChild(Q.firstChild);
      else
        en = Q;
      return (ne.shadowroot || ne.shadowrootmode) && (en = q.call(r, en, !0)), en;
    }
    let Nr = Ot ? Q.outerHTML : Q.innerHTML;
    return Ot && V["!doctype"] && Q.ownerDocument && Q.ownerDocument.doctype && Q.ownerDocument.doctype.name && Ui($3, Q.ownerDocument.doctype.name) && (Nr = "<!DOCTYPE " + Q.ownerDocument.doctype.name + `>
` + Nr), ut && Uh([P, Y, L], (mi) => {
      Nr = yf(Nr, mi, " ");
    }), S && Ke ? S.createHTML(Nr) : Nr;
  }, t.setConfig = function() {
    let vt = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : {};
    j(vt), Xt = !0;
  }, t.clearConfig = function() {
    _e = null, Xt = !1;
  }, t.isValidAttribute = function(vt, ue, Q) {
    _e || j({});
    const ye = te(vt), ct = te(ue);
    return Cr(ye, ct, Q);
  }, t.addHook = function(vt, ue) {
    typeof ue == "function" && ($[vt] = $[vt] || [], Sf($[vt], ue));
  }, t.removeHook = function(vt) {
    if ($[vt])
      return Tk($[vt]);
  }, t.removeHooks = function(vt) {
    $[vt] && ($[vt] = []);
  }, t.removeAllHooks = function() {
    $ = {};
  }, t;
}
var dd = U3();
const cg = {
  /* CLAMP */
  min: {
    r: 0,
    g: 0,
    b: 0,
    s: 0,
    l: 0,
    a: 0
  },
  max: {
    r: 255,
    g: 255,
    b: 255,
    h: 360,
    s: 100,
    l: 100,
    a: 1
  },
  clamp: {
    r: (e) => e >= 255 ? 255 : e < 0 ? 0 : e,
    g: (e) => e >= 255 ? 255 : e < 0 ? 0 : e,
    b: (e) => e >= 255 ? 255 : e < 0 ? 0 : e,
    h: (e) => e % 360,
    s: (e) => e >= 100 ? 100 : e < 0 ? 0 : e,
    l: (e) => e >= 100 ? 100 : e < 0 ? 0 : e,
    a: (e) => e >= 1 ? 1 : e < 0 ? 0 : e
  },
  /* CONVERSION */
  //SOURCE: https://planetcalc.com/7779
  toLinear: (e) => {
    const t = e / 255;
    return e > 0.03928 ? Math.pow((t + 0.055) / 1.055, 2.4) : t / 12.92;
  },
  //SOURCE: https://gist.github.com/mjackson/5311256
  hue2rgb: (e, t, n) => (n < 0 && (n += 1), n > 1 && (n -= 1), n < 1 / 6 ? e + (t - e) * 6 * n : n < 1 / 2 ? t : n < 2 / 3 ? e + (t - e) * (2 / 3 - n) * 6 : e),
  hsl2rgb: ({ h: e, s: t, l: n }, r) => {
    if (!t)
      return n * 2.55;
    e /= 360, t /= 100, n /= 100;
    const i = n < 0.5 ? n * (1 + t) : n + t - n * t, a = 2 * n - i;
    switch (r) {
      case "r":
        return cg.hue2rgb(a, i, e + 1 / 3) * 255;
      case "g":
        return cg.hue2rgb(a, i, e) * 255;
      case "b":
        return cg.hue2rgb(a, i, e - 1 / 3) * 255;
    }
  },
  rgb2hsl: ({ r: e, g: t, b: n }, r) => {
    e /= 255, t /= 255, n /= 255;
    const i = Math.max(e, t, n), a = Math.min(e, t, n), o = (i + a) / 2;
    if (r === "l")
      return o * 100;
    if (i === a)
      return 0;
    const s = i - a, l = o > 0.5 ? s / (2 - i - a) : s / (i + a);
    if (r === "s")
      return l * 100;
    switch (i) {
      case e:
        return ((t - n) / s + (t < n ? 6 : 0)) * 60;
      case t:
        return ((n - e) / s + 2) * 60;
      case n:
        return ((e - t) / s + 4) * 60;
      default:
        return -1;
    }
  }
}, fae = {
  /* API */
  clamp: (e, t, n) => t > n ? Math.min(t, Math.max(n, e)) : Math.min(n, Math.max(t, e)),
  round: (e) => Math.round(e * 1e10) / 1e10
}, pae = {
  /* API */
  dec2hex: (e) => {
    const t = Math.round(e).toString(16);
    return t.length > 1 ? t : `0${t}`;
  }
}, Qt = {
  channel: cg,
  lang: fae,
  unit: pae
}, El = {};
for (let e = 0; e <= 255; e++)
  El[e] = Qt.unit.dec2hex(e);
const xi = {
  ALL: 0,
  RGB: 1,
  HSL: 2
};
let mae = class {
  constructor() {
    this.type = xi.ALL;
  }
  /* API */
  get() {
    return this.type;
  }
  set(t) {
    if (this.type && this.type !== t)
      throw new Error("Cannot change both RGB and HSL channels at the same time");
    this.type = t;
  }
  reset() {
    this.type = xi.ALL;
  }
  is(t) {
    return this.type === t;
  }
};
class hae {
  /* CONSTRUCTOR */
  constructor(t, n) {
    this.color = n, this.changed = !1, this.data = t, this.type = new mae();
  }
  /* API */
  set(t, n) {
    return this.color = n, this.changed = !1, this.data = t, this.type.type = xi.ALL, this;
  }
  /* HELPERS */
  _ensureHSL() {
    const t = this.data, { h: n, s: r, l: i } = t;
    n === void 0 && (t.h = Qt.channel.rgb2hsl(t, "h")), r === void 0 && (t.s = Qt.channel.rgb2hsl(t, "s")), i === void 0 && (t.l = Qt.channel.rgb2hsl(t, "l"));
  }
  _ensureRGB() {
    const t = this.data, { r: n, g: r, b: i } = t;
    n === void 0 && (t.r = Qt.channel.hsl2rgb(t, "r")), r === void 0 && (t.g = Qt.channel.hsl2rgb(t, "g")), i === void 0 && (t.b = Qt.channel.hsl2rgb(t, "b"));
  }
  /* GETTERS */
  get r() {
    const t = this.data, n = t.r;
    return !this.type.is(xi.HSL) && n !== void 0 ? n : (this._ensureHSL(), Qt.channel.hsl2rgb(t, "r"));
  }
  get g() {
    const t = this.data, n = t.g;
    return !this.type.is(xi.HSL) && n !== void 0 ? n : (this._ensureHSL(), Qt.channel.hsl2rgb(t, "g"));
  }
  get b() {
    const t = this.data, n = t.b;
    return !this.type.is(xi.HSL) && n !== void 0 ? n : (this._ensureHSL(), Qt.channel.hsl2rgb(t, "b"));
  }
  get h() {
    const t = this.data, n = t.h;
    return !this.type.is(xi.RGB) && n !== void 0 ? n : (this._ensureRGB(), Qt.channel.rgb2hsl(t, "h"));
  }
  get s() {
    const t = this.data, n = t.s;
    return !this.type.is(xi.RGB) && n !== void 0 ? n : (this._ensureRGB(), Qt.channel.rgb2hsl(t, "s"));
  }
  get l() {
    const t = this.data, n = t.l;
    return !this.type.is(xi.RGB) && n !== void 0 ? n : (this._ensureRGB(), Qt.channel.rgb2hsl(t, "l"));
  }
  get a() {
    return this.data.a;
  }
  /* SETTERS */
  set r(t) {
    this.type.set(xi.RGB), this.changed = !0, this.data.r = t;
  }
  set g(t) {
    this.type.set(xi.RGB), this.changed = !0, this.data.g = t;
  }
  set b(t) {
    this.type.set(xi.RGB), this.changed = !0, this.data.b = t;
  }
  set h(t) {
    this.type.set(xi.HSL), this.changed = !0, this.data.h = t;
  }
  set s(t) {
    this.type.set(xi.HSL), this.changed = !0, this.data.s = t;
  }
  set l(t) {
    this.type.set(xi.HSL), this.changed = !0, this.data.l = t;
  }
  set a(t) {
    this.changed = !0, this.data.a = t;
  }
}
const W_ = new hae({ r: 0, g: 0, b: 0, a: 0 }, "transparent"), ed = {
  /* VARIABLES */
  re: /^#((?:[a-f0-9]{2}){2,4}|[a-f0-9]{3})$/i,
  /* API */
  parse: (e) => {
    if (e.charCodeAt(0) !== 35)
      return;
    const t = e.match(ed.re);
    if (!t)
      return;
    const n = t[1], r = parseInt(n, 16), i = n.length, a = i % 4 === 0, o = i > 4, s = o ? 1 : 17, l = o ? 8 : 4, u = a ? 0 : -1, c = o ? 255 : 15;
    return W_.set({
      r: (r >> l * (u + 3) & c) * s,
      g: (r >> l * (u + 2) & c) * s,
      b: (r >> l * (u + 1) & c) * s,
      a: a ? (r & c) * s / 255 : 1
    }, e);
  },
  stringify: (e) => {
    const { r: t, g: n, b: r, a: i } = e;
    return i < 1 ? `#${El[Math.round(t)]}${El[Math.round(n)]}${El[Math.round(r)]}${El[Math.round(i * 255)]}` : `#${El[Math.round(t)]}${El[Math.round(n)]}${El[Math.round(r)]}`;
  }
}, Nu = {
  /* VARIABLES */
  re: /^hsla?\(\s*?(-?(?:\d+(?:\.\d+)?|(?:\.\d+))(?:e-?\d+)?(?:deg|grad|rad|turn)?)\s*?(?:,|\s)\s*?(-?(?:\d+(?:\.\d+)?|(?:\.\d+))(?:e-?\d+)?%)\s*?(?:,|\s)\s*?(-?(?:\d+(?:\.\d+)?|(?:\.\d+))(?:e-?\d+)?%)(?:\s*?(?:,|\/)\s*?\+?(-?(?:\d+(?:\.\d+)?|(?:\.\d+))(?:e-?\d+)?(%)?))?\s*?\)$/i,
  hueRe: /^(.+?)(deg|grad|rad|turn)$/i,
  /* HELPERS */
  _hue2deg: (e) => {
    const t = e.match(Nu.hueRe);
    if (t) {
      const [, n, r] = t;
      switch (r) {
        case "grad":
          return Qt.channel.clamp.h(parseFloat(n) * 0.9);
        case "rad":
          return Qt.channel.clamp.h(parseFloat(n) * 180 / Math.PI);
        case "turn":
          return Qt.channel.clamp.h(parseFloat(n) * 360);
      }
    }
    return Qt.channel.clamp.h(parseFloat(e));
  },
  /* API */
  parse: (e) => {
    const t = e.charCodeAt(0);
    if (t !== 104 && t !== 72)
      return;
    const n = e.match(Nu.re);
    if (!n)
      return;
    const [, r, i, a, o, s] = n;
    return W_.set({
      h: Nu._hue2deg(r),
      s: Qt.channel.clamp.s(parseFloat(i)),
      l: Qt.channel.clamp.l(parseFloat(a)),
      a: o ? Qt.channel.clamp.a(s ? parseFloat(o) / 100 : parseFloat(o)) : 1
    }, e);
  },
  stringify: (e) => {
    const { h: t, s: n, l: r, a: i } = e;
    return i < 1 ? `hsla(${Qt.lang.round(t)}, ${Qt.lang.round(n)}%, ${Qt.lang.round(r)}%, ${i})` : `hsl(${Qt.lang.round(t)}, ${Qt.lang.round(n)}%, ${Qt.lang.round(r)}%)`;
  }
}, jf = {
  /* VARIABLES */
  colors: {
    aliceblue: "#f0f8ff",
    antiquewhite: "#faebd7",
    aqua: "#00ffff",
    aquamarine: "#7fffd4",
    azure: "#f0ffff",
    beige: "#f5f5dc",
    bisque: "#ffe4c4",
    black: "#000000",
    blanchedalmond: "#ffebcd",
    blue: "#0000ff",
    blueviolet: "#8a2be2",
    brown: "#a52a2a",
    burlywood: "#deb887",
    cadetblue: "#5f9ea0",
    chartreuse: "#7fff00",
    chocolate: "#d2691e",
    coral: "#ff7f50",
    cornflowerblue: "#6495ed",
    cornsilk: "#fff8dc",
    crimson: "#dc143c",
    cyanaqua: "#00ffff",
    darkblue: "#00008b",
    darkcyan: "#008b8b",
    darkgoldenrod: "#b8860b",
    darkgray: "#a9a9a9",
    darkgreen: "#006400",
    darkgrey: "#a9a9a9",
    darkkhaki: "#bdb76b",
    darkmagenta: "#8b008b",
    darkolivegreen: "#556b2f",
    darkorange: "#ff8c00",
    darkorchid: "#9932cc",
    darkred: "#8b0000",
    darksalmon: "#e9967a",
    darkseagreen: "#8fbc8f",
    darkslateblue: "#483d8b",
    darkslategray: "#2f4f4f",
    darkslategrey: "#2f4f4f",
    darkturquoise: "#00ced1",
    darkviolet: "#9400d3",
    deeppink: "#ff1493",
    deepskyblue: "#00bfff",
    dimgray: "#696969",
    dimgrey: "#696969",
    dodgerblue: "#1e90ff",
    firebrick: "#b22222",
    floralwhite: "#fffaf0",
    forestgreen: "#228b22",
    fuchsia: "#ff00ff",
    gainsboro: "#dcdcdc",
    ghostwhite: "#f8f8ff",
    gold: "#ffd700",
    goldenrod: "#daa520",
    gray: "#808080",
    green: "#008000",
    greenyellow: "#adff2f",
    grey: "#808080",
    honeydew: "#f0fff0",
    hotpink: "#ff69b4",
    indianred: "#cd5c5c",
    indigo: "#4b0082",
    ivory: "#fffff0",
    khaki: "#f0e68c",
    lavender: "#e6e6fa",
    lavenderblush: "#fff0f5",
    lawngreen: "#7cfc00",
    lemonchiffon: "#fffacd",
    lightblue: "#add8e6",
    lightcoral: "#f08080",
    lightcyan: "#e0ffff",
    lightgoldenrodyellow: "#fafad2",
    lightgray: "#d3d3d3",
    lightgreen: "#90ee90",
    lightgrey: "#d3d3d3",
    lightpink: "#ffb6c1",
    lightsalmon: "#ffa07a",
    lightseagreen: "#20b2aa",
    lightskyblue: "#87cefa",
    lightslategray: "#778899",
    lightslategrey: "#778899",
    lightsteelblue: "#b0c4de",
    lightyellow: "#ffffe0",
    lime: "#00ff00",
    limegreen: "#32cd32",
    linen: "#faf0e6",
    magenta: "#ff00ff",
    maroon: "#800000",
    mediumaquamarine: "#66cdaa",
    mediumblue: "#0000cd",
    mediumorchid: "#ba55d3",
    mediumpurple: "#9370db",
    mediumseagreen: "#3cb371",
    mediumslateblue: "#7b68ee",
    mediumspringgreen: "#00fa9a",
    mediumturquoise: "#48d1cc",
    mediumvioletred: "#c71585",
    midnightblue: "#191970",
    mintcream: "#f5fffa",
    mistyrose: "#ffe4e1",
    moccasin: "#ffe4b5",
    navajowhite: "#ffdead",
    navy: "#000080",
    oldlace: "#fdf5e6",
    olive: "#808000",
    olivedrab: "#6b8e23",
    orange: "#ffa500",
    orangered: "#ff4500",
    orchid: "#da70d6",
    palegoldenrod: "#eee8aa",
    palegreen: "#98fb98",
    paleturquoise: "#afeeee",
    palevioletred: "#db7093",
    papayawhip: "#ffefd5",
    peachpuff: "#ffdab9",
    peru: "#cd853f",
    pink: "#ffc0cb",
    plum: "#dda0dd",
    powderblue: "#b0e0e6",
    purple: "#800080",
    rebeccapurple: "#663399",
    red: "#ff0000",
    rosybrown: "#bc8f8f",
    royalblue: "#4169e1",
    saddlebrown: "#8b4513",
    salmon: "#fa8072",
    sandybrown: "#f4a460",
    seagreen: "#2e8b57",
    seashell: "#fff5ee",
    sienna: "#a0522d",
    silver: "#c0c0c0",
    skyblue: "#87ceeb",
    slateblue: "#6a5acd",
    slategray: "#708090",
    slategrey: "#708090",
    snow: "#fffafa",
    springgreen: "#00ff7f",
    tan: "#d2b48c",
    teal: "#008080",
    thistle: "#d8bfd8",
    transparent: "#00000000",
    turquoise: "#40e0d0",
    violet: "#ee82ee",
    wheat: "#f5deb3",
    white: "#ffffff",
    whitesmoke: "#f5f5f5",
    yellow: "#ffff00",
    yellowgreen: "#9acd32"
  },
  /* API */
  parse: (e) => {
    e = e.toLowerCase();
    const t = jf.colors[e];
    if (t)
      return ed.parse(t);
  },
  stringify: (e) => {
    const t = ed.stringify(e);
    for (const n in jf.colors)
      if (jf.colors[n] === t)
        return n;
  }
}, Uf = {
  /* VARIABLES */
  re: /^rgba?\(\s*?(-?(?:\d+(?:\.\d+)?|(?:\.\d+))(?:e\d+)?(%?))\s*?(?:,|\s)\s*?(-?(?:\d+(?:\.\d+)?|(?:\.\d+))(?:e\d+)?(%?))\s*?(?:,|\s)\s*?(-?(?:\d+(?:\.\d+)?|(?:\.\d+))(?:e\d+)?(%?))(?:\s*?(?:,|\/)\s*?\+?(-?(?:\d+(?:\.\d+)?|(?:\.\d+))(?:e\d+)?(%?)))?\s*?\)$/i,
  /* API */
  parse: (e) => {
    const t = e.charCodeAt(0);
    if (t !== 114 && t !== 82)
      return;
    const n = e.match(Uf.re);
    if (!n)
      return;
    const [, r, i, a, o, s, l, u, c] = n;
    return W_.set({
      r: Qt.channel.clamp.r(i ? parseFloat(r) * 2.55 : parseFloat(r)),
      g: Qt.channel.clamp.g(o ? parseFloat(a) * 2.55 : parseFloat(a)),
      b: Qt.channel.clamp.b(l ? parseFloat(s) * 2.55 : parseFloat(s)),
      a: u ? Qt.channel.clamp.a(c ? parseFloat(u) / 100 : parseFloat(u)) : 1
    }, e);
  },
  stringify: (e) => {
    const { r: t, g: n, b: r, a: i } = e;
    return i < 1 ? `rgba(${Qt.lang.round(t)}, ${Qt.lang.round(n)}, ${Qt.lang.round(r)}, ${Qt.lang.round(i)})` : `rgb(${Qt.lang.round(t)}, ${Qt.lang.round(n)}, ${Qt.lang.round(r)})`;
  }
}, Ko = {
  /* VARIABLES */
  format: {
    keyword: jf,
    hex: ed,
    rgb: Uf,
    rgba: Uf,
    hsl: Nu,
    hsla: Nu
  },
  /* API */
  parse: (e) => {
    if (typeof e != "string")
      return e;
    const t = ed.parse(e) || Uf.parse(e) || Nu.parse(e) || jf.parse(e);
    if (t)
      return t;
    throw new Error(`Unsupported color format: "${e}"`);
  },
  stringify: (e) => !e.changed && e.color ? e.color : e.type.is(xi.HSL) || e.data.r === void 0 ? Nu.stringify(e) : e.a < 1 || !Number.isInteger(e.r) || !Number.isInteger(e.g) || !Number.isInteger(e.b) ? Uf.stringify(e) : ed.stringify(e)
}, q3 = (e, t) => {
  const n = Ko.parse(e);
  for (const r in t)
    n[r] = Qt.channel.clamp[r](t[r]);
  return Ko.stringify(n);
}, Qf = (e, t, n = 0, r = 1) => {
  if (typeof e != "number")
    return q3(e, { a: t });
  const i = W_.set({
    r: Qt.channel.clamp.r(e),
    g: Qt.channel.clamp.g(t),
    b: Qt.channel.clamp.b(n),
    a: Qt.channel.clamp.a(r)
  });
  return Ko.stringify(i);
}, gae = (e) => {
  const { r: t, g: n, b: r } = Ko.parse(e), i = 0.2126 * Qt.channel.toLinear(t) + 0.7152 * Qt.channel.toLinear(n) + 0.0722 * Qt.channel.toLinear(r);
  return Qt.lang.round(i);
}, _ae = (e) => gae(e) >= 0.5, dm = (e) => !_ae(e), G3 = (e, t, n) => {
  const r = Ko.parse(e), i = r[t], a = Qt.channel.clamp[t](i + n);
  return i !== a && (r[t] = a), Ko.stringify(r);
}, xt = (e, t) => G3(e, "l", t), $t = (e, t) => G3(e, "l", -t), ve = (e, t) => {
  const n = Ko.parse(e), r = {};
  for (const i in t)
    t[i] && (r[i] = n[i] + t[i]);
  return q3(e, r);
}, vae = (e, t, n = 50) => {
  const { r, g: i, b: a, a: o } = Ko.parse(e), { r: s, g: l, b: u, a: c } = Ko.parse(t), d = n / 100, f = d * 2 - 1, h = o - c, v = ((f * h === -1 ? f : (f + h) / (1 + f * h)) + 1) / 2, b = 1 - v, y = r * v + s * b, g = i * v + l * b, E = a * v + u * b, S = o * d + c * (1 - d);
  return Qf(y, g, E, S);
}, at = (e, t = 100) => {
  const n = Ko.parse(e);
  return n.r = 255 - n.r, n.g = 255 - n.g, n.b = 255 - n.b, vae(n, e, t);
};
var Y3 = typeof global == "object" && global && global.Object === Object && global, bae = typeof self == "object" && self && self.Object === Object && self, rs = Y3 || bae || Function("return this")(), zg = rs.Symbol, H3 = Object.prototype, Eae = H3.hasOwnProperty, Sae = H3.toString, Of = zg ? zg.toStringTag : void 0;
function yae(e) {
  var t = Eae.call(e, Of), n = e[Of];
  try {
    e[Of] = void 0;
    var r = !0;
  } catch {
  }
  var i = Sae.call(e);
  return r && (t ? e[Of] = n : delete e[Of]), i;
}
var Tae = Object.prototype, Cae = Tae.toString;
function Aae(e) {
  return Cae.call(e);
}
var Oae = "[object Null]", Rae = "[object Undefined]", Nk = zg ? zg.toStringTag : void 0;
function Od(e) {
  return e == null ? e === void 0 ? Rae : Oae : Nk && Nk in Object(e) ? yae(e) : Aae(e);
}
function Xu(e) {
  var t = typeof e;
  return e != null && (t == "object" || t == "function");
}
var wae = "[object AsyncFunction]", xae = "[object Function]", Nae = "[object GeneratorFunction]", Dae = "[object Proxy]";
function F1(e) {
  if (!Xu(e))
    return !1;
  var t = Od(e);
  return t == xae || t == Nae || t == wae || t == Dae;
}
var tT = rs["__core-js_shared__"], Dk = function() {
  var e = /[^.]+$/.exec(tT && tT.keys && tT.keys.IE_PROTO || "");
  return e ? "Symbol(src)_1." + e : "";
}();
function Iae(e) {
  return !!Dk && Dk in e;
}
var Lae = Function.prototype, kae = Lae.toString;
function Zu(e) {
  if (e != null) {
    try {
      return kae.call(e);
    } catch {
    }
    try {
      return e + "";
    } catch {
    }
  }
  return "";
}
var Mae = /[\\^$.*+?()[\]{}|]/g, Pae = /^\[object .+?Constructor\]$/, Fae = Function.prototype, Bae = Object.prototype, $ae = Fae.toString, Uae = Bae.hasOwnProperty, qae = RegExp(
  "^" + $ae.call(Uae).replace(Mae, "\\$&").replace(/hasOwnProperty|(function).*?(?=\\\()| for .+?(?=\\\])/g, "$1.*?") + "$"
);
function Gae(e) {
  if (!Xu(e) || Iae(e))
    return !1;
  var t = F1(e) ? qae : Pae;
  return t.test(Zu(e));
}
function Yae(e, t) {
  return e == null ? void 0 : e[t];
}
function Ju(e, t) {
  var n = Yae(e, t);
  return Gae(n) ? n : void 0;
}
var xp = Ju(Object, "create");
function Hae() {
  this.__data__ = xp ? xp(null) : {}, this.size = 0;
}
function zae(e) {
  var t = this.has(e) && delete this.__data__[e];
  return this.size -= t ? 1 : 0, t;
}
var Vae = "__lodash_hash_undefined__", Wae = Object.prototype, Kae = Wae.hasOwnProperty;
function jae(e) {
  var t = this.__data__;
  if (xp) {
    var n = t[e];
    return n === Vae ? void 0 : n;
  }
  return Kae.call(t, e) ? t[e] : void 0;
}
var Qae = Object.prototype, Xae = Qae.hasOwnProperty;
function Zae(e) {
  var t = this.__data__;
  return xp ? t[e] !== void 0 : Xae.call(t, e);
}
var Jae = "__lodash_hash_undefined__";
function eoe(e, t) {
  var n = this.__data__;
  return this.size += this.has(e) ? 0 : 1, n[e] = xp && t === void 0 ? Jae : t, this;
}
function Hu(e) {
  var t = -1, n = e == null ? 0 : e.length;
  for (this.clear(); ++t < n; ) {
    var r = e[t];
    this.set(r[0], r[1]);
  }
}
Hu.prototype.clear = Hae;
Hu.prototype.delete = zae;
Hu.prototype.get = jae;
Hu.prototype.has = Zae;
Hu.prototype.set = eoe;
function toe() {
  this.__data__ = [], this.size = 0;
}
function K_(e, t) {
  return e === t || e !== e && t !== t;
}
function j_(e, t) {
  for (var n = e.length; n--; )
    if (K_(e[n][0], t))
      return n;
  return -1;
}
var noe = Array.prototype, roe = noe.splice;
function ioe(e) {
  var t = this.__data__, n = j_(t, e);
  if (n < 0)
    return !1;
  var r = t.length - 1;
  return n == r ? t.pop() : roe.call(t, n, 1), --this.size, !0;
}
function aoe(e) {
  var t = this.__data__, n = j_(t, e);
  return n < 0 ? void 0 : t[n][1];
}
function ooe(e) {
  return j_(this.__data__, e) > -1;
}
function soe(e, t) {
  var n = this.__data__, r = j_(n, e);
  return r < 0 ? (++this.size, n.push([e, t])) : n[r][1] = t, this;
}
function Vs(e) {
  var t = -1, n = e == null ? 0 : e.length;
  for (this.clear(); ++t < n; ) {
    var r = e[t];
    this.set(r[0], r[1]);
  }
}
Vs.prototype.clear = toe;
Vs.prototype.delete = ioe;
Vs.prototype.get = aoe;
Vs.prototype.has = ooe;
Vs.prototype.set = soe;
var Np = Ju(rs, "Map");
function loe() {
  this.size = 0, this.__data__ = {
    hash: new Hu(),
    map: new (Np || Vs)(),
    string: new Hu()
  };
}
function uoe(e) {
  var t = typeof e;
  return t == "string" || t == "number" || t == "symbol" || t == "boolean" ? e !== "__proto__" : e === null;
}
function Q_(e, t) {
  var n = e.__data__;
  return uoe(t) ? n[typeof t == "string" ? "string" : "hash"] : n.map;
}
function coe(e) {
  var t = Q_(this, e).delete(e);
  return this.size -= t ? 1 : 0, t;
}
function doe(e) {
  return Q_(this, e).get(e);
}
function foe(e) {
  return Q_(this, e).has(e);
}
function poe(e, t) {
  var n = Q_(this, e), r = n.size;
  return n.set(e, t), this.size += n.size == r ? 0 : 1, this;
}
function Hl(e) {
  var t = -1, n = e == null ? 0 : e.length;
  for (this.clear(); ++t < n; ) {
    var r = e[t];
    this.set(r[0], r[1]);
  }
}
Hl.prototype.clear = loe;
Hl.prototype.delete = coe;
Hl.prototype.get = doe;
Hl.prototype.has = foe;
Hl.prototype.set = poe;
var moe = "Expected a function";
function fm(e, t) {
  if (typeof e != "function" || t != null && typeof t != "function")
    throw new TypeError(moe);
  var n = function() {
    var r = arguments, i = t ? t.apply(this, r) : r[0], a = n.cache;
    if (a.has(i))
      return a.get(i);
    var o = e.apply(this, r);
    return n.cache = a.set(i, o) || a, o;
  };
  return n.cache = new (fm.Cache || Hl)(), n;
}
fm.Cache = Hl;
function hoe() {
  this.__data__ = new Vs(), this.size = 0;
}
function goe(e) {
  var t = this.__data__, n = t.delete(e);
  return this.size = t.size, n;
}
function _oe(e) {
  return this.__data__.get(e);
}
function voe(e) {
  return this.__data__.has(e);
}
var boe = 200;
function Eoe(e, t) {
  var n = this.__data__;
  if (n instanceof Vs) {
    var r = n.__data__;
    if (!Np || r.length < boe - 1)
      return r.push([e, t]), this.size = ++n.size, this;
    n = this.__data__ = new Hl(r);
  }
  return n.set(e, t), this.size = n.size, this;
}
function Rd(e) {
  var t = this.__data__ = new Vs(e);
  this.size = t.size;
}
Rd.prototype.clear = hoe;
Rd.prototype.delete = goe;
Rd.prototype.get = _oe;
Rd.prototype.has = voe;
Rd.prototype.set = Eoe;
var Vg = function() {
  try {
    var e = Ju(Object, "defineProperty");
    return e({}, "", {}), e;
  } catch {
  }
}();
function B1(e, t, n) {
  t == "__proto__" && Vg ? Vg(e, t, {
    configurable: !0,
    enumerable: !0,
    value: n,
    writable: !0
  }) : e[t] = n;
}
function dC(e, t, n) {
  (n !== void 0 && !K_(e[t], n) || n === void 0 && !(t in e)) && B1(e, t, n);
}
function Soe(e) {
  return function(t, n, r) {
    for (var i = -1, a = Object(t), o = r(t), s = o.length; s--; ) {
      var l = o[++i];
      if (n(a[l], l, a) === !1)
        break;
    }
    return t;
  };
}
var yoe = Soe(), z3 = typeof exports == "object" && exports && !exports.nodeType && exports, Ik = z3 && typeof module == "object" && module && !module.nodeType && module, Toe = Ik && Ik.exports === z3, Lk = Toe ? rs.Buffer : void 0, kk = Lk ? Lk.allocUnsafe : void 0;
function Coe(e, t) {
  if (t)
    return e.slice();
  var n = e.length, r = kk ? kk(n) : new e.constructor(n);
  return e.copy(r), r;
}
var Mk = rs.Uint8Array;
function Aoe(e) {
  var t = new e.constructor(e.byteLength);
  return new Mk(t).set(new Mk(e)), t;
}
function Ooe(e, t) {
  var n = t ? Aoe(e.buffer) : e.buffer;
  return new e.constructor(n, e.byteOffset, e.length);
}
function Roe(e, t) {
  var n = -1, r = e.length;
  for (t || (t = Array(r)); ++n < r; )
    t[n] = e[n];
  return t;
}
var Pk = Object.create, woe = /* @__PURE__ */ function() {
  function e() {
  }
  return function(t) {
    if (!Xu(t))
      return {};
    if (Pk)
      return Pk(t);
    e.prototype = t;
    var n = new e();
    return e.prototype = void 0, n;
  };
}();
function V3(e, t) {
  return function(n) {
    return e(t(n));
  };
}
var W3 = V3(Object.getPrototypeOf, Object), xoe = Object.prototype;
function X_(e) {
  var t = e && e.constructor, n = typeof t == "function" && t.prototype || xoe;
  return e === n;
}
function Noe(e) {
  return typeof e.constructor == "function" && !X_(e) ? woe(W3(e)) : {};
}
function pm(e) {
  return e != null && typeof e == "object";
}
var Doe = "[object Arguments]";
function Fk(e) {
  return pm(e) && Od(e) == Doe;
}
var K3 = Object.prototype, Ioe = K3.hasOwnProperty, Loe = K3.propertyIsEnumerable, Wg = Fk(/* @__PURE__ */ function() {
  return arguments;
}()) ? Fk : function(e) {
  return pm(e) && Ioe.call(e, "callee") && !Loe.call(e, "callee");
}, Kg = Array.isArray, koe = 9007199254740991;
function j3(e) {
  return typeof e == "number" && e > -1 && e % 1 == 0 && e <= koe;
}
function Z_(e) {
  return e != null && j3(e.length) && !F1(e);
}
function Moe(e) {
  return pm(e) && Z_(e);
}
function Poe() {
  return !1;
}
var Q3 = typeof exports == "object" && exports && !exports.nodeType && exports, Bk = Q3 && typeof module == "object" && module && !module.nodeType && module, Foe = Bk && Bk.exports === Q3, $k = Foe ? rs.Buffer : void 0, Boe = $k ? $k.isBuffer : void 0, $1 = Boe || Poe, $oe = "[object Object]", Uoe = Function.prototype, qoe = Object.prototype, X3 = Uoe.toString, Goe = qoe.hasOwnProperty, Yoe = X3.call(Object);
function Hoe(e) {
  if (!pm(e) || Od(e) != $oe)
    return !1;
  var t = W3(e);
  if (t === null)
    return !0;
  var n = Goe.call(t, "constructor") && t.constructor;
  return typeof n == "function" && n instanceof n && X3.call(n) == Yoe;
}
var zoe = "[object Arguments]", Voe = "[object Array]", Woe = "[object Boolean]", Koe = "[object Date]", joe = "[object Error]", Qoe = "[object Function]", Xoe = "[object Map]", Zoe = "[object Number]", Joe = "[object Object]", ese = "[object RegExp]", tse = "[object Set]", nse = "[object String]", rse = "[object WeakMap]", ise = "[object ArrayBuffer]", ase = "[object DataView]", ose = "[object Float32Array]", sse = "[object Float64Array]", lse = "[object Int8Array]", use = "[object Int16Array]", cse = "[object Int32Array]", dse = "[object Uint8Array]", fse = "[object Uint8ClampedArray]", pse = "[object Uint16Array]", mse = "[object Uint32Array]", pr = {};
pr[ose] = pr[sse] = pr[lse] = pr[use] = pr[cse] = pr[dse] = pr[fse] = pr[pse] = pr[mse] = !0;
pr[zoe] = pr[Voe] = pr[ise] = pr[Woe] = pr[ase] = pr[Koe] = pr[joe] = pr[Qoe] = pr[Xoe] = pr[Zoe] = pr[Joe] = pr[ese] = pr[tse] = pr[nse] = pr[rse] = !1;
function hse(e) {
  return pm(e) && j3(e.length) && !!pr[Od(e)];
}
function gse(e) {
  return function(t) {
    return e(t);
  };
}
var Z3 = typeof exports == "object" && exports && !exports.nodeType && exports, Xf = Z3 && typeof module == "object" && module && !module.nodeType && module, _se = Xf && Xf.exports === Z3, nT = _se && Y3.process, Uk = function() {
  try {
    var e = Xf && Xf.require && Xf.require("util").types;
    return e || nT && nT.binding && nT.binding("util");
  } catch {
  }
}(), qk = Uk && Uk.isTypedArray, U1 = qk ? gse(qk) : hse;
function fC(e, t) {
  if (!(t === "constructor" && typeof e[t] == "function") && t != "__proto__")
    return e[t];
}
var vse = Object.prototype, bse = vse.hasOwnProperty;
function Ese(e, t, n) {
  var r = e[t];
  (!(bse.call(e, t) && K_(r, n)) || n === void 0 && !(t in e)) && B1(e, t, n);
}
function Sse(e, t, n, r) {
  var i = !n;
  n || (n = {});
  for (var a = -1, o = t.length; ++a < o; ) {
    var s = t[a], l = void 0;
    l === void 0 && (l = e[s]), i ? B1(n, s, l) : Ese(n, s, l);
  }
  return n;
}
function yse(e, t) {
  for (var n = -1, r = Array(e); ++n < e; )
    r[n] = t(n);
  return r;
}
var Tse = 9007199254740991, Cse = /^(?:0|[1-9]\d*)$/;
function J3(e, t) {
  var n = typeof e;
  return t = t ?? Tse, !!t && (n == "number" || n != "symbol" && Cse.test(e)) && e > -1 && e % 1 == 0 && e < t;
}
var Ase = Object.prototype, Ose = Ase.hasOwnProperty;
function Rse(e, t) {
  var n = Kg(e), r = !n && Wg(e), i = !n && !r && $1(e), a = !n && !r && !i && U1(e), o = n || r || i || a, s = o ? yse(e.length, String) : [], l = s.length;
  for (var u in e)
    (t || Ose.call(e, u)) && !(o && // Safari 9 has enumerable `arguments.length` in strict mode.
    (u == "length" || // Node.js 0.10 has enumerable non-index properties on buffers.
    i && (u == "offset" || u == "parent") || // PhantomJS 2 has enumerable non-index properties on typed arrays.
    a && (u == "buffer" || u == "byteLength" || u == "byteOffset") || // Skip index properties.
    J3(u, l))) && s.push(u);
  return s;
}
function wse(e) {
  var t = [];
  if (e != null)
    for (var n in Object(e))
      t.push(n);
  return t;
}
var xse = Object.prototype, Nse = xse.hasOwnProperty;
function Dse(e) {
  if (!Xu(e))
    return wse(e);
  var t = X_(e), n = [];
  for (var r in e)
    r == "constructor" && (t || !Nse.call(e, r)) || n.push(r);
  return n;
}
function eB(e) {
  return Z_(e) ? Rse(e, !0) : Dse(e);
}
function Ise(e) {
  return Sse(e, eB(e));
}
function Lse(e, t, n, r, i, a, o) {
  var s = fC(e, n), l = fC(t, n), u = o.get(l);
  if (u) {
    dC(e, n, u);
    return;
  }
  var c = a ? a(s, l, n + "", e, t, o) : void 0, d = c === void 0;
  if (d) {
    var f = Kg(l), h = !f && $1(l), m = !f && !h && U1(l);
    c = l, f || h || m ? Kg(s) ? c = s : Moe(s) ? c = Roe(s) : h ? (d = !1, c = Coe(l, !0)) : m ? (d = !1, c = Ooe(l, !0)) : c = [] : Hoe(l) || Wg(l) ? (c = s, Wg(s) ? c = Ise(s) : (!Xu(s) || F1(s)) && (c = Noe(l))) : d = !1;
  }
  d && (o.set(l, c), i(c, l, r, a, o), o.delete(l)), dC(e, n, c);
}
function tB(e, t, n, r, i) {
  e !== t && yoe(t, function(a, o) {
    if (i || (i = new Rd()), Xu(a))
      Lse(e, t, o, n, tB, r, i);
    else {
      var s = r ? r(fC(e, o), a, o + "", e, t, i) : void 0;
      s === void 0 && (s = a), dC(e, o, s);
    }
  }, eB);
}
function nB(e) {
  return e;
}
function kse(e, t, n) {
  switch (n.length) {
    case 0:
      return e.call(t);
    case 1:
      return e.call(t, n[0]);
    case 2:
      return e.call(t, n[0], n[1]);
    case 3:
      return e.call(t, n[0], n[1], n[2]);
  }
  return e.apply(t, n);
}
var Gk = Math.max;
function Mse(e, t, n) {
  return t = Gk(t === void 0 ? e.length - 1 : t, 0), function() {
    for (var r = arguments, i = -1, a = Gk(r.length - t, 0), o = Array(a); ++i < a; )
      o[i] = r[t + i];
    i = -1;
    for (var s = Array(t + 1); ++i < t; )
      s[i] = r[i];
    return s[t] = n(o), kse(e, this, s);
  };
}
function Pse(e) {
  return function() {
    return e;
  };
}
var Fse = Vg ? function(e, t) {
  return Vg(e, "toString", {
    configurable: !0,
    enumerable: !1,
    value: Pse(t),
    writable: !0
  });
} : nB, Bse = 800, $se = 16, Use = Date.now;
function qse(e) {
  var t = 0, n = 0;
  return function() {
    var r = Use(), i = $se - (r - n);
    if (n = r, i > 0) {
      if (++t >= Bse)
        return arguments[0];
    } else
      t = 0;
    return e.apply(void 0, arguments);
  };
}
var Gse = qse(Fse);
function Yse(e, t) {
  return Gse(Mse(e, t, nB), e + "");
}
function Hse(e, t, n) {
  if (!Xu(n))
    return !1;
  var r = typeof t;
  return (r == "number" ? Z_(n) && J3(t, n.length) : r == "string" && t in n) ? K_(n[t], e) : !1;
}
function zse(e) {
  return Yse(function(t, n) {
    var r = -1, i = n.length, a = i > 1 ? n[i - 1] : void 0, o = i > 2 ? n[2] : void 0;
    for (a = e.length > 3 && typeof a == "function" ? (i--, a) : void 0, o && Hse(n[0], n[1], o) && (a = i < 3 ? void 0 : a, i = 1), t = Object(t); ++r < i; ) {
      var s = n[r];
      s && e(t, s, r, a);
    }
    return t;
  });
}
var Vse = zse(function(e, t, n) {
  tB(e, t, n);
}), rB = "comm", iB = "rule", aB = "decl", Wse = "@import", Kse = "@keyframes", jse = "@layer", oB = Math.abs, q1 = String.fromCharCode;
function sB(e) {
  return e.trim();
}
function dg(e, t, n) {
  return e.replace(t, n);
}
function Qse(e, t, n) {
  return e.indexOf(t, n);
}
function Dp(e, t) {
  return e.charCodeAt(t) | 0;
}
function Ip(e, t, n) {
  return e.slice(t, n);
}
function xs(e) {
  return e.length;
}
function Xse(e) {
  return e.length;
}
function Gh(e, t) {
  return t.push(e), e;
}
var J_ = 1, fd = 1, lB = 0, eo = 0, jr = 0, wd = "";
function G1(e, t, n, r, i, a, o, s) {
  return { value: e, root: t, parent: n, type: r, props: i, children: a, line: J_, column: fd, length: o, return: "", siblings: s };
}
function Zse() {
  return jr;
}
function Jse() {
  return jr = eo > 0 ? Dp(wd, --eo) : 0, fd--, jr === 10 && (fd = 1, J_--), jr;
}
function Eo() {
  return jr = eo < lB ? Dp(wd, eo++) : 0, fd++, jr === 10 && (fd = 1, J_++), jr;
}
function Mu() {
  return Dp(wd, eo);
}
function fg() {
  return eo;
}
function ev(e, t) {
  return Ip(wd, e, t);
}
function pC(e) {
  switch (e) {
    case 0:
    case 9:
    case 10:
    case 13:
    case 32:
      return 5;
    case 33:
    case 43:
    case 44:
    case 47:
    case 62:
    case 64:
    case 126:
    case 59:
    case 123:
    case 125:
      return 4;
    case 58:
      return 3;
    case 34:
    case 39:
    case 40:
    case 91:
      return 2;
    case 41:
    case 93:
      return 1;
  }
  return 0;
}
function ele(e) {
  return J_ = fd = 1, lB = xs(wd = e), eo = 0, [];
}
function tle(e) {
  return wd = "", e;
}
function rT(e) {
  return sB(ev(eo - 1, mC(e === 91 ? e + 2 : e === 40 ? e + 1 : e)));
}
function nle(e) {
  for (; (jr = Mu()) && jr < 33; )
    Eo();
  return pC(e) > 2 || pC(jr) > 3 ? "" : " ";
}
function rle(e, t) {
  for (; --t && Eo() && !(jr < 48 || jr > 102 || jr > 57 && jr < 65 || jr > 70 && jr < 97); )
    ;
  return ev(e, fg() + (t < 6 && Mu() == 32 && Eo() == 32));
}
function mC(e) {
  for (; Eo(); )
    switch (jr) {
      case e:
        return eo;
      case 34:
      case 39:
        e !== 34 && e !== 39 && mC(jr);
        break;
      case 40:
        e === 41 && mC(e);
        break;
      case 92:
        Eo();
        break;
    }
  return eo;
}
function ile(e, t) {
  for (; Eo() && e + jr !== 57; )
    if (e + jr === 84 && Mu() === 47)
      break;
  return "/*" + ev(t, eo - 1) + "*" + q1(e === 47 ? e : Eo());
}
function ale(e) {
  for (; !pC(Mu()); )
    Eo();
  return ev(e, eo);
}
function ole(e) {
  return tle(pg("", null, null, null, [""], e = ele(e), 0, [0], e));
}
function pg(e, t, n, r, i, a, o, s, l) {
  for (var u = 0, c = 0, d = o, f = 0, h = 0, m = 0, v = 1, b = 1, y = 1, g = 0, E = "", S = i, C = a, T = r, O = E; b; )
    switch (m = g, g = Eo()) {
      case 40:
        if (m != 108 && Dp(O, d - 1) == 58) {
          Qse(O += dg(rT(g), "&", "&\f"), "&\f", oB(u ? s[u - 1] : 0)) != -1 && (y = -1);
          break;
        }
      case 34:
      case 39:
      case 91:
        O += rT(g);
        break;
      case 9:
      case 10:
      case 13:
      case 32:
        O += nle(m);
        break;
      case 92:
        O += rle(fg() - 1, 7);
        continue;
      case 47:
        switch (Mu()) {
          case 42:
          case 47:
            Gh(sle(ile(Eo(), fg()), t, n, l), l);
            break;
          default:
            O += "/";
        }
        break;
      case 123 * v:
        s[u++] = xs(O) * y;
      case 125 * v:
      case 59:
      case 0:
        switch (g) {
          case 0:
          case 125:
            b = 0;
          case 59 + c:
            y == -1 && (O = dg(O, /\f/g, "")), h > 0 && xs(O) - d && Gh(h > 32 ? Hk(O + ";", r, n, d - 1, l) : Hk(dg(O, " ", "") + ";", r, n, d - 2, l), l);
            break;
          case 59:
            O += ";";
          default:
            if (Gh(T = Yk(O, t, n, u, c, i, s, E, S = [], C = [], d, a), a), g === 123)
              if (c === 0)
                pg(O, t, T, T, S, a, d, s, C);
              else
                switch (f === 99 && Dp(O, 3) === 110 ? 100 : f) {
                  case 100:
                  case 108:
                  case 109:
                  case 115:
                    pg(e, T, T, r && Gh(Yk(e, T, T, 0, 0, i, s, E, i, S = [], d, C), C), i, C, d, s, r ? S : C);
                    break;
                  default:
                    pg(O, T, T, T, [""], C, 0, s, C);
                }
        }
        u = c = h = 0, v = y = 1, E = O = "", d = o;
        break;
      case 58:
        d = 1 + xs(O), h = m;
      default:
        if (v < 1) {
          if (g == 123)
            --v;
          else if (g == 125 && v++ == 0 && Jse() == 125)
            continue;
        }
        switch (O += q1(g), g * v) {
          case 38:
            y = c > 0 ? 1 : (O += "\f", -1);
            break;
          case 44:
            s[u++] = (xs(O) - 1) * y, y = 1;
            break;
          case 64:
            Mu() === 45 && (O += rT(Eo())), f = Mu(), c = d = xs(E = O += ale(fg())), g++;
            break;
          case 45:
            m === 45 && xs(O) == 2 && (v = 0);
        }
    }
  return a;
}
function Yk(e, t, n, r, i, a, o, s, l, u, c, d) {
  for (var f = i - 1, h = i === 0 ? a : [""], m = Xse(h), v = 0, b = 0, y = 0; v < r; ++v)
    for (var g = 0, E = Ip(e, f + 1, f = oB(b = o[v])), S = e; g < m; ++g)
      (S = sB(b > 0 ? h[g] + " " + E : dg(E, /&\f/g, h[g]))) && (l[y++] = S);
  return G1(e, t, n, i === 0 ? iB : s, l, u, c, d);
}
function sle(e, t, n, r) {
  return G1(e, t, n, rB, q1(Zse()), Ip(e, 2, -2), 0, r);
}
function Hk(e, t, n, r, i) {
  return G1(e, t, n, aB, Ip(e, 0, r), Ip(e, r + 1, -1), r, i);
}
function hC(e, t) {
  for (var n = "", r = 0; r < e.length; r++)
    n += t(e[r], r, e, t) || "";
  return n;
}
function lle(e, t, n, r) {
  switch (e.type) {
    case jse:
      if (e.children.length) break;
    case Wse:
    case aB:
      return e.return = e.return || e.value;
    case rB:
      return "";
    case Kse:
      return e.return = e.value + "{" + hC(e.children, r) + "}";
    case iB:
      if (!xs(e.value = e.props.join(","))) return "";
  }
  return xs(n = hC(e.children, r)) ? e.return = e.value + "{" + n + "}" : "";
}
var ule = V3(Object.keys, Object), cle = Object.prototype, dle = cle.hasOwnProperty;
function fle(e) {
  if (!X_(e))
    return ule(e);
  var t = [];
  for (var n in Object(e))
    dle.call(e, n) && n != "constructor" && t.push(n);
  return t;
}
var gC = Ju(rs, "DataView"), _C = Ju(rs, "Promise"), vC = Ju(rs, "Set"), bC = Ju(rs, "WeakMap"), zk = "[object Map]", ple = "[object Object]", Vk = "[object Promise]", Wk = "[object Set]", Kk = "[object WeakMap]", jk = "[object DataView]", mle = Zu(gC), hle = Zu(Np), gle = Zu(_C), _le = Zu(vC), vle = Zu(bC), Cu = Od;
(gC && Cu(new gC(new ArrayBuffer(1))) != jk || Np && Cu(new Np()) != zk || _C && Cu(_C.resolve()) != Vk || vC && Cu(new vC()) != Wk || bC && Cu(new bC()) != Kk) && (Cu = function(e) {
  var t = Od(e), n = t == ple ? e.constructor : void 0, r = n ? Zu(n) : "";
  if (r)
    switch (r) {
      case mle:
        return jk;
      case hle:
        return zk;
      case gle:
        return Vk;
      case _le:
        return Wk;
      case vle:
        return Kk;
    }
  return t;
});
var ble = "[object Map]", Ele = "[object Set]", Sle = Object.prototype, yle = Sle.hasOwnProperty;
function iT(e) {
  if (e == null)
    return !0;
  if (Z_(e) && (Kg(e) || typeof e == "string" || typeof e.splice == "function" || $1(e) || U1(e) || Wg(e)))
    return !e.length;
  var t = Cu(e);
  if (t == ble || t == Ele)
    return !e.size;
  if (X_(e))
    return !fle(e).length;
  for (var n in e)
    if (yle.call(e, n))
      return !1;
  return !0;
}
const ys = {
  trace: 0,
  debug: 1,
  info: 2,
  warn: 3,
  error: 4,
  fatal: 5
}, Ft = {
  trace: (...e) => {
  },
  debug: (...e) => {
  },
  info: (...e) => {
  },
  warn: (...e) => {
  },
  error: (...e) => {
  },
  fatal: (...e) => {
  }
}, Y1 = function(e = "fatal") {
  let t = ys.fatal;
  typeof e == "string" ? (e = e.toLowerCase(), e in ys && (t = ys[e])) : typeof e == "number" && (t = e), Ft.trace = () => {
  }, Ft.debug = () => {
  }, Ft.info = () => {
  }, Ft.warn = () => {
  }, Ft.error = () => {
  }, Ft.fatal = () => {
  }, t <= ys.fatal && (Ft.fatal = console.error ? console.error.bind(console, Ha("FATAL"), "color: orange") : console.log.bind(console, "\x1B[35m", Ha("FATAL"))), t <= ys.error && (Ft.error = console.error ? console.error.bind(console, Ha("ERROR"), "color: orange") : console.log.bind(console, "\x1B[31m", Ha("ERROR"))), t <= ys.warn && (Ft.warn = console.warn ? console.warn.bind(console, Ha("WARN"), "color: orange") : console.log.bind(console, "\x1B[33m", Ha("WARN"))), t <= ys.info && (Ft.info = console.info ? console.info.bind(console, Ha("INFO"), "color: lightblue") : console.log.bind(console, "\x1B[34m", Ha("INFO"))), t <= ys.debug && (Ft.debug = console.debug ? console.debug.bind(console, Ha("DEBUG"), "color: lightgreen") : console.log.bind(console, "\x1B[32m", Ha("DEBUG"))), t <= ys.trace && (Ft.trace = console.debug ? console.debug.bind(console, Ha("TRACE"), "color: lightgreen") : console.log.bind(console, "\x1B[32m", Ha("TRACE")));
}, Ha = (e) => `%c${fte().format("ss.SSS")} : ${e} : `, tv = /<br\s*\/?>/gi, Tle = (e) => e ? cB(e).replace(/\\n/g, "#br#").split("#br#") : [""], Cle = /* @__PURE__ */ (() => {
  let e = !1;
  return () => {
    e || (Ale(), e = !0);
  };
})();
function Ale() {
  const e = "data-temp-href-target";
  dd.addHook("beforeSanitizeAttributes", (t) => {
    t.tagName === "A" && t.hasAttribute("target") && t.setAttribute(e, t.getAttribute("target") || "");
  }), dd.addHook("afterSanitizeAttributes", (t) => {
    t.tagName === "A" && t.hasAttribute(e) && (t.setAttribute("target", t.getAttribute(e) || ""), t.removeAttribute(e), t.getAttribute("target") === "_blank" && t.setAttribute("rel", "noopener"));
  });
}
const uB = (e) => (Cle(), dd.sanitize(e)), Qk = (e, t) => {
  var n;
  if (((n = t.flowchart) == null ? void 0 : n.htmlLabels) !== !1) {
    const r = t.securityLevel;
    r === "antiscript" || r === "strict" ? e = uB(e) : r !== "loose" && (e = cB(e), e = e.replace(/</g, "&lt;").replace(/>/g, "&gt;"), e = e.replace(/=/g, "&equals;"), e = xle(e));
  }
  return e;
}, Lp = (e, t) => e && (t.dompurifyConfig ? e = dd.sanitize(Qk(e, t), t.dompurifyConfig).toString() : e = dd.sanitize(Qk(e, t), {
  FORBID_TAGS: ["style"]
}).toString(), e), Ole = (e, t) => typeof e == "string" ? Lp(e, t) : e.flat().map((n) => Lp(n, t)), Rle = (e) => tv.test(e), wle = (e) => e.split(tv), xle = (e) => e.replace(/#br#/g, "<br/>"), cB = (e) => e.replace(tv, "#br#"), Nle = (e) => {
  let t = "";
  return e && (t = window.location.protocol + "//" + window.location.host + window.location.pathname + window.location.search, t = t.replaceAll(/\(/g, "\\("), t = t.replaceAll(/\)/g, "\\)")), t;
}, dB = (e) => !(e === !1 || ["false", "null", "0"].includes(String(e).trim().toLowerCase())), Dle = function(...e) {
  const t = e.filter((n) => !isNaN(n));
  return Math.max(...t);
}, Ile = function(...e) {
  const t = e.filter((n) => !isNaN(n));
  return Math.min(...t);
}, v7e = function(e) {
  const t = e.split(/(,)/), n = [];
  for (let r = 0; r < t.length; r++) {
    let i = t[r];
    if (i === "," && r > 0 && r + 1 < t.length) {
      const a = t[r - 1], o = t[r + 1];
      Lle(a, o) && (i = a + "," + o, r++, n.pop());
    }
    n.push(kle(i));
  }
  return n.join("");
}, EC = (e, t) => Math.max(0, e.split(t).length - 1), Lle = (e, t) => {
  const n = EC(e, "~"), r = EC(t, "~");
  return n === 1 && r === 1;
}, kle = (e) => {
  const t = EC(e, "~");
  let n = !1;
  if (t <= 1)
    return e;
  t % 2 !== 0 && e.startsWith("~") && (e = e.substring(1), n = !0);
  const r = [...e];
  let i = r.indexOf("~"), a = r.lastIndexOf("~");
  for (; i !== -1 && a !== -1 && i !== a; )
    r[i] = "<", r[a] = ">", i = r.indexOf("~"), a = r.lastIndexOf("~");
  return n && r.unshift("~"), r.join("");
}, H1 = {
  getRows: Tle,
  sanitizeText: Lp,
  sanitizeTextOrArray: Ole,
  hasBreaks: Rle,
  splitBreaks: wle,
  lineBreakRegex: tv,
  removeScript: uB,
  getUrl: Nle,
  evaluate: dB,
  getMax: Dle,
  getMin: Ile
}, Vi = (e, t) => t ? ve(e, { s: -40, l: 10 }) : ve(e, { s: -40, l: -10 }), nv = "#ffffff", rv = "#f2f2f2";
let Mle = class {
  constructor() {
    this.background = "#f4f4f4", this.primaryColor = "#fff4dd", this.noteBkgColor = "#fff5ad", this.noteTextColor = "#333", this.THEME_COLOR_LIMIT = 12, this.fontFamily = '"trebuchet ms", verdana, arial, sans-serif', this.fontSize = "16px";
  }
  updateColors() {
    var t, n, r, i, a, o, s, l, u, c, d;
    if (this.primaryTextColor = this.primaryTextColor || (this.darkMode ? "#eee" : "#333"), this.secondaryColor = this.secondaryColor || ve(this.primaryColor, { h: -120 }), this.tertiaryColor = this.tertiaryColor || ve(this.primaryColor, { h: 180, l: 5 }), this.primaryBorderColor = this.primaryBorderColor || Vi(this.primaryColor, this.darkMode), this.secondaryBorderColor = this.secondaryBorderColor || Vi(this.secondaryColor, this.darkMode), this.tertiaryBorderColor = this.tertiaryBorderColor || Vi(this.tertiaryColor, this.darkMode), this.noteBorderColor = this.noteBorderColor || Vi(this.noteBkgColor, this.darkMode), this.noteBkgColor = this.noteBkgColor || "#fff5ad", this.noteTextColor = this.noteTextColor || "#333", this.secondaryTextColor = this.secondaryTextColor || at(this.secondaryColor), this.tertiaryTextColor = this.tertiaryTextColor || at(this.tertiaryColor), this.lineColor = this.lineColor || at(this.background), this.arrowheadColor = this.arrowheadColor || at(this.background), this.textColor = this.textColor || this.primaryTextColor, this.border2 = this.border2 || this.tertiaryBorderColor, this.nodeBkg = this.nodeBkg || this.primaryColor, this.mainBkg = this.mainBkg || this.primaryColor, this.nodeBorder = this.nodeBorder || this.primaryBorderColor, this.clusterBkg = this.clusterBkg || this.tertiaryColor, this.clusterBorder = this.clusterBorder || this.tertiaryBorderColor, this.defaultLinkColor = this.defaultLinkColor || this.lineColor, this.titleColor = this.titleColor || this.tertiaryTextColor, this.edgeLabelBackground = this.edgeLabelBackground || (this.darkMode ? $t(this.secondaryColor, 30) : this.secondaryColor), this.nodeTextColor = this.nodeTextColor || this.primaryTextColor, this.actorBorder = this.actorBorder || this.primaryBorderColor, this.actorBkg = this.actorBkg || this.mainBkg, this.actorTextColor = this.actorTextColor || this.primaryTextColor, this.actorLineColor = this.actorLineColor || "grey", this.labelBoxBkgColor = this.labelBoxBkgColor || this.actorBkg, this.signalColor = this.signalColor || this.textColor, this.signalTextColor = this.signalTextColor || this.textColor, this.labelBoxBorderColor = this.labelBoxBorderColor || this.actorBorder, this.labelTextColor = this.labelTextColor || this.actorTextColor, this.loopTextColor = this.loopTextColor || this.actorTextColor, this.activationBorderColor = this.activationBorderColor || $t(this.secondaryColor, 10), this.activationBkgColor = this.activationBkgColor || this.secondaryColor, this.sequenceNumberColor = this.sequenceNumberColor || at(this.lineColor), this.sectionBkgColor = this.sectionBkgColor || this.tertiaryColor, this.altSectionBkgColor = this.altSectionBkgColor || "white", this.sectionBkgColor = this.sectionBkgColor || this.secondaryColor, this.sectionBkgColor2 = this.sectionBkgColor2 || this.primaryColor, this.excludeBkgColor = this.excludeBkgColor || "#eeeeee", this.taskBorderColor = this.taskBorderColor || this.primaryBorderColor, this.taskBkgColor = this.taskBkgColor || this.primaryColor, this.activeTaskBorderColor = this.activeTaskBorderColor || this.primaryColor, this.activeTaskBkgColor = this.activeTaskBkgColor || xt(this.primaryColor, 23), this.gridColor = this.gridColor || "lightgrey", this.doneTaskBkgColor = this.doneTaskBkgColor || "lightgrey", this.doneTaskBorderColor = this.doneTaskBorderColor || "grey", this.critBorderColor = this.critBorderColor || "#ff8888", this.critBkgColor = this.critBkgColor || "red", this.todayLineColor = this.todayLineColor || "red", this.taskTextColor = this.taskTextColor || this.textColor, this.taskTextOutsideColor = this.taskTextOutsideColor || this.textColor, this.taskTextLightColor = this.taskTextLightColor || this.textColor, this.taskTextColor = this.taskTextColor || this.primaryTextColor, this.taskTextDarkColor = this.taskTextDarkColor || this.textColor, this.taskTextClickableColor = this.taskTextClickableColor || "#003163", this.personBorder = this.personBorder || this.primaryBorderColor, this.personBkg = this.personBkg || this.mainBkg, this.transitionColor = this.transitionColor || this.lineColor, this.transitionLabelColor = this.transitionLabelColor || this.textColor, this.stateLabelColor = this.stateLabelColor || this.stateBkg || this.primaryTextColor, this.stateBkg = this.stateBkg || this.mainBkg, this.labelBackgroundColor = this.labelBackgroundColor || this.stateBkg, this.compositeBackground = this.compositeBackground || this.background || this.tertiaryColor, this.altBackground = this.altBackground || this.tertiaryColor, this.compositeTitleBackground = this.compositeTitleBackground || this.mainBkg, this.compositeBorder = this.compositeBorder || this.nodeBorder, this.innerEndBackground = this.nodeBorder, this.errorBkgColor = this.errorBkgColor || this.tertiaryColor, this.errorTextColor = this.errorTextColor || this.tertiaryTextColor, this.transitionColor = this.transitionColor || this.lineColor, this.specialStateColor = this.lineColor, this.cScale0 = this.cScale0 || this.primaryColor, this.cScale1 = this.cScale1 || this.secondaryColor, this.cScale2 = this.cScale2 || this.tertiaryColor, this.cScale3 = this.cScale3 || ve(this.primaryColor, { h: 30 }), this.cScale4 = this.cScale4 || ve(this.primaryColor, { h: 60 }), this.cScale5 = this.cScale5 || ve(this.primaryColor, { h: 90 }), this.cScale6 = this.cScale6 || ve(this.primaryColor, { h: 120 }), this.cScale7 = this.cScale7 || ve(this.primaryColor, { h: 150 }), this.cScale8 = this.cScale8 || ve(this.primaryColor, { h: 210, l: 150 }), this.cScale9 = this.cScale9 || ve(this.primaryColor, { h: 270 }), this.cScale10 = this.cScale10 || ve(this.primaryColor, { h: 300 }), this.cScale11 = this.cScale11 || ve(this.primaryColor, { h: 330 }), this.darkMode)
      for (let h = 0; h < this.THEME_COLOR_LIMIT; h++)
        this["cScale" + h] = $t(this["cScale" + h], 75);
    else
      for (let h = 0; h < this.THEME_COLOR_LIMIT; h++)
        this["cScale" + h] = $t(this["cScale" + h], 25);
    for (let h = 0; h < this.THEME_COLOR_LIMIT; h++)
      this["cScaleInv" + h] = this["cScaleInv" + h] || at(this["cScale" + h]);
    for (let h = 0; h < this.THEME_COLOR_LIMIT; h++)
      this.darkMode ? this["cScalePeer" + h] = this["cScalePeer" + h] || xt(this["cScale" + h], 10) : this["cScalePeer" + h] = this["cScalePeer" + h] || $t(this["cScale" + h], 10);
    this.scaleLabelColor = this.scaleLabelColor || this.labelTextColor;
    for (let h = 0; h < this.THEME_COLOR_LIMIT; h++)
      this["cScaleLabel" + h] = this["cScaleLabel" + h] || this.scaleLabelColor;
    const f = this.darkMode ? -4 : -1;
    for (let h = 0; h < 5; h++)
      this["surface" + h] = this["surface" + h] || ve(this.mainBkg, { h: 180, s: -15, l: f * (5 + h * 3) }), this["surfacePeer" + h] = this["surfacePeer" + h] || ve(this.mainBkg, { h: 180, s: -15, l: f * (8 + h * 3) });
    this.classText = this.classText || this.textColor, this.fillType0 = this.fillType0 || this.primaryColor, this.fillType1 = this.fillType1 || this.secondaryColor, this.fillType2 = this.fillType2 || ve(this.primaryColor, { h: 64 }), this.fillType3 = this.fillType3 || ve(this.secondaryColor, { h: 64 }), this.fillType4 = this.fillType4 || ve(this.primaryColor, { h: -64 }), this.fillType5 = this.fillType5 || ve(this.secondaryColor, { h: -64 }), this.fillType6 = this.fillType6 || ve(this.primaryColor, { h: 128 }), this.fillType7 = this.fillType7 || ve(this.secondaryColor, { h: 128 }), this.pie1 = this.pie1 || this.primaryColor, this.pie2 = this.pie2 || this.secondaryColor, this.pie3 = this.pie3 || this.tertiaryColor, this.pie4 = this.pie4 || ve(this.primaryColor, { l: -10 }), this.pie5 = this.pie5 || ve(this.secondaryColor, { l: -10 }), this.pie6 = this.pie6 || ve(this.tertiaryColor, { l: -10 }), this.pie7 = this.pie7 || ve(this.primaryColor, { h: 60, l: -10 }), this.pie8 = this.pie8 || ve(this.primaryColor, { h: -60, l: -10 }), this.pie9 = this.pie9 || ve(this.primaryColor, { h: 120, l: 0 }), this.pie10 = this.pie10 || ve(this.primaryColor, { h: 60, l: -20 }), this.pie11 = this.pie11 || ve(this.primaryColor, { h: -60, l: -20 }), this.pie12 = this.pie12 || ve(this.primaryColor, { h: 120, l: -10 }), this.pieTitleTextSize = this.pieTitleTextSize || "25px", this.pieTitleTextColor = this.pieTitleTextColor || this.taskTextDarkColor, this.pieSectionTextSize = this.pieSectionTextSize || "17px", this.pieSectionTextColor = this.pieSectionTextColor || this.textColor, this.pieLegendTextSize = this.pieLegendTextSize || "17px", this.pieLegendTextColor = this.pieLegendTextColor || this.taskTextDarkColor, this.pieStrokeColor = this.pieStrokeColor || "black", this.pieStrokeWidth = this.pieStrokeWidth || "2px", this.pieOuterStrokeWidth = this.pieOuterStrokeWidth || "2px", this.pieOuterStrokeColor = this.pieOuterStrokeColor || "black", this.pieOpacity = this.pieOpacity || "0.7", this.quadrant1Fill = this.quadrant1Fill || this.primaryColor, this.quadrant2Fill = this.quadrant2Fill || ve(this.primaryColor, { r: 5, g: 5, b: 5 }), this.quadrant3Fill = this.quadrant3Fill || ve(this.primaryColor, { r: 10, g: 10, b: 10 }), this.quadrant4Fill = this.quadrant4Fill || ve(this.primaryColor, { r: 15, g: 15, b: 15 }), this.quadrant1TextFill = this.quadrant1TextFill || this.primaryTextColor, this.quadrant2TextFill = this.quadrant2TextFill || ve(this.primaryTextColor, { r: -5, g: -5, b: -5 }), this.quadrant3TextFill = this.quadrant3TextFill || ve(this.primaryTextColor, { r: -10, g: -10, b: -10 }), this.quadrant4TextFill = this.quadrant4TextFill || ve(this.primaryTextColor, { r: -15, g: -15, b: -15 }), this.quadrantPointFill = this.quadrantPointFill || dm(this.quadrant1Fill) ? xt(this.quadrant1Fill) : $t(this.quadrant1Fill), this.quadrantPointTextFill = this.quadrantPointTextFill || this.primaryTextColor, this.quadrantXAxisTextFill = this.quadrantXAxisTextFill || this.primaryTextColor, this.quadrantYAxisTextFill = this.quadrantYAxisTextFill || this.primaryTextColor, this.quadrantInternalBorderStrokeFill = this.quadrantInternalBorderStrokeFill || this.primaryBorderColor, this.quadrantExternalBorderStrokeFill = this.quadrantExternalBorderStrokeFill || this.primaryBorderColor, this.quadrantTitleFill = this.quadrantTitleFill || this.primaryTextColor, this.xyChart = {
      backgroundColor: ((t = this.xyChart) == null ? void 0 : t.backgroundColor) || this.background,
      titleColor: ((n = this.xyChart) == null ? void 0 : n.titleColor) || this.primaryTextColor,
      xAxisTitleColor: ((r = this.xyChart) == null ? void 0 : r.xAxisTitleColor) || this.primaryTextColor,
      xAxisLabelColor: ((i = this.xyChart) == null ? void 0 : i.xAxisLabelColor) || this.primaryTextColor,
      xAxisTickColor: ((a = this.xyChart) == null ? void 0 : a.xAxisTickColor) || this.primaryTextColor,
      xAxisLineColor: ((o = this.xyChart) == null ? void 0 : o.xAxisLineColor) || this.primaryTextColor,
      yAxisTitleColor: ((s = this.xyChart) == null ? void 0 : s.yAxisTitleColor) || this.primaryTextColor,
      yAxisLabelColor: ((l = this.xyChart) == null ? void 0 : l.yAxisLabelColor) || this.primaryTextColor,
      yAxisTickColor: ((u = this.xyChart) == null ? void 0 : u.yAxisTickColor) || this.primaryTextColor,
      yAxisLineColor: ((c = this.xyChart) == null ? void 0 : c.yAxisLineColor) || this.primaryTextColor,
      plotColorPalette: ((d = this.xyChart) == null ? void 0 : d.plotColorPalette) || "#FFF4DD,#FFD8B1,#FFA07A,#ECEFF1,#D6DBDF,#C3E0A8,#FFB6A4,#FFD74D,#738FA7,#FFFFF0"
    }, this.requirementBackground = this.requirementBackground || this.primaryColor, this.requirementBorderColor = this.requirementBorderColor || this.primaryBorderColor, this.requirementBorderSize = this.requirementBorderSize || "1", this.requirementTextColor = this.requirementTextColor || this.primaryTextColor, this.relationColor = this.relationColor || this.lineColor, this.relationLabelBackground = this.relationLabelBackground || (this.darkMode ? $t(this.secondaryColor, 30) : this.secondaryColor), this.relationLabelColor = this.relationLabelColor || this.actorTextColor, this.git0 = this.git0 || this.primaryColor, this.git1 = this.git1 || this.secondaryColor, this.git2 = this.git2 || this.tertiaryColor, this.git3 = this.git3 || ve(this.primaryColor, { h: -30 }), this.git4 = this.git4 || ve(this.primaryColor, { h: -60 }), this.git5 = this.git5 || ve(this.primaryColor, { h: -90 }), this.git6 = this.git6 || ve(this.primaryColor, { h: 60 }), this.git7 = this.git7 || ve(this.primaryColor, { h: 120 }), this.darkMode ? (this.git0 = xt(this.git0, 25), this.git1 = xt(this.git1, 25), this.git2 = xt(this.git2, 25), this.git3 = xt(this.git3, 25), this.git4 = xt(this.git4, 25), this.git5 = xt(this.git5, 25), this.git6 = xt(this.git6, 25), this.git7 = xt(this.git7, 25)) : (this.git0 = $t(this.git0, 25), this.git1 = $t(this.git1, 25), this.git2 = $t(this.git2, 25), this.git3 = $t(this.git3, 25), this.git4 = $t(this.git4, 25), this.git5 = $t(this.git5, 25), this.git6 = $t(this.git6, 25), this.git7 = $t(this.git7, 25)), this.gitInv0 = this.gitInv0 || at(this.git0), this.gitInv1 = this.gitInv1 || at(this.git1), this.gitInv2 = this.gitInv2 || at(this.git2), this.gitInv3 = this.gitInv3 || at(this.git3), this.gitInv4 = this.gitInv4 || at(this.git4), this.gitInv5 = this.gitInv5 || at(this.git5), this.gitInv6 = this.gitInv6 || at(this.git6), this.gitInv7 = this.gitInv7 || at(this.git7), this.branchLabelColor = this.branchLabelColor || (this.darkMode ? "black" : this.labelTextColor), this.gitBranchLabel0 = this.gitBranchLabel0 || this.branchLabelColor, this.gitBranchLabel1 = this.gitBranchLabel1 || this.branchLabelColor, this.gitBranchLabel2 = this.gitBranchLabel2 || this.branchLabelColor, this.gitBranchLabel3 = this.gitBranchLabel3 || this.branchLabelColor, this.gitBranchLabel4 = this.gitBranchLabel4 || this.branchLabelColor, this.gitBranchLabel5 = this.gitBranchLabel5 || this.branchLabelColor, this.gitBranchLabel6 = this.gitBranchLabel6 || this.branchLabelColor, this.gitBranchLabel7 = this.gitBranchLabel7 || this.branchLabelColor, this.tagLabelColor = this.tagLabelColor || this.primaryTextColor, this.tagLabelBackground = this.tagLabelBackground || this.primaryColor, this.tagLabelBorder = this.tagBorder || this.primaryBorderColor, this.tagLabelFontSize = this.tagLabelFontSize || "10px", this.commitLabelColor = this.commitLabelColor || this.secondaryTextColor, this.commitLabelBackground = this.commitLabelBackground || this.secondaryColor, this.commitLabelFontSize = this.commitLabelFontSize || "10px", this.attributeBackgroundColorOdd = this.attributeBackgroundColorOdd || nv, this.attributeBackgroundColorEven = this.attributeBackgroundColorEven || rv;
  }
  calculate(t) {
    if (typeof t != "object") {
      this.updateColors();
      return;
    }
    const n = Object.keys(t);
    n.forEach((r) => {
      this[r] = t[r];
    }), this.updateColors(), n.forEach((r) => {
      this[r] = t[r];
    });
  }
};
const Ple = (e) => {
  const t = new Mle();
  return t.calculate(e), t;
};
let Fle = class {
  constructor() {
    this.background = "#333", this.primaryColor = "#1f2020", this.secondaryColor = xt(this.primaryColor, 16), this.tertiaryColor = ve(this.primaryColor, { h: -160 }), this.primaryBorderColor = at(this.background), this.secondaryBorderColor = Vi(this.secondaryColor, this.darkMode), this.tertiaryBorderColor = Vi(this.tertiaryColor, this.darkMode), this.primaryTextColor = at(this.primaryColor), this.secondaryTextColor = at(this.secondaryColor), this.tertiaryTextColor = at(this.tertiaryColor), this.lineColor = at(this.background), this.textColor = at(this.background), this.mainBkg = "#1f2020", this.secondBkg = "calculated", this.mainContrastColor = "lightgrey", this.darkTextColor = xt(at("#323D47"), 10), this.lineColor = "calculated", this.border1 = "#81B1DB", this.border2 = Qf(255, 255, 255, 0.25), this.arrowheadColor = "calculated", this.fontFamily = '"trebuchet ms", verdana, arial, sans-serif', this.fontSize = "16px", this.labelBackground = "#181818", this.textColor = "#ccc", this.THEME_COLOR_LIMIT = 12, this.nodeBkg = "calculated", this.nodeBorder = "calculated", this.clusterBkg = "calculated", this.clusterBorder = "calculated", this.defaultLinkColor = "calculated", this.titleColor = "#F9FFFE", this.edgeLabelBackground = "calculated", this.actorBorder = "calculated", this.actorBkg = "calculated", this.actorTextColor = "calculated", this.actorLineColor = "calculated", this.signalColor = "calculated", this.signalTextColor = "calculated", this.labelBoxBkgColor = "calculated", this.labelBoxBorderColor = "calculated", this.labelTextColor = "calculated", this.loopTextColor = "calculated", this.noteBorderColor = "calculated", this.noteBkgColor = "#fff5ad", this.noteTextColor = "calculated", this.activationBorderColor = "calculated", this.activationBkgColor = "calculated", this.sequenceNumberColor = "black", this.sectionBkgColor = $t("#EAE8D9", 30), this.altSectionBkgColor = "calculated", this.sectionBkgColor2 = "#EAE8D9", this.excludeBkgColor = $t(this.sectionBkgColor, 10), this.taskBorderColor = Qf(255, 255, 255, 70), this.taskBkgColor = "calculated", this.taskTextColor = "calculated", this.taskTextLightColor = "calculated", this.taskTextOutsideColor = "calculated", this.taskTextClickableColor = "#003163", this.activeTaskBorderColor = Qf(255, 255, 255, 50), this.activeTaskBkgColor = "#81B1DB", this.gridColor = "calculated", this.doneTaskBkgColor = "calculated", this.doneTaskBorderColor = "grey", this.critBorderColor = "#E83737", this.critBkgColor = "#E83737", this.taskTextDarkColor = "calculated", this.todayLineColor = "#DB5757", this.personBorder = this.primaryBorderColor, this.personBkg = this.mainBkg, this.labelColor = "calculated", this.errorBkgColor = "#a44141", this.errorTextColor = "#ddd";
  }
  updateColors() {
    var t, n, r, i, a, o, s, l, u, c, d;
    this.secondBkg = xt(this.mainBkg, 16), this.lineColor = this.mainContrastColor, this.arrowheadColor = this.mainContrastColor, this.nodeBkg = this.mainBkg, this.nodeBorder = this.border1, this.clusterBkg = this.secondBkg, this.clusterBorder = this.border2, this.defaultLinkColor = this.lineColor, this.edgeLabelBackground = xt(this.labelBackground, 25), this.actorBorder = this.border1, this.actorBkg = this.mainBkg, this.actorTextColor = this.mainContrastColor, this.actorLineColor = this.mainContrastColor, this.signalColor = this.mainContrastColor, this.signalTextColor = this.mainContrastColor, this.labelBoxBkgColor = this.actorBkg, this.labelBoxBorderColor = this.actorBorder, this.labelTextColor = this.mainContrastColor, this.loopTextColor = this.mainContrastColor, this.noteBorderColor = this.secondaryBorderColor, this.noteBkgColor = this.secondBkg, this.noteTextColor = this.secondaryTextColor, this.activationBorderColor = this.border1, this.activationBkgColor = this.secondBkg, this.altSectionBkgColor = this.background, this.taskBkgColor = xt(this.mainBkg, 23), this.taskTextColor = this.darkTextColor, this.taskTextLightColor = this.mainContrastColor, this.taskTextOutsideColor = this.taskTextLightColor, this.gridColor = this.mainContrastColor, this.doneTaskBkgColor = this.mainContrastColor, this.taskTextDarkColor = this.darkTextColor, this.transitionColor = this.transitionColor || this.lineColor, this.transitionLabelColor = this.transitionLabelColor || this.textColor, this.stateLabelColor = this.stateLabelColor || this.stateBkg || this.primaryTextColor, this.stateBkg = this.stateBkg || this.mainBkg, this.labelBackgroundColor = this.labelBackgroundColor || this.stateBkg, this.compositeBackground = this.compositeBackground || this.background || this.tertiaryColor, this.altBackground = this.altBackground || "#555", this.compositeTitleBackground = this.compositeTitleBackground || this.mainBkg, this.compositeBorder = this.compositeBorder || this.nodeBorder, this.innerEndBackground = this.primaryBorderColor, this.specialStateColor = "#f4f4f4", this.errorBkgColor = this.errorBkgColor || this.tertiaryColor, this.errorTextColor = this.errorTextColor || this.tertiaryTextColor, this.fillType0 = this.primaryColor, this.fillType1 = this.secondaryColor, this.fillType2 = ve(this.primaryColor, { h: 64 }), this.fillType3 = ve(this.secondaryColor, { h: 64 }), this.fillType4 = ve(this.primaryColor, { h: -64 }), this.fillType5 = ve(this.secondaryColor, { h: -64 }), this.fillType6 = ve(this.primaryColor, { h: 128 }), this.fillType7 = ve(this.secondaryColor, { h: 128 }), this.cScale1 = this.cScale1 || "#0b0000", this.cScale2 = this.cScale2 || "#4d1037", this.cScale3 = this.cScale3 || "#3f5258", this.cScale4 = this.cScale4 || "#4f2f1b", this.cScale5 = this.cScale5 || "#6e0a0a", this.cScale6 = this.cScale6 || "#3b0048", this.cScale7 = this.cScale7 || "#995a01", this.cScale8 = this.cScale8 || "#154706", this.cScale9 = this.cScale9 || "#161722", this.cScale10 = this.cScale10 || "#00296f", this.cScale11 = this.cScale11 || "#01629c", this.cScale12 = this.cScale12 || "#010029", this.cScale0 = this.cScale0 || this.primaryColor, this.cScale1 = this.cScale1 || this.secondaryColor, this.cScale2 = this.cScale2 || this.tertiaryColor, this.cScale3 = this.cScale3 || ve(this.primaryColor, { h: 30 }), this.cScale4 = this.cScale4 || ve(this.primaryColor, { h: 60 }), this.cScale5 = this.cScale5 || ve(this.primaryColor, { h: 90 }), this.cScale6 = this.cScale6 || ve(this.primaryColor, { h: 120 }), this.cScale7 = this.cScale7 || ve(this.primaryColor, { h: 150 }), this.cScale8 = this.cScale8 || ve(this.primaryColor, { h: 210 }), this.cScale9 = this.cScale9 || ve(this.primaryColor, { h: 270 }), this.cScale10 = this.cScale10 || ve(this.primaryColor, { h: 300 }), this.cScale11 = this.cScale11 || ve(this.primaryColor, { h: 330 });
    for (let f = 0; f < this.THEME_COLOR_LIMIT; f++)
      this["cScaleInv" + f] = this["cScaleInv" + f] || at(this["cScale" + f]);
    for (let f = 0; f < this.THEME_COLOR_LIMIT; f++)
      this["cScalePeer" + f] = this["cScalePeer" + f] || xt(this["cScale" + f], 10);
    for (let f = 0; f < 5; f++)
      this["surface" + f] = this["surface" + f] || ve(this.mainBkg, { h: 30, s: -30, l: -(-10 + f * 4) }), this["surfacePeer" + f] = this["surfacePeer" + f] || ve(this.mainBkg, { h: 30, s: -30, l: -(-7 + f * 4) });
    this.scaleLabelColor = this.scaleLabelColor || (this.darkMode ? "black" : this.labelTextColor);
    for (let f = 0; f < this.THEME_COLOR_LIMIT; f++)
      this["cScaleLabel" + f] = this["cScaleLabel" + f] || this.scaleLabelColor;
    for (let f = 0; f < this.THEME_COLOR_LIMIT; f++)
      this["pie" + f] = this["cScale" + f];
    this.pieTitleTextSize = this.pieTitleTextSize || "25px", this.pieTitleTextColor = this.pieTitleTextColor || this.taskTextDarkColor, this.pieSectionTextSize = this.pieSectionTextSize || "17px", this.pieSectionTextColor = this.pieSectionTextColor || this.textColor, this.pieLegendTextSize = this.pieLegendTextSize || "17px", this.pieLegendTextColor = this.pieLegendTextColor || this.taskTextDarkColor, this.pieStrokeColor = this.pieStrokeColor || "black", this.pieStrokeWidth = this.pieStrokeWidth || "2px", this.pieOuterStrokeWidth = this.pieOuterStrokeWidth || "2px", this.pieOuterStrokeColor = this.pieOuterStrokeColor || "black", this.pieOpacity = this.pieOpacity || "0.7", this.quadrant1Fill = this.quadrant1Fill || this.primaryColor, this.quadrant2Fill = this.quadrant2Fill || ve(this.primaryColor, { r: 5, g: 5, b: 5 }), this.quadrant3Fill = this.quadrant3Fill || ve(this.primaryColor, { r: 10, g: 10, b: 10 }), this.quadrant4Fill = this.quadrant4Fill || ve(this.primaryColor, { r: 15, g: 15, b: 15 }), this.quadrant1TextFill = this.quadrant1TextFill || this.primaryTextColor, this.quadrant2TextFill = this.quadrant2TextFill || ve(this.primaryTextColor, { r: -5, g: -5, b: -5 }), this.quadrant3TextFill = this.quadrant3TextFill || ve(this.primaryTextColor, { r: -10, g: -10, b: -10 }), this.quadrant4TextFill = this.quadrant4TextFill || ve(this.primaryTextColor, { r: -15, g: -15, b: -15 }), this.quadrantPointFill = this.quadrantPointFill || dm(this.quadrant1Fill) ? xt(this.quadrant1Fill) : $t(this.quadrant1Fill), this.quadrantPointTextFill = this.quadrantPointTextFill || this.primaryTextColor, this.quadrantXAxisTextFill = this.quadrantXAxisTextFill || this.primaryTextColor, this.quadrantYAxisTextFill = this.quadrantYAxisTextFill || this.primaryTextColor, this.quadrantInternalBorderStrokeFill = this.quadrantInternalBorderStrokeFill || this.primaryBorderColor, this.quadrantExternalBorderStrokeFill = this.quadrantExternalBorderStrokeFill || this.primaryBorderColor, this.quadrantTitleFill = this.quadrantTitleFill || this.primaryTextColor, this.xyChart = {
      backgroundColor: ((t = this.xyChart) == null ? void 0 : t.backgroundColor) || this.background,
      titleColor: ((n = this.xyChart) == null ? void 0 : n.titleColor) || this.primaryTextColor,
      xAxisTitleColor: ((r = this.xyChart) == null ? void 0 : r.xAxisTitleColor) || this.primaryTextColor,
      xAxisLabelColor: ((i = this.xyChart) == null ? void 0 : i.xAxisLabelColor) || this.primaryTextColor,
      xAxisTickColor: ((a = this.xyChart) == null ? void 0 : a.xAxisTickColor) || this.primaryTextColor,
      xAxisLineColor: ((o = this.xyChart) == null ? void 0 : o.xAxisLineColor) || this.primaryTextColor,
      yAxisTitleColor: ((s = this.xyChart) == null ? void 0 : s.yAxisTitleColor) || this.primaryTextColor,
      yAxisLabelColor: ((l = this.xyChart) == null ? void 0 : l.yAxisLabelColor) || this.primaryTextColor,
      yAxisTickColor: ((u = this.xyChart) == null ? void 0 : u.yAxisTickColor) || this.primaryTextColor,
      yAxisLineColor: ((c = this.xyChart) == null ? void 0 : c.yAxisLineColor) || this.primaryTextColor,
      plotColorPalette: ((d = this.xyChart) == null ? void 0 : d.plotColorPalette) || "#3498db,#2ecc71,#e74c3c,#f1c40f,#bdc3c7,#ffffff,#34495e,#9b59b6,#1abc9c,#e67e22"
    }, this.classText = this.primaryTextColor, this.requirementBackground = this.requirementBackground || this.primaryColor, this.requirementBorderColor = this.requirementBorderColor || this.primaryBorderColor, this.requirementBorderSize = this.requirementBorderSize || "1", this.requirementTextColor = this.requirementTextColor || this.primaryTextColor, this.relationColor = this.relationColor || this.lineColor, this.relationLabelBackground = this.relationLabelBackground || (this.darkMode ? $t(this.secondaryColor, 30) : this.secondaryColor), this.relationLabelColor = this.relationLabelColor || this.actorTextColor, this.git0 = xt(this.secondaryColor, 20), this.git1 = xt(this.pie2 || this.secondaryColor, 20), this.git2 = xt(this.pie3 || this.tertiaryColor, 20), this.git3 = xt(this.pie4 || ve(this.primaryColor, { h: -30 }), 20), this.git4 = xt(this.pie5 || ve(this.primaryColor, { h: -60 }), 20), this.git5 = xt(this.pie6 || ve(this.primaryColor, { h: -90 }), 10), this.git6 = xt(this.pie7 || ve(this.primaryColor, { h: 60 }), 10), this.git7 = xt(this.pie8 || ve(this.primaryColor, { h: 120 }), 20), this.gitInv0 = this.gitInv0 || at(this.git0), this.gitInv1 = this.gitInv1 || at(this.git1), this.gitInv2 = this.gitInv2 || at(this.git2), this.gitInv3 = this.gitInv3 || at(this.git3), this.gitInv4 = this.gitInv4 || at(this.git4), this.gitInv5 = this.gitInv5 || at(this.git5), this.gitInv6 = this.gitInv6 || at(this.git6), this.gitInv7 = this.gitInv7 || at(this.git7), this.gitBranchLabel0 = this.gitBranchLabel0 || at(this.labelTextColor), this.gitBranchLabel1 = this.gitBranchLabel1 || this.labelTextColor, this.gitBranchLabel2 = this.gitBranchLabel2 || this.labelTextColor, this.gitBranchLabel3 = this.gitBranchLabel3 || at(this.labelTextColor), this.gitBranchLabel4 = this.gitBranchLabel4 || this.labelTextColor, this.gitBranchLabel5 = this.gitBranchLabel5 || this.labelTextColor, this.gitBranchLabel6 = this.gitBranchLabel6 || this.labelTextColor, this.gitBranchLabel7 = this.gitBranchLabel7 || this.labelTextColor, this.tagLabelColor = this.tagLabelColor || this.primaryTextColor, this.tagLabelBackground = this.tagLabelBackground || this.primaryColor, this.tagLabelBorder = this.tagBorder || this.primaryBorderColor, this.tagLabelFontSize = this.tagLabelFontSize || "10px", this.commitLabelColor = this.commitLabelColor || this.secondaryTextColor, this.commitLabelBackground = this.commitLabelBackground || this.secondaryColor, this.commitLabelFontSize = this.commitLabelFontSize || "10px", this.attributeBackgroundColorOdd = this.attributeBackgroundColorOdd || xt(this.background, 12), this.attributeBackgroundColorEven = this.attributeBackgroundColorEven || xt(this.background, 2);
  }
  calculate(t) {
    if (typeof t != "object") {
      this.updateColors();
      return;
    }
    const n = Object.keys(t);
    n.forEach((r) => {
      this[r] = t[r];
    }), this.updateColors(), n.forEach((r) => {
      this[r] = t[r];
    });
  }
};
const Ble = (e) => {
  const t = new Fle();
  return t.calculate(e), t;
};
let $le = class {
  constructor() {
    this.background = "#f4f4f4", this.primaryColor = "#ECECFF", this.secondaryColor = ve(this.primaryColor, { h: 120 }), this.secondaryColor = "#ffffde", this.tertiaryColor = ve(this.primaryColor, { h: -160 }), this.primaryBorderColor = Vi(this.primaryColor, this.darkMode), this.secondaryBorderColor = Vi(this.secondaryColor, this.darkMode), this.tertiaryBorderColor = Vi(this.tertiaryColor, this.darkMode), this.primaryTextColor = at(this.primaryColor), this.secondaryTextColor = at(this.secondaryColor), this.tertiaryTextColor = at(this.tertiaryColor), this.lineColor = at(this.background), this.textColor = at(this.background), this.background = "white", this.mainBkg = "#ECECFF", this.secondBkg = "#ffffde", this.lineColor = "#333333", this.border1 = "#9370DB", this.border2 = "#aaaa33", this.arrowheadColor = "#333333", this.fontFamily = '"trebuchet ms", verdana, arial, sans-serif', this.fontSize = "16px", this.labelBackground = "#e8e8e8", this.textColor = "#333", this.THEME_COLOR_LIMIT = 12, this.nodeBkg = "calculated", this.nodeBorder = "calculated", this.clusterBkg = "calculated", this.clusterBorder = "calculated", this.defaultLinkColor = "calculated", this.titleColor = "calculated", this.edgeLabelBackground = "calculated", this.actorBorder = "calculated", this.actorBkg = "calculated", this.actorTextColor = "black", this.actorLineColor = "grey", this.signalColor = "calculated", this.signalTextColor = "calculated", this.labelBoxBkgColor = "calculated", this.labelBoxBorderColor = "calculated", this.labelTextColor = "calculated", this.loopTextColor = "calculated", this.noteBorderColor = "calculated", this.noteBkgColor = "#fff5ad", this.noteTextColor = "calculated", this.activationBorderColor = "#666", this.activationBkgColor = "#f4f4f4", this.sequenceNumberColor = "white", this.sectionBkgColor = "calculated", this.altSectionBkgColor = "calculated", this.sectionBkgColor2 = "calculated", this.excludeBkgColor = "#eeeeee", this.taskBorderColor = "calculated", this.taskBkgColor = "calculated", this.taskTextLightColor = "calculated", this.taskTextColor = this.taskTextLightColor, this.taskTextDarkColor = "calculated", this.taskTextOutsideColor = this.taskTextDarkColor, this.taskTextClickableColor = "calculated", this.activeTaskBorderColor = "calculated", this.activeTaskBkgColor = "calculated", this.gridColor = "calculated", this.doneTaskBkgColor = "calculated", this.doneTaskBorderColor = "calculated", this.critBorderColor = "calculated", this.critBkgColor = "calculated", this.todayLineColor = "calculated", this.sectionBkgColor = Qf(102, 102, 255, 0.49), this.altSectionBkgColor = "white", this.sectionBkgColor2 = "#fff400", this.taskBorderColor = "#534fbc", this.taskBkgColor = "#8a90dd", this.taskTextLightColor = "white", this.taskTextColor = "calculated", this.taskTextDarkColor = "black", this.taskTextOutsideColor = "calculated", this.taskTextClickableColor = "#003163", this.activeTaskBorderColor = "#534fbc", this.activeTaskBkgColor = "#bfc7ff", this.gridColor = "lightgrey", this.doneTaskBkgColor = "lightgrey", this.doneTaskBorderColor = "grey", this.critBorderColor = "#ff8888", this.critBkgColor = "red", this.todayLineColor = "red", this.personBorder = this.primaryBorderColor, this.personBkg = this.mainBkg, this.labelColor = "black", this.errorBkgColor = "#552222", this.errorTextColor = "#552222", this.updateColors();
  }
  updateColors() {
    var t, n, r, i, a, o, s, l, u, c, d;
    this.cScale0 = this.cScale0 || this.primaryColor, this.cScale1 = this.cScale1 || this.secondaryColor, this.cScale2 = this.cScale2 || this.tertiaryColor, this.cScale3 = this.cScale3 || ve(this.primaryColor, { h: 30 }), this.cScale4 = this.cScale4 || ve(this.primaryColor, { h: 60 }), this.cScale5 = this.cScale5 || ve(this.primaryColor, { h: 90 }), this.cScale6 = this.cScale6 || ve(this.primaryColor, { h: 120 }), this.cScale7 = this.cScale7 || ve(this.primaryColor, { h: 150 }), this.cScale8 = this.cScale8 || ve(this.primaryColor, { h: 210 }), this.cScale9 = this.cScale9 || ve(this.primaryColor, { h: 270 }), this.cScale10 = this.cScale10 || ve(this.primaryColor, { h: 300 }), this.cScale11 = this.cScale11 || ve(this.primaryColor, { h: 330 }), this.cScalePeer1 = this.cScalePeer1 || $t(this.secondaryColor, 45), this.cScalePeer2 = this.cScalePeer2 || $t(this.tertiaryColor, 40);
    for (let f = 0; f < this.THEME_COLOR_LIMIT; f++)
      this["cScale" + f] = $t(this["cScale" + f], 10), this["cScalePeer" + f] = this["cScalePeer" + f] || $t(this["cScale" + f], 25);
    for (let f = 0; f < this.THEME_COLOR_LIMIT; f++)
      this["cScaleInv" + f] = this["cScaleInv" + f] || ve(this["cScale" + f], { h: 180 });
    for (let f = 0; f < 5; f++)
      this["surface" + f] = this["surface" + f] || ve(this.mainBkg, { h: 30, l: -(5 + f * 5) }), this["surfacePeer" + f] = this["surfacePeer" + f] || ve(this.mainBkg, { h: 30, l: -(7 + f * 5) });
    if (this.scaleLabelColor = this.scaleLabelColor !== "calculated" && this.scaleLabelColor ? this.scaleLabelColor : this.labelTextColor, this.labelTextColor !== "calculated") {
      this.cScaleLabel0 = this.cScaleLabel0 || at(this.labelTextColor), this.cScaleLabel3 = this.cScaleLabel3 || at(this.labelTextColor);
      for (let f = 0; f < this.THEME_COLOR_LIMIT; f++)
        this["cScaleLabel" + f] = this["cScaleLabel" + f] || this.labelTextColor;
    }
    this.nodeBkg = this.mainBkg, this.nodeBorder = this.border1, this.clusterBkg = this.secondBkg, this.clusterBorder = this.border2, this.defaultLinkColor = this.lineColor, this.titleColor = this.textColor, this.edgeLabelBackground = this.labelBackground, this.actorBorder = xt(this.border1, 23), this.actorBkg = this.mainBkg, this.labelBoxBkgColor = this.actorBkg, this.signalColor = this.textColor, this.signalTextColor = this.textColor, this.labelBoxBorderColor = this.actorBorder, this.labelTextColor = this.actorTextColor, this.loopTextColor = this.actorTextColor, this.noteBorderColor = this.border2, this.noteTextColor = this.actorTextColor, this.taskTextColor = this.taskTextLightColor, this.taskTextOutsideColor = this.taskTextDarkColor, this.transitionColor = this.transitionColor || this.lineColor, this.transitionLabelColor = this.transitionLabelColor || this.textColor, this.stateLabelColor = this.stateLabelColor || this.stateBkg || this.primaryTextColor, this.stateBkg = this.stateBkg || this.mainBkg, this.labelBackgroundColor = this.labelBackgroundColor || this.stateBkg, this.compositeBackground = this.compositeBackground || this.background || this.tertiaryColor, this.altBackground = this.altBackground || "#f0f0f0", this.compositeTitleBackground = this.compositeTitleBackground || this.mainBkg, this.compositeBorder = this.compositeBorder || this.nodeBorder, this.innerEndBackground = this.nodeBorder, this.specialStateColor = this.lineColor, this.errorBkgColor = this.errorBkgColor || this.tertiaryColor, this.errorTextColor = this.errorTextColor || this.tertiaryTextColor, this.transitionColor = this.transitionColor || this.lineColor, this.classText = this.primaryTextColor, this.fillType0 = this.primaryColor, this.fillType1 = this.secondaryColor, this.fillType2 = ve(this.primaryColor, { h: 64 }), this.fillType3 = ve(this.secondaryColor, { h: 64 }), this.fillType4 = ve(this.primaryColor, { h: -64 }), this.fillType5 = ve(this.secondaryColor, { h: -64 }), this.fillType6 = ve(this.primaryColor, { h: 128 }), this.fillType7 = ve(this.secondaryColor, { h: 128 }), this.pie1 = this.pie1 || this.primaryColor, this.pie2 = this.pie2 || this.secondaryColor, this.pie3 = this.pie3 || ve(this.tertiaryColor, { l: -40 }), this.pie4 = this.pie4 || ve(this.primaryColor, { l: -10 }), this.pie5 = this.pie5 || ve(this.secondaryColor, { l: -30 }), this.pie6 = this.pie6 || ve(this.tertiaryColor, { l: -20 }), this.pie7 = this.pie7 || ve(this.primaryColor, { h: 60, l: -20 }), this.pie8 = this.pie8 || ve(this.primaryColor, { h: -60, l: -40 }), this.pie9 = this.pie9 || ve(this.primaryColor, { h: 120, l: -40 }), this.pie10 = this.pie10 || ve(this.primaryColor, { h: 60, l: -40 }), this.pie11 = this.pie11 || ve(this.primaryColor, { h: -90, l: -40 }), this.pie12 = this.pie12 || ve(this.primaryColor, { h: 120, l: -30 }), this.pieTitleTextSize = this.pieTitleTextSize || "25px", this.pieTitleTextColor = this.pieTitleTextColor || this.taskTextDarkColor, this.pieSectionTextSize = this.pieSectionTextSize || "17px", this.pieSectionTextColor = this.pieSectionTextColor || this.textColor, this.pieLegendTextSize = this.pieLegendTextSize || "17px", this.pieLegendTextColor = this.pieLegendTextColor || this.taskTextDarkColor, this.pieStrokeColor = this.pieStrokeColor || "black", this.pieStrokeWidth = this.pieStrokeWidth || "2px", this.pieOuterStrokeWidth = this.pieOuterStrokeWidth || "2px", this.pieOuterStrokeColor = this.pieOuterStrokeColor || "black", this.pieOpacity = this.pieOpacity || "0.7", this.quadrant1Fill = this.quadrant1Fill || this.primaryColor, this.quadrant2Fill = this.quadrant2Fill || ve(this.primaryColor, { r: 5, g: 5, b: 5 }), this.quadrant3Fill = this.quadrant3Fill || ve(this.primaryColor, { r: 10, g: 10, b: 10 }), this.quadrant4Fill = this.quadrant4Fill || ve(this.primaryColor, { r: 15, g: 15, b: 15 }), this.quadrant1TextFill = this.quadrant1TextFill || this.primaryTextColor, this.quadrant2TextFill = this.quadrant2TextFill || ve(this.primaryTextColor, { r: -5, g: -5, b: -5 }), this.quadrant3TextFill = this.quadrant3TextFill || ve(this.primaryTextColor, { r: -10, g: -10, b: -10 }), this.quadrant4TextFill = this.quadrant4TextFill || ve(this.primaryTextColor, { r: -15, g: -15, b: -15 }), this.quadrantPointFill = this.quadrantPointFill || dm(this.quadrant1Fill) ? xt(this.quadrant1Fill) : $t(this.quadrant1Fill), this.quadrantPointTextFill = this.quadrantPointTextFill || this.primaryTextColor, this.quadrantXAxisTextFill = this.quadrantXAxisTextFill || this.primaryTextColor, this.quadrantYAxisTextFill = this.quadrantYAxisTextFill || this.primaryTextColor, this.quadrantInternalBorderStrokeFill = this.quadrantInternalBorderStrokeFill || this.primaryBorderColor, this.quadrantExternalBorderStrokeFill = this.quadrantExternalBorderStrokeFill || this.primaryBorderColor, this.quadrantTitleFill = this.quadrantTitleFill || this.primaryTextColor, this.xyChart = {
      backgroundColor: ((t = this.xyChart) == null ? void 0 : t.backgroundColor) || this.background,
      titleColor: ((n = this.xyChart) == null ? void 0 : n.titleColor) || this.primaryTextColor,
      xAxisTitleColor: ((r = this.xyChart) == null ? void 0 : r.xAxisTitleColor) || this.primaryTextColor,
      xAxisLabelColor: ((i = this.xyChart) == null ? void 0 : i.xAxisLabelColor) || this.primaryTextColor,
      xAxisTickColor: ((a = this.xyChart) == null ? void 0 : a.xAxisTickColor) || this.primaryTextColor,
      xAxisLineColor: ((o = this.xyChart) == null ? void 0 : o.xAxisLineColor) || this.primaryTextColor,
      yAxisTitleColor: ((s = this.xyChart) == null ? void 0 : s.yAxisTitleColor) || this.primaryTextColor,
      yAxisLabelColor: ((l = this.xyChart) == null ? void 0 : l.yAxisLabelColor) || this.primaryTextColor,
      yAxisTickColor: ((u = this.xyChart) == null ? void 0 : u.yAxisTickColor) || this.primaryTextColor,
      yAxisLineColor: ((c = this.xyChart) == null ? void 0 : c.yAxisLineColor) || this.primaryTextColor,
      plotColorPalette: ((d = this.xyChart) == null ? void 0 : d.plotColorPalette) || "#ECECFF,#8493A6,#FFC3A0,#DCDDE1,#B8E994,#D1A36F,#C3CDE6,#FFB6C1,#496078,#F8F3E3"
    }, this.requirementBackground = this.requirementBackground || this.primaryColor, this.requirementBorderColor = this.requirementBorderColor || this.primaryBorderColor, this.requirementBorderSize = this.requirementBorderSize || "1", this.requirementTextColor = this.requirementTextColor || this.primaryTextColor, this.relationColor = this.relationColor || this.lineColor, this.relationLabelBackground = this.relationLabelBackground || this.labelBackground, this.relationLabelColor = this.relationLabelColor || this.actorTextColor, this.git0 = this.git0 || this.primaryColor, this.git1 = this.git1 || this.secondaryColor, this.git2 = this.git2 || this.tertiaryColor, this.git3 = this.git3 || ve(this.primaryColor, { h: -30 }), this.git4 = this.git4 || ve(this.primaryColor, { h: -60 }), this.git5 = this.git5 || ve(this.primaryColor, { h: -90 }), this.git6 = this.git6 || ve(this.primaryColor, { h: 60 }), this.git7 = this.git7 || ve(this.primaryColor, { h: 120 }), this.darkMode ? (this.git0 = xt(this.git0, 25), this.git1 = xt(this.git1, 25), this.git2 = xt(this.git2, 25), this.git3 = xt(this.git3, 25), this.git4 = xt(this.git4, 25), this.git5 = xt(this.git5, 25), this.git6 = xt(this.git6, 25), this.git7 = xt(this.git7, 25)) : (this.git0 = $t(this.git0, 25), this.git1 = $t(this.git1, 25), this.git2 = $t(this.git2, 25), this.git3 = $t(this.git3, 25), this.git4 = $t(this.git4, 25), this.git5 = $t(this.git5, 25), this.git6 = $t(this.git6, 25), this.git7 = $t(this.git7, 25)), this.gitInv0 = this.gitInv0 || $t(at(this.git0), 25), this.gitInv1 = this.gitInv1 || at(this.git1), this.gitInv2 = this.gitInv2 || at(this.git2), this.gitInv3 = this.gitInv3 || at(this.git3), this.gitInv4 = this.gitInv4 || at(this.git4), this.gitInv5 = this.gitInv5 || at(this.git5), this.gitInv6 = this.gitInv6 || at(this.git6), this.gitInv7 = this.gitInv7 || at(this.git7), this.gitBranchLabel0 = this.gitBranchLabel0 || at(this.labelTextColor), this.gitBranchLabel1 = this.gitBranchLabel1 || this.labelTextColor, this.gitBranchLabel2 = this.gitBranchLabel2 || this.labelTextColor, this.gitBranchLabel3 = this.gitBranchLabel3 || at(this.labelTextColor), this.gitBranchLabel4 = this.gitBranchLabel4 || this.labelTextColor, this.gitBranchLabel5 = this.gitBranchLabel5 || this.labelTextColor, this.gitBranchLabel6 = this.gitBranchLabel6 || this.labelTextColor, this.gitBranchLabel7 = this.gitBranchLabel7 || this.labelTextColor, this.tagLabelColor = this.tagLabelColor || this.primaryTextColor, this.tagLabelBackground = this.tagLabelBackground || this.primaryColor, this.tagLabelBorder = this.tagBorder || this.primaryBorderColor, this.tagLabelFontSize = this.tagLabelFontSize || "10px", this.commitLabelColor = this.commitLabelColor || this.secondaryTextColor, this.commitLabelBackground = this.commitLabelBackground || this.secondaryColor, this.commitLabelFontSize = this.commitLabelFontSize || "10px", this.attributeBackgroundColorOdd = this.attributeBackgroundColorOdd || nv, this.attributeBackgroundColorEven = this.attributeBackgroundColorEven || rv;
  }
  calculate(t) {
    if (typeof t != "object") {
      this.updateColors();
      return;
    }
    const n = Object.keys(t);
    n.forEach((r) => {
      this[r] = t[r];
    }), this.updateColors(), n.forEach((r) => {
      this[r] = t[r];
    });
  }
};
const Ule = (e) => {
  const t = new $le();
  return t.calculate(e), t;
};
let qle = class {
  constructor() {
    this.background = "#f4f4f4", this.primaryColor = "#cde498", this.secondaryColor = "#cdffb2", this.background = "white", this.mainBkg = "#cde498", this.secondBkg = "#cdffb2", this.lineColor = "green", this.border1 = "#13540c", this.border2 = "#6eaa49", this.arrowheadColor = "green", this.fontFamily = '"trebuchet ms", verdana, arial, sans-serif', this.fontSize = "16px", this.tertiaryColor = xt("#cde498", 10), this.primaryBorderColor = Vi(this.primaryColor, this.darkMode), this.secondaryBorderColor = Vi(this.secondaryColor, this.darkMode), this.tertiaryBorderColor = Vi(this.tertiaryColor, this.darkMode), this.primaryTextColor = at(this.primaryColor), this.secondaryTextColor = at(this.secondaryColor), this.tertiaryTextColor = at(this.primaryColor), this.lineColor = at(this.background), this.textColor = at(this.background), this.THEME_COLOR_LIMIT = 12, this.nodeBkg = "calculated", this.nodeBorder = "calculated", this.clusterBkg = "calculated", this.clusterBorder = "calculated", this.defaultLinkColor = "calculated", this.titleColor = "#333", this.edgeLabelBackground = "#e8e8e8", this.actorBorder = "calculated", this.actorBkg = "calculated", this.actorTextColor = "black", this.actorLineColor = "grey", this.signalColor = "#333", this.signalTextColor = "#333", this.labelBoxBkgColor = "calculated", this.labelBoxBorderColor = "#326932", this.labelTextColor = "calculated", this.loopTextColor = "calculated", this.noteBorderColor = "calculated", this.noteBkgColor = "#fff5ad", this.noteTextColor = "calculated", this.activationBorderColor = "#666", this.activationBkgColor = "#f4f4f4", this.sequenceNumberColor = "white", this.sectionBkgColor = "#6eaa49", this.altSectionBkgColor = "white", this.sectionBkgColor2 = "#6eaa49", this.excludeBkgColor = "#eeeeee", this.taskBorderColor = "calculated", this.taskBkgColor = "#487e3a", this.taskTextLightColor = "white", this.taskTextColor = "calculated", this.taskTextDarkColor = "black", this.taskTextOutsideColor = "calculated", this.taskTextClickableColor = "#003163", this.activeTaskBorderColor = "calculated", this.activeTaskBkgColor = "calculated", this.gridColor = "lightgrey", this.doneTaskBkgColor = "lightgrey", this.doneTaskBorderColor = "grey", this.critBorderColor = "#ff8888", this.critBkgColor = "red", this.todayLineColor = "red", this.personBorder = this.primaryBorderColor, this.personBkg = this.mainBkg, this.labelColor = "black", this.errorBkgColor = "#552222", this.errorTextColor = "#552222";
  }
  updateColors() {
    var t, n, r, i, a, o, s, l, u, c, d;
    this.actorBorder = $t(this.mainBkg, 20), this.actorBkg = this.mainBkg, this.labelBoxBkgColor = this.actorBkg, this.labelTextColor = this.actorTextColor, this.loopTextColor = this.actorTextColor, this.noteBorderColor = this.border2, this.noteTextColor = this.actorTextColor, this.cScale0 = this.cScale0 || this.primaryColor, this.cScale1 = this.cScale1 || this.secondaryColor, this.cScale2 = this.cScale2 || this.tertiaryColor, this.cScale3 = this.cScale3 || ve(this.primaryColor, { h: 30 }), this.cScale4 = this.cScale4 || ve(this.primaryColor, { h: 60 }), this.cScale5 = this.cScale5 || ve(this.primaryColor, { h: 90 }), this.cScale6 = this.cScale6 || ve(this.primaryColor, { h: 120 }), this.cScale7 = this.cScale7 || ve(this.primaryColor, { h: 150 }), this.cScale8 = this.cScale8 || ve(this.primaryColor, { h: 210 }), this.cScale9 = this.cScale9 || ve(this.primaryColor, { h: 270 }), this.cScale10 = this.cScale10 || ve(this.primaryColor, { h: 300 }), this.cScale11 = this.cScale11 || ve(this.primaryColor, { h: 330 }), this.cScalePeer1 = this.cScalePeer1 || $t(this.secondaryColor, 45), this.cScalePeer2 = this.cScalePeer2 || $t(this.tertiaryColor, 40);
    for (let f = 0; f < this.THEME_COLOR_LIMIT; f++)
      this["cScale" + f] = $t(this["cScale" + f], 10), this["cScalePeer" + f] = this["cScalePeer" + f] || $t(this["cScale" + f], 25);
    for (let f = 0; f < this.THEME_COLOR_LIMIT; f++)
      this["cScaleInv" + f] = this["cScaleInv" + f] || ve(this["cScale" + f], { h: 180 });
    this.scaleLabelColor = this.scaleLabelColor !== "calculated" && this.scaleLabelColor ? this.scaleLabelColor : this.labelTextColor;
    for (let f = 0; f < this.THEME_COLOR_LIMIT; f++)
      this["cScaleLabel" + f] = this["cScaleLabel" + f] || this.scaleLabelColor;
    for (let f = 0; f < 5; f++)
      this["surface" + f] = this["surface" + f] || ve(this.mainBkg, { h: 30, s: -30, l: -(5 + f * 5) }), this["surfacePeer" + f] = this["surfacePeer" + f] || ve(this.mainBkg, { h: 30, s: -30, l: -(8 + f * 5) });
    this.nodeBkg = this.mainBkg, this.nodeBorder = this.border1, this.clusterBkg = this.secondBkg, this.clusterBorder = this.border2, this.defaultLinkColor = this.lineColor, this.taskBorderColor = this.border1, this.taskTextColor = this.taskTextLightColor, this.taskTextOutsideColor = this.taskTextDarkColor, this.activeTaskBorderColor = this.taskBorderColor, this.activeTaskBkgColor = this.mainBkg, this.transitionColor = this.transitionColor || this.lineColor, this.transitionLabelColor = this.transitionLabelColor || this.textColor, this.stateLabelColor = this.stateLabelColor || this.stateBkg || this.primaryTextColor, this.stateBkg = this.stateBkg || this.mainBkg, this.labelBackgroundColor = this.labelBackgroundColor || this.stateBkg, this.compositeBackground = this.compositeBackground || this.background || this.tertiaryColor, this.altBackground = this.altBackground || "#f0f0f0", this.compositeTitleBackground = this.compositeTitleBackground || this.mainBkg, this.compositeBorder = this.compositeBorder || this.nodeBorder, this.innerEndBackground = this.primaryBorderColor, this.specialStateColor = this.lineColor, this.errorBkgColor = this.errorBkgColor || this.tertiaryColor, this.errorTextColor = this.errorTextColor || this.tertiaryTextColor, this.transitionColor = this.transitionColor || this.lineColor, this.classText = this.primaryTextColor, this.fillType0 = this.primaryColor, this.fillType1 = this.secondaryColor, this.fillType2 = ve(this.primaryColor, { h: 64 }), this.fillType3 = ve(this.secondaryColor, { h: 64 }), this.fillType4 = ve(this.primaryColor, { h: -64 }), this.fillType5 = ve(this.secondaryColor, { h: -64 }), this.fillType6 = ve(this.primaryColor, { h: 128 }), this.fillType7 = ve(this.secondaryColor, { h: 128 }), this.pie1 = this.pie1 || this.primaryColor, this.pie2 = this.pie2 || this.secondaryColor, this.pie3 = this.pie3 || this.tertiaryColor, this.pie4 = this.pie4 || ve(this.primaryColor, { l: -30 }), this.pie5 = this.pie5 || ve(this.secondaryColor, { l: -30 }), this.pie6 = this.pie6 || ve(this.tertiaryColor, { h: 40, l: -40 }), this.pie7 = this.pie7 || ve(this.primaryColor, { h: 60, l: -10 }), this.pie8 = this.pie8 || ve(this.primaryColor, { h: -60, l: -10 }), this.pie9 = this.pie9 || ve(this.primaryColor, { h: 120, l: 0 }), this.pie10 = this.pie10 || ve(this.primaryColor, { h: 60, l: -50 }), this.pie11 = this.pie11 || ve(this.primaryColor, { h: -60, l: -50 }), this.pie12 = this.pie12 || ve(this.primaryColor, { h: 120, l: -50 }), this.pieTitleTextSize = this.pieTitleTextSize || "25px", this.pieTitleTextColor = this.pieTitleTextColor || this.taskTextDarkColor, this.pieSectionTextSize = this.pieSectionTextSize || "17px", this.pieSectionTextColor = this.pieSectionTextColor || this.textColor, this.pieLegendTextSize = this.pieLegendTextSize || "17px", this.pieLegendTextColor = this.pieLegendTextColor || this.taskTextDarkColor, this.pieStrokeColor = this.pieStrokeColor || "black", this.pieStrokeWidth = this.pieStrokeWidth || "2px", this.pieOuterStrokeWidth = this.pieOuterStrokeWidth || "2px", this.pieOuterStrokeColor = this.pieOuterStrokeColor || "black", this.pieOpacity = this.pieOpacity || "0.7", this.quadrant1Fill = this.quadrant1Fill || this.primaryColor, this.quadrant2Fill = this.quadrant2Fill || ve(this.primaryColor, { r: 5, g: 5, b: 5 }), this.quadrant3Fill = this.quadrant3Fill || ve(this.primaryColor, { r: 10, g: 10, b: 10 }), this.quadrant4Fill = this.quadrant4Fill || ve(this.primaryColor, { r: 15, g: 15, b: 15 }), this.quadrant1TextFill = this.quadrant1TextFill || this.primaryTextColor, this.quadrant2TextFill = this.quadrant2TextFill || ve(this.primaryTextColor, { r: -5, g: -5, b: -5 }), this.quadrant3TextFill = this.quadrant3TextFill || ve(this.primaryTextColor, { r: -10, g: -10, b: -10 }), this.quadrant4TextFill = this.quadrant4TextFill || ve(this.primaryTextColor, { r: -15, g: -15, b: -15 }), this.quadrantPointFill = this.quadrantPointFill || dm(this.quadrant1Fill) ? xt(this.quadrant1Fill) : $t(this.quadrant1Fill), this.quadrantPointTextFill = this.quadrantPointTextFill || this.primaryTextColor, this.quadrantXAxisTextFill = this.quadrantXAxisTextFill || this.primaryTextColor, this.quadrantYAxisTextFill = this.quadrantYAxisTextFill || this.primaryTextColor, this.quadrantInternalBorderStrokeFill = this.quadrantInternalBorderStrokeFill || this.primaryBorderColor, this.quadrantExternalBorderStrokeFill = this.quadrantExternalBorderStrokeFill || this.primaryBorderColor, this.quadrantTitleFill = this.quadrantTitleFill || this.primaryTextColor, this.xyChart = {
      backgroundColor: ((t = this.xyChart) == null ? void 0 : t.backgroundColor) || this.background,
      titleColor: ((n = this.xyChart) == null ? void 0 : n.titleColor) || this.primaryTextColor,
      xAxisTitleColor: ((r = this.xyChart) == null ? void 0 : r.xAxisTitleColor) || this.primaryTextColor,
      xAxisLabelColor: ((i = this.xyChart) == null ? void 0 : i.xAxisLabelColor) || this.primaryTextColor,
      xAxisTickColor: ((a = this.xyChart) == null ? void 0 : a.xAxisTickColor) || this.primaryTextColor,
      xAxisLineColor: ((o = this.xyChart) == null ? void 0 : o.xAxisLineColor) || this.primaryTextColor,
      yAxisTitleColor: ((s = this.xyChart) == null ? void 0 : s.yAxisTitleColor) || this.primaryTextColor,
      yAxisLabelColor: ((l = this.xyChart) == null ? void 0 : l.yAxisLabelColor) || this.primaryTextColor,
      yAxisTickColor: ((u = this.xyChart) == null ? void 0 : u.yAxisTickColor) || this.primaryTextColor,
      yAxisLineColor: ((c = this.xyChart) == null ? void 0 : c.yAxisLineColor) || this.primaryTextColor,
      plotColorPalette: ((d = this.xyChart) == null ? void 0 : d.plotColorPalette) || "#CDE498,#FF6B6B,#A0D2DB,#D7BDE2,#F0F0F0,#FFC3A0,#7FD8BE,#FF9A8B,#FAF3E0,#FFF176"
    }, this.requirementBackground = this.requirementBackground || this.primaryColor, this.requirementBorderColor = this.requirementBorderColor || this.primaryBorderColor, this.requirementBorderSize = this.requirementBorderSize || "1", this.requirementTextColor = this.requirementTextColor || this.primaryTextColor, this.relationColor = this.relationColor || this.lineColor, this.relationLabelBackground = this.relationLabelBackground || this.edgeLabelBackground, this.relationLabelColor = this.relationLabelColor || this.actorTextColor, this.git0 = this.git0 || this.primaryColor, this.git1 = this.git1 || this.secondaryColor, this.git2 = this.git2 || this.tertiaryColor, this.git3 = this.git3 || ve(this.primaryColor, { h: -30 }), this.git4 = this.git4 || ve(this.primaryColor, { h: -60 }), this.git5 = this.git5 || ve(this.primaryColor, { h: -90 }), this.git6 = this.git6 || ve(this.primaryColor, { h: 60 }), this.git7 = this.git7 || ve(this.primaryColor, { h: 120 }), this.darkMode ? (this.git0 = xt(this.git0, 25), this.git1 = xt(this.git1, 25), this.git2 = xt(this.git2, 25), this.git3 = xt(this.git3, 25), this.git4 = xt(this.git4, 25), this.git5 = xt(this.git5, 25), this.git6 = xt(this.git6, 25), this.git7 = xt(this.git7, 25)) : (this.git0 = $t(this.git0, 25), this.git1 = $t(this.git1, 25), this.git2 = $t(this.git2, 25), this.git3 = $t(this.git3, 25), this.git4 = $t(this.git4, 25), this.git5 = $t(this.git5, 25), this.git6 = $t(this.git6, 25), this.git7 = $t(this.git7, 25)), this.gitInv0 = this.gitInv0 || at(this.git0), this.gitInv1 = this.gitInv1 || at(this.git1), this.gitInv2 = this.gitInv2 || at(this.git2), this.gitInv3 = this.gitInv3 || at(this.git3), this.gitInv4 = this.gitInv4 || at(this.git4), this.gitInv5 = this.gitInv5 || at(this.git5), this.gitInv6 = this.gitInv6 || at(this.git6), this.gitInv7 = this.gitInv7 || at(this.git7), this.gitBranchLabel0 = this.gitBranchLabel0 || at(this.labelTextColor), this.gitBranchLabel1 = this.gitBranchLabel1 || this.labelTextColor, this.gitBranchLabel2 = this.gitBranchLabel2 || this.labelTextColor, this.gitBranchLabel3 = this.gitBranchLabel3 || at(this.labelTextColor), this.gitBranchLabel4 = this.gitBranchLabel4 || this.labelTextColor, this.gitBranchLabel5 = this.gitBranchLabel5 || this.labelTextColor, this.gitBranchLabel6 = this.gitBranchLabel6 || this.labelTextColor, this.gitBranchLabel7 = this.gitBranchLabel7 || this.labelTextColor, this.tagLabelColor = this.tagLabelColor || this.primaryTextColor, this.tagLabelBackground = this.tagLabelBackground || this.primaryColor, this.tagLabelBorder = this.tagBorder || this.primaryBorderColor, this.tagLabelFontSize = this.tagLabelFontSize || "10px", this.commitLabelColor = this.commitLabelColor || this.secondaryTextColor, this.commitLabelBackground = this.commitLabelBackground || this.secondaryColor, this.commitLabelFontSize = this.commitLabelFontSize || "10px", this.attributeBackgroundColorOdd = this.attributeBackgroundColorOdd || nv, this.attributeBackgroundColorEven = this.attributeBackgroundColorEven || rv;
  }
  calculate(t) {
    if (typeof t != "object") {
      this.updateColors();
      return;
    }
    const n = Object.keys(t);
    n.forEach((r) => {
      this[r] = t[r];
    }), this.updateColors(), n.forEach((r) => {
      this[r] = t[r];
    });
  }
};
const Gle = (e) => {
  const t = new qle();
  return t.calculate(e), t;
};
class Yle {
  constructor() {
    this.primaryColor = "#eee", this.contrast = "#707070", this.secondaryColor = xt(this.contrast, 55), this.background = "#ffffff", this.tertiaryColor = ve(this.primaryColor, { h: -160 }), this.primaryBorderColor = Vi(this.primaryColor, this.darkMode), this.secondaryBorderColor = Vi(this.secondaryColor, this.darkMode), this.tertiaryBorderColor = Vi(this.tertiaryColor, this.darkMode), this.primaryTextColor = at(this.primaryColor), this.secondaryTextColor = at(this.secondaryColor), this.tertiaryTextColor = at(this.tertiaryColor), this.lineColor = at(this.background), this.textColor = at(this.background), this.mainBkg = "#eee", this.secondBkg = "calculated", this.lineColor = "#666", this.border1 = "#999", this.border2 = "calculated", this.note = "#ffa", this.text = "#333", this.critical = "#d42", this.done = "#bbb", this.arrowheadColor = "#333333", this.fontFamily = '"trebuchet ms", verdana, arial, sans-serif', this.fontSize = "16px", this.THEME_COLOR_LIMIT = 12, this.nodeBkg = "calculated", this.nodeBorder = "calculated", this.clusterBkg = "calculated", this.clusterBorder = "calculated", this.defaultLinkColor = "calculated", this.titleColor = "calculated", this.edgeLabelBackground = "white", this.actorBorder = "calculated", this.actorBkg = "calculated", this.actorTextColor = "calculated", this.actorLineColor = "calculated", this.signalColor = "calculated", this.signalTextColor = "calculated", this.labelBoxBkgColor = "calculated", this.labelBoxBorderColor = "calculated", this.labelTextColor = "calculated", this.loopTextColor = "calculated", this.noteBorderColor = "calculated", this.noteBkgColor = "calculated", this.noteTextColor = "calculated", this.activationBorderColor = "#666", this.activationBkgColor = "#f4f4f4", this.sequenceNumberColor = "white", this.sectionBkgColor = "calculated", this.altSectionBkgColor = "white", this.sectionBkgColor2 = "calculated", this.excludeBkgColor = "#eeeeee", this.taskBorderColor = "calculated", this.taskBkgColor = "calculated", this.taskTextLightColor = "white", this.taskTextColor = "calculated", this.taskTextDarkColor = "calculated", this.taskTextOutsideColor = "calculated", this.taskTextClickableColor = "#003163", this.activeTaskBorderColor = "calculated", this.activeTaskBkgColor = "calculated", this.gridColor = "calculated", this.doneTaskBkgColor = "calculated", this.doneTaskBorderColor = "calculated", this.critBkgColor = "calculated", this.critBorderColor = "calculated", this.todayLineColor = "calculated", this.personBorder = this.primaryBorderColor, this.personBkg = this.mainBkg, this.labelColor = "black", this.errorBkgColor = "#552222", this.errorTextColor = "#552222";
  }
  updateColors() {
    var t, n, r, i, a, o, s, l, u, c, d;
    this.secondBkg = xt(this.contrast, 55), this.border2 = this.contrast, this.actorBorder = xt(this.border1, 23), this.actorBkg = this.mainBkg, this.actorTextColor = this.text, this.actorLineColor = this.lineColor, this.signalColor = this.text, this.signalTextColor = this.text, this.labelBoxBkgColor = this.actorBkg, this.labelBoxBorderColor = this.actorBorder, this.labelTextColor = this.text, this.loopTextColor = this.text, this.noteBorderColor = "#999", this.noteBkgColor = "#666", this.noteTextColor = "#fff", this.cScale0 = this.cScale0 || "#555", this.cScale1 = this.cScale1 || "#F4F4F4", this.cScale2 = this.cScale2 || "#555", this.cScale3 = this.cScale3 || "#BBB", this.cScale4 = this.cScale4 || "#777", this.cScale5 = this.cScale5 || "#999", this.cScale6 = this.cScale6 || "#DDD", this.cScale7 = this.cScale7 || "#FFF", this.cScale8 = this.cScale8 || "#DDD", this.cScale9 = this.cScale9 || "#BBB", this.cScale10 = this.cScale10 || "#999", this.cScale11 = this.cScale11 || "#777";
    for (let f = 0; f < this.THEME_COLOR_LIMIT; f++)
      this["cScaleInv" + f] = this["cScaleInv" + f] || at(this["cScale" + f]);
    for (let f = 0; f < this.THEME_COLOR_LIMIT; f++)
      this.darkMode ? this["cScalePeer" + f] = this["cScalePeer" + f] || xt(this["cScale" + f], 10) : this["cScalePeer" + f] = this["cScalePeer" + f] || $t(this["cScale" + f], 10);
    this.scaleLabelColor = this.scaleLabelColor || (this.darkMode ? "black" : this.labelTextColor), this.cScaleLabel0 = this.cScaleLabel0 || this.cScale1, this.cScaleLabel2 = this.cScaleLabel2 || this.cScale1;
    for (let f = 0; f < this.THEME_COLOR_LIMIT; f++)
      this["cScaleLabel" + f] = this["cScaleLabel" + f] || this.scaleLabelColor;
    for (let f = 0; f < 5; f++)
      this["surface" + f] = this["surface" + f] || ve(this.mainBkg, { l: -(5 + f * 5) }), this["surfacePeer" + f] = this["surfacePeer" + f] || ve(this.mainBkg, { l: -(8 + f * 5) });
    this.nodeBkg = this.mainBkg, this.nodeBorder = this.border1, this.clusterBkg = this.secondBkg, this.clusterBorder = this.border2, this.defaultLinkColor = this.lineColor, this.titleColor = this.text, this.sectionBkgColor = xt(this.contrast, 30), this.sectionBkgColor2 = xt(this.contrast, 30), this.taskBorderColor = $t(this.contrast, 10), this.taskBkgColor = this.contrast, this.taskTextColor = this.taskTextLightColor, this.taskTextDarkColor = this.text, this.taskTextOutsideColor = this.taskTextDarkColor, this.activeTaskBorderColor = this.taskBorderColor, this.activeTaskBkgColor = this.mainBkg, this.gridColor = xt(this.border1, 30), this.doneTaskBkgColor = this.done, this.doneTaskBorderColor = this.lineColor, this.critBkgColor = this.critical, this.critBorderColor = $t(this.critBkgColor, 10), this.todayLineColor = this.critBkgColor, this.transitionColor = this.transitionColor || "#000", this.transitionLabelColor = this.transitionLabelColor || this.textColor, this.stateLabelColor = this.stateLabelColor || this.stateBkg || this.primaryTextColor, this.stateBkg = this.stateBkg || this.mainBkg, this.labelBackgroundColor = this.labelBackgroundColor || this.stateBkg, this.compositeBackground = this.compositeBackground || this.background || this.tertiaryColor, this.altBackground = this.altBackground || "#f4f4f4", this.compositeTitleBackground = this.compositeTitleBackground || this.mainBkg, this.stateBorder = this.stateBorder || "#000", this.innerEndBackground = this.primaryBorderColor, this.specialStateColor = "#222", this.errorBkgColor = this.errorBkgColor || this.tertiaryColor, this.errorTextColor = this.errorTextColor || this.tertiaryTextColor, this.classText = this.primaryTextColor, this.fillType0 = this.primaryColor, this.fillType1 = this.secondaryColor, this.fillType2 = ve(this.primaryColor, { h: 64 }), this.fillType3 = ve(this.secondaryColor, { h: 64 }), this.fillType4 = ve(this.primaryColor, { h: -64 }), this.fillType5 = ve(this.secondaryColor, { h: -64 }), this.fillType6 = ve(this.primaryColor, { h: 128 }), this.fillType7 = ve(this.secondaryColor, { h: 128 });
    for (let f = 0; f < this.THEME_COLOR_LIMIT; f++)
      this["pie" + f] = this["cScale" + f];
    this.pie12 = this.pie0, this.pieTitleTextSize = this.pieTitleTextSize || "25px", this.pieTitleTextColor = this.pieTitleTextColor || this.taskTextDarkColor, this.pieSectionTextSize = this.pieSectionTextSize || "17px", this.pieSectionTextColor = this.pieSectionTextColor || this.textColor, this.pieLegendTextSize = this.pieLegendTextSize || "17px", this.pieLegendTextColor = this.pieLegendTextColor || this.taskTextDarkColor, this.pieStrokeColor = this.pieStrokeColor || "black", this.pieStrokeWidth = this.pieStrokeWidth || "2px", this.pieOuterStrokeWidth = this.pieOuterStrokeWidth || "2px", this.pieOuterStrokeColor = this.pieOuterStrokeColor || "black", this.pieOpacity = this.pieOpacity || "0.7", this.quadrant1Fill = this.quadrant1Fill || this.primaryColor, this.quadrant2Fill = this.quadrant2Fill || ve(this.primaryColor, { r: 5, g: 5, b: 5 }), this.quadrant3Fill = this.quadrant3Fill || ve(this.primaryColor, { r: 10, g: 10, b: 10 }), this.quadrant4Fill = this.quadrant4Fill || ve(this.primaryColor, { r: 15, g: 15, b: 15 }), this.quadrant1TextFill = this.quadrant1TextFill || this.primaryTextColor, this.quadrant2TextFill = this.quadrant2TextFill || ve(this.primaryTextColor, { r: -5, g: -5, b: -5 }), this.quadrant3TextFill = this.quadrant3TextFill || ve(this.primaryTextColor, { r: -10, g: -10, b: -10 }), this.quadrant4TextFill = this.quadrant4TextFill || ve(this.primaryTextColor, { r: -15, g: -15, b: -15 }), this.quadrantPointFill = this.quadrantPointFill || dm(this.quadrant1Fill) ? xt(this.quadrant1Fill) : $t(this.quadrant1Fill), this.quadrantPointTextFill = this.quadrantPointTextFill || this.primaryTextColor, this.quadrantXAxisTextFill = this.quadrantXAxisTextFill || this.primaryTextColor, this.quadrantYAxisTextFill = this.quadrantYAxisTextFill || this.primaryTextColor, this.quadrantInternalBorderStrokeFill = this.quadrantInternalBorderStrokeFill || this.primaryBorderColor, this.quadrantExternalBorderStrokeFill = this.quadrantExternalBorderStrokeFill || this.primaryBorderColor, this.quadrantTitleFill = this.quadrantTitleFill || this.primaryTextColor, this.xyChart = {
      backgroundColor: ((t = this.xyChart) == null ? void 0 : t.backgroundColor) || this.background,
      titleColor: ((n = this.xyChart) == null ? void 0 : n.titleColor) || this.primaryTextColor,
      xAxisTitleColor: ((r = this.xyChart) == null ? void 0 : r.xAxisTitleColor) || this.primaryTextColor,
      xAxisLabelColor: ((i = this.xyChart) == null ? void 0 : i.xAxisLabelColor) || this.primaryTextColor,
      xAxisTickColor: ((a = this.xyChart) == null ? void 0 : a.xAxisTickColor) || this.primaryTextColor,
      xAxisLineColor: ((o = this.xyChart) == null ? void 0 : o.xAxisLineColor) || this.primaryTextColor,
      yAxisTitleColor: ((s = this.xyChart) == null ? void 0 : s.yAxisTitleColor) || this.primaryTextColor,
      yAxisLabelColor: ((l = this.xyChart) == null ? void 0 : l.yAxisLabelColor) || this.primaryTextColor,
      yAxisTickColor: ((u = this.xyChart) == null ? void 0 : u.yAxisTickColor) || this.primaryTextColor,
      yAxisLineColor: ((c = this.xyChart) == null ? void 0 : c.yAxisLineColor) || this.primaryTextColor,
      plotColorPalette: ((d = this.xyChart) == null ? void 0 : d.plotColorPalette) || "#EEE,#6BB8E4,#8ACB88,#C7ACD6,#E8DCC2,#FFB2A8,#FFF380,#7E8D91,#FFD8B1,#FAF3E0"
    }, this.requirementBackground = this.requirementBackground || this.primaryColor, this.requirementBorderColor = this.requirementBorderColor || this.primaryBorderColor, this.requirementBorderSize = this.requirementBorderSize || "1", this.requirementTextColor = this.requirementTextColor || this.primaryTextColor, this.relationColor = this.relationColor || this.lineColor, this.relationLabelBackground = this.relationLabelBackground || this.edgeLabelBackground, this.relationLabelColor = this.relationLabelColor || this.actorTextColor, this.git0 = $t(this.pie1, 25) || this.primaryColor, this.git1 = this.pie2 || this.secondaryColor, this.git2 = this.pie3 || this.tertiaryColor, this.git3 = this.pie4 || ve(this.primaryColor, { h: -30 }), this.git4 = this.pie5 || ve(this.primaryColor, { h: -60 }), this.git5 = this.pie6 || ve(this.primaryColor, { h: -90 }), this.git6 = this.pie7 || ve(this.primaryColor, { h: 60 }), this.git7 = this.pie8 || ve(this.primaryColor, { h: 120 }), this.gitInv0 = this.gitInv0 || at(this.git0), this.gitInv1 = this.gitInv1 || at(this.git1), this.gitInv2 = this.gitInv2 || at(this.git2), this.gitInv3 = this.gitInv3 || at(this.git3), this.gitInv4 = this.gitInv4 || at(this.git4), this.gitInv5 = this.gitInv5 || at(this.git5), this.gitInv6 = this.gitInv6 || at(this.git6), this.gitInv7 = this.gitInv7 || at(this.git7), this.branchLabelColor = this.branchLabelColor || this.labelTextColor, this.gitBranchLabel0 = this.branchLabelColor, this.gitBranchLabel1 = "white", this.gitBranchLabel2 = this.branchLabelColor, this.gitBranchLabel3 = "white", this.gitBranchLabel4 = this.branchLabelColor, this.gitBranchLabel5 = this.branchLabelColor, this.gitBranchLabel6 = this.branchLabelColor, this.gitBranchLabel7 = this.branchLabelColor, this.tagLabelColor = this.tagLabelColor || this.primaryTextColor, this.tagLabelBackground = this.tagLabelBackground || this.primaryColor, this.tagLabelBorder = this.tagBorder || this.primaryBorderColor, this.tagLabelFontSize = this.tagLabelFontSize || "10px", this.commitLabelColor = this.commitLabelColor || this.secondaryTextColor, this.commitLabelBackground = this.commitLabelBackground || this.secondaryColor, this.commitLabelFontSize = this.commitLabelFontSize || "10px", this.attributeBackgroundColorOdd = this.attributeBackgroundColorOdd || nv, this.attributeBackgroundColorEven = this.attributeBackgroundColorEven || rv;
  }
  calculate(t) {
    if (typeof t != "object") {
      this.updateColors();
      return;
    }
    const n = Object.keys(t);
    n.forEach((r) => {
      this[r] = t[r];
    }), this.updateColors(), n.forEach((r) => {
      this[r] = t[r];
    });
  }
}
const Hle = (e) => {
  const t = new Yle();
  return t.calculate(e), t;
}, Ms = {
  base: {
    getThemeVariables: Ple
  },
  dark: {
    getThemeVariables: Ble
  },
  default: {
    getThemeVariables: Ule
  },
  forest: {
    getThemeVariables: Gle
  },
  neutral: {
    getThemeVariables: Hle
  }
}, Ts = {
  flowchart: {
    useMaxWidth: !0,
    titleTopMargin: 25,
    subGraphTitleMargin: {
      top: 0,
      bottom: 0
    },
    diagramPadding: 8,
    htmlLabels: !0,
    nodeSpacing: 50,
    rankSpacing: 50,
    curve: "basis",
    padding: 15,
    defaultRenderer: "dagre-wrapper",
    wrappingWidth: 200
  },
  sequence: {
    useMaxWidth: !0,
    hideUnusedParticipants: !1,
    activationWidth: 10,
    diagramMarginX: 50,
    diagramMarginY: 10,
    actorMargin: 50,
    width: 150,
    height: 65,
    boxMargin: 10,
    boxTextMargin: 5,
    noteMargin: 10,
    messageMargin: 35,
    messageAlign: "center",
    mirrorActors: !0,
    forceMenus: !1,
    bottomMarginAdj: 1,
    rightAngles: !1,
    showSequenceNumbers: !1,
    actorFontSize: 14,
    actorFontFamily: '"Open Sans", sans-serif',
    actorFontWeight: 400,
    noteFontSize: 14,
    noteFontFamily: '"trebuchet ms", verdana, arial, sans-serif',
    noteFontWeight: 400,
    noteAlign: "center",
    messageFontSize: 16,
    messageFontFamily: '"trebuchet ms", verdana, arial, sans-serif',
    messageFontWeight: 400,
    wrap: !1,
    wrapPadding: 10,
    labelBoxWidth: 50,
    labelBoxHeight: 20
  },
  gantt: {
    useMaxWidth: !0,
    titleTopMargin: 25,
    barHeight: 20,
    barGap: 4,
    topPadding: 50,
    rightPadding: 75,
    leftPadding: 75,
    gridLineStartPadding: 35,
    fontSize: 11,
    sectionFontSize: 11,
    numberSectionStyles: 4,
    axisFormat: "%Y-%m-%d",
    topAxis: !1,
    displayMode: "",
    weekday: "sunday"
  },
  journey: {
    useMaxWidth: !0,
    diagramMarginX: 50,
    diagramMarginY: 10,
    leftMargin: 150,
    width: 150,
    height: 50,
    boxMargin: 10,
    boxTextMargin: 5,
    noteMargin: 10,
    messageMargin: 35,
    messageAlign: "center",
    bottomMarginAdj: 1,
    rightAngles: !1,
    taskFontSize: 14,
    taskFontFamily: '"Open Sans", sans-serif',
    taskMargin: 50,
    activationWidth: 10,
    textPlacement: "fo",
    actorColours: [
      "#8FBC8F",
      "#7CFC00",
      "#00FFFF",
      "#20B2AA",
      "#B0E0E6",
      "#FFFFE0"
    ],
    sectionFills: [
      "#191970",
      "#8B008B",
      "#4B0082",
      "#2F4F4F",
      "#800000",
      "#8B4513",
      "#00008B"
    ],
    sectionColours: [
      "#fff"
    ]
  },
  class: {
    useMaxWidth: !0,
    titleTopMargin: 25,
    arrowMarkerAbsolute: !1,
    dividerMargin: 10,
    padding: 5,
    textHeight: 10,
    defaultRenderer: "dagre-wrapper",
    htmlLabels: !1
  },
  state: {
    useMaxWidth: !0,
    titleTopMargin: 25,
    dividerMargin: 10,
    sizeUnit: 5,
    padding: 8,
    textHeight: 10,
    titleShift: -15,
    noteMargin: 10,
    forkWidth: 70,
    forkHeight: 7,
    miniPadding: 2,
    fontSizeFactor: 5.02,
    fontSize: 24,
    labelHeight: 16,
    edgeLengthFactor: "20",
    compositTitleSize: 35,
    radius: 5,
    defaultRenderer: "dagre-wrapper"
  },
  er: {
    useMaxWidth: !0,
    titleTopMargin: 25,
    diagramPadding: 20,
    layoutDirection: "TB",
    minEntityWidth: 100,
    minEntityHeight: 75,
    entityPadding: 15,
    stroke: "gray",
    fill: "honeydew",
    fontSize: 12
  },
  pie: {
    useMaxWidth: !0,
    textPosition: 0.75
  },
  quadrantChart: {
    useMaxWidth: !0,
    chartWidth: 500,
    chartHeight: 500,
    titleFontSize: 20,
    titlePadding: 10,
    quadrantPadding: 5,
    xAxisLabelPadding: 5,
    yAxisLabelPadding: 5,
    xAxisLabelFontSize: 16,
    yAxisLabelFontSize: 16,
    quadrantLabelFontSize: 16,
    quadrantTextTopPadding: 5,
    pointTextPadding: 5,
    pointLabelFontSize: 12,
    pointRadius: 5,
    xAxisPosition: "top",
    yAxisPosition: "left",
    quadrantInternalBorderStrokeWidth: 1,
    quadrantExternalBorderStrokeWidth: 2
  },
  xyChart: {
    useMaxWidth: !0,
    width: 700,
    height: 500,
    titleFontSize: 20,
    titlePadding: 10,
    showTitle: !0,
    xAxis: {
      $ref: "#/$defs/XYChartAxisConfig",
      showLabel: !0,
      labelFontSize: 14,
      labelPadding: 5,
      showTitle: !0,
      titleFontSize: 16,
      titlePadding: 5,
      showTick: !0,
      tickLength: 5,
      tickWidth: 2,
      showAxisLine: !0,
      axisLineWidth: 2
    },
    yAxis: {
      $ref: "#/$defs/XYChartAxisConfig",
      showLabel: !0,
      labelFontSize: 14,
      labelPadding: 5,
      showTitle: !0,
      titleFontSize: 16,
      titlePadding: 5,
      showTick: !0,
      tickLength: 5,
      tickWidth: 2,
      showAxisLine: !0,
      axisLineWidth: 2
    },
    chartOrientation: "vertical",
    plotReservedSpacePercent: 50
  },
  requirement: {
    useMaxWidth: !0,
    rect_fill: "#f9f9f9",
    text_color: "#333",
    rect_border_size: "0.5px",
    rect_border_color: "#bbb",
    rect_min_width: 200,
    rect_min_height: 200,
    fontSize: 14,
    rect_padding: 10,
    line_height: 20
  },
  mindmap: {
    useMaxWidth: !0,
    padding: 10,
    maxNodeWidth: 200
  },
  timeline: {
    useMaxWidth: !0,
    diagramMarginX: 50,
    diagramMarginY: 10,
    leftMargin: 150,
    width: 150,
    height: 50,
    boxMargin: 10,
    boxTextMargin: 5,
    noteMargin: 10,
    messageMargin: 35,
    messageAlign: "center",
    bottomMarginAdj: 1,
    rightAngles: !1,
    taskFontSize: 14,
    taskFontFamily: '"Open Sans", sans-serif',
    taskMargin: 50,
    activationWidth: 10,
    textPlacement: "fo",
    actorColours: [
      "#8FBC8F",
      "#7CFC00",
      "#00FFFF",
      "#20B2AA",
      "#B0E0E6",
      "#FFFFE0"
    ],
    sectionFills: [
      "#191970",
      "#8B008B",
      "#4B0082",
      "#2F4F4F",
      "#800000",
      "#8B4513",
      "#00008B"
    ],
    sectionColours: [
      "#fff"
    ],
    disableMulticolor: !1
  },
  gitGraph: {
    useMaxWidth: !0,
    titleTopMargin: 25,
    diagramPadding: 8,
    nodeLabel: {
      width: 75,
      height: 100,
      x: -25,
      y: 0
    },
    mainBranchName: "main",
    mainBranchOrder: 0,
    showCommitLabel: !0,
    showBranches: !0,
    rotateCommitLabel: !0,
    parallelCommits: !1,
    arrowMarkerAbsolute: !1
  },
  c4: {
    useMaxWidth: !0,
    diagramMarginX: 50,
    diagramMarginY: 10,
    c4ShapeMargin: 50,
    c4ShapePadding: 20,
    width: 216,
    height: 60,
    boxMargin: 10,
    c4ShapeInRow: 4,
    nextLinePaddingX: 0,
    c4BoundaryInRow: 2,
    personFontSize: 14,
    personFontFamily: '"Open Sans", sans-serif',
    personFontWeight: "normal",
    external_personFontSize: 14,
    external_personFontFamily: '"Open Sans", sans-serif',
    external_personFontWeight: "normal",
    systemFontSize: 14,
    systemFontFamily: '"Open Sans", sans-serif',
    systemFontWeight: "normal",
    external_systemFontSize: 14,
    external_systemFontFamily: '"Open Sans", sans-serif',
    external_systemFontWeight: "normal",
    system_dbFontSize: 14,
    system_dbFontFamily: '"Open Sans", sans-serif',
    system_dbFontWeight: "normal",
    external_system_dbFontSize: 14,
    external_system_dbFontFamily: '"Open Sans", sans-serif',
    external_system_dbFontWeight: "normal",
    system_queueFontSize: 14,
    system_queueFontFamily: '"Open Sans", sans-serif',
    system_queueFontWeight: "normal",
    external_system_queueFontSize: 14,
    external_system_queueFontFamily: '"Open Sans", sans-serif',
    external_system_queueFontWeight: "normal",
    boundaryFontSize: 14,
    boundaryFontFamily: '"Open Sans", sans-serif',
    boundaryFontWeight: "normal",
    messageFontSize: 12,
    messageFontFamily: '"Open Sans", sans-serif',
    messageFontWeight: "normal",
    containerFontSize: 14,
    containerFontFamily: '"Open Sans", sans-serif',
    containerFontWeight: "normal",
    external_containerFontSize: 14,
    external_containerFontFamily: '"Open Sans", sans-serif',
    external_containerFontWeight: "normal",
    container_dbFontSize: 14,
    container_dbFontFamily: '"Open Sans", sans-serif',
    container_dbFontWeight: "normal",
    external_container_dbFontSize: 14,
    external_container_dbFontFamily: '"Open Sans", sans-serif',
    external_container_dbFontWeight: "normal",
    container_queueFontSize: 14,
    container_queueFontFamily: '"Open Sans", sans-serif',
    container_queueFontWeight: "normal",
    external_container_queueFontSize: 14,
    external_container_queueFontFamily: '"Open Sans", sans-serif',
    external_container_queueFontWeight: "normal",
    componentFontSize: 14,
    componentFontFamily: '"Open Sans", sans-serif',
    componentFontWeight: "normal",
    external_componentFontSize: 14,
    external_componentFontFamily: '"Open Sans", sans-serif',
    external_componentFontWeight: "normal",
    component_dbFontSize: 14,
    component_dbFontFamily: '"Open Sans", sans-serif',
    component_dbFontWeight: "normal",
    external_component_dbFontSize: 14,
    external_component_dbFontFamily: '"Open Sans", sans-serif',
    external_component_dbFontWeight: "normal",
    component_queueFontSize: 14,
    component_queueFontFamily: '"Open Sans", sans-serif',
    component_queueFontWeight: "normal",
    external_component_queueFontSize: 14,
    external_component_queueFontFamily: '"Open Sans", sans-serif',
    external_component_queueFontWeight: "normal",
    wrap: !0,
    wrapPadding: 10,
    person_bg_color: "#08427B",
    person_border_color: "#073B6F",
    external_person_bg_color: "#686868",
    external_person_border_color: "#8A8A8A",
    system_bg_color: "#1168BD",
    system_border_color: "#3C7FC0",
    system_db_bg_color: "#1168BD",
    system_db_border_color: "#3C7FC0",
    system_queue_bg_color: "#1168BD",
    system_queue_border_color: "#3C7FC0",
    external_system_bg_color: "#999999",
    external_system_border_color: "#8A8A8A",
    external_system_db_bg_color: "#999999",
    external_system_db_border_color: "#8A8A8A",
    external_system_queue_bg_color: "#999999",
    external_system_queue_border_color: "#8A8A8A",
    container_bg_color: "#438DD5",
    container_border_color: "#3C7FC0",
    container_db_bg_color: "#438DD5",
    container_db_border_color: "#3C7FC0",
    container_queue_bg_color: "#438DD5",
    container_queue_border_color: "#3C7FC0",
    external_container_bg_color: "#B3B3B3",
    external_container_border_color: "#A6A6A6",
    external_container_db_bg_color: "#B3B3B3",
    external_container_db_border_color: "#A6A6A6",
    external_container_queue_bg_color: "#B3B3B3",
    external_container_queue_border_color: "#A6A6A6",
    component_bg_color: "#85BBF0",
    component_border_color: "#78A8D8",
    component_db_bg_color: "#85BBF0",
    component_db_border_color: "#78A8D8",
    component_queue_bg_color: "#85BBF0",
    component_queue_border_color: "#78A8D8",
    external_component_bg_color: "#CCCCCC",
    external_component_border_color: "#BFBFBF",
    external_component_db_bg_color: "#CCCCCC",
    external_component_db_border_color: "#BFBFBF",
    external_component_queue_bg_color: "#CCCCCC",
    external_component_queue_border_color: "#BFBFBF"
  },
  sankey: {
    useMaxWidth: !0,
    width: 600,
    height: 400,
    linkColor: "gradient",
    nodeAlignment: "justify",
    showValues: !0,
    prefix: "",
    suffix: ""
  },
  block: {
    useMaxWidth: !0,
    padding: 8
  },
  theme: "default",
  maxTextSize: 5e4,
  maxEdges: 500,
  darkMode: !1,
  fontFamily: '"trebuchet ms", verdana, arial, sans-serif;',
  logLevel: 5,
  securityLevel: "strict",
  startOnLoad: !0,
  arrowMarkerAbsolute: !1,
  secure: [
    "secure",
    "securityLevel",
    "startOnLoad",
    "maxTextSize",
    "maxEdges"
  ],
  deterministicIds: !1,
  fontSize: 16
}, fB = {
  ...Ts,
  // Set, even though they're `undefined` so that `configKeys` finds these keys
  // TODO: Should we replace these with `null` so that they can go in the JSON Schema?
  deterministicIDSeed: void 0,
  themeCSS: void 0,
  // add non-JSON default config values
  themeVariables: Ms.default.getThemeVariables(),
  sequence: {
    ...Ts.sequence,
    messageFont: function() {
      return {
        fontFamily: this.messageFontFamily,
        fontSize: this.messageFontSize,
        fontWeight: this.messageFontWeight
      };
    },
    noteFont: function() {
      return {
        fontFamily: this.noteFontFamily,
        fontSize: this.noteFontSize,
        fontWeight: this.noteFontWeight
      };
    },
    actorFont: function() {
      return {
        fontFamily: this.actorFontFamily,
        fontSize: this.actorFontSize,
        fontWeight: this.actorFontWeight
      };
    }
  },
  gantt: {
    ...Ts.gantt,
    tickInterval: void 0,
    useWidth: void 0
    // can probably be removed since `configKeys` already includes this
  },
  c4: {
    ...Ts.c4,
    useWidth: void 0,
    personFont: function() {
      return {
        fontFamily: this.personFontFamily,
        fontSize: this.personFontSize,
        fontWeight: this.personFontWeight
      };
    },
    external_personFont: function() {
      return {
        fontFamily: this.external_personFontFamily,
        fontSize: this.external_personFontSize,
        fontWeight: this.external_personFontWeight
      };
    },
    systemFont: function() {
      return {
        fontFamily: this.systemFontFamily,
        fontSize: this.systemFontSize,
        fontWeight: this.systemFontWeight
      };
    },
    external_systemFont: function() {
      return {
        fontFamily: this.external_systemFontFamily,
        fontSize: this.external_systemFontSize,
        fontWeight: this.external_systemFontWeight
      };
    },
    system_dbFont: function() {
      return {
        fontFamily: this.system_dbFontFamily,
        fontSize: this.system_dbFontSize,
        fontWeight: this.system_dbFontWeight
      };
    },
    external_system_dbFont: function() {
      return {
        fontFamily: this.external_system_dbFontFamily,
        fontSize: this.external_system_dbFontSize,
        fontWeight: this.external_system_dbFontWeight
      };
    },
    system_queueFont: function() {
      return {
        fontFamily: this.system_queueFontFamily,
        fontSize: this.system_queueFontSize,
        fontWeight: this.system_queueFontWeight
      };
    },
    external_system_queueFont: function() {
      return {
        fontFamily: this.external_system_queueFontFamily,
        fontSize: this.external_system_queueFontSize,
        fontWeight: this.external_system_queueFontWeight
      };
    },
    containerFont: function() {
      return {
        fontFamily: this.containerFontFamily,
        fontSize: this.containerFontSize,
        fontWeight: this.containerFontWeight
      };
    },
    external_containerFont: function() {
      return {
        fontFamily: this.external_containerFontFamily,
        fontSize: this.external_containerFontSize,
        fontWeight: this.external_containerFontWeight
      };
    },
    container_dbFont: function() {
      return {
        fontFamily: this.container_dbFontFamily,
        fontSize: this.container_dbFontSize,
        fontWeight: this.container_dbFontWeight
      };
    },
    external_container_dbFont: function() {
      return {
        fontFamily: this.external_container_dbFontFamily,
        fontSize: this.external_container_dbFontSize,
        fontWeight: this.external_container_dbFontWeight
      };
    },
    container_queueFont: function() {
      return {
        fontFamily: this.container_queueFontFamily,
        fontSize: this.container_queueFontSize,
        fontWeight: this.container_queueFontWeight
      };
    },
    external_container_queueFont: function() {
      return {
        fontFamily: this.external_container_queueFontFamily,
        fontSize: this.external_container_queueFontSize,
        fontWeight: this.external_container_queueFontWeight
      };
    },
    componentFont: function() {
      return {
        fontFamily: this.componentFontFamily,
        fontSize: this.componentFontSize,
        fontWeight: this.componentFontWeight
      };
    },
    external_componentFont: function() {
      return {
        fontFamily: this.external_componentFontFamily,
        fontSize: this.external_componentFontSize,
        fontWeight: this.external_componentFontWeight
      };
    },
    component_dbFont: function() {
      return {
        fontFamily: this.component_dbFontFamily,
        fontSize: this.component_dbFontSize,
        fontWeight: this.component_dbFontWeight
      };
    },
    external_component_dbFont: function() {
      return {
        fontFamily: this.external_component_dbFontFamily,
        fontSize: this.external_component_dbFontSize,
        fontWeight: this.external_component_dbFontWeight
      };
    },
    component_queueFont: function() {
      return {
        fontFamily: this.component_queueFontFamily,
        fontSize: this.component_queueFontSize,
        fontWeight: this.component_queueFontWeight
      };
    },
    external_component_queueFont: function() {
      return {
        fontFamily: this.external_component_queueFontFamily,
        fontSize: this.external_component_queueFontSize,
        fontWeight: this.external_component_queueFontWeight
      };
    },
    boundaryFont: function() {
      return {
        fontFamily: this.boundaryFontFamily,
        fontSize: this.boundaryFontSize,
        fontWeight: this.boundaryFontWeight
      };
    },
    messageFont: function() {
      return {
        fontFamily: this.messageFontFamily,
        fontSize: this.messageFontSize,
        fontWeight: this.messageFontWeight
      };
    }
  },
  pie: {
    ...Ts.pie,
    useWidth: 984
  },
  xyChart: {
    ...Ts.xyChart,
    useWidth: void 0
  },
  requirement: {
    ...Ts.requirement,
    useWidth: void 0
  },
  gitGraph: {
    ...Ts.gitGraph,
    // TODO: This is a temporary override for `gitGraph`, since every other
    //       diagram does have `useMaxWidth`, but instead sets it to `true`.
    //       Should we set this to `true` instead?
    useMaxWidth: !1
  },
  sankey: {
    ...Ts.sankey,
    // this is false, unlike every other diagram (other than gitGraph)
    // TODO: can we make this default to `true` instead?
    useMaxWidth: !1
  }
}, pB = (e, t = "") => Object.keys(e).reduce((n, r) => Array.isArray(e[r]) ? n : typeof e[r] == "object" && e[r] !== null ? [...n, t + r, ...pB(e[r], "")] : [...n, t + r], []), zle = new Set(pB(fB, "")), Vle = fB, jg = (e) => {
  if (Ft.debug("sanitizeDirective called with", e), !(typeof e != "object" || e == null)) {
    if (Array.isArray(e)) {
      e.forEach((t) => jg(t));
      return;
    }
    for (const t of Object.keys(e)) {
      if (Ft.debug("Checking key", t), t.startsWith("__") || t.includes("proto") || t.includes("constr") || !zle.has(t) || e[t] == null) {
        Ft.debug("sanitize deleting key: ", t), delete e[t];
        continue;
      }
      if (typeof e[t] == "object") {
        Ft.debug("sanitizing object", t), jg(e[t]);
        continue;
      }
      const n = ["themeCSS", "fontFamily", "altFontFamily"];
      for (const r of n)
        t.includes(r) && (Ft.debug("sanitizing css option", t), e[t] = Wle(e[t]));
    }
    if (e.themeVariables)
      for (const t of Object.keys(e.themeVariables)) {
        const n = e.themeVariables[t];
        n != null && n.match && !n.match(/^[\d "#%(),.;A-Za-z]+$/) && (e.themeVariables[t] = "");
      }
    Ft.debug("After sanitization", e);
  }
}, Wle = (e) => {
  let t = 0, n = 0;
  for (const r of e) {
    if (t < n)
      return "{ /* ERROR: Unbalanced CSS */ }";
    r === "{" ? t++ : r === "}" && n++;
  }
  return t !== n ? "{ /* ERROR: Unbalanced CSS */ }" : e;
}, mB = /^-{3}\s*[\n\r](.*?)[\n\r]-{3}\s*[\n\r]+/s, Zf = /%{2}{\s*(?:(\w+)\s*:|(\w+))\s*(?:(\w+)|((?:(?!}%{2}).|\r?\n)*))?\s*(?:}%{2})?/gi, Kle = /\s*%%.*\n/gm;
class hB extends Error {
  constructor(t) {
    super(t), this.name = "UnknownDiagramError";
  }
}
const pd = {}, iv = function(e, t) {
  e = e.replace(mB, "").replace(Zf, "").replace(Kle, `
`);
  for (const [n, { detector: r }] of Object.entries(pd))
    if (r(e, t))
      return n;
  throw new hB(
    `No diagram type detected matching given configuration for text: ${e}`
  );
}, gB = (...e) => {
  for (const { id: t, detector: n, loader: r } of e)
    _B(t, n, r);
}, _B = (e, t, n) => {
  pd[e] ? Ft.error(`Detector with key ${e} already exists`) : pd[e] = { detector: t, loader: n }, Ft.debug(`Detector with key ${e} added${n ? " with loader" : ""}`);
}, jle = (e) => pd[e].loader, SC = (e, t, { depth: n = 2, clobber: r = !1 } = {}) => {
  const i = { depth: n, clobber: r };
  return Array.isArray(t) && !Array.isArray(e) ? (t.forEach((a) => SC(e, a, i)), e) : Array.isArray(t) && Array.isArray(e) ? (t.forEach((a) => {
    e.includes(a) || e.push(a);
  }), e) : e === void 0 || n <= 0 ? e != null && typeof e == "object" && typeof t == "object" ? Object.assign(e, t) : t : (t !== void 0 && typeof e == "object" && typeof t == "object" && Object.keys(t).forEach((a) => {
    typeof t[a] == "object" && (e[a] === void 0 || typeof e[a] == "object") ? (e[a] === void 0 && (e[a] = Array.isArray(t[a]) ? [] : {}), e[a] = SC(e[a], t[a], { depth: n - 1, clobber: r })) : (r || typeof e[a] != "object" && typeof t[a] != "object") && (e[a] = t[a]);
  }), e);
}, Di = SC, Qle = "​", Xle = {
  curveBasis: Nie,
  curveBasisClosed: Die,
  curveBasisOpen: Iie,
  curveBumpX: wie,
  curveBumpY: xie,
  curveBundle: Lie,
  curveCardinalClosed: Mie,
  curveCardinalOpen: Pie,
  curveCardinal: kie,
  curveCatmullRomClosed: Bie,
  curveCatmullRomOpen: $ie,
  curveCatmullRom: Fie,
  curveLinear: Rie,
  curveLinearClosed: Uie,
  curveMonotoneX: qie,
  curveMonotoneY: Gie,
  curveNatural: Yie,
  curveStep: Hie,
  curveStepAfter: Vie,
  curveStepBefore: zie
}, Zle = /\s*(?:(\w+)(?=:):|(\w+))\s*(?:(\w+)|((?:(?!}%{2}).|\r?\n)*))?\s*(?:}%{2})?/gi, Jle = function(e, t) {
  const n = vB(e, /(?:init\b)|(?:initialize\b)/);
  let r = {};
  if (Array.isArray(n)) {
    const o = n.map((s) => s.args);
    jg(o), r = Di(r, [...o]);
  } else
    r = n.args;
  if (!r)
    return;
  let i = iv(e, t);
  const a = "config";
  return r[a] !== void 0 && (i === "flowchart-v2" && (i = "flowchart"), r[i] = r[a], delete r[a]), r;
}, vB = function(e, t = null) {
  try {
    const n = new RegExp(
      `[%]{2}(?![{]${Zle.source})(?=[}][%]{2}).*
`,
      "ig"
    );
    e = e.trim().replace(n, "").replace(/'/gm, '"'), Ft.debug(
      `Detecting diagram directive${t !== null ? " type:" + t : ""} based on the text:${e}`
    );
    let r;
    const i = [];
    for (; (r = Zf.exec(e)) !== null; )
      if (r.index === Zf.lastIndex && Zf.lastIndex++, r && !t || t && r[1] && r[1].match(t) || t && r[2] && r[2].match(t)) {
        const a = r[1] ? r[1] : r[2], o = r[3] ? r[3].trim() : r[4] ? JSON.parse(r[4].trim()) : null;
        i.push({ type: a, args: o });
      }
    return i.length === 0 ? { type: e, args: null } : i.length === 1 ? i[0] : i;
  } catch (n) {
    return Ft.error(
      `ERROR: ${n.message} - Unable to parse directive type: '${t}' based on the text: '${e}'`
    ), { type: void 0, args: null };
  }
}, eue = function(e) {
  return e.replace(Zf, "");
}, tue = function(e, t) {
  for (const [n, r] of t.entries())
    if (r.match(e))
      return n;
  return -1;
};
function nue(e, t) {
  if (!e)
    return t;
  const n = `curve${e.charAt(0).toUpperCase() + e.slice(1)}`;
  return Xle[n] ?? t;
}
function rue(e, t) {
  const n = e.trim();
  if (n)
    return t.securityLevel !== "loose" ? XF.sanitizeUrl(n) : n;
}
const iue = (e, ...t) => {
  const n = e.split("."), r = n.length - 1, i = n[r];
  let a = window;
  for (let o = 0; o < r; o++)
    if (a = a[n[o]], !a) {
      Ft.error(`Function name: ${e} not found in window`);
      return;
    }
  a[i](...t);
};
function bB(e, t) {
  return !e || !t ? 0 : Math.sqrt(Math.pow(t.x - e.x, 2) + Math.pow(t.y - e.y, 2));
}
function aue(e) {
  let t, n = 0;
  e.forEach((i) => {
    n += bB(i, t), t = i;
  });
  const r = n / 2;
  return z1(e, r);
}
function oue(e) {
  return e.length === 1 ? e[0] : aue(e);
}
const Xk = (e, t = 2) => {
  const n = Math.pow(10, t);
  return Math.round(e * n) / n;
}, z1 = (e, t) => {
  let n, r = t;
  for (const i of e) {
    if (n) {
      const a = bB(i, n);
      if (a < r)
        r -= a;
      else {
        const o = r / a;
        if (o <= 0)
          return n;
        if (o >= 1)
          return { x: i.x, y: i.y };
        if (o > 0 && o < 1)
          return {
            x: Xk((1 - o) * n.x + o * i.x, 5),
            y: Xk((1 - o) * n.y + o * i.y, 5)
          };
      }
    }
    n = i;
  }
  throw new Error("Could not find a suitable point for the given distance");
}, sue = (e, t, n) => {
  Ft.info(`our points ${JSON.stringify(t)}`), t[0] !== n && (t = t.reverse());
  const i = z1(t, 25), a = e ? 10 : 5, o = Math.atan2(t[0].y - i.y, t[0].x - i.x), s = { x: 0, y: 0 };
  return s.x = Math.sin(o) * a + (t[0].x + i.x) / 2, s.y = -Math.cos(o) * a + (t[0].y + i.y) / 2, s;
};
function lue(e, t, n) {
  const r = structuredClone(n);
  Ft.info("our points", r), t !== "start_left" && t !== "start_right" && r.reverse();
  const i = 25 + e, a = z1(r, i), o = 10 + e * 0.5, s = Math.atan2(r[0].y - a.y, r[0].x - a.x), l = { x: 0, y: 0 };
  return t === "start_left" ? (l.x = Math.sin(s + Math.PI) * o + (r[0].x + a.x) / 2, l.y = -Math.cos(s + Math.PI) * o + (r[0].y + a.y) / 2) : t === "end_right" ? (l.x = Math.sin(s - Math.PI) * o + (r[0].x + a.x) / 2 - 5, l.y = -Math.cos(s - Math.PI) * o + (r[0].y + a.y) / 2 - 5) : t === "end_left" ? (l.x = Math.sin(s) * o + (r[0].x + a.x) / 2 - 5, l.y = -Math.cos(s) * o + (r[0].y + a.y) / 2 - 5) : (l.x = Math.sin(s) * o + (r[0].x + a.x) / 2, l.y = -Math.cos(s) * o + (r[0].y + a.y) / 2), l;
}
function uue(e) {
  let t = "", n = "";
  for (const r of e)
    r !== void 0 && (r.startsWith("color:") || r.startsWith("text-align:") ? n = n + r + ";" : t = t + r + ";");
  return { style: t, labelStyle: n };
}
let Zk = 0;
const cue = () => (Zk++, "id-" + Math.random().toString(36).substr(2, 12) + "-" + Zk);
function due(e) {
  let t = "";
  const n = "0123456789abcdef", r = n.length;
  for (let i = 0; i < e; i++)
    t += n.charAt(Math.floor(Math.random() * r));
  return t;
}
const fue = (e) => due(e.length), pue = function() {
  return {
    x: 0,
    y: 0,
    fill: void 0,
    anchor: "start",
    style: "#666",
    width: 100,
    height: 100,
    textMargin: 0,
    rx: 0,
    ry: 0,
    valign: void 0,
    text: ""
  };
}, mue = function(e, t) {
  const n = t.text.replace(H1.lineBreakRegex, " "), [, r] = W1(t.fontSize), i = e.append("text");
  i.attr("x", t.x), i.attr("y", t.y), i.style("text-anchor", t.anchor), i.style("font-family", t.fontFamily), i.style("font-size", r), i.style("font-weight", t.fontWeight), i.attr("fill", t.fill), t.class !== void 0 && i.attr("class", t.class);
  const a = i.append("tspan");
  return a.attr("x", t.x + t.textMargin * 2), a.attr("fill", t.fill), a.text(n), i;
}, hue = fm(
  (e, t, n) => {
    if (!e || (n = Object.assign(
      { fontSize: 12, fontWeight: 400, fontFamily: "Arial", joinWith: "<br/>" },
      n
    ), H1.lineBreakRegex.test(e)))
      return e;
    const r = e.split(" "), i = [];
    let a = "";
    return r.forEach((o, s) => {
      const l = Qg(`${o} `, n), u = Qg(a, n);
      if (l > t) {
        const { hyphenatedStrings: f, remainingWord: h } = gue(o, t, "-", n);
        i.push(a, ...f), a = h;
      } else u + l >= t ? (i.push(a), a = o) : a = [a, o].filter(Boolean).join(" ");
      s + 1 === r.length && i.push(a);
    }), i.filter((o) => o !== "").join(n.joinWith);
  },
  (e, t, n) => `${e}${t}${n.fontSize}${n.fontWeight}${n.fontFamily}${n.joinWith}`
), gue = fm(
  (e, t, n = "-", r) => {
    r = Object.assign(
      { fontSize: 12, fontWeight: 400, fontFamily: "Arial", margin: 0 },
      r
    );
    const i = [...e], a = [];
    let o = "";
    return i.forEach((s, l) => {
      const u = `${o}${s}`;
      if (Qg(u, r) >= t) {
        const d = l + 1, f = i.length === d, h = `${u}${n}`;
        a.push(f ? u : h), o = "";
      } else
        o = u;
    }), { hyphenatedStrings: a, remainingWord: o };
  },
  (e, t, n = "-", r) => `${e}${t}${n}${r.fontSize}${r.fontWeight}${r.fontFamily}`
);
function _ue(e, t) {
  return V1(e, t).height;
}
function Qg(e, t) {
  return V1(e, t).width;
}
const V1 = fm(
  (e, t) => {
    const { fontSize: n = 12, fontFamily: r = "Arial", fontWeight: i = 400 } = t;
    if (!e)
      return { width: 0, height: 0 };
    const [, a] = W1(n), o = ["sans-serif", r], s = e.split(H1.lineBreakRegex), l = [], u = ja("body");
    if (!u.remove)
      return { width: 0, height: 0, lineHeight: 0 };
    const c = u.append("svg");
    for (const f of o) {
      let h = 0;
      const m = { width: 0, height: 0, lineHeight: 0 };
      for (const v of s) {
        const b = pue();
        b.text = v || Qle;
        const y = mue(c, b).style("font-size", a).style("font-weight", i).style("font-family", f), g = (y._groups || y)[0][0].getBBox();
        if (g.width === 0 && g.height === 0)
          throw new Error("svg element not in render tree");
        m.width = Math.round(Math.max(m.width, g.width)), h = Math.round(g.height), m.height += h, m.lineHeight = Math.round(Math.max(m.lineHeight, h));
      }
      l.push(m);
    }
    c.remove();
    const d = isNaN(l[1].height) || isNaN(l[1].width) || isNaN(l[1].lineHeight) || l[0].height > l[1].height && l[0].width > l[1].width && l[0].lineHeight > l[1].lineHeight ? 0 : 1;
    return l[d];
  },
  (e, t) => `${e}${t.fontSize}${t.fontWeight}${t.fontFamily}`
);
class vue {
  constructor(t = !1, n) {
    this.count = 0, this.count = n ? n.length : 0, this.next = t ? () => this.count++ : () => Date.now();
  }
}
let Yh;
const bue = function(e) {
  return Yh = Yh || document.createElement("div"), e = escape(e).replace(/%26/g, "&").replace(/%23/g, "#").replace(/%3B/g, ";"), Yh.innerHTML = e, unescape(Yh.textContent);
};
function EB(e) {
  return "str" in e;
}
const Eue = (e, t, n, r) => {
  var i;
  if (!r)
    return;
  const a = (i = e.node()) == null ? void 0 : i.getBBox();
  a && e.append("text").text(r).attr("x", a.x + a.width / 2).attr("y", -n).attr("class", t);
}, W1 = (e) => {
  if (typeof e == "number")
    return [e, e + "px"];
  const t = parseInt(e ?? "", 10);
  return Number.isNaN(t) ? [void 0, void 0] : e === String(t) ? [t, e + "px"] : [t, e];
};
function SB(e, t) {
  return Vse({}, e, t);
}
const Jf = {
  assignWithDepth: Di,
  wrapLabel: hue,
  calculateTextHeight: _ue,
  calculateTextWidth: Qg,
  calculateTextDimensions: V1,
  cleanAndMerge: SB,
  detectInit: Jle,
  detectDirective: vB,
  isSubstringInArray: tue,
  interpolateToCurve: nue,
  calcLabelPosition: oue,
  calcCardinalityPosition: sue,
  calcTerminalLabelPosition: lue,
  formatUrl: rue,
  getStylesFromArray: uue,
  generateId: cue,
  random: fue,
  runFunc: iue,
  entityDecode: bue,
  insertTitle: Eue,
  parseFontSize: W1,
  InitIDGenerator: vue
}, Sue = function(e) {
  let t = e;
  return t = t.replace(/style.*:\S*#.*;/g, function(n) {
    return n.substring(0, n.length - 1);
  }), t = t.replace(/classDef.*:\S*#.*;/g, function(n) {
    return n.substring(0, n.length - 1);
  }), t = t.replace(/#\w+;/g, function(n) {
    const r = n.substring(1, n.length - 1);
    return /^\+?\d+$/.test(r) ? "ﬂ°°" + r + "¶ß" : "ﬂ°" + r + "¶ß";
  }), t;
}, yue = function(e) {
  return e.replace(/ﬂ°°/g, "&#").replace(/ﬂ°/g, "&").replace(/¶ß/g, ";");
}, Jk = "10.8.0", md = Object.freeze(Vle);
let oa = Di({}, md), yB, hd = [], ep = Di({}, md);
const av = (e, t) => {
  let n = Di({}, e), r = {};
  for (const i of t)
    AB(i), r = Di(r, i);
  if (n = Di(n, r), r.theme && r.theme in Ms) {
    const i = Di({}, yB), a = Di(
      i.themeVariables || {},
      r.themeVariables
    );
    n.theme && n.theme in Ms && (n.themeVariables = Ms[n.theme].getThemeVariables(a));
  }
  return ep = n, OB(ep), ep;
}, Tue = (e) => (oa = Di({}, md), oa = Di(oa, e), e.theme && Ms[e.theme] && (oa.themeVariables = Ms[e.theme].getThemeVariables(e.themeVariables)), av(oa, hd), oa), Cue = (e) => {
  yB = Di({}, e);
}, Aue = (e) => (oa = Di(oa, e), av(oa, hd), oa), TB = () => Di({}, oa), CB = (e) => (OB(e), Di(ep, e), jo()), jo = () => Di({}, ep), AB = (e) => {
  e && (["secure", ...oa.secure ?? []].forEach((t) => {
    Object.hasOwn(e, t) && (Ft.debug(`Denied attempt to modify a secure key ${t}`, e[t]), delete e[t]);
  }), Object.keys(e).forEach((t) => {
    t.startsWith("__") && delete e[t];
  }), Object.keys(e).forEach((t) => {
    typeof e[t] == "string" && (e[t].includes("<") || e[t].includes(">") || e[t].includes("url(data:")) && delete e[t], typeof e[t] == "object" && AB(e[t]);
  }));
}, Oue = (e) => {
  jg(e), e.fontFamily && (!e.themeVariables || !e.themeVariables.fontFamily) && (e.themeVariables = { fontFamily: e.fontFamily }), hd.push(e), av(oa, hd);
}, Xg = (e = oa) => {
  hd = [], av(e, hd);
}, Rue = {
  LAZY_LOAD_DEPRECATED: "The configuration options lazyLoadedDiagrams and loadExternalDiagramsAtStartup are deprecated. Please use registerExternalDiagrams instead."
}, e2 = {}, wue = (e) => {
  e2[e] || (Ft.warn(Rue[e]), e2[e] = !0);
}, OB = (e) => {
  e && (e.lazyLoadedDiagrams || e.loadExternalDiagramsAtStartup) && wue("LAZY_LOAD_DEPRECATED");
}, RB = "c4", xue = (e) => /^\s*C4Context|C4Container|C4Component|C4Dynamic|C4Deployment/.test(e), Nue = async () => {
  const { diagram: e } = await import("./c4Diagram-b947cdbb-BHzrjvq5.js");
  return { id: RB, diagram: e };
}, Due = {
  id: RB,
  detector: xue,
  loader: Nue
}, Iue = Due, wB = "flowchart", Lue = (e, t) => {
  var n, r;
  return ((n = t == null ? void 0 : t.flowchart) == null ? void 0 : n.defaultRenderer) === "dagre-wrapper" || ((r = t == null ? void 0 : t.flowchart) == null ? void 0 : r.defaultRenderer) === "elk" ? !1 : /^\s*graph/.test(e);
}, kue = async () => {
  const { diagram: e } = await import("./flowDiagram-d949d7c1-BAuQcUXL.js");
  return { id: wB, diagram: e };
}, Mue = {
  id: wB,
  detector: Lue,
  loader: kue
}, Pue = Mue, xB = "flowchart-v2", Fue = (e, t) => {
  var n, r, i;
  return ((n = t == null ? void 0 : t.flowchart) == null ? void 0 : n.defaultRenderer) === "dagre-d3" || ((r = t == null ? void 0 : t.flowchart) == null ? void 0 : r.defaultRenderer) === "elk" ? !1 : /^\s*graph/.test(e) && ((i = t == null ? void 0 : t.flowchart) == null ? void 0 : i.defaultRenderer) === "dagre-wrapper" ? !0 : /^\s*flowchart/.test(e);
}, Bue = async () => {
  const { diagram: e } = await import("./flowDiagram-v2-49332944-Yvkjh7JA.js");
  return { id: xB, diagram: e };
}, $ue = {
  id: xB,
  detector: Fue,
  loader: Bue
}, Uue = $ue, NB = "er", que = (e) => /^\s*erDiagram/.test(e), Gue = async () => {
  const { diagram: e } = await import("./erDiagram-0ea73325-C4U23wjW.js");
  return { id: NB, diagram: e };
}, Yue = {
  id: NB,
  detector: que,
  loader: Gue
}, Hue = Yue, DB = "gitGraph", zue = (e) => /^\s*gitGraph/.test(e), Vue = async () => {
  const { diagram: e } = await import("./gitGraphDiagram-b9d81de9-CNjE1l-N.js");
  return { id: DB, diagram: e };
}, Wue = {
  id: DB,
  detector: zue,
  loader: Vue
}, Kue = Wue, IB = "gantt", jue = (e) => /^\s*gantt/.test(e), Que = async () => {
  const { diagram: e } = await import("./ganttDiagram-5c869e3b-DNFqkXN3.js");
  return { id: IB, diagram: e };
}, Xue = {
  id: IB,
  detector: jue,
  loader: Que
}, Zue = Xue, LB = "info", Jue = (e) => /^\s*info/.test(e), ece = async () => {
  const { diagram: e } = await import("./infoDiagram-db7b18fc-BbvALx55.js");
  return { id: LB, diagram: e };
}, tce = {
  id: LB,
  detector: Jue,
  loader: ece
}, kB = "pie", nce = (e) => /^\s*pie/.test(e), rce = async () => {
  const { diagram: e } = await import("./pieDiagram-b0208e96-CW8NCC89.js");
  return { id: kB, diagram: e };
}, ice = {
  id: kB,
  detector: nce,
  loader: rce
}, MB = "quadrantChart", ace = (e) => /^\s*quadrantChart/.test(e), oce = async () => {
  const { diagram: e } = await import("./quadrantDiagram-0332be45-UKXjptvE.js");
  return { id: MB, diagram: e };
}, sce = {
  id: MB,
  detector: ace,
  loader: oce
}, lce = sce, PB = "xychart", uce = (e) => /^\s*xychart-beta/.test(e), cce = async () => {
  const { diagram: e } = await import("./xychartDiagram-e50adddc-DofgF4DX.js");
  return { id: PB, diagram: e };
}, dce = {
  id: PB,
  detector: uce,
  loader: cce
}, fce = dce, FB = "requirement", pce = (e) => /^\s*requirement(Diagram)?/.test(e), mce = async () => {
  const { diagram: e } = await import("./requirementDiagram-bf7890df-Ci6fFCAX.js");
  return { id: FB, diagram: e };
}, hce = {
  id: FB,
  detector: pce,
  loader: mce
}, gce = hce, BB = "sequence", _ce = (e) => /^\s*sequenceDiagram/.test(e), vce = async () => {
  const { diagram: e } = await import("./sequenceDiagram-c18d009d-CfOh3XpY.js");
  return { id: BB, diagram: e };
}, bce = {
  id: BB,
  detector: _ce,
  loader: vce
}, Ece = bce, $B = "class", Sce = (e, t) => {
  var n;
  return ((n = t == null ? void 0 : t.class) == null ? void 0 : n.defaultRenderer) === "dagre-wrapper" ? !1 : /^\s*classDiagram/.test(e);
}, yce = async () => {
  const { diagram: e } = await import("./classDiagram-35230388-CkzHAtJB.js");
  return { id: $B, diagram: e };
}, Tce = {
  id: $B,
  detector: Sce,
  loader: yce
}, Cce = Tce, UB = "classDiagram", Ace = (e, t) => {
  var n;
  return /^\s*classDiagram/.test(e) && ((n = t == null ? void 0 : t.class) == null ? void 0 : n.defaultRenderer) === "dagre-wrapper" ? !0 : /^\s*classDiagram-v2/.test(e);
}, Oce = async () => {
  const { diagram: e } = await import("./classDiagram-v2-412acd34-2iWblgAH.js");
  return { id: UB, diagram: e };
}, Rce = {
  id: UB,
  detector: Ace,
  loader: Oce
}, wce = Rce, qB = "state", xce = (e, t) => {
  var n;
  return ((n = t == null ? void 0 : t.state) == null ? void 0 : n.defaultRenderer) === "dagre-wrapper" ? !1 : /^\s*stateDiagram/.test(e);
}, Nce = async () => {
  const { diagram: e } = await import("./stateDiagram-43596fc0-CLl1QFWX.js");
  return { id: qB, diagram: e };
}, Dce = {
  id: qB,
  detector: xce,
  loader: Nce
}, Ice = Dce, GB = "stateDiagram", Lce = (e, t) => {
  var n;
  return !!(/^\s*stateDiagram-v2/.test(e) || /^\s*stateDiagram/.test(e) && ((n = t == null ? void 0 : t.state) == null ? void 0 : n.defaultRenderer) === "dagre-wrapper");
}, kce = async () => {
  const { diagram: e } = await import("./stateDiagram-v2-2ead4f9c-C6mWNZ1m.js");
  return { id: GB, diagram: e };
}, Mce = {
  id: GB,
  detector: Lce,
  loader: kce
}, Pce = Mce, YB = "journey", Fce = (e) => /^\s*journey/.test(e), Bce = async () => {
  const { diagram: e } = await import("./journeyDiagram-d5636530-CuB1XqMZ.js");
  return { id: YB, diagram: e };
}, $ce = {
  id: YB,
  detector: Fce,
  loader: Bce
}, Uce = $ce, qce = function(e, t) {
  for (let n of t)
    e.attr(n[0], n[1]);
}, Gce = function(e, t, n) {
  let r = /* @__PURE__ */ new Map();
  return n ? (r.set("width", "100%"), r.set("style", `max-width: ${t}px;`)) : (r.set("height", e), r.set("width", t)), r;
}, HB = function(e, t, n, r) {
  const i = Gce(t, n, r);
  qce(e, i);
}, Yce = function(e, t, n, r) {
  const i = t.node().getBBox(), a = i.width, o = i.height;
  Ft.info(`SVG bounds: ${a}x${o}`, i);
  let s = 0, l = 0;
  Ft.info(`Graph bounds: ${s}x${l}`, e), s = a + n * 2, l = o + n * 2, Ft.info(`Calculated bounds: ${s}x${l}`), HB(t, l, s, r);
  const u = `${i.x - n} ${i.y - n} ${i.width + 2 * n} ${i.height + 2 * n}`;
  t.attr("viewBox", u);
}, mg = {}, Hce = (e, t, n) => {
  let r = "";
  return e in mg && mg[e] ? r = mg[e](n) : Ft.warn(`No theme found for ${e}`), ` & {
    font-family: ${n.fontFamily};
    font-size: ${n.fontSize};
    fill: ${n.textColor}
  }

  /* Classes common for multiple diagrams */

  & .error-icon {
    fill: ${n.errorBkgColor};
  }
  & .error-text {
    fill: ${n.errorTextColor};
    stroke: ${n.errorTextColor};
  }

  & .edge-thickness-normal {
    stroke-width: 2px;
  }
  & .edge-thickness-thick {
    stroke-width: 3.5px
  }
  & .edge-pattern-solid {
    stroke-dasharray: 0;
  }

  & .edge-pattern-dashed{
    stroke-dasharray: 3;
  }
  .edge-pattern-dotted {
    stroke-dasharray: 2;
  }

  & .marker {
    fill: ${n.lineColor};
    stroke: ${n.lineColor};
  }
  & .marker.cross {
    stroke: ${n.lineColor};
  }

  & svg {
    font-family: ${n.fontFamily};
    font-size: ${n.fontSize};
  }

  ${r}

  ${t}
`;
}, zce = (e, t) => {
  t !== void 0 && (mg[e] = t);
}, Vce = Hce;
let K1 = "", j1 = "", Q1 = "";
const X1 = (e) => Lp(e, jo()), Wce = () => {
  K1 = "", Q1 = "", j1 = "";
}, Kce = (e) => {
  K1 = X1(e).replace(/^\s+/g, "");
}, jce = () => K1, Qce = (e) => {
  Q1 = X1(e).replace(/\n\s+/g, `
`);
}, Xce = () => Q1, Zce = (e) => {
  j1 = X1(e);
}, Jce = () => j1, ede = /* @__PURE__ */ Object.freeze(/* @__PURE__ */ Object.defineProperty({
  __proto__: null,
  clear: Wce,
  getAccDescription: Xce,
  getAccTitle: jce,
  getDiagramTitle: Jce,
  setAccDescription: Qce,
  setAccTitle: Kce,
  setDiagramTitle: Zce
}, Symbol.toStringTag, { value: "Module" })), tde = Ft, nde = Y1, Z1 = jo, T7e = CB, C7e = md, rde = (e) => Lp(e, Z1()), ide = Yce, ade = () => ede, Zg = {}, Jg = (e, t, n) => {
  var r;
  if (Zg[e])
    throw new Error(`Diagram ${e} already registered.`);
  Zg[e] = t, n && _B(e, n), zce(e, t.styles), (r = t.injectUtils) == null || r.call(
    t,
    tde,
    nde,
    Z1,
    rde,
    ide,
    ade(),
    () => {
    }
  );
}, J1 = (e) => {
  if (e in Zg)
    return Zg[e];
  throw new ode(e);
};
class ode extends Error {
  constructor(t) {
    super(`Diagram ${t} not found.`);
  }
}
const sde = (e) => {
  var t;
  const { securityLevel: n } = Z1();
  let r = ja("body");
  if (n === "sandbox") {
    const o = ((t = ja(`#i${e}`).node()) == null ? void 0 : t.contentDocument) ?? document;
    r = ja(o.body);
  }
  return r.select(`#${e}`);
}, lde = (e, t, n) => {
  Ft.debug(`rendering svg for syntax error
`);
  const r = sde(t);
  r.attr("viewBox", "0 0 2412 512"), HB(r, 100, 512, !0);
  const i = r.append("g");
  i.append("path").attr("class", "error-icon").attr(
    "d",
    "m411.313,123.313c6.25-6.25 6.25-16.375 0-22.625s-16.375-6.25-22.625,0l-32,32-9.375,9.375-20.688-20.688c-12.484-12.5-32.766-12.5-45.25,0l-16,16c-1.261,1.261-2.304,2.648-3.31,4.051-21.739-8.561-45.324-13.426-70.065-13.426-105.867,0-192,86.133-192,192s86.133,192 192,192 192-86.133 192-192c0-24.741-4.864-48.327-13.426-70.065 1.402-1.007 2.79-2.049 4.051-3.31l16-16c12.5-12.492 12.5-32.758 0-45.25l-20.688-20.688 9.375-9.375 32.001-31.999zm-219.313,100.687c-52.938,0-96,43.063-96,96 0,8.836-7.164,16-16,16s-16-7.164-16-16c0-70.578 57.422-128 128-128 8.836,0 16,7.164 16,16s-7.164,16-16,16z"
  ), i.append("path").attr("class", "error-icon").attr(
    "d",
    "m459.02,148.98c-6.25-6.25-16.375-6.25-22.625,0s-6.25,16.375 0,22.625l16,16c3.125,3.125 7.219,4.688 11.313,4.688 4.094,0 8.188-1.563 11.313-4.688 6.25-6.25 6.25-16.375 0-22.625l-16.001-16z"
  ), i.append("path").attr("class", "error-icon").attr(
    "d",
    "m340.395,75.605c3.125,3.125 7.219,4.688 11.313,4.688 4.094,0 8.188-1.563 11.313-4.688 6.25-6.25 6.25-16.375 0-22.625l-16-16c-6.25-6.25-16.375-6.25-22.625,0s-6.25,16.375 0,22.625l15.999,16z"
  ), i.append("path").attr("class", "error-icon").attr(
    "d",
    "m400,64c8.844,0 16-7.164 16-16v-32c0-8.836-7.156-16-16-16-8.844,0-16,7.164-16,16v32c0,8.836 7.156,16 16,16z"
  ), i.append("path").attr("class", "error-icon").attr(
    "d",
    "m496,96.586h-32c-8.844,0-16,7.164-16,16 0,8.836 7.156,16 16,16h32c8.844,0 16-7.164 16-16 0-8.836-7.156-16-16-16z"
  ), i.append("path").attr("class", "error-icon").attr(
    "d",
    "m436.98,75.605c3.125,3.125 7.219,4.688 11.313,4.688 4.094,0 8.188-1.563 11.313-4.688l32-32c6.25-6.25 6.25-16.375 0-22.625s-16.375-6.25-22.625,0l-32,32c-6.251,6.25-6.251,16.375-0.001,22.625z"
  ), i.append("text").attr("class", "error-text").attr("x", 1440).attr("y", 250).attr("font-size", "150px").style("text-anchor", "middle").text("Syntax error in text"), i.append("text").attr("class", "error-text").attr("x", 1250).attr("y", 400).attr("font-size", "100px").style("text-anchor", "middle").text(`mermaid version ${n}`);
}, zB = { draw: lde }, ude = zB, cde = {
  db: {},
  renderer: zB,
  parser: {
    parser: { yy: {} },
    parse: () => {
    }
  }
}, dde = cde, VB = "flowchart-elk", fde = (e, t) => {
  var n;
  return (
    // If diagram explicitly states flowchart-elk
    !!(/^\s*flowchart-elk/.test(e) || // If a flowchart/graph diagram has their default renderer set to elk
    /^\s*flowchart|graph/.test(e) && ((n = t == null ? void 0 : t.flowchart) == null ? void 0 : n.defaultRenderer) === "elk")
  );
}, pde = async () => {
  const { diagram: e } = await import("./flowchart-elk-definition-27cc417a-Bp7OLq1Y.js");
  return { id: VB, diagram: e };
}, mde = {
  id: VB,
  detector: fde,
  loader: pde
}, hde = mde, WB = "timeline", gde = (e) => /^\s*timeline/.test(e), _de = async () => {
  const { diagram: e } = await import("./timeline-definition-d977decf-yimOn8lr.js");
  return { id: WB, diagram: e };
}, vde = {
  id: WB,
  detector: gde,
  loader: _de
}, bde = vde, KB = "mindmap", Ede = (e) => /^\s*mindmap/.test(e), Sde = async () => {
  const { diagram: e } = await import("./mindmap-definition-377f8f1f-D3u4vb5v.js");
  return { id: KB, diagram: e };
}, yde = {
  id: KB,
  detector: Ede,
  loader: Sde
}, Tde = yde, jB = "sankey", Cde = (e) => /^\s*sankey-beta/.test(e), Ade = async () => {
  const { diagram: e } = await import("./sankeyDiagram-0acdec17-VMdy_h38.js");
  return { id: jB, diagram: e };
}, Ode = {
  id: jB,
  detector: Cde,
  loader: Ade
}, Rde = Ode, QB = "block", wde = (e) => /^\s*block-beta/.test(e), xde = async () => {
  const { diagram: e } = await import("./blockDiagram-6b2b5046-M354Z1wI.js");
  return { id: QB, diagram: e };
}, Nde = {
  id: QB,
  detector: wde,
  loader: xde
}, Dde = Nde;
let t2 = !1;
const eA = () => {
  t2 || (t2 = !0, Jg("error", dde, (e) => e.toLowerCase().trim() === "error"), Jg(
    "---",
    // --- diagram type may appear if YAML front-matter is not parsed correctly
    {
      db: {
        clear: () => {
        }
      },
      styles: {},
      // should never be used
      renderer: {
        draw: () => {
        }
      },
      parser: {
        parser: { yy: {} },
        parse: () => {
          throw new Error(
            "Diagrams beginning with --- are not valid. If you were trying to use a YAML front-matter, please ensure that you've correctly opened and closed the YAML front-matter with un-indented `---` blocks"
          );
        }
      },
      init: () => null
      // no op
    },
    (e) => e.toLowerCase().trimStart().startsWith("---")
  ), gB(
    Iue,
    wce,
    Cce,
    Hue,
    Zue,
    tce,
    ice,
    gce,
    Ece,
    hde,
    Uue,
    Pue,
    Tde,
    bde,
    Kue,
    Pce,
    Ice,
    Uce,
    lce,
    Rde,
    fce,
    Dde
  ));
};
class XB {
  constructor(t, n = {}) {
    this.text = t, this.metadata = n, this.type = "graph", this.text = Sue(t), this.text += `
`;
    const r = jo();
    try {
      this.type = iv(t, r);
    } catch (a) {
      this.type = "error", this.detectError = a;
    }
    const i = J1(this.type);
    Ft.debug("Type " + this.type), this.db = i.db, this.renderer = i.renderer, this.parser = i.parser, this.parser.parser.yy = this.db, this.init = i.init, this.parse();
  }
  parse() {
    var t, n, r, i, a;
    if (this.detectError)
      throw this.detectError;
    (n = (t = this.db).clear) == null || n.call(t);
    const o = jo();
    (r = this.init) == null || r.call(this, o), this.metadata.title && ((a = (i = this.db).setDiagramTitle) == null || a.call(i, this.metadata.title)), this.parser.parse(this.text);
  }
  async render(t, n) {
    await this.renderer.draw(this.text, t, n, this);
  }
  getParser() {
    return this.parser;
  }
  getType() {
    return this.type;
  }
}
const Ide = async (e, t = {}) => {
  const n = iv(e, jo());
  try {
    J1(n);
  } catch {
    const i = jle(n);
    if (!i)
      throw new hB(`Diagram ${n} not found.`);
    const { id: a, diagram: o } = await i();
    Jg(a, o);
  }
  return new XB(e, t);
};
let n2 = [];
const Lde = () => {
  n2.forEach((e) => {
    e();
  }), n2 = [];
}, kde = "graphics-document document";
function Mde(e, t) {
  e.attr("role", kde), t !== "" && e.attr("aria-roledescription", t);
}
function Pde(e, t, n, r) {
  if (e.insert !== void 0) {
    if (n) {
      const i = `chart-desc-${r}`;
      e.attr("aria-describedby", i), e.insert("desc", ":first-child").attr("id", i).text(n);
    }
    if (t) {
      const i = `chart-title-${r}`;
      e.attr("aria-labelledby", i), e.insert("title", ":first-child").attr("id", i).text(t);
    }
  }
}
const Fde = (e) => e.replace(/^\s*%%(?!{)[^\n]+\n?/gm, "").trimStart();
/*! js-yaml 4.1.0 https://github.com/nodeca/js-yaml @license MIT */
function ZB(e) {
  return typeof e > "u" || e === null;
}
function Bde(e) {
  return typeof e == "object" && e !== null;
}
function $de(e) {
  return Array.isArray(e) ? e : ZB(e) ? [] : [e];
}
function Ude(e, t) {
  var n, r, i, a;
  if (t)
    for (a = Object.keys(t), n = 0, r = a.length; n < r; n += 1)
      i = a[n], e[i] = t[i];
  return e;
}
function qde(e, t) {
  var n = "", r;
  for (r = 0; r < t; r += 1)
    n += e;
  return n;
}
function Gde(e) {
  return e === 0 && Number.NEGATIVE_INFINITY === 1 / e;
}
var Yde = ZB, Hde = Bde, zde = $de, Vde = qde, Wde = Gde, Kde = Ude, Hi = {
  isNothing: Yde,
  isObject: Hde,
  toArray: zde,
  repeat: Vde,
  isNegativeZero: Wde,
  extend: Kde
};
function JB(e, t) {
  var n = "", r = e.reason || "(unknown reason)";
  return e.mark ? (e.mark.name && (n += 'in "' + e.mark.name + '" '), n += "(" + (e.mark.line + 1) + ":" + (e.mark.column + 1) + ")", !t && e.mark.snippet && (n += `

` + e.mark.snippet), r + " " + n) : r;
}
function kp(e, t) {
  Error.call(this), this.name = "YAMLException", this.reason = e, this.mark = t, this.message = JB(this, !1), Error.captureStackTrace ? Error.captureStackTrace(this, this.constructor) : this.stack = new Error().stack || "";
}
kp.prototype = Object.create(Error.prototype);
kp.prototype.constructor = kp;
kp.prototype.toString = function(t) {
  return this.name + ": " + JB(this, t);
};
var Ns = kp;
function aT(e, t, n, r, i) {
  var a = "", o = "", s = Math.floor(i / 2) - 1;
  return r - t > s && (a = " ... ", t = r - s + a.length), n - r > s && (o = " ...", n = r + s - o.length), {
    str: a + e.slice(t, n).replace(/\t/g, "→") + o,
    pos: r - t + a.length
    // relative position
  };
}
function oT(e, t) {
  return Hi.repeat(" ", t - e.length) + e;
}
function jde(e, t) {
  if (t = Object.create(t || null), !e.buffer)
    return null;
  t.maxLength || (t.maxLength = 79), typeof t.indent != "number" && (t.indent = 1), typeof t.linesBefore != "number" && (t.linesBefore = 3), typeof t.linesAfter != "number" && (t.linesAfter = 2);
  for (var n = /\r?\n|\r|\0/g, r = [0], i = [], a, o = -1; a = n.exec(e.buffer); )
    i.push(a.index), r.push(a.index + a[0].length), e.position <= a.index && o < 0 && (o = r.length - 2);
  o < 0 && (o = r.length - 1);
  var s = "", l, u, c = Math.min(e.line + t.linesAfter, i.length).toString().length, d = t.maxLength - (t.indent + c + 3);
  for (l = 1; l <= t.linesBefore && !(o - l < 0); l++)
    u = aT(
      e.buffer,
      r[o - l],
      i[o - l],
      e.position - (r[o] - r[o - l]),
      d
    ), s = Hi.repeat(" ", t.indent) + oT((e.line - l + 1).toString(), c) + " | " + u.str + `
` + s;
  for (u = aT(e.buffer, r[o], i[o], e.position, d), s += Hi.repeat(" ", t.indent) + oT((e.line + 1).toString(), c) + " | " + u.str + `
`, s += Hi.repeat("-", t.indent + c + 3 + u.pos) + `^
`, l = 1; l <= t.linesAfter && !(o + l >= i.length); l++)
    u = aT(
      e.buffer,
      r[o + l],
      i[o + l],
      e.position - (r[o] - r[o + l]),
      d
    ), s += Hi.repeat(" ", t.indent) + oT((e.line + l + 1).toString(), c) + " | " + u.str + `
`;
  return s.replace(/\n$/, "");
}
var Qde = jde, Xde = [
  "kind",
  "multi",
  "resolve",
  "construct",
  "instanceOf",
  "predicate",
  "represent",
  "representName",
  "defaultStyle",
  "styleAliases"
], Zde = [
  "scalar",
  "sequence",
  "mapping"
];
function Jde(e) {
  var t = {};
  return e !== null && Object.keys(e).forEach(function(n) {
    e[n].forEach(function(r) {
      t[String(r)] = n;
    });
  }), t;
}
function efe(e, t) {
  if (t = t || {}, Object.keys(t).forEach(function(n) {
    if (Xde.indexOf(n) === -1)
      throw new Ns('Unknown option "' + n + '" is met in definition of "' + e + '" YAML type.');
  }), this.options = t, this.tag = e, this.kind = t.kind || null, this.resolve = t.resolve || function() {
    return !0;
  }, this.construct = t.construct || function(n) {
    return n;
  }, this.instanceOf = t.instanceOf || null, this.predicate = t.predicate || null, this.represent = t.represent || null, this.representName = t.representName || null, this.defaultStyle = t.defaultStyle || null, this.multi = t.multi || !1, this.styleAliases = Jde(t.styleAliases || null), Zde.indexOf(this.kind) === -1)
    throw new Ns('Unknown kind "' + this.kind + '" is specified for "' + e + '" YAML type.');
}
var Ii = efe;
function r2(e, t) {
  var n = [];
  return e[t].forEach(function(r) {
    var i = n.length;
    n.forEach(function(a, o) {
      a.tag === r.tag && a.kind === r.kind && a.multi === r.multi && (i = o);
    }), n[i] = r;
  }), n;
}
function tfe() {
  var e = {
    scalar: {},
    sequence: {},
    mapping: {},
    fallback: {},
    multi: {
      scalar: [],
      sequence: [],
      mapping: [],
      fallback: []
    }
  }, t, n;
  function r(i) {
    i.multi ? (e.multi[i.kind].push(i), e.multi.fallback.push(i)) : e[i.kind][i.tag] = e.fallback[i.tag] = i;
  }
  for (t = 0, n = arguments.length; t < n; t += 1)
    arguments[t].forEach(r);
  return e;
}
function yC(e) {
  return this.extend(e);
}
yC.prototype.extend = function(t) {
  var n = [], r = [];
  if (t instanceof Ii)
    r.push(t);
  else if (Array.isArray(t))
    r = r.concat(t);
  else if (t && (Array.isArray(t.implicit) || Array.isArray(t.explicit)))
    t.implicit && (n = n.concat(t.implicit)), t.explicit && (r = r.concat(t.explicit));
  else
    throw new Ns("Schema.extend argument should be a Type, [ Type ], or a schema definition ({ implicit: [...], explicit: [...] })");
  n.forEach(function(a) {
    if (!(a instanceof Ii))
      throw new Ns("Specified list of YAML types (or a single Type object) contains a non-Type object.");
    if (a.loadKind && a.loadKind !== "scalar")
      throw new Ns("There is a non-scalar type in the implicit list of a schema. Implicit resolving of such types is not supported.");
    if (a.multi)
      throw new Ns("There is a multi type in the implicit list of a schema. Multi tags can only be listed as explicit.");
  }), r.forEach(function(a) {
    if (!(a instanceof Ii))
      throw new Ns("Specified list of YAML types (or a single Type object) contains a non-Type object.");
  });
  var i = Object.create(yC.prototype);
  return i.implicit = (this.implicit || []).concat(n), i.explicit = (this.explicit || []).concat(r), i.compiledImplicit = r2(i, "implicit"), i.compiledExplicit = r2(i, "explicit"), i.compiledTypeMap = tfe(i.compiledImplicit, i.compiledExplicit), i;
};
var nfe = yC, rfe = new Ii("tag:yaml.org,2002:str", {
  kind: "scalar",
  construct: function(e) {
    return e !== null ? e : "";
  }
}), ife = new Ii("tag:yaml.org,2002:seq", {
  kind: "sequence",
  construct: function(e) {
    return e !== null ? e : [];
  }
}), afe = new Ii("tag:yaml.org,2002:map", {
  kind: "mapping",
  construct: function(e) {
    return e !== null ? e : {};
  }
}), ofe = new nfe({
  explicit: [
    rfe,
    ife,
    afe
  ]
});
function sfe(e) {
  if (e === null)
    return !0;
  var t = e.length;
  return t === 1 && e === "~" || t === 4 && (e === "null" || e === "Null" || e === "NULL");
}
function lfe() {
  return null;
}
function ufe(e) {
  return e === null;
}
var cfe = new Ii("tag:yaml.org,2002:null", {
  kind: "scalar",
  resolve: sfe,
  construct: lfe,
  predicate: ufe,
  represent: {
    canonical: function() {
      return "~";
    },
    lowercase: function() {
      return "null";
    },
    uppercase: function() {
      return "NULL";
    },
    camelcase: function() {
      return "Null";
    },
    empty: function() {
      return "";
    }
  },
  defaultStyle: "lowercase"
});
function dfe(e) {
  if (e === null)
    return !1;
  var t = e.length;
  return t === 4 && (e === "true" || e === "True" || e === "TRUE") || t === 5 && (e === "false" || e === "False" || e === "FALSE");
}
function ffe(e) {
  return e === "true" || e === "True" || e === "TRUE";
}
function pfe(e) {
  return Object.prototype.toString.call(e) === "[object Boolean]";
}
var mfe = new Ii("tag:yaml.org,2002:bool", {
  kind: "scalar",
  resolve: dfe,
  construct: ffe,
  predicate: pfe,
  represent: {
    lowercase: function(e) {
      return e ? "true" : "false";
    },
    uppercase: function(e) {
      return e ? "TRUE" : "FALSE";
    },
    camelcase: function(e) {
      return e ? "True" : "False";
    }
  },
  defaultStyle: "lowercase"
});
function hfe(e) {
  return 48 <= e && e <= 57 || 65 <= e && e <= 70 || 97 <= e && e <= 102;
}
function gfe(e) {
  return 48 <= e && e <= 55;
}
function _fe(e) {
  return 48 <= e && e <= 57;
}
function vfe(e) {
  if (e === null)
    return !1;
  var t = e.length, n = 0, r = !1, i;
  if (!t)
    return !1;
  if (i = e[n], (i === "-" || i === "+") && (i = e[++n]), i === "0") {
    if (n + 1 === t)
      return !0;
    if (i = e[++n], i === "b") {
      for (n++; n < t; n++)
        if (i = e[n], i !== "_") {
          if (i !== "0" && i !== "1")
            return !1;
          r = !0;
        }
      return r && i !== "_";
    }
    if (i === "x") {
      for (n++; n < t; n++)
        if (i = e[n], i !== "_") {
          if (!hfe(e.charCodeAt(n)))
            return !1;
          r = !0;
        }
      return r && i !== "_";
    }
    if (i === "o") {
      for (n++; n < t; n++)
        if (i = e[n], i !== "_") {
          if (!gfe(e.charCodeAt(n)))
            return !1;
          r = !0;
        }
      return r && i !== "_";
    }
  }
  if (i === "_")
    return !1;
  for (; n < t; n++)
    if (i = e[n], i !== "_") {
      if (!_fe(e.charCodeAt(n)))
        return !1;
      r = !0;
    }
  return !(!r || i === "_");
}
function bfe(e) {
  var t = e, n = 1, r;
  if (t.indexOf("_") !== -1 && (t = t.replace(/_/g, "")), r = t[0], (r === "-" || r === "+") && (r === "-" && (n = -1), t = t.slice(1), r = t[0]), t === "0")
    return 0;
  if (r === "0") {
    if (t[1] === "b")
      return n * parseInt(t.slice(2), 2);
    if (t[1] === "x")
      return n * parseInt(t.slice(2), 16);
    if (t[1] === "o")
      return n * parseInt(t.slice(2), 8);
  }
  return n * parseInt(t, 10);
}
function Efe(e) {
  return Object.prototype.toString.call(e) === "[object Number]" && e % 1 === 0 && !Hi.isNegativeZero(e);
}
var Sfe = new Ii("tag:yaml.org,2002:int", {
  kind: "scalar",
  resolve: vfe,
  construct: bfe,
  predicate: Efe,
  represent: {
    binary: function(e) {
      return e >= 0 ? "0b" + e.toString(2) : "-0b" + e.toString(2).slice(1);
    },
    octal: function(e) {
      return e >= 0 ? "0o" + e.toString(8) : "-0o" + e.toString(8).slice(1);
    },
    decimal: function(e) {
      return e.toString(10);
    },
    /* eslint-disable max-len */
    hexadecimal: function(e) {
      return e >= 0 ? "0x" + e.toString(16).toUpperCase() : "-0x" + e.toString(16).toUpperCase().slice(1);
    }
  },
  defaultStyle: "decimal",
  styleAliases: {
    binary: [2, "bin"],
    octal: [8, "oct"],
    decimal: [10, "dec"],
    hexadecimal: [16, "hex"]
  }
}), yfe = new RegExp(
  // 2.5e4, 2.5 and integers
  "^(?:[-+]?(?:[0-9][0-9_]*)(?:\\.[0-9_]*)?(?:[eE][-+]?[0-9]+)?|\\.[0-9_]+(?:[eE][-+]?[0-9]+)?|[-+]?\\.(?:inf|Inf|INF)|\\.(?:nan|NaN|NAN))$"
);
function Tfe(e) {
  return !(e === null || !yfe.test(e) || // Quick hack to not allow integers end with `_`
  // Probably should update regexp & check speed
  e[e.length - 1] === "_");
}
function Cfe(e) {
  var t, n;
  return t = e.replace(/_/g, "").toLowerCase(), n = t[0] === "-" ? -1 : 1, "+-".indexOf(t[0]) >= 0 && (t = t.slice(1)), t === ".inf" ? n === 1 ? Number.POSITIVE_INFINITY : Number.NEGATIVE_INFINITY : t === ".nan" ? NaN : n * parseFloat(t, 10);
}
var Afe = /^[-+]?[0-9]+e/;
function Ofe(e, t) {
  var n;
  if (isNaN(e))
    switch (t) {
      case "lowercase":
        return ".nan";
      case "uppercase":
        return ".NAN";
      case "camelcase":
        return ".NaN";
    }
  else if (Number.POSITIVE_INFINITY === e)
    switch (t) {
      case "lowercase":
        return ".inf";
      case "uppercase":
        return ".INF";
      case "camelcase":
        return ".Inf";
    }
  else if (Number.NEGATIVE_INFINITY === e)
    switch (t) {
      case "lowercase":
        return "-.inf";
      case "uppercase":
        return "-.INF";
      case "camelcase":
        return "-.Inf";
    }
  else if (Hi.isNegativeZero(e))
    return "-0.0";
  return n = e.toString(10), Afe.test(n) ? n.replace("e", ".e") : n;
}
function Rfe(e) {
  return Object.prototype.toString.call(e) === "[object Number]" && (e % 1 !== 0 || Hi.isNegativeZero(e));
}
var wfe = new Ii("tag:yaml.org,2002:float", {
  kind: "scalar",
  resolve: Tfe,
  construct: Cfe,
  predicate: Rfe,
  represent: Ofe,
  defaultStyle: "lowercase"
}), e6 = ofe.extend({
  implicit: [
    cfe,
    mfe,
    Sfe,
    wfe
  ]
}), xfe = e6, t6 = new RegExp(
  "^([0-9][0-9][0-9][0-9])-([0-9][0-9])-([0-9][0-9])$"
), n6 = new RegExp(
  "^([0-9][0-9][0-9][0-9])-([0-9][0-9]?)-([0-9][0-9]?)(?:[Tt]|[ \\t]+)([0-9][0-9]?):([0-9][0-9]):([0-9][0-9])(?:\\.([0-9]*))?(?:[ \\t]*(Z|([-+])([0-9][0-9]?)(?::([0-9][0-9]))?))?$"
);
function Nfe(e) {
  return e === null ? !1 : t6.exec(e) !== null || n6.exec(e) !== null;
}
function Dfe(e) {
  var t, n, r, i, a, o, s, l = 0, u = null, c, d, f;
  if (t = t6.exec(e), t === null && (t = n6.exec(e)), t === null)
    throw new Error("Date resolve error");
  if (n = +t[1], r = +t[2] - 1, i = +t[3], !t[4])
    return new Date(Date.UTC(n, r, i));
  if (a = +t[4], o = +t[5], s = +t[6], t[7]) {
    for (l = t[7].slice(0, 3); l.length < 3; )
      l += "0";
    l = +l;
  }
  return t[9] && (c = +t[10], d = +(t[11] || 0), u = (c * 60 + d) * 6e4, t[9] === "-" && (u = -u)), f = new Date(Date.UTC(n, r, i, a, o, s, l)), u && f.setTime(f.getTime() - u), f;
}
function Ife(e) {
  return e.toISOString();
}
var Lfe = new Ii("tag:yaml.org,2002:timestamp", {
  kind: "scalar",
  resolve: Nfe,
  construct: Dfe,
  instanceOf: Date,
  represent: Ife
});
function kfe(e) {
  return e === "<<" || e === null;
}
var Mfe = new Ii("tag:yaml.org,2002:merge", {
  kind: "scalar",
  resolve: kfe
}), tA = `ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/=
\r`;
function Pfe(e) {
  if (e === null)
    return !1;
  var t, n, r = 0, i = e.length, a = tA;
  for (n = 0; n < i; n++)
    if (t = a.indexOf(e.charAt(n)), !(t > 64)) {
      if (t < 0)
        return !1;
      r += 6;
    }
  return r % 8 === 0;
}
function Ffe(e) {
  var t, n, r = e.replace(/[\r\n=]/g, ""), i = r.length, a = tA, o = 0, s = [];
  for (t = 0; t < i; t++)
    t % 4 === 0 && t && (s.push(o >> 16 & 255), s.push(o >> 8 & 255), s.push(o & 255)), o = o << 6 | a.indexOf(r.charAt(t));
  return n = i % 4 * 6, n === 0 ? (s.push(o >> 16 & 255), s.push(o >> 8 & 255), s.push(o & 255)) : n === 18 ? (s.push(o >> 10 & 255), s.push(o >> 2 & 255)) : n === 12 && s.push(o >> 4 & 255), new Uint8Array(s);
}
function Bfe(e) {
  var t = "", n = 0, r, i, a = e.length, o = tA;
  for (r = 0; r < a; r++)
    r % 3 === 0 && r && (t += o[n >> 18 & 63], t += o[n >> 12 & 63], t += o[n >> 6 & 63], t += o[n & 63]), n = (n << 8) + e[r];
  return i = a % 3, i === 0 ? (t += o[n >> 18 & 63], t += o[n >> 12 & 63], t += o[n >> 6 & 63], t += o[n & 63]) : i === 2 ? (t += o[n >> 10 & 63], t += o[n >> 4 & 63], t += o[n << 2 & 63], t += o[64]) : i === 1 && (t += o[n >> 2 & 63], t += o[n << 4 & 63], t += o[64], t += o[64]), t;
}
function $fe(e) {
  return Object.prototype.toString.call(e) === "[object Uint8Array]";
}
var Ufe = new Ii("tag:yaml.org,2002:binary", {
  kind: "scalar",
  resolve: Pfe,
  construct: Ffe,
  predicate: $fe,
  represent: Bfe
}), qfe = Object.prototype.hasOwnProperty, Gfe = Object.prototype.toString;
function Yfe(e) {
  if (e === null)
    return !0;
  var t = [], n, r, i, a, o, s = e;
  for (n = 0, r = s.length; n < r; n += 1) {
    if (i = s[n], o = !1, Gfe.call(i) !== "[object Object]")
      return !1;
    for (a in i)
      if (qfe.call(i, a))
        if (!o)
          o = !0;
        else
          return !1;
    if (!o)
      return !1;
    if (t.indexOf(a) === -1)
      t.push(a);
    else
      return !1;
  }
  return !0;
}
function Hfe(e) {
  return e !== null ? e : [];
}
var zfe = new Ii("tag:yaml.org,2002:omap", {
  kind: "sequence",
  resolve: Yfe,
  construct: Hfe
}), Vfe = Object.prototype.toString;
function Wfe(e) {
  if (e === null)
    return !0;
  var t, n, r, i, a, o = e;
  for (a = new Array(o.length), t = 0, n = o.length; t < n; t += 1) {
    if (r = o[t], Vfe.call(r) !== "[object Object]" || (i = Object.keys(r), i.length !== 1))
      return !1;
    a[t] = [i[0], r[i[0]]];
  }
  return !0;
}
function Kfe(e) {
  if (e === null)
    return [];
  var t, n, r, i, a, o = e;
  for (a = new Array(o.length), t = 0, n = o.length; t < n; t += 1)
    r = o[t], i = Object.keys(r), a[t] = [i[0], r[i[0]]];
  return a;
}
var jfe = new Ii("tag:yaml.org,2002:pairs", {
  kind: "sequence",
  resolve: Wfe,
  construct: Kfe
}), Qfe = Object.prototype.hasOwnProperty;
function Xfe(e) {
  if (e === null)
    return !0;
  var t, n = e;
  for (t in n)
    if (Qfe.call(n, t) && n[t] !== null)
      return !1;
  return !0;
}
function Zfe(e) {
  return e !== null ? e : {};
}
var Jfe = new Ii("tag:yaml.org,2002:set", {
  kind: "mapping",
  resolve: Xfe,
  construct: Zfe
}), epe = xfe.extend({
  implicit: [
    Lfe,
    Mfe
  ],
  explicit: [
    Ufe,
    zfe,
    jfe,
    Jfe
  ]
}), Ul = Object.prototype.hasOwnProperty, e_ = 1, r6 = 2, i6 = 3, t_ = 4, sT = 1, tpe = 2, i2 = 3, npe = /[\x00-\x08\x0B\x0C\x0E-\x1F\x7F-\x84\x86-\x9F\uFFFE\uFFFF]|[\uD800-\uDBFF](?![\uDC00-\uDFFF])|(?:[^\uD800-\uDBFF]|^)[\uDC00-\uDFFF]/, rpe = /[\x85\u2028\u2029]/, ipe = /[,\[\]\{\}]/, a6 = /^(?:!|!!|![a-z\-]+!)$/i, o6 = /^(?:!|[^,\[\]\{\}])(?:%[0-9a-f]{2}|[0-9a-z\-#;\/\?:@&=\+\$,_\.!~\*'\(\)\[\]])*$/i;
function a2(e) {
  return Object.prototype.toString.call(e);
}
function Yo(e) {
  return e === 10 || e === 13;
}
function Pu(e) {
  return e === 9 || e === 32;
}
function ua(e) {
  return e === 9 || e === 32 || e === 10 || e === 13;
}
function Hc(e) {
  return e === 44 || e === 91 || e === 93 || e === 123 || e === 125;
}
function ape(e) {
  var t;
  return 48 <= e && e <= 57 ? e - 48 : (t = e | 32, 97 <= t && t <= 102 ? t - 97 + 10 : -1);
}
function ope(e) {
  return e === 120 ? 2 : e === 117 ? 4 : e === 85 ? 8 : 0;
}
function spe(e) {
  return 48 <= e && e <= 57 ? e - 48 : -1;
}
function o2(e) {
  return e === 48 ? "\0" : e === 97 ? "\x07" : e === 98 ? "\b" : e === 116 || e === 9 ? "	" : e === 110 ? `
` : e === 118 ? "\v" : e === 102 ? "\f" : e === 114 ? "\r" : e === 101 ? "\x1B" : e === 32 ? " " : e === 34 ? '"' : e === 47 ? "/" : e === 92 ? "\\" : e === 78 ? "" : e === 95 ? " " : e === 76 ? "\u2028" : e === 80 ? "\u2029" : "";
}
function lpe(e) {
  return e <= 65535 ? String.fromCharCode(e) : String.fromCharCode(
    (e - 65536 >> 10) + 55296,
    (e - 65536 & 1023) + 56320
  );
}
var s6 = new Array(256), l6 = new Array(256);
for (var wc = 0; wc < 256; wc++)
  s6[wc] = o2(wc) ? 1 : 0, l6[wc] = o2(wc);
function upe(e, t) {
  this.input = e, this.filename = t.filename || null, this.schema = t.schema || epe, this.onWarning = t.onWarning || null, this.legacy = t.legacy || !1, this.json = t.json || !1, this.listener = t.listener || null, this.implicitTypes = this.schema.compiledImplicit, this.typeMap = this.schema.compiledTypeMap, this.length = e.length, this.position = 0, this.line = 0, this.lineStart = 0, this.lineIndent = 0, this.firstTabInLine = -1, this.documents = [];
}
function u6(e, t) {
  var n = {
    name: e.filename,
    buffer: e.input.slice(0, -1),
    // omit trailing \0
    position: e.position,
    line: e.line,
    column: e.position - e.lineStart
  };
  return n.snippet = Qde(n), new Ns(t, n);
}
function Nt(e, t) {
  throw u6(e, t);
}
function n_(e, t) {
  e.onWarning && e.onWarning.call(null, u6(e, t));
}
var s2 = {
  YAML: function(t, n, r) {
    var i, a, o;
    t.version !== null && Nt(t, "duplication of %YAML directive"), r.length !== 1 && Nt(t, "YAML directive accepts exactly one argument"), i = /^([0-9]+)\.([0-9]+)$/.exec(r[0]), i === null && Nt(t, "ill-formed argument of the YAML directive"), a = parseInt(i[1], 10), o = parseInt(i[2], 10), a !== 1 && Nt(t, "unacceptable YAML version of the document"), t.version = r[0], t.checkLineBreaks = o < 2, o !== 1 && o !== 2 && n_(t, "unsupported YAML version of the document");
  },
  TAG: function(t, n, r) {
    var i, a;
    r.length !== 2 && Nt(t, "TAG directive accepts exactly two arguments"), i = r[0], a = r[1], a6.test(i) || Nt(t, "ill-formed tag handle (first argument) of the TAG directive"), Ul.call(t.tagMap, i) && Nt(t, 'there is a previously declared suffix for "' + i + '" tag handle'), o6.test(a) || Nt(t, "ill-formed tag prefix (second argument) of the TAG directive");
    try {
      a = decodeURIComponent(a);
    } catch {
      Nt(t, "tag prefix is malformed: " + a);
    }
    t.tagMap[i] = a;
  }
};
function kl(e, t, n, r) {
  var i, a, o, s;
  if (t < n) {
    if (s = e.input.slice(t, n), r)
      for (i = 0, a = s.length; i < a; i += 1)
        o = s.charCodeAt(i), o === 9 || 32 <= o && o <= 1114111 || Nt(e, "expected valid JSON character");
    else npe.test(s) && Nt(e, "the stream contains non-printable characters");
    e.result += s;
  }
}
function l2(e, t, n, r) {
  var i, a, o, s;
  for (Hi.isObject(n) || Nt(e, "cannot merge mappings; the provided source object is unacceptable"), i = Object.keys(n), o = 0, s = i.length; o < s; o += 1)
    a = i[o], Ul.call(t, a) || (t[a] = n[a], r[a] = !0);
}
function zc(e, t, n, r, i, a, o, s, l) {
  var u, c;
  if (Array.isArray(i))
    for (i = Array.prototype.slice.call(i), u = 0, c = i.length; u < c; u += 1)
      Array.isArray(i[u]) && Nt(e, "nested arrays are not supported inside keys"), typeof i == "object" && a2(i[u]) === "[object Object]" && (i[u] = "[object Object]");
  if (typeof i == "object" && a2(i) === "[object Object]" && (i = "[object Object]"), i = String(i), t === null && (t = {}), r === "tag:yaml.org,2002:merge")
    if (Array.isArray(a))
      for (u = 0, c = a.length; u < c; u += 1)
        l2(e, t, a[u], n);
    else
      l2(e, t, a, n);
  else
    !e.json && !Ul.call(n, i) && Ul.call(t, i) && (e.line = o || e.line, e.lineStart = s || e.lineStart, e.position = l || e.position, Nt(e, "duplicated mapping key")), i === "__proto__" ? Object.defineProperty(t, i, {
      configurable: !0,
      enumerable: !0,
      writable: !0,
      value: a
    }) : t[i] = a, delete n[i];
  return t;
}
function nA(e) {
  var t;
  t = e.input.charCodeAt(e.position), t === 10 ? e.position++ : t === 13 ? (e.position++, e.input.charCodeAt(e.position) === 10 && e.position++) : Nt(e, "a line break is expected"), e.line += 1, e.lineStart = e.position, e.firstTabInLine = -1;
}
function Qr(e, t, n) {
  for (var r = 0, i = e.input.charCodeAt(e.position); i !== 0; ) {
    for (; Pu(i); )
      i === 9 && e.firstTabInLine === -1 && (e.firstTabInLine = e.position), i = e.input.charCodeAt(++e.position);
    if (t && i === 35)
      do
        i = e.input.charCodeAt(++e.position);
      while (i !== 10 && i !== 13 && i !== 0);
    if (Yo(i))
      for (nA(e), i = e.input.charCodeAt(e.position), r++, e.lineIndent = 0; i === 32; )
        e.lineIndent++, i = e.input.charCodeAt(++e.position);
    else
      break;
  }
  return n !== -1 && r !== 0 && e.lineIndent < n && n_(e, "deficient indentation"), r;
}
function ov(e) {
  var t = e.position, n;
  return n = e.input.charCodeAt(t), !!((n === 45 || n === 46) && n === e.input.charCodeAt(t + 1) && n === e.input.charCodeAt(t + 2) && (t += 3, n = e.input.charCodeAt(t), n === 0 || ua(n)));
}
function rA(e, t) {
  t === 1 ? e.result += " " : t > 1 && (e.result += Hi.repeat(`
`, t - 1));
}
function cpe(e, t, n) {
  var r, i, a, o, s, l, u, c, d = e.kind, f = e.result, h;
  if (h = e.input.charCodeAt(e.position), ua(h) || Hc(h) || h === 35 || h === 38 || h === 42 || h === 33 || h === 124 || h === 62 || h === 39 || h === 34 || h === 37 || h === 64 || h === 96 || (h === 63 || h === 45) && (i = e.input.charCodeAt(e.position + 1), ua(i) || n && Hc(i)))
    return !1;
  for (e.kind = "scalar", e.result = "", a = o = e.position, s = !1; h !== 0; ) {
    if (h === 58) {
      if (i = e.input.charCodeAt(e.position + 1), ua(i) || n && Hc(i))
        break;
    } else if (h === 35) {
      if (r = e.input.charCodeAt(e.position - 1), ua(r))
        break;
    } else {
      if (e.position === e.lineStart && ov(e) || n && Hc(h))
        break;
      if (Yo(h))
        if (l = e.line, u = e.lineStart, c = e.lineIndent, Qr(e, !1, -1), e.lineIndent >= t) {
          s = !0, h = e.input.charCodeAt(e.position);
          continue;
        } else {
          e.position = o, e.line = l, e.lineStart = u, e.lineIndent = c;
          break;
        }
    }
    s && (kl(e, a, o, !1), rA(e, e.line - l), a = o = e.position, s = !1), Pu(h) || (o = e.position + 1), h = e.input.charCodeAt(++e.position);
  }
  return kl(e, a, o, !1), e.result ? !0 : (e.kind = d, e.result = f, !1);
}
function dpe(e, t) {
  var n, r, i;
  if (n = e.input.charCodeAt(e.position), n !== 39)
    return !1;
  for (e.kind = "scalar", e.result = "", e.position++, r = i = e.position; (n = e.input.charCodeAt(e.position)) !== 0; )
    if (n === 39)
      if (kl(e, r, e.position, !0), n = e.input.charCodeAt(++e.position), n === 39)
        r = e.position, e.position++, i = e.position;
      else
        return !0;
    else Yo(n) ? (kl(e, r, i, !0), rA(e, Qr(e, !1, t)), r = i = e.position) : e.position === e.lineStart && ov(e) ? Nt(e, "unexpected end of the document within a single quoted scalar") : (e.position++, i = e.position);
  Nt(e, "unexpected end of the stream within a single quoted scalar");
}
function fpe(e, t) {
  var n, r, i, a, o, s;
  if (s = e.input.charCodeAt(e.position), s !== 34)
    return !1;
  for (e.kind = "scalar", e.result = "", e.position++, n = r = e.position; (s = e.input.charCodeAt(e.position)) !== 0; ) {
    if (s === 34)
      return kl(e, n, e.position, !0), e.position++, !0;
    if (s === 92) {
      if (kl(e, n, e.position, !0), s = e.input.charCodeAt(++e.position), Yo(s))
        Qr(e, !1, t);
      else if (s < 256 && s6[s])
        e.result += l6[s], e.position++;
      else if ((o = ope(s)) > 0) {
        for (i = o, a = 0; i > 0; i--)
          s = e.input.charCodeAt(++e.position), (o = ape(s)) >= 0 ? a = (a << 4) + o : Nt(e, "expected hexadecimal character");
        e.result += lpe(a), e.position++;
      } else
        Nt(e, "unknown escape sequence");
      n = r = e.position;
    } else Yo(s) ? (kl(e, n, r, !0), rA(e, Qr(e, !1, t)), n = r = e.position) : e.position === e.lineStart && ov(e) ? Nt(e, "unexpected end of the document within a double quoted scalar") : (e.position++, r = e.position);
  }
  Nt(e, "unexpected end of the stream within a double quoted scalar");
}
function ppe(e, t) {
  var n = !0, r, i, a, o = e.tag, s, l = e.anchor, u, c, d, f, h, m = /* @__PURE__ */ Object.create(null), v, b, y, g;
  if (g = e.input.charCodeAt(e.position), g === 91)
    c = 93, h = !1, s = [];
  else if (g === 123)
    c = 125, h = !0, s = {};
  else
    return !1;
  for (e.anchor !== null && (e.anchorMap[e.anchor] = s), g = e.input.charCodeAt(++e.position); g !== 0; ) {
    if (Qr(e, !0, t), g = e.input.charCodeAt(e.position), g === c)
      return e.position++, e.tag = o, e.anchor = l, e.kind = h ? "mapping" : "sequence", e.result = s, !0;
    n ? g === 44 && Nt(e, "expected the node content, but found ','") : Nt(e, "missed comma between flow collection entries"), b = v = y = null, d = f = !1, g === 63 && (u = e.input.charCodeAt(e.position + 1), ua(u) && (d = f = !0, e.position++, Qr(e, !0, t))), r = e.line, i = e.lineStart, a = e.position, gd(e, t, e_, !1, !0), b = e.tag, v = e.result, Qr(e, !0, t), g = e.input.charCodeAt(e.position), (f || e.line === r) && g === 58 && (d = !0, g = e.input.charCodeAt(++e.position), Qr(e, !0, t), gd(e, t, e_, !1, !0), y = e.result), h ? zc(e, s, m, b, v, y, r, i, a) : d ? s.push(zc(e, null, m, b, v, y, r, i, a)) : s.push(v), Qr(e, !0, t), g = e.input.charCodeAt(e.position), g === 44 ? (n = !0, g = e.input.charCodeAt(++e.position)) : n = !1;
  }
  Nt(e, "unexpected end of the stream within a flow collection");
}
function mpe(e, t) {
  var n, r, i = sT, a = !1, o = !1, s = t, l = 0, u = !1, c, d;
  if (d = e.input.charCodeAt(e.position), d === 124)
    r = !1;
  else if (d === 62)
    r = !0;
  else
    return !1;
  for (e.kind = "scalar", e.result = ""; d !== 0; )
    if (d = e.input.charCodeAt(++e.position), d === 43 || d === 45)
      sT === i ? i = d === 43 ? i2 : tpe : Nt(e, "repeat of a chomping mode identifier");
    else if ((c = spe(d)) >= 0)
      c === 0 ? Nt(e, "bad explicit indentation width of a block scalar; it cannot be less than one") : o ? Nt(e, "repeat of an indentation width identifier") : (s = t + c - 1, o = !0);
    else
      break;
  if (Pu(d)) {
    do
      d = e.input.charCodeAt(++e.position);
    while (Pu(d));
    if (d === 35)
      do
        d = e.input.charCodeAt(++e.position);
      while (!Yo(d) && d !== 0);
  }
  for (; d !== 0; ) {
    for (nA(e), e.lineIndent = 0, d = e.input.charCodeAt(e.position); (!o || e.lineIndent < s) && d === 32; )
      e.lineIndent++, d = e.input.charCodeAt(++e.position);
    if (!o && e.lineIndent > s && (s = e.lineIndent), Yo(d)) {
      l++;
      continue;
    }
    if (e.lineIndent < s) {
      i === i2 ? e.result += Hi.repeat(`
`, a ? 1 + l : l) : i === sT && a && (e.result += `
`);
      break;
    }
    for (r ? Pu(d) ? (u = !0, e.result += Hi.repeat(`
`, a ? 1 + l : l)) : u ? (u = !1, e.result += Hi.repeat(`
`, l + 1)) : l === 0 ? a && (e.result += " ") : e.result += Hi.repeat(`
`, l) : e.result += Hi.repeat(`
`, a ? 1 + l : l), a = !0, o = !0, l = 0, n = e.position; !Yo(d) && d !== 0; )
      d = e.input.charCodeAt(++e.position);
    kl(e, n, e.position, !1);
  }
  return !0;
}
function u2(e, t) {
  var n, r = e.tag, i = e.anchor, a = [], o, s = !1, l;
  if (e.firstTabInLine !== -1)
    return !1;
  for (e.anchor !== null && (e.anchorMap[e.anchor] = a), l = e.input.charCodeAt(e.position); l !== 0 && (e.firstTabInLine !== -1 && (e.position = e.firstTabInLine, Nt(e, "tab characters must not be used in indentation")), !(l !== 45 || (o = e.input.charCodeAt(e.position + 1), !ua(o)))); ) {
    if (s = !0, e.position++, Qr(e, !0, -1) && e.lineIndent <= t) {
      a.push(null), l = e.input.charCodeAt(e.position);
      continue;
    }
    if (n = e.line, gd(e, t, i6, !1, !0), a.push(e.result), Qr(e, !0, -1), l = e.input.charCodeAt(e.position), (e.line === n || e.lineIndent > t) && l !== 0)
      Nt(e, "bad indentation of a sequence entry");
    else if (e.lineIndent < t)
      break;
  }
  return s ? (e.tag = r, e.anchor = i, e.kind = "sequence", e.result = a, !0) : !1;
}
function hpe(e, t, n) {
  var r, i, a, o, s, l, u = e.tag, c = e.anchor, d = {}, f = /* @__PURE__ */ Object.create(null), h = null, m = null, v = null, b = !1, y = !1, g;
  if (e.firstTabInLine !== -1)
    return !1;
  for (e.anchor !== null && (e.anchorMap[e.anchor] = d), g = e.input.charCodeAt(e.position); g !== 0; ) {
    if (!b && e.firstTabInLine !== -1 && (e.position = e.firstTabInLine, Nt(e, "tab characters must not be used in indentation")), r = e.input.charCodeAt(e.position + 1), a = e.line, (g === 63 || g === 58) && ua(r))
      g === 63 ? (b && (zc(e, d, f, h, m, null, o, s, l), h = m = v = null), y = !0, b = !0, i = !0) : b ? (b = !1, i = !0) : Nt(e, "incomplete explicit mapping pair; a key node is missed; or followed by a non-tabulated empty line"), e.position += 1, g = r;
    else {
      if (o = e.line, s = e.lineStart, l = e.position, !gd(e, n, r6, !1, !0))
        break;
      if (e.line === a) {
        for (g = e.input.charCodeAt(e.position); Pu(g); )
          g = e.input.charCodeAt(++e.position);
        if (g === 58)
          g = e.input.charCodeAt(++e.position), ua(g) || Nt(e, "a whitespace character is expected after the key-value separator within a block mapping"), b && (zc(e, d, f, h, m, null, o, s, l), h = m = v = null), y = !0, b = !1, i = !1, h = e.tag, m = e.result;
        else if (y)
          Nt(e, "can not read an implicit mapping pair; a colon is missed");
        else
          return e.tag = u, e.anchor = c, !0;
      } else if (y)
        Nt(e, "can not read a block mapping entry; a multiline key may not be an implicit key");
      else
        return e.tag = u, e.anchor = c, !0;
    }
    if ((e.line === a || e.lineIndent > t) && (b && (o = e.line, s = e.lineStart, l = e.position), gd(e, t, t_, !0, i) && (b ? m = e.result : v = e.result), b || (zc(e, d, f, h, m, v, o, s, l), h = m = v = null), Qr(e, !0, -1), g = e.input.charCodeAt(e.position)), (e.line === a || e.lineIndent > t) && g !== 0)
      Nt(e, "bad indentation of a mapping entry");
    else if (e.lineIndent < t)
      break;
  }
  return b && zc(e, d, f, h, m, null, o, s, l), y && (e.tag = u, e.anchor = c, e.kind = "mapping", e.result = d), y;
}
function gpe(e) {
  var t, n = !1, r = !1, i, a, o;
  if (o = e.input.charCodeAt(e.position), o !== 33)
    return !1;
  if (e.tag !== null && Nt(e, "duplication of a tag property"), o = e.input.charCodeAt(++e.position), o === 60 ? (n = !0, o = e.input.charCodeAt(++e.position)) : o === 33 ? (r = !0, i = "!!", o = e.input.charCodeAt(++e.position)) : i = "!", t = e.position, n) {
    do
      o = e.input.charCodeAt(++e.position);
    while (o !== 0 && o !== 62);
    e.position < e.length ? (a = e.input.slice(t, e.position), o = e.input.charCodeAt(++e.position)) : Nt(e, "unexpected end of the stream within a verbatim tag");
  } else {
    for (; o !== 0 && !ua(o); )
      o === 33 && (r ? Nt(e, "tag suffix cannot contain exclamation marks") : (i = e.input.slice(t - 1, e.position + 1), a6.test(i) || Nt(e, "named tag handle cannot contain such characters"), r = !0, t = e.position + 1)), o = e.input.charCodeAt(++e.position);
    a = e.input.slice(t, e.position), ipe.test(a) && Nt(e, "tag suffix cannot contain flow indicator characters");
  }
  a && !o6.test(a) && Nt(e, "tag name cannot contain such characters: " + a);
  try {
    a = decodeURIComponent(a);
  } catch {
    Nt(e, "tag name is malformed: " + a);
  }
  return n ? e.tag = a : Ul.call(e.tagMap, i) ? e.tag = e.tagMap[i] + a : i === "!" ? e.tag = "!" + a : i === "!!" ? e.tag = "tag:yaml.org,2002:" + a : Nt(e, 'undeclared tag handle "' + i + '"'), !0;
}
function _pe(e) {
  var t, n;
  if (n = e.input.charCodeAt(e.position), n !== 38)
    return !1;
  for (e.anchor !== null && Nt(e, "duplication of an anchor property"), n = e.input.charCodeAt(++e.position), t = e.position; n !== 0 && !ua(n) && !Hc(n); )
    n = e.input.charCodeAt(++e.position);
  return e.position === t && Nt(e, "name of an anchor node must contain at least one character"), e.anchor = e.input.slice(t, e.position), !0;
}
function vpe(e) {
  var t, n, r;
  if (r = e.input.charCodeAt(e.position), r !== 42)
    return !1;
  for (r = e.input.charCodeAt(++e.position), t = e.position; r !== 0 && !ua(r) && !Hc(r); )
    r = e.input.charCodeAt(++e.position);
  return e.position === t && Nt(e, "name of an alias node must contain at least one character"), n = e.input.slice(t, e.position), Ul.call(e.anchorMap, n) || Nt(e, 'unidentified alias "' + n + '"'), e.result = e.anchorMap[n], Qr(e, !0, -1), !0;
}
function gd(e, t, n, r, i) {
  var a, o, s, l = 1, u = !1, c = !1, d, f, h, m, v, b;
  if (e.listener !== null && e.listener("open", e), e.tag = null, e.anchor = null, e.kind = null, e.result = null, a = o = s = t_ === n || i6 === n, r && Qr(e, !0, -1) && (u = !0, e.lineIndent > t ? l = 1 : e.lineIndent === t ? l = 0 : e.lineIndent < t && (l = -1)), l === 1)
    for (; gpe(e) || _pe(e); )
      Qr(e, !0, -1) ? (u = !0, s = a, e.lineIndent > t ? l = 1 : e.lineIndent === t ? l = 0 : e.lineIndent < t && (l = -1)) : s = !1;
  if (s && (s = u || i), (l === 1 || t_ === n) && (e_ === n || r6 === n ? v = t : v = t + 1, b = e.position - e.lineStart, l === 1 ? s && (u2(e, b) || hpe(e, b, v)) || ppe(e, v) ? c = !0 : (o && mpe(e, v) || dpe(e, v) || fpe(e, v) ? c = !0 : vpe(e) ? (c = !0, (e.tag !== null || e.anchor !== null) && Nt(e, "alias node should not have any properties")) : cpe(e, v, e_ === n) && (c = !0, e.tag === null && (e.tag = "?")), e.anchor !== null && (e.anchorMap[e.anchor] = e.result)) : l === 0 && (c = s && u2(e, b))), e.tag === null)
    e.anchor !== null && (e.anchorMap[e.anchor] = e.result);
  else if (e.tag === "?") {
    for (e.result !== null && e.kind !== "scalar" && Nt(e, 'unacceptable node kind for !<?> tag; it should be "scalar", not "' + e.kind + '"'), d = 0, f = e.implicitTypes.length; d < f; d += 1)
      if (m = e.implicitTypes[d], m.resolve(e.result)) {
        e.result = m.construct(e.result), e.tag = m.tag, e.anchor !== null && (e.anchorMap[e.anchor] = e.result);
        break;
      }
  } else if (e.tag !== "!") {
    if (Ul.call(e.typeMap[e.kind || "fallback"], e.tag))
      m = e.typeMap[e.kind || "fallback"][e.tag];
    else
      for (m = null, h = e.typeMap.multi[e.kind || "fallback"], d = 0, f = h.length; d < f; d += 1)
        if (e.tag.slice(0, h[d].tag.length) === h[d].tag) {
          m = h[d];
          break;
        }
    m || Nt(e, "unknown tag !<" + e.tag + ">"), e.result !== null && m.kind !== e.kind && Nt(e, "unacceptable node kind for !<" + e.tag + '> tag; it should be "' + m.kind + '", not "' + e.kind + '"'), m.resolve(e.result, e.tag) ? (e.result = m.construct(e.result, e.tag), e.anchor !== null && (e.anchorMap[e.anchor] = e.result)) : Nt(e, "cannot resolve a node with !<" + e.tag + "> explicit tag");
  }
  return e.listener !== null && e.listener("close", e), e.tag !== null || e.anchor !== null || c;
}
function bpe(e) {
  var t = e.position, n, r, i, a = !1, o;
  for (e.version = null, e.checkLineBreaks = e.legacy, e.tagMap = /* @__PURE__ */ Object.create(null), e.anchorMap = /* @__PURE__ */ Object.create(null); (o = e.input.charCodeAt(e.position)) !== 0 && (Qr(e, !0, -1), o = e.input.charCodeAt(e.position), !(e.lineIndent > 0 || o !== 37)); ) {
    for (a = !0, o = e.input.charCodeAt(++e.position), n = e.position; o !== 0 && !ua(o); )
      o = e.input.charCodeAt(++e.position);
    for (r = e.input.slice(n, e.position), i = [], r.length < 1 && Nt(e, "directive name must not be less than one character in length"); o !== 0; ) {
      for (; Pu(o); )
        o = e.input.charCodeAt(++e.position);
      if (o === 35) {
        do
          o = e.input.charCodeAt(++e.position);
        while (o !== 0 && !Yo(o));
        break;
      }
      if (Yo(o))
        break;
      for (n = e.position; o !== 0 && !ua(o); )
        o = e.input.charCodeAt(++e.position);
      i.push(e.input.slice(n, e.position));
    }
    o !== 0 && nA(e), Ul.call(s2, r) ? s2[r](e, r, i) : n_(e, 'unknown document directive "' + r + '"');
  }
  if (Qr(e, !0, -1), e.lineIndent === 0 && e.input.charCodeAt(e.position) === 45 && e.input.charCodeAt(e.position + 1) === 45 && e.input.charCodeAt(e.position + 2) === 45 ? (e.position += 3, Qr(e, !0, -1)) : a && Nt(e, "directives end mark is expected"), gd(e, e.lineIndent - 1, t_, !1, !0), Qr(e, !0, -1), e.checkLineBreaks && rpe.test(e.input.slice(t, e.position)) && n_(e, "non-ASCII line breaks are interpreted as content"), e.documents.push(e.result), e.position === e.lineStart && ov(e)) {
    e.input.charCodeAt(e.position) === 46 && (e.position += 3, Qr(e, !0, -1));
    return;
  }
  if (e.position < e.length - 1)
    Nt(e, "end of the stream or a document separator is expected");
  else
    return;
}
function c6(e, t) {
  e = String(e), t = t || {}, e.length !== 0 && (e.charCodeAt(e.length - 1) !== 10 && e.charCodeAt(e.length - 1) !== 13 && (e += `
`), e.charCodeAt(0) === 65279 && (e = e.slice(1)));
  var n = new upe(e, t), r = e.indexOf("\0");
  for (r !== -1 && (n.position = r, Nt(n, "null byte is not allowed in input")), n.input += "\0"; n.input.charCodeAt(n.position) === 32; )
    n.lineIndent += 1, n.position += 1;
  for (; n.position < n.length - 1; )
    bpe(n);
  return n.documents;
}
function Epe(e, t, n) {
  t !== null && typeof t == "object" && typeof n > "u" && (n = t, t = null);
  var r = c6(e, n);
  if (typeof t != "function")
    return r;
  for (var i = 0, a = r.length; i < a; i += 1)
    t(r[i]);
}
function Spe(e, t) {
  var n = c6(e, t);
  if (n.length !== 0) {
    if (n.length === 1)
      return n[0];
    throw new Ns("expected a single document in the stream, but found more");
  }
}
var ype = Epe, Tpe = Spe, Cpe = {
  loadAll: ype,
  load: Tpe
}, Ape = e6, Ope = Cpe.load;
function Rpe(e) {
  const t = e.match(mB);
  if (!t)
    return {
      text: e,
      metadata: {}
    };
  let n = Ope(t[1], {
    // To support config, we need JSON schema.
    // https://www.yaml.org/spec/1.2/spec.html#id2803231
    schema: Ape
  }) ?? {};
  n = typeof n == "object" && !Array.isArray(n) ? n : {};
  const r = {};
  return n.displayMode && (r.displayMode = n.displayMode.toString()), n.title && (r.title = n.title.toString()), n.config && (r.config = n.config), {
    text: e.slice(t[0].length),
    metadata: r
  };
}
const wpe = (e) => e.replace(/\r\n?/g, `
`).replace(
  /<(\w+)([^>]*)>/g,
  (t, n, r) => "<" + n + r.replace(/="([^"]*)"/g, "='$1'") + ">"
), xpe = (e) => {
  const { text: t, metadata: n } = Rpe(e), { displayMode: r, title: i, config: a = {} } = n;
  return r && (a.gantt || (a.gantt = {}), a.gantt.displayMode = r), { title: i, config: a, text: t };
}, Npe = (e) => {
  const t = Jf.detectInit(e) ?? {}, n = Jf.detectDirective(e, "wrap");
  return Array.isArray(n) ? t.wrap = n.some(({ type: r }) => {
  }) : (n == null ? void 0 : n.type) === "wrap" && (t.wrap = !0), {
    text: eue(e),
    directive: t
  };
};
function d6(e) {
  const t = wpe(e), n = xpe(t), r = Npe(n.text), i = SB(n.config, r.directive);
  return e = Fde(r.text), {
    code: e,
    title: n.title,
    config: i
  };
}
const Dpe = 5e4, Ipe = "graph TB;a[Maximum text size in diagram exceeded];style a fill:#faa", Lpe = "sandbox", kpe = "loose", Mpe = "http://www.w3.org/2000/svg", Ppe = "http://www.w3.org/1999/xlink", Fpe = "http://www.w3.org/1999/xhtml", Bpe = "100%", $pe = "100%", Upe = "border:0;margin:0;", qpe = "margin:0", Gpe = "allow-top-navigation-by-user-activation allow-popups", Ype = 'The "iframe" tag is not supported by your browser.', Hpe = ["foreignobject"], zpe = ["dominant-baseline"];
function f6(e) {
  const t = d6(e);
  return Xg(), Oue(t.config ?? {}), t;
}
async function Vpe(e, t) {
  eA(), e = f6(e).code;
  try {
    await iA(e);
  } catch (n) {
    if (t != null && t.suppressErrors)
      return !1;
    throw n;
  }
  return !0;
}
const c2 = (e, t, n = []) => `
.${e} ${t} { ${n.join(" !important; ")} !important; }`, Wpe = (e, t = {}) => {
  var n;
  let r = "";
  if (e.themeCSS !== void 0 && (r += `
${e.themeCSS}`), e.fontFamily !== void 0 && (r += `
:root { --mermaid-font-family: ${e.fontFamily}}`), e.altFontFamily !== void 0 && (r += `
:root { --mermaid-alt-font-family: ${e.altFontFamily}}`), !iT(t)) {
    const s = e.htmlLabels || ((n = e.flowchart) == null ? void 0 : n.htmlLabels) ? ["> *", "span"] : ["rect", "polygon", "ellipse", "circle", "path"];
    for (const l in t) {
      const u = t[l];
      iT(u.styles) || s.forEach((c) => {
        r += c2(u.id, c, u.styles);
      }), iT(u.textStyles) || (r += c2(u.id, "tspan", u.textStyles));
    }
  }
  return r;
}, Kpe = (e, t, n, r) => {
  const i = Wpe(e, n), a = Vce(t, i, e.themeVariables);
  return hC(ole(`${r}{${a}}`), lle);
}, jpe = (e = "", t, n) => {
  let r = e;
  return !n && !t && (r = r.replace(
    /marker-end="url\([\d+./:=?A-Za-z-]*?#/g,
    'marker-end="url(#'
  )), r = yue(r), r = r.replace(/<br>/g, "<br/>"), r;
}, Qpe = (e = "", t) => {
  var n, r;
  const i = (r = (n = t == null ? void 0 : t.viewBox) == null ? void 0 : n.baseVal) != null && r.height ? t.viewBox.baseVal.height + "px" : $pe, a = btoa('<body style="' + qpe + '">' + e + "</body>");
  return `<iframe style="width:${Bpe};height:${i};${Upe}" src="data:text/html;base64,${a}" sandbox="${Gpe}">
  ${Ype}
</iframe>`;
}, d2 = (e, t, n, r, i) => {
  const a = e.append("div");
  a.attr("id", n), r && a.attr("style", r);
  const o = a.append("svg").attr("id", t).attr("width", "100%").attr("xmlns", Mpe);
  return i && o.attr("xmlns:xlink", i), o.append("g"), e;
};
function f2(e, t) {
  return e.append("iframe").attr("id", t).attr("style", "width: 100%; height: 100%;").attr("sandbox", "");
}
const Xpe = (e, t, n, r) => {
  var i, a, o;
  (i = e.getElementById(t)) == null || i.remove(), (a = e.getElementById(n)) == null || a.remove(), (o = e.getElementById(r)) == null || o.remove();
}, Zpe = async function(e, t, n) {
  var r, i, a, o, s, l;
  eA();
  const u = f6(t);
  t = u.code;
  const c = jo();
  Ft.debug(c), t.length > ((c == null ? void 0 : c.maxTextSize) ?? Dpe) && (t = Ipe);
  const d = "#" + e, f = "i" + e, h = "#" + f, m = "d" + e, v = "#" + m;
  let b = ja("body");
  const y = c.securityLevel === Lpe, g = c.securityLevel === kpe, E = c.fontFamily;
  if (n !== void 0) {
    if (n && (n.innerHTML = ""), y) {
      const W = f2(ja(n), f);
      b = ja(W.nodes()[0].contentDocument.body), b.node().style.margin = 0;
    } else
      b = ja(n);
    d2(b, e, m, `font-family: ${E}`, Ppe);
  } else {
    if (Xpe(document, e, m, f), y) {
      const W = f2(ja("body"), f);
      b = ja(W.nodes()[0].contentDocument.body), b.node().style.margin = 0;
    } else
      b = ja("body");
    d2(b, e, m);
  }
  let S, C;
  try {
    S = await iA(t, { title: u.title });
  } catch (W) {
    S = new XB("error"), C = W;
  }
  const T = b.select(v).node(), O = S.type, R = T.firstChild, D = R.firstChild, q = (i = (r = S.renderer).getClasses) == null ? void 0 : i.call(r, t, S), $ = Kpe(c, O, q, d), P = document.createElement("style");
  P.innerHTML = $, R.insertBefore(P, D);
  try {
    await S.renderer.draw(t, e, Jk, S);
  } catch (W) {
    throw ude.draw(t, e, Jk), W;
  }
  const Y = b.select(`${v} svg`), L = (o = (a = S.db).getAccTitle) == null ? void 0 : o.call(a), x = (l = (s = S.db).getAccDescription) == null ? void 0 : l.call(s);
  eme(O, Y, L, x), b.select(`[id="${e}"]`).selectAll("foreignobject > *").attr("xmlns", Fpe);
  let I = b.select(v).node().innerHTML;
  if (Ft.debug("config.arrowMarkerAbsolute", c.arrowMarkerAbsolute), I = jpe(I, y, dB(c.arrowMarkerAbsolute)), y) {
    const W = b.select(v + " svg").node();
    I = Qpe(I, W);
  } else g || (I = dd.sanitize(I, {
    ADD_TAGS: Hpe,
    ADD_ATTR: zpe
  }));
  if (Lde(), C)
    throw C;
  const B = ja(y ? h : v).node();
  return B && "remove" in B && B.remove(), {
    svg: I,
    bindFunctions: S.db.bindFunctions
  };
};
function Jpe(e = {}) {
  var t;
  e != null && e.fontFamily && !((t = e.themeVariables) != null && t.fontFamily) && (e.themeVariables || (e.themeVariables = {}), e.themeVariables.fontFamily = e.fontFamily), Cue(e), e != null && e.theme && e.theme in Ms ? e.themeVariables = Ms[e.theme].getThemeVariables(
    e.themeVariables
  ) : e && (e.themeVariables = Ms.default.getThemeVariables(e.themeVariables));
  const n = typeof e == "object" ? Tue(e) : TB();
  Y1(n.logLevel), eA();
}
const iA = (e, t = {}) => {
  const { code: n } = d6(e);
  return Ide(n, t);
};
function eme(e, t, n, r) {
  Mde(t, e), Pde(t, n, r, t.attr("id"));
}
const zu = Object.freeze({
  render: Zpe,
  parse: Vpe,
  getDiagramFromText: iA,
  initialize: Jpe,
  getConfig: jo,
  setConfig: CB,
  getSiteConfig: TB,
  updateSiteConfig: Aue,
  reset: () => {
    Xg();
  },
  globalReset: () => {
    Xg(md);
  },
  defaultConfig: md
});
Y1(jo().logLevel);
Xg(jo());
const tme = async () => {
  Ft.debug("Loading registered diagrams");
  const t = (await Promise.allSettled(
    Object.entries(pd).map(async ([n, { detector: r, loader: i }]) => {
      if (i)
        try {
          J1(n);
        } catch {
          try {
            const { diagram: o, id: s } = await i();
            Jg(s, o, r);
          } catch (o) {
            throw Ft.error(`Failed to load external diagram with key ${n}. Removing from detectors.`), delete pd[n], o;
          }
        }
    })
  )).filter((n) => n.status === "rejected");
  if (t.length > 0) {
    Ft.error(`Failed to load ${t.length} external diagrams`);
    for (const n of t)
      Ft.error(n);
    throw new Error(`Failed to load ${t.length} external diagrams`);
  }
}, nme = (e, t, n) => {
  Ft.warn(e), EB(e) ? (n && n(e.str, e.hash), t.push({ ...e, message: e.str, error: e })) : (n && n(e), e instanceof Error && t.push({
    str: e.message,
    message: e.message,
    hash: e.name,
    error: e
  }));
}, p6 = async function(e = {
  querySelector: ".mermaid"
}) {
  try {
    await rme(e);
  } catch (t) {
    if (EB(t) && Ft.error(t.str), Ia.parseError && Ia.parseError(t), !e.suppressErrors)
      throw Ft.error("Use the suppressErrors option to suppress these errors"), t;
  }
}, rme = async function({ postRenderCallback: e, querySelector: t, nodes: n } = {
  querySelector: ".mermaid"
}) {
  const r = zu.getConfig();
  Ft.debug(`${e ? "" : "No "}Callback function found`);
  let i;
  if (n)
    i = n;
  else if (t)
    i = document.querySelectorAll(t);
  else
    throw new Error("Nodes and querySelector are both undefined");
  Ft.debug(`Found ${i.length} diagrams`), (r == null ? void 0 : r.startOnLoad) !== void 0 && (Ft.debug("Start On Load: " + (r == null ? void 0 : r.startOnLoad)), zu.updateSiteConfig({ startOnLoad: r == null ? void 0 : r.startOnLoad }));
  const a = new Jf.InitIDGenerator(r.deterministicIds, r.deterministicIDSeed);
  let o;
  const s = [];
  for (const l of Array.from(i)) {
    Ft.info("Rendering diagram: " + l.id);
    /*! Check if previously processed */
    if (l.getAttribute("data-processed"))
      continue;
    l.setAttribute("data-processed", "true");
    const u = `mermaid-${a.next()}`;
    o = l.innerHTML, o = cte(Jf.entityDecode(o)).trim().replace(/<br\s*\/?>/gi, "<br/>");
    const c = Jf.detectInit(o);
    c && Ft.debug("Detected early reinit: ", c);
    try {
      const { svg: d, bindFunctions: f } = await _6(u, o, l);
      l.innerHTML = d, e && await e(u), f && f(l);
    } catch (d) {
      nme(d, s, Ia.parseError);
    }
  }
  if (s.length > 0)
    throw s[0];
}, m6 = function(e) {
  zu.initialize(e);
}, ime = async function(e, t, n) {
  Ft.warn("mermaid.init is deprecated. Please use run instead."), e && m6(e);
  const r = { postRenderCallback: n, querySelector: ".mermaid" };
  typeof t == "string" ? r.querySelector = t : t && (t instanceof HTMLElement ? r.nodes = [t] : r.nodes = t), await p6(r);
}, ame = async (e, {
  lazyLoad: t = !0
} = {}) => {
  gB(...e), t === !1 && await tme();
}, h6 = function() {
  if (Ia.startOnLoad) {
    const { startOnLoad: e } = zu.getConfig();
    e && Ia.run().catch((t) => Ft.error("Mermaid failed to initialize", t));
  }
};
if (typeof document < "u") {
  /*!
   * Wait for document loaded before starting the execution
   */
  window.addEventListener("load", h6, !1);
}
const ome = function(e) {
  Ia.parseError = e;
}, r_ = [];
let lT = !1;
const g6 = async () => {
  if (!lT) {
    for (lT = !0; r_.length > 0; ) {
      const e = r_.shift();
      if (e)
        try {
          await e();
        } catch (t) {
          Ft.error("Error executing queue", t);
        }
    }
    lT = !1;
  }
}, sme = async (e, t) => new Promise((n, r) => {
  const i = () => new Promise((a, o) => {
    zu.parse(e, t).then(
      (s) => {
        a(s), n(s);
      },
      (s) => {
        var l;
        Ft.error("Error parsing", s), (l = Ia.parseError) == null || l.call(Ia, s), o(s), r(s);
      }
    );
  });
  r_.push(i), g6().catch(r);
}), _6 = (e, t, n) => new Promise((r, i) => {
  const a = () => new Promise((o, s) => {
    zu.render(e, t, n).then(
      (l) => {
        o(l), r(l);
      },
      (l) => {
        var u;
        Ft.error("Error parsing", l), (u = Ia.parseError) == null || u.call(Ia, l), s(l), i(l);
      }
    );
  });
  r_.push(a), g6().catch(i);
}), Ia = {
  startOnLoad: !0,
  mermaidAPI: zu,
  parse: sme,
  render: _6,
  init: ime,
  run: p6,
  registerExternalDiagrams: ame,
  initialize: m6,
  parseError: void 0,
  contentLoaded: h6,
  setParseErrorHandler: ome,
  detectType: iv
};
function v6(e, t) {
  return function() {
    return e.apply(t, arguments);
  };
}
const { toString: lme } = Object.prototype, { getPrototypeOf: aA } = Object, sv = /* @__PURE__ */ ((e) => (t) => {
  const n = lme.call(t);
  return e[n] || (e[n] = n.slice(8, -1).toLowerCase());
})(/* @__PURE__ */ Object.create(null)), Ro = (e) => (e = e.toLowerCase(), (t) => sv(t) === e), lv = (e) => (t) => typeof t === e, { isArray: xd } = Array, Mp = lv("undefined");
function ume(e) {
  return e !== null && !Mp(e) && e.constructor !== null && !Mp(e.constructor) && wa(e.constructor.isBuffer) && e.constructor.isBuffer(e);
}
const b6 = Ro("ArrayBuffer");
function cme(e) {
  let t;
  return typeof ArrayBuffer < "u" && ArrayBuffer.isView ? t = ArrayBuffer.isView(e) : t = e && e.buffer && b6(e.buffer), t;
}
const dme = lv("string"), wa = lv("function"), E6 = lv("number"), uv = (e) => e !== null && typeof e == "object", fme = (e) => e === !0 || e === !1, hg = (e) => {
  if (sv(e) !== "object")
    return !1;
  const t = aA(e);
  return (t === null || t === Object.prototype || Object.getPrototypeOf(t) === null) && !(Symbol.toStringTag in e) && !(Symbol.iterator in e);
}, pme = Ro("Date"), mme = Ro("File"), hme = Ro("Blob"), gme = Ro("FileList"), _me = (e) => uv(e) && wa(e.pipe), vme = (e) => {
  let t;
  return e && (typeof FormData == "function" && e instanceof FormData || wa(e.append) && ((t = sv(e)) === "formdata" || // detect form-data instance
  t === "object" && wa(e.toString) && e.toString() === "[object FormData]"));
}, bme = Ro("URLSearchParams"), [Eme, Sme, yme, Tme] = ["ReadableStream", "Request", "Response", "Headers"].map(Ro), Cme = (e) => e.trim ? e.trim() : e.replace(/^[\s\uFEFF\xA0]+|[\s\uFEFF\xA0]+$/g, "");
function mm(e, t, { allOwnKeys: n = !1 } = {}) {
  if (e === null || typeof e > "u")
    return;
  let r, i;
  if (typeof e != "object" && (e = [e]), xd(e))
    for (r = 0, i = e.length; r < i; r++)
      t.call(null, e[r], r, e);
  else {
    const a = n ? Object.getOwnPropertyNames(e) : Object.keys(e), o = a.length;
    let s;
    for (r = 0; r < o; r++)
      s = a[r], t.call(null, e[s], s, e);
  }
}
function S6(e, t) {
  t = t.toLowerCase();
  const n = Object.keys(e);
  let r = n.length, i;
  for (; r-- > 0; )
    if (i = n[r], t === i.toLowerCase())
      return i;
  return null;
}
const Du = typeof globalThis < "u" ? globalThis : typeof self < "u" ? self : typeof window < "u" ? window : global, y6 = (e) => !Mp(e) && e !== Du;
function TC() {
  const { caseless: e } = y6(this) && this || {}, t = {}, n = (r, i) => {
    const a = e && S6(t, i) || i;
    hg(t[a]) && hg(r) ? t[a] = TC(t[a], r) : hg(r) ? t[a] = TC({}, r) : xd(r) ? t[a] = r.slice() : t[a] = r;
  };
  for (let r = 0, i = arguments.length; r < i; r++)
    arguments[r] && mm(arguments[r], n);
  return t;
}
const Ame = (e, t, n, { allOwnKeys: r } = {}) => (mm(t, (i, a) => {
  n && wa(i) ? e[a] = v6(i, n) : e[a] = i;
}, { allOwnKeys: r }), e), Ome = (e) => (e.charCodeAt(0) === 65279 && (e = e.slice(1)), e), Rme = (e, t, n, r) => {
  e.prototype = Object.create(t.prototype, r), e.prototype.constructor = e, Object.defineProperty(e, "super", {
    value: t.prototype
  }), n && Object.assign(e.prototype, n);
}, wme = (e, t, n, r) => {
  let i, a, o;
  const s = {};
  if (t = t || {}, e == null) return t;
  do {
    for (i = Object.getOwnPropertyNames(e), a = i.length; a-- > 0; )
      o = i[a], (!r || r(o, e, t)) && !s[o] && (t[o] = e[o], s[o] = !0);
    e = n !== !1 && aA(e);
  } while (e && (!n || n(e, t)) && e !== Object.prototype);
  return t;
}, xme = (e, t, n) => {
  e = String(e), (n === void 0 || n > e.length) && (n = e.length), n -= t.length;
  const r = e.indexOf(t, n);
  return r !== -1 && r === n;
}, Nme = (e) => {
  if (!e) return null;
  if (xd(e)) return e;
  let t = e.length;
  if (!E6(t)) return null;
  const n = new Array(t);
  for (; t-- > 0; )
    n[t] = e[t];
  return n;
}, Dme = /* @__PURE__ */ ((e) => (t) => e && t instanceof e)(typeof Uint8Array < "u" && aA(Uint8Array)), Ime = (e, t) => {
  const r = (e && e[Symbol.iterator]).call(e);
  let i;
  for (; (i = r.next()) && !i.done; ) {
    const a = i.value;
    t.call(e, a[0], a[1]);
  }
}, Lme = (e, t) => {
  let n;
  const r = [];
  for (; (n = e.exec(t)) !== null; )
    r.push(n);
  return r;
}, kme = Ro("HTMLFormElement"), Mme = (e) => e.toLowerCase().replace(
  /[-_\s]([a-z\d])(\w*)/g,
  function(n, r, i) {
    return r.toUpperCase() + i;
  }
), p2 = (({ hasOwnProperty: e }) => (t, n) => e.call(t, n))(Object.prototype), Pme = Ro("RegExp"), T6 = (e, t) => {
  const n = Object.getOwnPropertyDescriptors(e), r = {};
  mm(n, (i, a) => {
    let o;
    (o = t(i, a, e)) !== !1 && (r[a] = o || i);
  }), Object.defineProperties(e, r);
}, Fme = (e) => {
  T6(e, (t, n) => {
    if (wa(e) && ["arguments", "caller", "callee"].indexOf(n) !== -1)
      return !1;
    const r = e[n];
    if (wa(r)) {
      if (t.enumerable = !1, "writable" in t) {
        t.writable = !1;
        return;
      }
      t.set || (t.set = () => {
        throw Error("Can not rewrite read-only method '" + n + "'");
      });
    }
  });
}, Bme = (e, t) => {
  const n = {}, r = (i) => {
    i.forEach((a) => {
      n[a] = !0;
    });
  };
  return xd(e) ? r(e) : r(String(e).split(t)), n;
}, $me = () => {
}, Ume = (e, t) => e != null && Number.isFinite(e = +e) ? e : t, uT = "abcdefghijklmnopqrstuvwxyz", m2 = "0123456789", C6 = {
  DIGIT: m2,
  ALPHA: uT,
  ALPHA_DIGIT: uT + uT.toUpperCase() + m2
}, qme = (e = 16, t = C6.ALPHA_DIGIT) => {
  let n = "";
  const { length: r } = t;
  for (; e--; )
    n += t[Math.random() * r | 0];
  return n;
};
function Gme(e) {
  return !!(e && wa(e.append) && e[Symbol.toStringTag] === "FormData" && e[Symbol.iterator]);
}
const Yme = (e) => {
  const t = new Array(10), n = (r, i) => {
    if (uv(r)) {
      if (t.indexOf(r) >= 0)
        return;
      if (!("toJSON" in r)) {
        t[i] = r;
        const a = xd(r) ? [] : {};
        return mm(r, (o, s) => {
          const l = n(o, i + 1);
          !Mp(l) && (a[s] = l);
        }), t[i] = void 0, a;
      }
    }
    return r;
  };
  return n(e, 0);
}, Hme = Ro("AsyncFunction"), zme = (e) => e && (uv(e) || wa(e)) && wa(e.then) && wa(e.catch), A6 = ((e, t) => e ? setImmediate : t ? ((n, r) => (Du.addEventListener("message", ({ source: i, data: a }) => {
  i === Du && a === n && r.length && r.shift()();
}, !1), (i) => {
  r.push(i), Du.postMessage(n, "*");
}))(`axios@${Math.random()}`, []) : (n) => setTimeout(n))(
  typeof setImmediate == "function",
  wa(Du.postMessage)
), Vme = typeof queueMicrotask < "u" ? queueMicrotask.bind(Du) : typeof process < "u" && process.nextTick || A6, Oe = {
  isArray: xd,
  isArrayBuffer: b6,
  isBuffer: ume,
  isFormData: vme,
  isArrayBufferView: cme,
  isString: dme,
  isNumber: E6,
  isBoolean: fme,
  isObject: uv,
  isPlainObject: hg,
  isReadableStream: Eme,
  isRequest: Sme,
  isResponse: yme,
  isHeaders: Tme,
  isUndefined: Mp,
  isDate: pme,
  isFile: mme,
  isBlob: hme,
  isRegExp: Pme,
  isFunction: wa,
  isStream: _me,
  isURLSearchParams: bme,
  isTypedArray: Dme,
  isFileList: gme,
  forEach: mm,
  merge: TC,
  extend: Ame,
  trim: Cme,
  stripBOM: Ome,
  inherits: Rme,
  toFlatObject: wme,
  kindOf: sv,
  kindOfTest: Ro,
  endsWith: xme,
  toArray: Nme,
  forEachEntry: Ime,
  matchAll: Lme,
  isHTMLForm: kme,
  hasOwnProperty: p2,
  hasOwnProp: p2,
  // an alias to avoid ESLint no-prototype-builtins detection
  reduceDescriptors: T6,
  freezeMethods: Fme,
  toObjectSet: Bme,
  toCamelCase: Mme,
  noop: $me,
  toFiniteNumber: Ume,
  findKey: S6,
  global: Du,
  isContextDefined: y6,
  ALPHABET: C6,
  generateString: qme,
  isSpecCompliantForm: Gme,
  toJSONObject: Yme,
  isAsyncFn: Hme,
  isThenable: zme,
  setImmediate: A6,
  asap: Vme
};
function ln(e, t, n, r, i) {
  Error.call(this), Error.captureStackTrace ? Error.captureStackTrace(this, this.constructor) : this.stack = new Error().stack, this.message = e, this.name = "AxiosError", t && (this.code = t), n && (this.config = n), r && (this.request = r), i && (this.response = i, this.status = i.status ? i.status : null);
}
Oe.inherits(ln, Error, {
  toJSON: function() {
    return {
      // Standard
      message: this.message,
      name: this.name,
      // Microsoft
      description: this.description,
      number: this.number,
      // Mozilla
      fileName: this.fileName,
      lineNumber: this.lineNumber,
      columnNumber: this.columnNumber,
      stack: this.stack,
      // Axios
      config: Oe.toJSONObject(this.config),
      code: this.code,
      status: this.status
    };
  }
});
const O6 = ln.prototype, R6 = {};
[
  "ERR_BAD_OPTION_VALUE",
  "ERR_BAD_OPTION",
  "ECONNABORTED",
  "ETIMEDOUT",
  "ERR_NETWORK",
  "ERR_FR_TOO_MANY_REDIRECTS",
  "ERR_DEPRECATED",
  "ERR_BAD_RESPONSE",
  "ERR_BAD_REQUEST",
  "ERR_CANCELED",
  "ERR_NOT_SUPPORT",
  "ERR_INVALID_URL"
  // eslint-disable-next-line func-names
].forEach((e) => {
  R6[e] = { value: e };
});
Object.defineProperties(ln, R6);
Object.defineProperty(O6, "isAxiosError", { value: !0 });
ln.from = (e, t, n, r, i, a) => {
  const o = Object.create(O6);
  return Oe.toFlatObject(e, o, function(l) {
    return l !== Error.prototype;
  }, (s) => s !== "isAxiosError"), ln.call(o, e.message, t, n, r, i), o.cause = e, o.name = e.name, a && Object.assign(o, a), o;
};
const Wme = null;
function CC(e) {
  return Oe.isPlainObject(e) || Oe.isArray(e);
}
function w6(e) {
  return Oe.endsWith(e, "[]") ? e.slice(0, -2) : e;
}
function h2(e, t, n) {
  return e ? e.concat(t).map(function(i, a) {
    return i = w6(i), !n && a ? "[" + i + "]" : i;
  }).join(n ? "." : "") : t;
}
function Kme(e) {
  return Oe.isArray(e) && !e.some(CC);
}
const jme = Oe.toFlatObject(Oe, {}, null, function(t) {
  return /^is[A-Z]/.test(t);
});
function cv(e, t, n) {
  if (!Oe.isObject(e))
    throw new TypeError("target must be an object");
  t = t || new FormData(), n = Oe.toFlatObject(n, {
    metaTokens: !0,
    dots: !1,
    indexes: !1
  }, !1, function(v, b) {
    return !Oe.isUndefined(b[v]);
  });
  const r = n.metaTokens, i = n.visitor || c, a = n.dots, o = n.indexes, l = (n.Blob || typeof Blob < "u" && Blob) && Oe.isSpecCompliantForm(t);
  if (!Oe.isFunction(i))
    throw new TypeError("visitor must be a function");
  function u(m) {
    if (m === null) return "";
    if (Oe.isDate(m))
      return m.toISOString();
    if (!l && Oe.isBlob(m))
      throw new ln("Blob is not supported. Use a Buffer instead.");
    return Oe.isArrayBuffer(m) || Oe.isTypedArray(m) ? l && typeof Blob == "function" ? new Blob([m]) : Buffer.from(m) : m;
  }
  function c(m, v, b) {
    let y = m;
    if (m && !b && typeof m == "object") {
      if (Oe.endsWith(v, "{}"))
        v = r ? v : v.slice(0, -2), m = JSON.stringify(m);
      else if (Oe.isArray(m) && Kme(m) || (Oe.isFileList(m) || Oe.endsWith(v, "[]")) && (y = Oe.toArray(m)))
        return v = w6(v), y.forEach(function(E, S) {
          !(Oe.isUndefined(E) || E === null) && t.append(
            // eslint-disable-next-line no-nested-ternary
            o === !0 ? h2([v], S, a) : o === null ? v : v + "[]",
            u(E)
          );
        }), !1;
    }
    return CC(m) ? !0 : (t.append(h2(b, v, a), u(m)), !1);
  }
  const d = [], f = Object.assign(jme, {
    defaultVisitor: c,
    convertValue: u,
    isVisitable: CC
  });
  function h(m, v) {
    if (!Oe.isUndefined(m)) {
      if (d.indexOf(m) !== -1)
        throw Error("Circular reference detected in " + v.join("."));
      d.push(m), Oe.forEach(m, function(y, g) {
        (!(Oe.isUndefined(y) || y === null) && i.call(
          t,
          y,
          Oe.isString(g) ? g.trim() : g,
          v,
          f
        )) === !0 && h(y, v ? v.concat(g) : [g]);
      }), d.pop();
    }
  }
  if (!Oe.isObject(e))
    throw new TypeError("data must be an object");
  return h(e), t;
}
function g2(e) {
  const t = {
    "!": "%21",
    "'": "%27",
    "(": "%28",
    ")": "%29",
    "~": "%7E",
    "%20": "+",
    "%00": "\0"
  };
  return encodeURIComponent(e).replace(/[!'()~]|%20|%00/g, function(r) {
    return t[r];
  });
}
function oA(e, t) {
  this._pairs = [], e && cv(e, this, t);
}
const x6 = oA.prototype;
x6.append = function(t, n) {
  this._pairs.push([t, n]);
};
x6.toString = function(t) {
  const n = t ? function(r) {
    return t.call(this, r, g2);
  } : g2;
  return this._pairs.map(function(i) {
    return n(i[0]) + "=" + n(i[1]);
  }, "").join("&");
};
function Qme(e) {
  return encodeURIComponent(e).replace(/%3A/gi, ":").replace(/%24/g, "$").replace(/%2C/gi, ",").replace(/%20/g, "+").replace(/%5B/gi, "[").replace(/%5D/gi, "]");
}
function N6(e, t, n) {
  if (!t)
    return e;
  const r = n && n.encode || Qme, i = n && n.serialize;
  let a;
  if (i ? a = i(t, n) : a = Oe.isURLSearchParams(t) ? t.toString() : new oA(t, n).toString(r), a) {
    const o = e.indexOf("#");
    o !== -1 && (e = e.slice(0, o)), e += (e.indexOf("?") === -1 ? "?" : "&") + a;
  }
  return e;
}
class _2 {
  constructor() {
    this.handlers = [];
  }
  /**
   * Add a new interceptor to the stack
   *
   * @param {Function} fulfilled The function to handle `then` for a `Promise`
   * @param {Function} rejected The function to handle `reject` for a `Promise`
   *
   * @return {Number} An ID used to remove interceptor later
   */
  use(t, n, r) {
    return this.handlers.push({
      fulfilled: t,
      rejected: n,
      synchronous: r ? r.synchronous : !1,
      runWhen: r ? r.runWhen : null
    }), this.handlers.length - 1;
  }
  /**
   * Remove an interceptor from the stack
   *
   * @param {Number} id The ID that was returned by `use`
   *
   * @returns {Boolean} `true` if the interceptor was removed, `false` otherwise
   */
  eject(t) {
    this.handlers[t] && (this.handlers[t] = null);
  }
  /**
   * Clear all interceptors from the stack
   *
   * @returns {void}
   */
  clear() {
    this.handlers && (this.handlers = []);
  }
  /**
   * Iterate over all the registered interceptors
   *
   * This method is particularly useful for skipping over any
   * interceptors that may have become `null` calling `eject`.
   *
   * @param {Function} fn The function to call for each interceptor
   *
   * @returns {void}
   */
  forEach(t) {
    Oe.forEach(this.handlers, function(r) {
      r !== null && t(r);
    });
  }
}
const D6 = {
  silentJSONParsing: !0,
  forcedJSONParsing: !0,
  clarifyTimeoutError: !1
}, Xme = typeof URLSearchParams < "u" ? URLSearchParams : oA, Zme = typeof FormData < "u" ? FormData : null, Jme = typeof Blob < "u" ? Blob : null, ehe = {
  isBrowser: !0,
  classes: {
    URLSearchParams: Xme,
    FormData: Zme,
    Blob: Jme
  },
  protocols: ["http", "https", "file", "blob", "url", "data"]
}, sA = typeof window < "u" && typeof document < "u", AC = typeof navigator == "object" && navigator || void 0, the = sA && (!AC || ["ReactNative", "NativeScript", "NS"].indexOf(AC.product) < 0), nhe = typeof WorkerGlobalScope < "u" && // eslint-disable-next-line no-undef
self instanceof WorkerGlobalScope && typeof self.importScripts == "function", rhe = sA && window.location.href || "http://localhost", ihe = /* @__PURE__ */ Object.freeze(/* @__PURE__ */ Object.defineProperty({
  __proto__: null,
  hasBrowserEnv: sA,
  hasStandardBrowserEnv: the,
  hasStandardBrowserWebWorkerEnv: nhe,
  navigator: AC,
  origin: rhe
}, Symbol.toStringTag, { value: "Module" })), da = {
  ...ihe,
  ...ehe
};
function ahe(e, t) {
  return cv(e, new da.classes.URLSearchParams(), Object.assign({
    visitor: function(n, r, i, a) {
      return da.isNode && Oe.isBuffer(n) ? (this.append(r, n.toString("base64")), !1) : a.defaultVisitor.apply(this, arguments);
    }
  }, t));
}
function ohe(e) {
  return Oe.matchAll(/\w+|\[(\w*)]/g, e).map((t) => t[0] === "[]" ? "" : t[1] || t[0]);
}
function she(e) {
  const t = {}, n = Object.keys(e);
  let r;
  const i = n.length;
  let a;
  for (r = 0; r < i; r++)
    a = n[r], t[a] = e[a];
  return t;
}
function I6(e) {
  function t(n, r, i, a) {
    let o = n[a++];
    if (o === "__proto__") return !0;
    const s = Number.isFinite(+o), l = a >= n.length;
    return o = !o && Oe.isArray(i) ? i.length : o, l ? (Oe.hasOwnProp(i, o) ? i[o] = [i[o], r] : i[o] = r, !s) : ((!i[o] || !Oe.isObject(i[o])) && (i[o] = []), t(n, r, i[o], a) && Oe.isArray(i[o]) && (i[o] = she(i[o])), !s);
  }
  if (Oe.isFormData(e) && Oe.isFunction(e.entries)) {
    const n = {};
    return Oe.forEachEntry(e, (r, i) => {
      t(ohe(r), i, n, 0);
    }), n;
  }
  return null;
}
function lhe(e, t, n) {
  if (Oe.isString(e))
    try {
      return (t || JSON.parse)(e), Oe.trim(e);
    } catch (r) {
      if (r.name !== "SyntaxError")
        throw r;
    }
  return (n || JSON.stringify)(e);
}
const hm = {
  transitional: D6,
  adapter: ["xhr", "http", "fetch"],
  transformRequest: [function(t, n) {
    const r = n.getContentType() || "", i = r.indexOf("application/json") > -1, a = Oe.isObject(t);
    if (a && Oe.isHTMLForm(t) && (t = new FormData(t)), Oe.isFormData(t))
      return i ? JSON.stringify(I6(t)) : t;
    if (Oe.isArrayBuffer(t) || Oe.isBuffer(t) || Oe.isStream(t) || Oe.isFile(t) || Oe.isBlob(t) || Oe.isReadableStream(t))
      return t;
    if (Oe.isArrayBufferView(t))
      return t.buffer;
    if (Oe.isURLSearchParams(t))
      return n.setContentType("application/x-www-form-urlencoded;charset=utf-8", !1), t.toString();
    let s;
    if (a) {
      if (r.indexOf("application/x-www-form-urlencoded") > -1)
        return ahe(t, this.formSerializer).toString();
      if ((s = Oe.isFileList(t)) || r.indexOf("multipart/form-data") > -1) {
        const l = this.env && this.env.FormData;
        return cv(
          s ? { "files[]": t } : t,
          l && new l(),
          this.formSerializer
        );
      }
    }
    return a || i ? (n.setContentType("application/json", !1), lhe(t)) : t;
  }],
  transformResponse: [function(t) {
    const n = this.transitional || hm.transitional, r = n && n.forcedJSONParsing, i = this.responseType === "json";
    if (Oe.isResponse(t) || Oe.isReadableStream(t))
      return t;
    if (t && Oe.isString(t) && (r && !this.responseType || i)) {
      const o = !(n && n.silentJSONParsing) && i;
      try {
        return JSON.parse(t);
      } catch (s) {
        if (o)
          throw s.name === "SyntaxError" ? ln.from(s, ln.ERR_BAD_RESPONSE, this, null, this.response) : s;
      }
    }
    return t;
  }],
  /**
   * A timeout in milliseconds to abort a request. If set to 0 (default) a
   * timeout is not created.
   */
  timeout: 0,
  xsrfCookieName: "XSRF-TOKEN",
  xsrfHeaderName: "X-XSRF-TOKEN",
  maxContentLength: -1,
  maxBodyLength: -1,
  env: {
    FormData: da.classes.FormData,
    Blob: da.classes.Blob
  },
  validateStatus: function(t) {
    return t >= 200 && t < 300;
  },
  headers: {
    common: {
      Accept: "application/json, text/plain, */*",
      "Content-Type": void 0
    }
  }
};
Oe.forEach(["delete", "get", "head", "post", "put", "patch"], (e) => {
  hm.headers[e] = {};
});
const uhe = Oe.toObjectSet([
  "age",
  "authorization",
  "content-length",
  "content-type",
  "etag",
  "expires",
  "from",
  "host",
  "if-modified-since",
  "if-unmodified-since",
  "last-modified",
  "location",
  "max-forwards",
  "proxy-authorization",
  "referer",
  "retry-after",
  "user-agent"
]), che = (e) => {
  const t = {};
  let n, r, i;
  return e && e.split(`
`).forEach(function(o) {
    i = o.indexOf(":"), n = o.substring(0, i).trim().toLowerCase(), r = o.substring(i + 1).trim(), !(!n || t[n] && uhe[n]) && (n === "set-cookie" ? t[n] ? t[n].push(r) : t[n] = [r] : t[n] = t[n] ? t[n] + ", " + r : r);
  }), t;
}, v2 = Symbol("internals");
function Rf(e) {
  return e && String(e).trim().toLowerCase();
}
function gg(e) {
  return e === !1 || e == null ? e : Oe.isArray(e) ? e.map(gg) : String(e);
}
function dhe(e) {
  const t = /* @__PURE__ */ Object.create(null), n = /([^\s,;=]+)\s*(?:=\s*([^,;]+))?/g;
  let r;
  for (; r = n.exec(e); )
    t[r[1]] = r[2];
  return t;
}
const fhe = (e) => /^[-_a-zA-Z0-9^`|~,!#$%&'*+.]+$/.test(e.trim());
function cT(e, t, n, r, i) {
  if (Oe.isFunction(r))
    return r.call(this, t, n);
  if (i && (t = n), !!Oe.isString(t)) {
    if (Oe.isString(r))
      return t.indexOf(r) !== -1;
    if (Oe.isRegExp(r))
      return r.test(t);
  }
}
function phe(e) {
  return e.trim().toLowerCase().replace(/([a-z\d])(\w*)/g, (t, n, r) => n.toUpperCase() + r);
}
function mhe(e, t) {
  const n = Oe.toCamelCase(" " + t);
  ["get", "set", "has"].forEach((r) => {
    Object.defineProperty(e, r + n, {
      value: function(i, a, o) {
        return this[r].call(this, t, i, a, o);
      },
      configurable: !0
    });
  });
}
class fa {
  constructor(t) {
    t && this.set(t);
  }
  set(t, n, r) {
    const i = this;
    function a(s, l, u) {
      const c = Rf(l);
      if (!c)
        throw new Error("header name must be a non-empty string");
      const d = Oe.findKey(i, c);
      (!d || i[d] === void 0 || u === !0 || u === void 0 && i[d] !== !1) && (i[d || l] = gg(s));
    }
    const o = (s, l) => Oe.forEach(s, (u, c) => a(u, c, l));
    if (Oe.isPlainObject(t) || t instanceof this.constructor)
      o(t, n);
    else if (Oe.isString(t) && (t = t.trim()) && !fhe(t))
      o(che(t), n);
    else if (Oe.isHeaders(t))
      for (const [s, l] of t.entries())
        a(l, s, r);
    else
      t != null && a(n, t, r);
    return this;
  }
  get(t, n) {
    if (t = Rf(t), t) {
      const r = Oe.findKey(this, t);
      if (r) {
        const i = this[r];
        if (!n)
          return i;
        if (n === !0)
          return dhe(i);
        if (Oe.isFunction(n))
          return n.call(this, i, r);
        if (Oe.isRegExp(n))
          return n.exec(i);
        throw new TypeError("parser must be boolean|regexp|function");
      }
    }
  }
  has(t, n) {
    if (t = Rf(t), t) {
      const r = Oe.findKey(this, t);
      return !!(r && this[r] !== void 0 && (!n || cT(this, this[r], r, n)));
    }
    return !1;
  }
  delete(t, n) {
    const r = this;
    let i = !1;
    function a(o) {
      if (o = Rf(o), o) {
        const s = Oe.findKey(r, o);
        s && (!n || cT(r, r[s], s, n)) && (delete r[s], i = !0);
      }
    }
    return Oe.isArray(t) ? t.forEach(a) : a(t), i;
  }
  clear(t) {
    const n = Object.keys(this);
    let r = n.length, i = !1;
    for (; r--; ) {
      const a = n[r];
      (!t || cT(this, this[a], a, t, !0)) && (delete this[a], i = !0);
    }
    return i;
  }
  normalize(t) {
    const n = this, r = {};
    return Oe.forEach(this, (i, a) => {
      const o = Oe.findKey(r, a);
      if (o) {
        n[o] = gg(i), delete n[a];
        return;
      }
      const s = t ? phe(a) : String(a).trim();
      s !== a && delete n[a], n[s] = gg(i), r[s] = !0;
    }), this;
  }
  concat(...t) {
    return this.constructor.concat(this, ...t);
  }
  toJSON(t) {
    const n = /* @__PURE__ */ Object.create(null);
    return Oe.forEach(this, (r, i) => {
      r != null && r !== !1 && (n[i] = t && Oe.isArray(r) ? r.join(", ") : r);
    }), n;
  }
  [Symbol.iterator]() {
    return Object.entries(this.toJSON())[Symbol.iterator]();
  }
  toString() {
    return Object.entries(this.toJSON()).map(([t, n]) => t + ": " + n).join(`
`);
  }
  get [Symbol.toStringTag]() {
    return "AxiosHeaders";
  }
  static from(t) {
    return t instanceof this ? t : new this(t);
  }
  static concat(t, ...n) {
    const r = new this(t);
    return n.forEach((i) => r.set(i)), r;
  }
  static accessor(t) {
    const r = (this[v2] = this[v2] = {
      accessors: {}
    }).accessors, i = this.prototype;
    function a(o) {
      const s = Rf(o);
      r[s] || (mhe(i, o), r[s] = !0);
    }
    return Oe.isArray(t) ? t.forEach(a) : a(t), this;
  }
}
fa.accessor(["Content-Type", "Content-Length", "Accept", "Accept-Encoding", "User-Agent", "Authorization"]);
Oe.reduceDescriptors(fa.prototype, ({ value: e }, t) => {
  let n = t[0].toUpperCase() + t.slice(1);
  return {
    get: () => e,
    set(r) {
      this[n] = r;
    }
  };
});
Oe.freezeMethods(fa);
function dT(e, t) {
  const n = this || hm, r = t || n, i = fa.from(r.headers);
  let a = r.data;
  return Oe.forEach(e, function(s) {
    a = s.call(n, a, i.normalize(), t ? t.status : void 0);
  }), i.normalize(), a;
}
function L6(e) {
  return !!(e && e.__CANCEL__);
}
function Nd(e, t, n) {
  ln.call(this, e ?? "canceled", ln.ERR_CANCELED, t, n), this.name = "CanceledError";
}
Oe.inherits(Nd, ln, {
  __CANCEL__: !0
});
function k6(e, t, n) {
  const r = n.config.validateStatus;
  !n.status || !r || r(n.status) ? e(n) : t(new ln(
    "Request failed with status code " + n.status,
    [ln.ERR_BAD_REQUEST, ln.ERR_BAD_RESPONSE][Math.floor(n.status / 100) - 4],
    n.config,
    n.request,
    n
  ));
}
function hhe(e) {
  const t = /^([-+\w]{1,25})(:?\/\/|:)/.exec(e);
  return t && t[1] || "";
}
function ghe(e, t) {
  e = e || 10;
  const n = new Array(e), r = new Array(e);
  let i = 0, a = 0, o;
  return t = t !== void 0 ? t : 1e3, function(l) {
    const u = Date.now(), c = r[a];
    o || (o = u), n[i] = l, r[i] = u;
    let d = a, f = 0;
    for (; d !== i; )
      f += n[d++], d = d % e;
    if (i = (i + 1) % e, i === a && (a = (a + 1) % e), u - o < t)
      return;
    const h = c && u - c;
    return h ? Math.round(f * 1e3 / h) : void 0;
  };
}
function _he(e, t) {
  let n = 0, r = 1e3 / t, i, a;
  const o = (u, c = Date.now()) => {
    n = c, i = null, a && (clearTimeout(a), a = null), e.apply(null, u);
  };
  return [(...u) => {
    const c = Date.now(), d = c - n;
    d >= r ? o(u, c) : (i = u, a || (a = setTimeout(() => {
      a = null, o(i);
    }, r - d)));
  }, () => i && o(i)];
}
const i_ = (e, t, n = 3) => {
  let r = 0;
  const i = ghe(50, 250);
  return _he((a) => {
    const o = a.loaded, s = a.lengthComputable ? a.total : void 0, l = o - r, u = i(l), c = o <= s;
    r = o;
    const d = {
      loaded: o,
      total: s,
      progress: s ? o / s : void 0,
      bytes: l,
      rate: u || void 0,
      estimated: u && s && c ? (s - o) / u : void 0,
      event: a,
      lengthComputable: s != null,
      [t ? "download" : "upload"]: !0
    };
    e(d);
  }, n);
}, b2 = (e, t) => {
  const n = e != null;
  return [(r) => t[0]({
    lengthComputable: n,
    total: e,
    loaded: r
  }), t[1]];
}, E2 = (e) => (...t) => Oe.asap(() => e(...t)), vhe = da.hasStandardBrowserEnv ? (
  // Standard browser envs have full support of the APIs needed to test
  // whether the request URL is of the same origin as current location.
  function() {
    const t = da.navigator && /(msie|trident)/i.test(da.navigator.userAgent), n = document.createElement("a");
    let r;
    function i(a) {
      let o = a;
      return t && (n.setAttribute("href", o), o = n.href), n.setAttribute("href", o), {
        href: n.href,
        protocol: n.protocol ? n.protocol.replace(/:$/, "") : "",
        host: n.host,
        search: n.search ? n.search.replace(/^\?/, "") : "",
        hash: n.hash ? n.hash.replace(/^#/, "") : "",
        hostname: n.hostname,
        port: n.port,
        pathname: n.pathname.charAt(0) === "/" ? n.pathname : "/" + n.pathname
      };
    }
    return r = i(window.location.href), function(o) {
      const s = Oe.isString(o) ? i(o) : o;
      return s.protocol === r.protocol && s.host === r.host;
    };
  }()
) : (
  // Non standard browser envs (web workers, react-native) lack needed support.
  /* @__PURE__ */ function() {
    return function() {
      return !0;
    };
  }()
), bhe = da.hasStandardBrowserEnv ? (
  // Standard browser envs support document.cookie
  {
    write(e, t, n, r, i, a) {
      const o = [e + "=" + encodeURIComponent(t)];
      Oe.isNumber(n) && o.push("expires=" + new Date(n).toGMTString()), Oe.isString(r) && o.push("path=" + r), Oe.isString(i) && o.push("domain=" + i), a === !0 && o.push("secure"), document.cookie = o.join("; ");
    },
    read(e) {
      const t = document.cookie.match(new RegExp("(^|;\\s*)(" + e + ")=([^;]*)"));
      return t ? decodeURIComponent(t[3]) : null;
    },
    remove(e) {
      this.write(e, "", Date.now() - 864e5);
    }
  }
) : (
  // Non-standard browser env (web workers, react-native) lack needed support.
  {
    write() {
    },
    read() {
      return null;
    },
    remove() {
    }
  }
);
function Ehe(e) {
  return /^([a-z][a-z\d+\-.]*:)?\/\//i.test(e);
}
function She(e, t) {
  return t ? e.replace(/\/?\/$/, "") + "/" + t.replace(/^\/+/, "") : e;
}
function M6(e, t) {
  return e && !Ehe(t) ? She(e, t) : t;
}
const S2 = (e) => e instanceof fa ? { ...e } : e;
function Vu(e, t) {
  t = t || {};
  const n = {};
  function r(u, c, d) {
    return Oe.isPlainObject(u) && Oe.isPlainObject(c) ? Oe.merge.call({ caseless: d }, u, c) : Oe.isPlainObject(c) ? Oe.merge({}, c) : Oe.isArray(c) ? c.slice() : c;
  }
  function i(u, c, d) {
    if (Oe.isUndefined(c)) {
      if (!Oe.isUndefined(u))
        return r(void 0, u, d);
    } else return r(u, c, d);
  }
  function a(u, c) {
    if (!Oe.isUndefined(c))
      return r(void 0, c);
  }
  function o(u, c) {
    if (Oe.isUndefined(c)) {
      if (!Oe.isUndefined(u))
        return r(void 0, u);
    } else return r(void 0, c);
  }
  function s(u, c, d) {
    if (d in t)
      return r(u, c);
    if (d in e)
      return r(void 0, u);
  }
  const l = {
    url: a,
    method: a,
    data: a,
    baseURL: o,
    transformRequest: o,
    transformResponse: o,
    paramsSerializer: o,
    timeout: o,
    timeoutMessage: o,
    withCredentials: o,
    withXSRFToken: o,
    adapter: o,
    responseType: o,
    xsrfCookieName: o,
    xsrfHeaderName: o,
    onUploadProgress: o,
    onDownloadProgress: o,
    decompress: o,
    maxContentLength: o,
    maxBodyLength: o,
    beforeRedirect: o,
    transport: o,
    httpAgent: o,
    httpsAgent: o,
    cancelToken: o,
    socketPath: o,
    responseEncoding: o,
    validateStatus: s,
    headers: (u, c) => i(S2(u), S2(c), !0)
  };
  return Oe.forEach(Object.keys(Object.assign({}, e, t)), function(c) {
    const d = l[c] || i, f = d(e[c], t[c], c);
    Oe.isUndefined(f) && d !== s || (n[c] = f);
  }), n;
}
const P6 = (e) => {
  const t = Vu({}, e);
  let { data: n, withXSRFToken: r, xsrfHeaderName: i, xsrfCookieName: a, headers: o, auth: s } = t;
  t.headers = o = fa.from(o), t.url = N6(M6(t.baseURL, t.url), e.params, e.paramsSerializer), s && o.set(
    "Authorization",
    "Basic " + btoa((s.username || "") + ":" + (s.password ? unescape(encodeURIComponent(s.password)) : ""))
  );
  let l;
  if (Oe.isFormData(n)) {
    if (da.hasStandardBrowserEnv || da.hasStandardBrowserWebWorkerEnv)
      o.setContentType(void 0);
    else if ((l = o.getContentType()) !== !1) {
      const [u, ...c] = l ? l.split(";").map((d) => d.trim()).filter(Boolean) : [];
      o.setContentType([u || "multipart/form-data", ...c].join("; "));
    }
  }
  if (da.hasStandardBrowserEnv && (r && Oe.isFunction(r) && (r = r(t)), r || r !== !1 && vhe(t.url))) {
    const u = i && a && bhe.read(a);
    u && o.set(i, u);
  }
  return t;
}, yhe = typeof XMLHttpRequest < "u", The = yhe && function(e) {
  return new Promise(function(n, r) {
    const i = P6(e);
    let a = i.data;
    const o = fa.from(i.headers).normalize();
    let { responseType: s, onUploadProgress: l, onDownloadProgress: u } = i, c, d, f, h, m;
    function v() {
      h && h(), m && m(), i.cancelToken && i.cancelToken.unsubscribe(c), i.signal && i.signal.removeEventListener("abort", c);
    }
    let b = new XMLHttpRequest();
    b.open(i.method.toUpperCase(), i.url, !0), b.timeout = i.timeout;
    function y() {
      if (!b)
        return;
      const E = fa.from(
        "getAllResponseHeaders" in b && b.getAllResponseHeaders()
      ), C = {
        data: !s || s === "text" || s === "json" ? b.responseText : b.response,
        status: b.status,
        statusText: b.statusText,
        headers: E,
        config: e,
        request: b
      };
      k6(function(O) {
        n(O), v();
      }, function(O) {
        r(O), v();
      }, C), b = null;
    }
    "onloadend" in b ? b.onloadend = y : b.onreadystatechange = function() {
      !b || b.readyState !== 4 || b.status === 0 && !(b.responseURL && b.responseURL.indexOf("file:") === 0) || setTimeout(y);
    }, b.onabort = function() {
      b && (r(new ln("Request aborted", ln.ECONNABORTED, e, b)), b = null);
    }, b.onerror = function() {
      r(new ln("Network Error", ln.ERR_NETWORK, e, b)), b = null;
    }, b.ontimeout = function() {
      let S = i.timeout ? "timeout of " + i.timeout + "ms exceeded" : "timeout exceeded";
      const C = i.transitional || D6;
      i.timeoutErrorMessage && (S = i.timeoutErrorMessage), r(new ln(
        S,
        C.clarifyTimeoutError ? ln.ETIMEDOUT : ln.ECONNABORTED,
        e,
        b
      )), b = null;
    }, a === void 0 && o.setContentType(null), "setRequestHeader" in b && Oe.forEach(o.toJSON(), function(S, C) {
      b.setRequestHeader(C, S);
    }), Oe.isUndefined(i.withCredentials) || (b.withCredentials = !!i.withCredentials), s && s !== "json" && (b.responseType = i.responseType), u && ([f, m] = i_(u, !0), b.addEventListener("progress", f)), l && b.upload && ([d, h] = i_(l), b.upload.addEventListener("progress", d), b.upload.addEventListener("loadend", h)), (i.cancelToken || i.signal) && (c = (E) => {
      b && (r(!E || E.type ? new Nd(null, e, b) : E), b.abort(), b = null);
    }, i.cancelToken && i.cancelToken.subscribe(c), i.signal && (i.signal.aborted ? c() : i.signal.addEventListener("abort", c)));
    const g = hhe(i.url);
    if (g && da.protocols.indexOf(g) === -1) {
      r(new ln("Unsupported protocol " + g + ":", ln.ERR_BAD_REQUEST, e));
      return;
    }
    b.send(a || null);
  });
}, Che = (e, t) => {
  const { length: n } = e = e ? e.filter(Boolean) : [];
  if (t || n) {
    let r = new AbortController(), i;
    const a = function(u) {
      if (!i) {
        i = !0, s();
        const c = u instanceof Error ? u : this.reason;
        r.abort(c instanceof ln ? c : new Nd(c instanceof Error ? c.message : c));
      }
    };
    let o = t && setTimeout(() => {
      o = null, a(new ln(`timeout ${t} of ms exceeded`, ln.ETIMEDOUT));
    }, t);
    const s = () => {
      e && (o && clearTimeout(o), o = null, e.forEach((u) => {
        u.unsubscribe ? u.unsubscribe(a) : u.removeEventListener("abort", a);
      }), e = null);
    };
    e.forEach((u) => u.addEventListener("abort", a));
    const { signal: l } = r;
    return l.unsubscribe = () => Oe.asap(s), l;
  }
}, Ahe = function* (e, t) {
  let n = e.byteLength;
  if (!t || n < t) {
    yield e;
    return;
  }
  let r = 0, i;
  for (; r < n; )
    i = r + t, yield e.slice(r, i), r = i;
}, Ohe = async function* (e, t) {
  for await (const n of Rhe(e))
    yield* Ahe(n, t);
}, Rhe = async function* (e) {
  if (e[Symbol.asyncIterator]) {
    yield* e;
    return;
  }
  const t = e.getReader();
  try {
    for (; ; ) {
      const { done: n, value: r } = await t.read();
      if (n)
        break;
      yield r;
    }
  } finally {
    await t.cancel();
  }
}, y2 = (e, t, n, r) => {
  const i = Ohe(e, t);
  let a = 0, o, s = (l) => {
    o || (o = !0, r && r(l));
  };
  return new ReadableStream({
    async pull(l) {
      try {
        const { done: u, value: c } = await i.next();
        if (u) {
          s(), l.close();
          return;
        }
        let d = c.byteLength;
        if (n) {
          let f = a += d;
          n(f);
        }
        l.enqueue(new Uint8Array(c));
      } catch (u) {
        throw s(u), u;
      }
    },
    cancel(l) {
      return s(l), i.return();
    }
  }, {
    highWaterMark: 2
  });
}, dv = typeof fetch == "function" && typeof Request == "function" && typeof Response == "function", F6 = dv && typeof ReadableStream == "function", whe = dv && (typeof TextEncoder == "function" ? /* @__PURE__ */ ((e) => (t) => e.encode(t))(new TextEncoder()) : async (e) => new Uint8Array(await new Response(e).arrayBuffer())), B6 = (e, ...t) => {
  try {
    return !!e(...t);
  } catch {
    return !1;
  }
}, xhe = F6 && B6(() => {
  let e = !1;
  const t = new Request(da.origin, {
    body: new ReadableStream(),
    method: "POST",
    get duplex() {
      return e = !0, "half";
    }
  }).headers.has("Content-Type");
  return e && !t;
}), T2 = 64 * 1024, OC = F6 && B6(() => Oe.isReadableStream(new Response("").body)), a_ = {
  stream: OC && ((e) => e.body)
};
dv && ((e) => {
  ["text", "arrayBuffer", "blob", "formData", "stream"].forEach((t) => {
    !a_[t] && (a_[t] = Oe.isFunction(e[t]) ? (n) => n[t]() : (n, r) => {
      throw new ln(`Response type '${t}' is not supported`, ln.ERR_NOT_SUPPORT, r);
    });
  });
})(new Response());
const Nhe = async (e) => {
  if (e == null)
    return 0;
  if (Oe.isBlob(e))
    return e.size;
  if (Oe.isSpecCompliantForm(e))
    return (await new Request(da.origin, {
      method: "POST",
      body: e
    }).arrayBuffer()).byteLength;
  if (Oe.isArrayBufferView(e) || Oe.isArrayBuffer(e))
    return e.byteLength;
  if (Oe.isURLSearchParams(e) && (e = e + ""), Oe.isString(e))
    return (await whe(e)).byteLength;
}, Dhe = async (e, t) => {
  const n = Oe.toFiniteNumber(e.getContentLength());
  return n ?? Nhe(t);
}, Ihe = dv && (async (e) => {
  let {
    url: t,
    method: n,
    data: r,
    signal: i,
    cancelToken: a,
    timeout: o,
    onDownloadProgress: s,
    onUploadProgress: l,
    responseType: u,
    headers: c,
    withCredentials: d = "same-origin",
    fetchOptions: f
  } = P6(e);
  u = u ? (u + "").toLowerCase() : "text";
  let h = Che([i, a && a.toAbortSignal()], o), m;
  const v = h && h.unsubscribe && (() => {
    h.unsubscribe();
  });
  let b;
  try {
    if (l && xhe && n !== "get" && n !== "head" && (b = await Dhe(c, r)) !== 0) {
      let C = new Request(t, {
        method: "POST",
        body: r,
        duplex: "half"
      }), T;
      if (Oe.isFormData(r) && (T = C.headers.get("content-type")) && c.setContentType(T), C.body) {
        const [O, R] = b2(
          b,
          i_(E2(l))
        );
        r = y2(C.body, T2, O, R);
      }
    }
    Oe.isString(d) || (d = d ? "include" : "omit");
    const y = "credentials" in Request.prototype;
    m = new Request(t, {
      ...f,
      signal: h,
      method: n.toUpperCase(),
      headers: c.normalize().toJSON(),
      body: r,
      duplex: "half",
      credentials: y ? d : void 0
    });
    let g = await fetch(m);
    const E = OC && (u === "stream" || u === "response");
    if (OC && (s || E && v)) {
      const C = {};
      ["status", "statusText", "headers"].forEach((D) => {
        C[D] = g[D];
      });
      const T = Oe.toFiniteNumber(g.headers.get("content-length")), [O, R] = s && b2(
        T,
        i_(E2(s), !0)
      ) || [];
      g = new Response(
        y2(g.body, T2, O, () => {
          R && R(), v && v();
        }),
        C
      );
    }
    u = u || "text";
    let S = await a_[Oe.findKey(a_, u) || "text"](g, e);
    return !E && v && v(), await new Promise((C, T) => {
      k6(C, T, {
        data: S,
        headers: fa.from(g.headers),
        status: g.status,
        statusText: g.statusText,
        config: e,
        request: m
      });
    });
  } catch (y) {
    throw v && v(), y && y.name === "TypeError" && /fetch/i.test(y.message) ? Object.assign(
      new ln("Network Error", ln.ERR_NETWORK, e, m),
      {
        cause: y.cause || y
      }
    ) : ln.from(y, y && y.code, e, m);
  }
}), RC = {
  http: Wme,
  xhr: The,
  fetch: Ihe
};
Oe.forEach(RC, (e, t) => {
  if (e) {
    try {
      Object.defineProperty(e, "name", { value: t });
    } catch {
    }
    Object.defineProperty(e, "adapterName", { value: t });
  }
});
const C2 = (e) => `- ${e}`, Lhe = (e) => Oe.isFunction(e) || e === null || e === !1, $6 = {
  getAdapter: (e) => {
    e = Oe.isArray(e) ? e : [e];
    const { length: t } = e;
    let n, r;
    const i = {};
    for (let a = 0; a < t; a++) {
      n = e[a];
      let o;
      if (r = n, !Lhe(n) && (r = RC[(o = String(n)).toLowerCase()], r === void 0))
        throw new ln(`Unknown adapter '${o}'`);
      if (r)
        break;
      i[o || "#" + a] = r;
    }
    if (!r) {
      const a = Object.entries(i).map(
        ([s, l]) => `adapter ${s} ` + (l === !1 ? "is not supported by the environment" : "is not available in the build")
      );
      let o = t ? a.length > 1 ? `since :
` + a.map(C2).join(`
`) : " " + C2(a[0]) : "as no adapter specified";
      throw new ln(
        "There is no suitable adapter to dispatch the request " + o,
        "ERR_NOT_SUPPORT"
      );
    }
    return r;
  },
  adapters: RC
};
function fT(e) {
  if (e.cancelToken && e.cancelToken.throwIfRequested(), e.signal && e.signal.aborted)
    throw new Nd(null, e);
}
function A2(e) {
  return fT(e), e.headers = fa.from(e.headers), e.data = dT.call(
    e,
    e.transformRequest
  ), ["post", "put", "patch"].indexOf(e.method) !== -1 && e.headers.setContentType("application/x-www-form-urlencoded", !1), $6.getAdapter(e.adapter || hm.adapter)(e).then(function(r) {
    return fT(e), r.data = dT.call(
      e,
      e.transformResponse,
      r
    ), r.headers = fa.from(r.headers), r;
  }, function(r) {
    return L6(r) || (fT(e), r && r.response && (r.response.data = dT.call(
      e,
      e.transformResponse,
      r.response
    ), r.response.headers = fa.from(r.response.headers))), Promise.reject(r);
  });
}
const U6 = "1.7.7", lA = {};
["object", "boolean", "number", "function", "string", "symbol"].forEach((e, t) => {
  lA[e] = function(r) {
    return typeof r === e || "a" + (t < 1 ? "n " : " ") + e;
  };
});
const O2 = {};
lA.transitional = function(t, n, r) {
  function i(a, o) {
    return "[Axios v" + U6 + "] Transitional option '" + a + "'" + o + (r ? ". " + r : "");
  }
  return (a, o, s) => {
    if (t === !1)
      throw new ln(
        i(o, " has been removed" + (n ? " in " + n : "")),
        ln.ERR_DEPRECATED
      );
    return n && !O2[o] && (O2[o] = !0, console.warn(
      i(
        o,
        " has been deprecated since v" + n + " and will be removed in the near future"
      )
    )), t ? t(a, o, s) : !0;
  };
};
function khe(e, t, n) {
  if (typeof e != "object")
    throw new ln("options must be an object", ln.ERR_BAD_OPTION_VALUE);
  const r = Object.keys(e);
  let i = r.length;
  for (; i-- > 0; ) {
    const a = r[i], o = t[a];
    if (o) {
      const s = e[a], l = s === void 0 || o(s, a, e);
      if (l !== !0)
        throw new ln("option " + a + " must be " + l, ln.ERR_BAD_OPTION_VALUE);
      continue;
    }
    if (n !== !0)
      throw new ln("Unknown option " + a, ln.ERR_BAD_OPTION);
  }
}
const wC = {
  assertOptions: khe,
  validators: lA
}, gl = wC.validators;
class Fu {
  constructor(t) {
    this.defaults = t, this.interceptors = {
      request: new _2(),
      response: new _2()
    };
  }
  /**
   * Dispatch a request
   *
   * @param {String|Object} configOrUrl The config specific for this request (merged with this.defaults)
   * @param {?Object} config
   *
   * @returns {Promise} The Promise to be fulfilled
   */
  async request(t, n) {
    try {
      return await this._request(t, n);
    } catch (r) {
      if (r instanceof Error) {
        let i;
        Error.captureStackTrace ? Error.captureStackTrace(i = {}) : i = new Error();
        const a = i.stack ? i.stack.replace(/^.+\n/, "") : "";
        try {
          r.stack ? a && !String(r.stack).endsWith(a.replace(/^.+\n.+\n/, "")) && (r.stack += `
` + a) : r.stack = a;
        } catch {
        }
      }
      throw r;
    }
  }
  _request(t, n) {
    typeof t == "string" ? (n = n || {}, n.url = t) : n = t || {}, n = Vu(this.defaults, n);
    const { transitional: r, paramsSerializer: i, headers: a } = n;
    r !== void 0 && wC.assertOptions(r, {
      silentJSONParsing: gl.transitional(gl.boolean),
      forcedJSONParsing: gl.transitional(gl.boolean),
      clarifyTimeoutError: gl.transitional(gl.boolean)
    }, !1), i != null && (Oe.isFunction(i) ? n.paramsSerializer = {
      serialize: i
    } : wC.assertOptions(i, {
      encode: gl.function,
      serialize: gl.function
    }, !0)), n.method = (n.method || this.defaults.method || "get").toLowerCase();
    let o = a && Oe.merge(
      a.common,
      a[n.method]
    );
    a && Oe.forEach(
      ["delete", "get", "head", "post", "put", "patch", "common"],
      (m) => {
        delete a[m];
      }
    ), n.headers = fa.concat(o, a);
    const s = [];
    let l = !0;
    this.interceptors.request.forEach(function(v) {
      typeof v.runWhen == "function" && v.runWhen(n) === !1 || (l = l && v.synchronous, s.unshift(v.fulfilled, v.rejected));
    });
    const u = [];
    this.interceptors.response.forEach(function(v) {
      u.push(v.fulfilled, v.rejected);
    });
    let c, d = 0, f;
    if (!l) {
      const m = [A2.bind(this), void 0];
      for (m.unshift.apply(m, s), m.push.apply(m, u), f = m.length, c = Promise.resolve(n); d < f; )
        c = c.then(m[d++], m[d++]);
      return c;
    }
    f = s.length;
    let h = n;
    for (d = 0; d < f; ) {
      const m = s[d++], v = s[d++];
      try {
        h = m(h);
      } catch (b) {
        v.call(this, b);
        break;
      }
    }
    try {
      c = A2.call(this, h);
    } catch (m) {
      return Promise.reject(m);
    }
    for (d = 0, f = u.length; d < f; )
      c = c.then(u[d++], u[d++]);
    return c;
  }
  getUri(t) {
    t = Vu(this.defaults, t);
    const n = M6(t.baseURL, t.url);
    return N6(n, t.params, t.paramsSerializer);
  }
}
Oe.forEach(["delete", "get", "head", "options"], function(t) {
  Fu.prototype[t] = function(n, r) {
    return this.request(Vu(r || {}, {
      method: t,
      url: n,
      data: (r || {}).data
    }));
  };
});
Oe.forEach(["post", "put", "patch"], function(t) {
  function n(r) {
    return function(a, o, s) {
      return this.request(Vu(s || {}, {
        method: t,
        headers: r ? {
          "Content-Type": "multipart/form-data"
        } : {},
        url: a,
        data: o
      }));
    };
  }
  Fu.prototype[t] = n(), Fu.prototype[t + "Form"] = n(!0);
});
class uA {
  constructor(t) {
    if (typeof t != "function")
      throw new TypeError("executor must be a function.");
    let n;
    this.promise = new Promise(function(a) {
      n = a;
    });
    const r = this;
    this.promise.then((i) => {
      if (!r._listeners) return;
      let a = r._listeners.length;
      for (; a-- > 0; )
        r._listeners[a](i);
      r._listeners = null;
    }), this.promise.then = (i) => {
      let a;
      const o = new Promise((s) => {
        r.subscribe(s), a = s;
      }).then(i);
      return o.cancel = function() {
        r.unsubscribe(a);
      }, o;
    }, t(function(a, o, s) {
      r.reason || (r.reason = new Nd(a, o, s), n(r.reason));
    });
  }
  /**
   * Throws a `CanceledError` if cancellation has been requested.
   */
  throwIfRequested() {
    if (this.reason)
      throw this.reason;
  }
  /**
   * Subscribe to the cancel signal
   */
  subscribe(t) {
    if (this.reason) {
      t(this.reason);
      return;
    }
    this._listeners ? this._listeners.push(t) : this._listeners = [t];
  }
  /**
   * Unsubscribe from the cancel signal
   */
  unsubscribe(t) {
    if (!this._listeners)
      return;
    const n = this._listeners.indexOf(t);
    n !== -1 && this._listeners.splice(n, 1);
  }
  toAbortSignal() {
    const t = new AbortController(), n = (r) => {
      t.abort(r);
    };
    return this.subscribe(n), t.signal.unsubscribe = () => this.unsubscribe(n), t.signal;
  }
  /**
   * Returns an object that contains a new `CancelToken` and a function that, when called,
   * cancels the `CancelToken`.
   */
  static source() {
    let t;
    return {
      token: new uA(function(i) {
        t = i;
      }),
      cancel: t
    };
  }
}
function Mhe(e) {
  return function(n) {
    return e.apply(null, n);
  };
}
function Phe(e) {
  return Oe.isObject(e) && e.isAxiosError === !0;
}
const xC = {
  Continue: 100,
  SwitchingProtocols: 101,
  Processing: 102,
  EarlyHints: 103,
  Ok: 200,
  Created: 201,
  Accepted: 202,
  NonAuthoritativeInformation: 203,
  NoContent: 204,
  ResetContent: 205,
  PartialContent: 206,
  MultiStatus: 207,
  AlreadyReported: 208,
  ImUsed: 226,
  MultipleChoices: 300,
  MovedPermanently: 301,
  Found: 302,
  SeeOther: 303,
  NotModified: 304,
  UseProxy: 305,
  Unused: 306,
  TemporaryRedirect: 307,
  PermanentRedirect: 308,
  BadRequest: 400,
  Unauthorized: 401,
  PaymentRequired: 402,
  Forbidden: 403,
  NotFound: 404,
  MethodNotAllowed: 405,
  NotAcceptable: 406,
  ProxyAuthenticationRequired: 407,
  RequestTimeout: 408,
  Conflict: 409,
  Gone: 410,
  LengthRequired: 411,
  PreconditionFailed: 412,
  PayloadTooLarge: 413,
  UriTooLong: 414,
  UnsupportedMediaType: 415,
  RangeNotSatisfiable: 416,
  ExpectationFailed: 417,
  ImATeapot: 418,
  MisdirectedRequest: 421,
  UnprocessableEntity: 422,
  Locked: 423,
  FailedDependency: 424,
  TooEarly: 425,
  UpgradeRequired: 426,
  PreconditionRequired: 428,
  TooManyRequests: 429,
  RequestHeaderFieldsTooLarge: 431,
  UnavailableForLegalReasons: 451,
  InternalServerError: 500,
  NotImplemented: 501,
  BadGateway: 502,
  ServiceUnavailable: 503,
  GatewayTimeout: 504,
  HttpVersionNotSupported: 505,
  VariantAlsoNegotiates: 506,
  InsufficientStorage: 507,
  LoopDetected: 508,
  NotExtended: 510,
  NetworkAuthenticationRequired: 511
};
Object.entries(xC).forEach(([e, t]) => {
  xC[t] = e;
});
function q6(e) {
  const t = new Fu(e), n = v6(Fu.prototype.request, t);
  return Oe.extend(n, Fu.prototype, t, { allOwnKeys: !0 }), Oe.extend(n, t, null, { allOwnKeys: !0 }), n.create = function(i) {
    return q6(Vu(e, i));
  }, n;
}
const Jr = q6(hm);
Jr.Axios = Fu;
Jr.CanceledError = Nd;
Jr.CancelToken = uA;
Jr.isCancel = L6;
Jr.VERSION = U6;
Jr.toFormData = cv;
Jr.AxiosError = ln;
Jr.Cancel = Jr.CanceledError;
Jr.all = function(t) {
  return Promise.all(t);
};
Jr.spread = Mhe;
Jr.isAxiosError = Phe;
Jr.mergeConfig = Vu;
Jr.AxiosHeaders = fa;
Jr.formToJSON = (e) => I6(Oe.isHTMLForm(e) ? new FormData(e) : e);
Jr.getAdapter = $6.getAdapter;
Jr.HttpStatusCode = xC;
Jr.default = Jr;
//! moment.js
//! version : 2.30.1
//! authors : Tim Wood, Iskren Chernev, Moment.js contributors
//! license : MIT
//! momentjs.com
var G6;
function Ge() {
  return G6.apply(null, arguments);
}
function Fhe(e) {
  G6 = e;
}
function To(e) {
  return e instanceof Array || Object.prototype.toString.call(e) === "[object Array]";
}
function Bu(e) {
  return e != null && Object.prototype.toString.call(e) === "[object Object]";
}
function Ln(e, t) {
  return Object.prototype.hasOwnProperty.call(e, t);
}
function cA(e) {
  if (Object.getOwnPropertyNames)
    return Object.getOwnPropertyNames(e).length === 0;
  var t;
  for (t in e)
    if (Ln(e, t))
      return !1;
  return !0;
}
function ra(e) {
  return e === void 0;
}
function qs(e) {
  return typeof e == "number" || Object.prototype.toString.call(e) === "[object Number]";
}
function gm(e) {
  return e instanceof Date || Object.prototype.toString.call(e) === "[object Date]";
}
function Y6(e, t) {
  var n = [], r, i = e.length;
  for (r = 0; r < i; ++r)
    n.push(t(e[r], r));
  return n;
}
function xl(e, t) {
  for (var n in t)
    Ln(t, n) && (e[n] = t[n]);
  return Ln(t, "toString") && (e.toString = t.toString), Ln(t, "valueOf") && (e.valueOf = t.valueOf), e;
}
function is(e, t, n, r) {
  return f4(e, t, n, r, !0).utc();
}
function Bhe() {
  return {
    empty: !1,
    unusedTokens: [],
    unusedInput: [],
    overflow: -2,
    charsLeftOver: 0,
    nullInput: !1,
    invalidEra: null,
    invalidMonth: null,
    invalidFormat: !1,
    userInvalidated: !1,
    iso: !1,
    parsedDateParts: [],
    era: null,
    meridiem: null,
    rfc2822: !1,
    weekdayMismatch: !1
  };
}
function dn(e) {
  return e._pf == null && (e._pf = Bhe()), e._pf;
}
var NC;
Array.prototype.some ? NC = Array.prototype.some : NC = function(e) {
  var t = Object(this), n = t.length >>> 0, r;
  for (r = 0; r < n; r++)
    if (r in t && e.call(this, t[r], r, t))
      return !0;
  return !1;
};
function dA(e) {
  var t = null, n = !1, r = e._d && !isNaN(e._d.getTime());
  if (r && (t = dn(e), n = NC.call(t.parsedDateParts, function(i) {
    return i != null;
  }), r = t.overflow < 0 && !t.empty && !t.invalidEra && !t.invalidMonth && !t.invalidWeekday && !t.weekdayMismatch && !t.nullInput && !t.invalidFormat && !t.userInvalidated && (!t.meridiem || t.meridiem && n), e._strict && (r = r && t.charsLeftOver === 0 && t.unusedTokens.length === 0 && t.bigHour === void 0)), Object.isFrozen == null || !Object.isFrozen(e))
    e._isValid = r;
  else
    return r;
  return e._isValid;
}
function fv(e) {
  var t = is(NaN);
  return e != null ? xl(dn(t), e) : dn(t).userInvalidated = !0, t;
}
var R2 = Ge.momentProperties = [], pT = !1;
function fA(e, t) {
  var n, r, i, a = R2.length;
  if (ra(t._isAMomentObject) || (e._isAMomentObject = t._isAMomentObject), ra(t._i) || (e._i = t._i), ra(t._f) || (e._f = t._f), ra(t._l) || (e._l = t._l), ra(t._strict) || (e._strict = t._strict), ra(t._tzm) || (e._tzm = t._tzm), ra(t._isUTC) || (e._isUTC = t._isUTC), ra(t._offset) || (e._offset = t._offset), ra(t._pf) || (e._pf = dn(t)), ra(t._locale) || (e._locale = t._locale), a > 0)
    for (n = 0; n < a; n++)
      r = R2[n], i = t[r], ra(i) || (e[r] = i);
  return e;
}
function _m(e) {
  fA(this, e), this._d = new Date(e._d != null ? e._d.getTime() : NaN), this.isValid() || (this._d = /* @__PURE__ */ new Date(NaN)), pT === !1 && (pT = !0, Ge.updateOffset(this), pT = !1);
}
function Co(e) {
  return e instanceof _m || e != null && e._isAMomentObject != null;
}
function H6(e) {
  Ge.suppressDeprecationWarnings === !1 && typeof console < "u" && console.warn && console.warn("Deprecation warning: " + e);
}
function to(e, t) {
  var n = !0;
  return xl(function() {
    if (Ge.deprecationHandler != null && Ge.deprecationHandler(null, e), n) {
      var r = [], i, a, o, s = arguments.length;
      for (a = 0; a < s; a++) {
        if (i = "", typeof arguments[a] == "object") {
          i += `
[` + a + "] ";
          for (o in arguments[0])
            Ln(arguments[0], o) && (i += o + ": " + arguments[0][o] + ", ");
          i = i.slice(0, -2);
        } else
          i = arguments[a];
        r.push(i);
      }
      H6(
        e + `
Arguments: ` + Array.prototype.slice.call(r).join("") + `
` + new Error().stack
      ), n = !1;
    }
    return t.apply(this, arguments);
  }, t);
}
var w2 = {};
function z6(e, t) {
  Ge.deprecationHandler != null && Ge.deprecationHandler(e, t), w2[e] || (H6(t), w2[e] = !0);
}
Ge.suppressDeprecationWarnings = !1;
Ge.deprecationHandler = null;
function as(e) {
  return typeof Function < "u" && e instanceof Function || Object.prototype.toString.call(e) === "[object Function]";
}
function $he(e) {
  var t, n;
  for (n in e)
    Ln(e, n) && (t = e[n], as(t) ? this[n] = t : this["_" + n] = t);
  this._config = e, this._dayOfMonthOrdinalParseLenient = new RegExp(
    (this._dayOfMonthOrdinalParse.source || this._ordinalParse.source) + "|" + /\d{1,2}/.source
  );
}
function DC(e, t) {
  var n = xl({}, e), r;
  for (r in t)
    Ln(t, r) && (Bu(e[r]) && Bu(t[r]) ? (n[r] = {}, xl(n[r], e[r]), xl(n[r], t[r])) : t[r] != null ? n[r] = t[r] : delete n[r]);
  for (r in e)
    Ln(e, r) && !Ln(t, r) && Bu(e[r]) && (n[r] = xl({}, n[r]));
  return n;
}
function pA(e) {
  e != null && this.set(e);
}
var IC;
Object.keys ? IC = Object.keys : IC = function(e) {
  var t, n = [];
  for (t in e)
    Ln(e, t) && n.push(t);
  return n;
};
var Uhe = {
  sameDay: "[Today at] LT",
  nextDay: "[Tomorrow at] LT",
  nextWeek: "dddd [at] LT",
  lastDay: "[Yesterday at] LT",
  lastWeek: "[Last] dddd [at] LT",
  sameElse: "L"
};
function qhe(e, t, n) {
  var r = this._calendar[e] || this._calendar.sameElse;
  return as(r) ? r.call(t, n) : r;
}
function Qo(e, t, n) {
  var r = "" + Math.abs(e), i = t - r.length, a = e >= 0;
  return (a ? n ? "+" : "" : "-") + Math.pow(10, Math.max(0, i)).toString().substr(1) + r;
}
var mA = /(\[[^\[]*\])|(\\)?([Hh]mm(ss)?|Mo|MM?M?M?|Do|DDDo|DD?D?D?|ddd?d?|do?|w[o|w]?|W[o|W]?|Qo?|N{1,5}|YYYYYY|YYYYY|YYYY|YY|y{2,4}|yo?|gg(ggg?)?|GG(GGG?)?|e|E|a|A|hh?|HH?|kk?|mm?|ss?|S{1,9}|x|X|zz?|ZZ?|.)/g, Hh = /(\[[^\[]*\])|(\\)?(LTS|LT|LL?L?L?|l{1,4})/g, mT = {}, td = {};
function Lt(e, t, n, r) {
  var i = r;
  typeof r == "string" && (i = function() {
    return this[r]();
  }), e && (td[e] = i), t && (td[t[0]] = function() {
    return Qo(i.apply(this, arguments), t[1], t[2]);
  }), n && (td[n] = function() {
    return this.localeData().ordinal(
      i.apply(this, arguments),
      e
    );
  });
}
function Ghe(e) {
  return e.match(/\[[\s\S]/) ? e.replace(/^\[|\]$/g, "") : e.replace(/\\/g, "");
}
function Yhe(e) {
  var t = e.match(mA), n, r;
  for (n = 0, r = t.length; n < r; n++)
    td[t[n]] ? t[n] = td[t[n]] : t[n] = Ghe(t[n]);
  return function(i) {
    var a = "", o;
    for (o = 0; o < r; o++)
      a += as(t[o]) ? t[o].call(i, e) : t[o];
    return a;
  };
}
function _g(e, t) {
  return e.isValid() ? (t = V6(t, e.localeData()), mT[t] = mT[t] || Yhe(t), mT[t](e)) : e.localeData().invalidDate();
}
function V6(e, t) {
  var n = 5;
  function r(i) {
    return t.longDateFormat(i) || i;
  }
  for (Hh.lastIndex = 0; n >= 0 && Hh.test(e); )
    e = e.replace(
      Hh,
      r
    ), Hh.lastIndex = 0, n -= 1;
  return e;
}
var Hhe = {
  LTS: "h:mm:ss A",
  LT: "h:mm A",
  L: "MM/DD/YYYY",
  LL: "MMMM D, YYYY",
  LLL: "MMMM D, YYYY h:mm A",
  LLLL: "dddd, MMMM D, YYYY h:mm A"
};
function zhe(e) {
  var t = this._longDateFormat[e], n = this._longDateFormat[e.toUpperCase()];
  return t || !n ? t : (this._longDateFormat[e] = n.match(mA).map(function(r) {
    return r === "MMMM" || r === "MM" || r === "DD" || r === "dddd" ? r.slice(1) : r;
  }).join(""), this._longDateFormat[e]);
}
var Vhe = "Invalid date";
function Whe() {
  return this._invalidDate;
}
var Khe = "%d", jhe = /\d{1,2}/;
function Qhe(e) {
  return this._ordinal.replace("%d", e);
}
var Xhe = {
  future: "in %s",
  past: "%s ago",
  s: "a few seconds",
  ss: "%d seconds",
  m: "a minute",
  mm: "%d minutes",
  h: "an hour",
  hh: "%d hours",
  d: "a day",
  dd: "%d days",
  w: "a week",
  ww: "%d weeks",
  M: "a month",
  MM: "%d months",
  y: "a year",
  yy: "%d years"
};
function Zhe(e, t, n, r) {
  var i = this._relativeTime[n];
  return as(i) ? i(e, t, n, r) : i.replace(/%d/i, e);
}
function Jhe(e, t) {
  var n = this._relativeTime[e > 0 ? "future" : "past"];
  return as(n) ? n(t) : n.replace(/%s/i, t);
}
var x2 = {
  D: "date",
  dates: "date",
  date: "date",
  d: "day",
  days: "day",
  day: "day",
  e: "weekday",
  weekdays: "weekday",
  weekday: "weekday",
  E: "isoWeekday",
  isoweekdays: "isoWeekday",
  isoweekday: "isoWeekday",
  DDD: "dayOfYear",
  dayofyears: "dayOfYear",
  dayofyear: "dayOfYear",
  h: "hour",
  hours: "hour",
  hour: "hour",
  ms: "millisecond",
  milliseconds: "millisecond",
  millisecond: "millisecond",
  m: "minute",
  minutes: "minute",
  minute: "minute",
  M: "month",
  months: "month",
  month: "month",
  Q: "quarter",
  quarters: "quarter",
  quarter: "quarter",
  s: "second",
  seconds: "second",
  second: "second",
  gg: "weekYear",
  weekyears: "weekYear",
  weekyear: "weekYear",
  GG: "isoWeekYear",
  isoweekyears: "isoWeekYear",
  isoweekyear: "isoWeekYear",
  w: "week",
  weeks: "week",
  week: "week",
  W: "isoWeek",
  isoweeks: "isoWeek",
  isoweek: "isoWeek",
  y: "year",
  years: "year",
  year: "year"
};
function no(e) {
  return typeof e == "string" ? x2[e] || x2[e.toLowerCase()] : void 0;
}
function hA(e) {
  var t = {}, n, r;
  for (r in e)
    Ln(e, r) && (n = no(r), n && (t[n] = e[r]));
  return t;
}
var ege = {
  date: 9,
  day: 11,
  weekday: 11,
  isoWeekday: 11,
  dayOfYear: 4,
  hour: 13,
  millisecond: 16,
  minute: 14,
  month: 8,
  quarter: 7,
  second: 15,
  weekYear: 1,
  isoWeekYear: 1,
  week: 5,
  isoWeek: 5,
  year: 1
};
function tge(e) {
  var t = [], n;
  for (n in e)
    Ln(e, n) && t.push({ unit: n, priority: ege[n] });
  return t.sort(function(r, i) {
    return r.priority - i.priority;
  }), t;
}
var W6 = /\d/, ka = /\d\d/, K6 = /\d{3}/, gA = /\d{4}/, pv = /[+-]?\d{6}/, gr = /\d\d?/, j6 = /\d\d\d\d?/, Q6 = /\d\d\d\d\d\d?/, mv = /\d{1,3}/, _A = /\d{1,4}/, hv = /[+-]?\d{1,6}/, Dd = /\d+/, gv = /[+-]?\d+/, nge = /Z|[+-]\d\d:?\d\d/gi, _v = /Z|[+-]\d\d(?::?\d\d)?/gi, rge = /[+-]?\d+(\.\d{1,3})?/, vm = /[0-9]{0,256}['a-z\u00A0-\u05FF\u0700-\uD7FF\uF900-\uFDCF\uFDF0-\uFF07\uFF10-\uFFEF]{1,256}|[\u0600-\u06FF\/]{1,256}(\s*?[\u0600-\u06FF]{1,256}){1,2}/i, Id = /^[1-9]\d?/, vA = /^([1-9]\d|\d)/, o_;
o_ = {};
function Et(e, t, n) {
  o_[e] = as(t) ? t : function(r, i) {
    return r && n ? n : t;
  };
}
function ige(e, t) {
  return Ln(o_, e) ? o_[e](t._strict, t._locale) : new RegExp(age(e));
}
function age(e) {
  return Ps(
    e.replace("\\", "").replace(
      /\\(\[)|\\(\])|\[([^\]\[]*)\]|\\(.)/g,
      function(t, n, r, i, a) {
        return n || r || i || a;
      }
    )
  );
}
function Ps(e) {
  return e.replace(/[-\/\\^$*+?.()|[\]{}]/g, "\\$&");
}
function Qa(e) {
  return e < 0 ? Math.ceil(e) || 0 : Math.floor(e);
}
function yn(e) {
  var t = +e, n = 0;
  return t !== 0 && isFinite(t) && (n = Qa(t)), n;
}
var LC = {};
function Wn(e, t) {
  var n, r = t, i;
  for (typeof e == "string" && (e = [e]), qs(t) && (r = function(a, o) {
    o[t] = yn(a);
  }), i = e.length, n = 0; n < i; n++)
    LC[e[n]] = r;
}
function bm(e, t) {
  Wn(e, function(n, r, i, a) {
    i._w = i._w || {}, t(n, i._w, i, a);
  });
}
function oge(e, t, n) {
  t != null && Ln(LC, e) && LC[e](t, n._a, n, e);
}
function vv(e) {
  return e % 4 === 0 && e % 100 !== 0 || e % 400 === 0;
}
var Li = 0, Ds = 1, Bo = 2, ai = 3, vo = 4, Is = 5, Iu = 6, sge = 7, lge = 8;
Lt("Y", 0, 0, function() {
  var e = this.year();
  return e <= 9999 ? Qo(e, 4) : "+" + e;
});
Lt(0, ["YY", 2], 0, function() {
  return this.year() % 100;
});
Lt(0, ["YYYY", 4], 0, "year");
Lt(0, ["YYYYY", 5], 0, "year");
Lt(0, ["YYYYYY", 6, !0], 0, "year");
Et("Y", gv);
Et("YY", gr, ka);
Et("YYYY", _A, gA);
Et("YYYYY", hv, pv);
Et("YYYYYY", hv, pv);
Wn(["YYYYY", "YYYYYY"], Li);
Wn("YYYY", function(e, t) {
  t[Li] = e.length === 2 ? Ge.parseTwoDigitYear(e) : yn(e);
});
Wn("YY", function(e, t) {
  t[Li] = Ge.parseTwoDigitYear(e);
});
Wn("Y", function(e, t) {
  t[Li] = parseInt(e, 10);
});
function tp(e) {
  return vv(e) ? 366 : 365;
}
Ge.parseTwoDigitYear = function(e) {
  return yn(e) + (yn(e) > 68 ? 1900 : 2e3);
};
var X6 = Ld("FullYear", !0);
function uge() {
  return vv(this.year());
}
function Ld(e, t) {
  return function(n) {
    return n != null ? (Z6(this, e, n), Ge.updateOffset(this, t), this) : Pp(this, e);
  };
}
function Pp(e, t) {
  if (!e.isValid())
    return NaN;
  var n = e._d, r = e._isUTC;
  switch (t) {
    case "Milliseconds":
      return r ? n.getUTCMilliseconds() : n.getMilliseconds();
    case "Seconds":
      return r ? n.getUTCSeconds() : n.getSeconds();
    case "Minutes":
      return r ? n.getUTCMinutes() : n.getMinutes();
    case "Hours":
      return r ? n.getUTCHours() : n.getHours();
    case "Date":
      return r ? n.getUTCDate() : n.getDate();
    case "Day":
      return r ? n.getUTCDay() : n.getDay();
    case "Month":
      return r ? n.getUTCMonth() : n.getMonth();
    case "FullYear":
      return r ? n.getUTCFullYear() : n.getFullYear();
    default:
      return NaN;
  }
}
function Z6(e, t, n) {
  var r, i, a, o, s;
  if (!(!e.isValid() || isNaN(n))) {
    switch (r = e._d, i = e._isUTC, t) {
      case "Milliseconds":
        return void (i ? r.setUTCMilliseconds(n) : r.setMilliseconds(n));
      case "Seconds":
        return void (i ? r.setUTCSeconds(n) : r.setSeconds(n));
      case "Minutes":
        return void (i ? r.setUTCMinutes(n) : r.setMinutes(n));
      case "Hours":
        return void (i ? r.setUTCHours(n) : r.setHours(n));
      case "Date":
        return void (i ? r.setUTCDate(n) : r.setDate(n));
      case "FullYear":
        break;
      default:
        return;
    }
    a = n, o = e.month(), s = e.date(), s = s === 29 && o === 1 && !vv(a) ? 28 : s, i ? r.setUTCFullYear(a, o, s) : r.setFullYear(a, o, s);
  }
}
function cge(e) {
  return e = no(e), as(this[e]) ? this[e]() : this;
}
function dge(e, t) {
  if (typeof e == "object") {
    e = hA(e);
    var n = tge(e), r, i = n.length;
    for (r = 0; r < i; r++)
      this[n[r].unit](e[n[r].unit]);
  } else if (e = no(e), as(this[e]))
    return this[e](t);
  return this;
}
function fge(e, t) {
  return (e % t + t) % t;
}
var Br;
Array.prototype.indexOf ? Br = Array.prototype.indexOf : Br = function(e) {
  var t;
  for (t = 0; t < this.length; ++t)
    if (this[t] === e)
      return t;
  return -1;
};
function bA(e, t) {
  if (isNaN(e) || isNaN(t))
    return NaN;
  var n = fge(t, 12);
  return e += (t - n) / 12, n === 1 ? vv(e) ? 29 : 28 : 31 - n % 7 % 2;
}
Lt("M", ["MM", 2], "Mo", function() {
  return this.month() + 1;
});
Lt("MMM", 0, 0, function(e) {
  return this.localeData().monthsShort(this, e);
});
Lt("MMMM", 0, 0, function(e) {
  return this.localeData().months(this, e);
});
Et("M", gr, Id);
Et("MM", gr, ka);
Et("MMM", function(e, t) {
  return t.monthsShortRegex(e);
});
Et("MMMM", function(e, t) {
  return t.monthsRegex(e);
});
Wn(["M", "MM"], function(e, t) {
  t[Ds] = yn(e) - 1;
});
Wn(["MMM", "MMMM"], function(e, t, n, r) {
  var i = n._locale.monthsParse(e, r, n._strict);
  i != null ? t[Ds] = i : dn(n).invalidMonth = e;
});
var pge = "January_February_March_April_May_June_July_August_September_October_November_December".split(
  "_"
), J6 = "Jan_Feb_Mar_Apr_May_Jun_Jul_Aug_Sep_Oct_Nov_Dec".split("_"), e4 = /D[oD]?(\[[^\[\]]*\]|\s)+MMMM?/, mge = vm, hge = vm;
function gge(e, t) {
  return e ? To(this._months) ? this._months[e.month()] : this._months[(this._months.isFormat || e4).test(t) ? "format" : "standalone"][e.month()] : To(this._months) ? this._months : this._months.standalone;
}
function _ge(e, t) {
  return e ? To(this._monthsShort) ? this._monthsShort[e.month()] : this._monthsShort[e4.test(t) ? "format" : "standalone"][e.month()] : To(this._monthsShort) ? this._monthsShort : this._monthsShort.standalone;
}
function vge(e, t, n) {
  var r, i, a, o = e.toLocaleLowerCase();
  if (!this._monthsParse)
    for (this._monthsParse = [], this._longMonthsParse = [], this._shortMonthsParse = [], r = 0; r < 12; ++r)
      a = is([2e3, r]), this._shortMonthsParse[r] = this.monthsShort(
        a,
        ""
      ).toLocaleLowerCase(), this._longMonthsParse[r] = this.months(a, "").toLocaleLowerCase();
  return n ? t === "MMM" ? (i = Br.call(this._shortMonthsParse, o), i !== -1 ? i : null) : (i = Br.call(this._longMonthsParse, o), i !== -1 ? i : null) : t === "MMM" ? (i = Br.call(this._shortMonthsParse, o), i !== -1 ? i : (i = Br.call(this._longMonthsParse, o), i !== -1 ? i : null)) : (i = Br.call(this._longMonthsParse, o), i !== -1 ? i : (i = Br.call(this._shortMonthsParse, o), i !== -1 ? i : null));
}
function bge(e, t, n) {
  var r, i, a;
  if (this._monthsParseExact)
    return vge.call(this, e, t, n);
  for (this._monthsParse || (this._monthsParse = [], this._longMonthsParse = [], this._shortMonthsParse = []), r = 0; r < 12; r++) {
    if (i = is([2e3, r]), n && !this._longMonthsParse[r] && (this._longMonthsParse[r] = new RegExp(
      "^" + this.months(i, "").replace(".", "") + "$",
      "i"
    ), this._shortMonthsParse[r] = new RegExp(
      "^" + this.monthsShort(i, "").replace(".", "") + "$",
      "i"
    )), !n && !this._monthsParse[r] && (a = "^" + this.months(i, "") + "|^" + this.monthsShort(i, ""), this._monthsParse[r] = new RegExp(a.replace(".", ""), "i")), n && t === "MMMM" && this._longMonthsParse[r].test(e))
      return r;
    if (n && t === "MMM" && this._shortMonthsParse[r].test(e))
      return r;
    if (!n && this._monthsParse[r].test(e))
      return r;
  }
}
function t4(e, t) {
  if (!e.isValid())
    return e;
  if (typeof t == "string") {
    if (/^\d+$/.test(t))
      t = yn(t);
    else if (t = e.localeData().monthsParse(t), !qs(t))
      return e;
  }
  var n = t, r = e.date();
  return r = r < 29 ? r : Math.min(r, bA(e.year(), n)), e._isUTC ? e._d.setUTCMonth(n, r) : e._d.setMonth(n, r), e;
}
function n4(e) {
  return e != null ? (t4(this, e), Ge.updateOffset(this, !0), this) : Pp(this, "Month");
}
function Ege() {
  return bA(this.year(), this.month());
}
function Sge(e) {
  return this._monthsParseExact ? (Ln(this, "_monthsRegex") || r4.call(this), e ? this._monthsShortStrictRegex : this._monthsShortRegex) : (Ln(this, "_monthsShortRegex") || (this._monthsShortRegex = mge), this._monthsShortStrictRegex && e ? this._monthsShortStrictRegex : this._monthsShortRegex);
}
function yge(e) {
  return this._monthsParseExact ? (Ln(this, "_monthsRegex") || r4.call(this), e ? this._monthsStrictRegex : this._monthsRegex) : (Ln(this, "_monthsRegex") || (this._monthsRegex = hge), this._monthsStrictRegex && e ? this._monthsStrictRegex : this._monthsRegex);
}
function r4() {
  function e(l, u) {
    return u.length - l.length;
  }
  var t = [], n = [], r = [], i, a, o, s;
  for (i = 0; i < 12; i++)
    a = is([2e3, i]), o = Ps(this.monthsShort(a, "")), s = Ps(this.months(a, "")), t.push(o), n.push(s), r.push(s), r.push(o);
  t.sort(e), n.sort(e), r.sort(e), this._monthsRegex = new RegExp("^(" + r.join("|") + ")", "i"), this._monthsShortRegex = this._monthsRegex, this._monthsStrictRegex = new RegExp(
    "^(" + n.join("|") + ")",
    "i"
  ), this._monthsShortStrictRegex = new RegExp(
    "^(" + t.join("|") + ")",
    "i"
  );
}
function Tge(e, t, n, r, i, a, o) {
  var s;
  return e < 100 && e >= 0 ? (s = new Date(e + 400, t, n, r, i, a, o), isFinite(s.getFullYear()) && s.setFullYear(e)) : s = new Date(e, t, n, r, i, a, o), s;
}
function Fp(e) {
  var t, n;
  return e < 100 && e >= 0 ? (n = Array.prototype.slice.call(arguments), n[0] = e + 400, t = new Date(Date.UTC.apply(null, n)), isFinite(t.getUTCFullYear()) && t.setUTCFullYear(e)) : t = new Date(Date.UTC.apply(null, arguments)), t;
}
function s_(e, t, n) {
  var r = 7 + t - n, i = (7 + Fp(e, 0, r).getUTCDay() - t) % 7;
  return -i + r - 1;
}
function i4(e, t, n, r, i) {
  var a = (7 + n - r) % 7, o = s_(e, r, i), s = 1 + 7 * (t - 1) + a + o, l, u;
  return s <= 0 ? (l = e - 1, u = tp(l) + s) : s > tp(e) ? (l = e + 1, u = s - tp(e)) : (l = e, u = s), {
    year: l,
    dayOfYear: u
  };
}
function Bp(e, t, n) {
  var r = s_(e.year(), t, n), i = Math.floor((e.dayOfYear() - r - 1) / 7) + 1, a, o;
  return i < 1 ? (o = e.year() - 1, a = i + Fs(o, t, n)) : i > Fs(e.year(), t, n) ? (a = i - Fs(e.year(), t, n), o = e.year() + 1) : (o = e.year(), a = i), {
    week: a,
    year: o
  };
}
function Fs(e, t, n) {
  var r = s_(e, t, n), i = s_(e + 1, t, n);
  return (tp(e) - r + i) / 7;
}
Lt("w", ["ww", 2], "wo", "week");
Lt("W", ["WW", 2], "Wo", "isoWeek");
Et("w", gr, Id);
Et("ww", gr, ka);
Et("W", gr, Id);
Et("WW", gr, ka);
bm(
  ["w", "ww", "W", "WW"],
  function(e, t, n, r) {
    t[r.substr(0, 1)] = yn(e);
  }
);
function Cge(e) {
  return Bp(e, this._week.dow, this._week.doy).week;
}
var Age = {
  dow: 0,
  // Sunday is the first day of the week.
  doy: 6
  // The week that contains Jan 6th is the first week of the year.
};
function Oge() {
  return this._week.dow;
}
function Rge() {
  return this._week.doy;
}
function wge(e) {
  var t = this.localeData().week(this);
  return e == null ? t : this.add((e - t) * 7, "d");
}
function xge(e) {
  var t = Bp(this, 1, 4).week;
  return e == null ? t : this.add((e - t) * 7, "d");
}
Lt("d", 0, "do", "day");
Lt("dd", 0, 0, function(e) {
  return this.localeData().weekdaysMin(this, e);
});
Lt("ddd", 0, 0, function(e) {
  return this.localeData().weekdaysShort(this, e);
});
Lt("dddd", 0, 0, function(e) {
  return this.localeData().weekdays(this, e);
});
Lt("e", 0, 0, "weekday");
Lt("E", 0, 0, "isoWeekday");
Et("d", gr);
Et("e", gr);
Et("E", gr);
Et("dd", function(e, t) {
  return t.weekdaysMinRegex(e);
});
Et("ddd", function(e, t) {
  return t.weekdaysShortRegex(e);
});
Et("dddd", function(e, t) {
  return t.weekdaysRegex(e);
});
bm(["dd", "ddd", "dddd"], function(e, t, n, r) {
  var i = n._locale.weekdaysParse(e, r, n._strict);
  i != null ? t.d = i : dn(n).invalidWeekday = e;
});
bm(["d", "e", "E"], function(e, t, n, r) {
  t[r] = yn(e);
});
function Nge(e, t) {
  return typeof e != "string" ? e : isNaN(e) ? (e = t.weekdaysParse(e), typeof e == "number" ? e : null) : parseInt(e, 10);
}
function Dge(e, t) {
  return typeof e == "string" ? t.weekdaysParse(e) % 7 || 7 : isNaN(e) ? null : e;
}
function EA(e, t) {
  return e.slice(t, 7).concat(e.slice(0, t));
}
var Ige = "Sunday_Monday_Tuesday_Wednesday_Thursday_Friday_Saturday".split("_"), a4 = "Sun_Mon_Tue_Wed_Thu_Fri_Sat".split("_"), Lge = "Su_Mo_Tu_We_Th_Fr_Sa".split("_"), kge = vm, Mge = vm, Pge = vm;
function Fge(e, t) {
  var n = To(this._weekdays) ? this._weekdays : this._weekdays[e && e !== !0 && this._weekdays.isFormat.test(t) ? "format" : "standalone"];
  return e === !0 ? EA(n, this._week.dow) : e ? n[e.day()] : n;
}
function Bge(e) {
  return e === !0 ? EA(this._weekdaysShort, this._week.dow) : e ? this._weekdaysShort[e.day()] : this._weekdaysShort;
}
function $ge(e) {
  return e === !0 ? EA(this._weekdaysMin, this._week.dow) : e ? this._weekdaysMin[e.day()] : this._weekdaysMin;
}
function Uge(e, t, n) {
  var r, i, a, o = e.toLocaleLowerCase();
  if (!this._weekdaysParse)
    for (this._weekdaysParse = [], this._shortWeekdaysParse = [], this._minWeekdaysParse = [], r = 0; r < 7; ++r)
      a = is([2e3, 1]).day(r), this._minWeekdaysParse[r] = this.weekdaysMin(
        a,
        ""
      ).toLocaleLowerCase(), this._shortWeekdaysParse[r] = this.weekdaysShort(
        a,
        ""
      ).toLocaleLowerCase(), this._weekdaysParse[r] = this.weekdays(a, "").toLocaleLowerCase();
  return n ? t === "dddd" ? (i = Br.call(this._weekdaysParse, o), i !== -1 ? i : null) : t === "ddd" ? (i = Br.call(this._shortWeekdaysParse, o), i !== -1 ? i : null) : (i = Br.call(this._minWeekdaysParse, o), i !== -1 ? i : null) : t === "dddd" ? (i = Br.call(this._weekdaysParse, o), i !== -1 || (i = Br.call(this._shortWeekdaysParse, o), i !== -1) ? i : (i = Br.call(this._minWeekdaysParse, o), i !== -1 ? i : null)) : t === "ddd" ? (i = Br.call(this._shortWeekdaysParse, o), i !== -1 || (i = Br.call(this._weekdaysParse, o), i !== -1) ? i : (i = Br.call(this._minWeekdaysParse, o), i !== -1 ? i : null)) : (i = Br.call(this._minWeekdaysParse, o), i !== -1 || (i = Br.call(this._weekdaysParse, o), i !== -1) ? i : (i = Br.call(this._shortWeekdaysParse, o), i !== -1 ? i : null));
}
function qge(e, t, n) {
  var r, i, a;
  if (this._weekdaysParseExact)
    return Uge.call(this, e, t, n);
  for (this._weekdaysParse || (this._weekdaysParse = [], this._minWeekdaysParse = [], this._shortWeekdaysParse = [], this._fullWeekdaysParse = []), r = 0; r < 7; r++) {
    if (i = is([2e3, 1]).day(r), n && !this._fullWeekdaysParse[r] && (this._fullWeekdaysParse[r] = new RegExp(
      "^" + this.weekdays(i, "").replace(".", "\\.?") + "$",
      "i"
    ), this._shortWeekdaysParse[r] = new RegExp(
      "^" + this.weekdaysShort(i, "").replace(".", "\\.?") + "$",
      "i"
    ), this._minWeekdaysParse[r] = new RegExp(
      "^" + this.weekdaysMin(i, "").replace(".", "\\.?") + "$",
      "i"
    )), this._weekdaysParse[r] || (a = "^" + this.weekdays(i, "") + "|^" + this.weekdaysShort(i, "") + "|^" + this.weekdaysMin(i, ""), this._weekdaysParse[r] = new RegExp(a.replace(".", ""), "i")), n && t === "dddd" && this._fullWeekdaysParse[r].test(e))
      return r;
    if (n && t === "ddd" && this._shortWeekdaysParse[r].test(e))
      return r;
    if (n && t === "dd" && this._minWeekdaysParse[r].test(e))
      return r;
    if (!n && this._weekdaysParse[r].test(e))
      return r;
  }
}
function Gge(e) {
  if (!this.isValid())
    return e != null ? this : NaN;
  var t = Pp(this, "Day");
  return e != null ? (e = Nge(e, this.localeData()), this.add(e - t, "d")) : t;
}
function Yge(e) {
  if (!this.isValid())
    return e != null ? this : NaN;
  var t = (this.day() + 7 - this.localeData()._week.dow) % 7;
  return e == null ? t : this.add(e - t, "d");
}
function Hge(e) {
  if (!this.isValid())
    return e != null ? this : NaN;
  if (e != null) {
    var t = Dge(e, this.localeData());
    return this.day(this.day() % 7 ? t : t - 7);
  } else
    return this.day() || 7;
}
function zge(e) {
  return this._weekdaysParseExact ? (Ln(this, "_weekdaysRegex") || SA.call(this), e ? this._weekdaysStrictRegex : this._weekdaysRegex) : (Ln(this, "_weekdaysRegex") || (this._weekdaysRegex = kge), this._weekdaysStrictRegex && e ? this._weekdaysStrictRegex : this._weekdaysRegex);
}
function Vge(e) {
  return this._weekdaysParseExact ? (Ln(this, "_weekdaysRegex") || SA.call(this), e ? this._weekdaysShortStrictRegex : this._weekdaysShortRegex) : (Ln(this, "_weekdaysShortRegex") || (this._weekdaysShortRegex = Mge), this._weekdaysShortStrictRegex && e ? this._weekdaysShortStrictRegex : this._weekdaysShortRegex);
}
function Wge(e) {
  return this._weekdaysParseExact ? (Ln(this, "_weekdaysRegex") || SA.call(this), e ? this._weekdaysMinStrictRegex : this._weekdaysMinRegex) : (Ln(this, "_weekdaysMinRegex") || (this._weekdaysMinRegex = Pge), this._weekdaysMinStrictRegex && e ? this._weekdaysMinStrictRegex : this._weekdaysMinRegex);
}
function SA() {
  function e(c, d) {
    return d.length - c.length;
  }
  var t = [], n = [], r = [], i = [], a, o, s, l, u;
  for (a = 0; a < 7; a++)
    o = is([2e3, 1]).day(a), s = Ps(this.weekdaysMin(o, "")), l = Ps(this.weekdaysShort(o, "")), u = Ps(this.weekdays(o, "")), t.push(s), n.push(l), r.push(u), i.push(s), i.push(l), i.push(u);
  t.sort(e), n.sort(e), r.sort(e), i.sort(e), this._weekdaysRegex = new RegExp("^(" + i.join("|") + ")", "i"), this._weekdaysShortRegex = this._weekdaysRegex, this._weekdaysMinRegex = this._weekdaysRegex, this._weekdaysStrictRegex = new RegExp(
    "^(" + r.join("|") + ")",
    "i"
  ), this._weekdaysShortStrictRegex = new RegExp(
    "^(" + n.join("|") + ")",
    "i"
  ), this._weekdaysMinStrictRegex = new RegExp(
    "^(" + t.join("|") + ")",
    "i"
  );
}
function yA() {
  return this.hours() % 12 || 12;
}
function Kge() {
  return this.hours() || 24;
}
Lt("H", ["HH", 2], 0, "hour");
Lt("h", ["hh", 2], 0, yA);
Lt("k", ["kk", 2], 0, Kge);
Lt("hmm", 0, 0, function() {
  return "" + yA.apply(this) + Qo(this.minutes(), 2);
});
Lt("hmmss", 0, 0, function() {
  return "" + yA.apply(this) + Qo(this.minutes(), 2) + Qo(this.seconds(), 2);
});
Lt("Hmm", 0, 0, function() {
  return "" + this.hours() + Qo(this.minutes(), 2);
});
Lt("Hmmss", 0, 0, function() {
  return "" + this.hours() + Qo(this.minutes(), 2) + Qo(this.seconds(), 2);
});
function o4(e, t) {
  Lt(e, 0, 0, function() {
    return this.localeData().meridiem(
      this.hours(),
      this.minutes(),
      t
    );
  });
}
o4("a", !0);
o4("A", !1);
function s4(e, t) {
  return t._meridiemParse;
}
Et("a", s4);
Et("A", s4);
Et("H", gr, vA);
Et("h", gr, Id);
Et("k", gr, Id);
Et("HH", gr, ka);
Et("hh", gr, ka);
Et("kk", gr, ka);
Et("hmm", j6);
Et("hmmss", Q6);
Et("Hmm", j6);
Et("Hmmss", Q6);
Wn(["H", "HH"], ai);
Wn(["k", "kk"], function(e, t, n) {
  var r = yn(e);
  t[ai] = r === 24 ? 0 : r;
});
Wn(["a", "A"], function(e, t, n) {
  n._isPm = n._locale.isPM(e), n._meridiem = e;
});
Wn(["h", "hh"], function(e, t, n) {
  t[ai] = yn(e), dn(n).bigHour = !0;
});
Wn("hmm", function(e, t, n) {
  var r = e.length - 2;
  t[ai] = yn(e.substr(0, r)), t[vo] = yn(e.substr(r)), dn(n).bigHour = !0;
});
Wn("hmmss", function(e, t, n) {
  var r = e.length - 4, i = e.length - 2;
  t[ai] = yn(e.substr(0, r)), t[vo] = yn(e.substr(r, 2)), t[Is] = yn(e.substr(i)), dn(n).bigHour = !0;
});
Wn("Hmm", function(e, t, n) {
  var r = e.length - 2;
  t[ai] = yn(e.substr(0, r)), t[vo] = yn(e.substr(r));
});
Wn("Hmmss", function(e, t, n) {
  var r = e.length - 4, i = e.length - 2;
  t[ai] = yn(e.substr(0, r)), t[vo] = yn(e.substr(r, 2)), t[Is] = yn(e.substr(i));
});
function jge(e) {
  return (e + "").toLowerCase().charAt(0) === "p";
}
var Qge = /[ap]\.?m?\.?/i, Xge = Ld("Hours", !0);
function Zge(e, t, n) {
  return e > 11 ? n ? "pm" : "PM" : n ? "am" : "AM";
}
var l4 = {
  calendar: Uhe,
  longDateFormat: Hhe,
  invalidDate: Vhe,
  ordinal: Khe,
  dayOfMonthOrdinalParse: jhe,
  relativeTime: Xhe,
  months: pge,
  monthsShort: J6,
  week: Age,
  weekdays: Ige,
  weekdaysMin: Lge,
  weekdaysShort: a4,
  meridiemParse: Qge
}, Tr = {}, wf = {}, $p;
function Jge(e, t) {
  var n, r = Math.min(e.length, t.length);
  for (n = 0; n < r; n += 1)
    if (e[n] !== t[n])
      return n;
  return r;
}
function N2(e) {
  return e && e.toLowerCase().replace("_", "-");
}
function e_e(e) {
  for (var t = 0, n, r, i, a; t < e.length; ) {
    for (a = N2(e[t]).split("-"), n = a.length, r = N2(e[t + 1]), r = r ? r.split("-") : null; n > 0; ) {
      if (i = bv(a.slice(0, n).join("-")), i)
        return i;
      if (r && r.length >= n && Jge(a, r) >= n - 1)
        break;
      n--;
    }
    t++;
  }
  return $p;
}
function t_e(e) {
  return !!(e && e.match("^[^/\\\\]*$"));
}
function bv(e) {
  var t = null, n;
  if (Tr[e] === void 0 && typeof module < "u" && module && module.exports && t_e(e))
    try {
      t = $p._abbr, n = require, n("./locale/" + e), Ml(t);
    } catch {
      Tr[e] = null;
    }
  return Tr[e];
}
function Ml(e, t) {
  var n;
  return e && (ra(t) ? n = Ws(e) : n = TA(e, t), n ? $p = n : typeof console < "u" && console.warn && console.warn(
    "Locale " + e + " not found. Did you forget to load it?"
  )), $p._abbr;
}
function TA(e, t) {
  if (t !== null) {
    var n, r = l4;
    if (t.abbr = e, Tr[e] != null)
      z6(
        "defineLocaleOverride",
        "use moment.updateLocale(localeName, config) to change an existing locale. moment.defineLocale(localeName, config) should only be used for creating a new locale See http://momentjs.com/guides/#/warnings/define-locale/ for more info."
      ), r = Tr[e]._config;
    else if (t.parentLocale != null)
      if (Tr[t.parentLocale] != null)
        r = Tr[t.parentLocale]._config;
      else if (n = bv(t.parentLocale), n != null)
        r = n._config;
      else
        return wf[t.parentLocale] || (wf[t.parentLocale] = []), wf[t.parentLocale].push({
          name: e,
          config: t
        }), null;
    return Tr[e] = new pA(DC(r, t)), wf[e] && wf[e].forEach(function(i) {
      TA(i.name, i.config);
    }), Ml(e), Tr[e];
  } else
    return delete Tr[e], null;
}
function n_e(e, t) {
  if (t != null) {
    var n, r, i = l4;
    Tr[e] != null && Tr[e].parentLocale != null ? Tr[e].set(DC(Tr[e]._config, t)) : (r = bv(e), r != null && (i = r._config), t = DC(i, t), r == null && (t.abbr = e), n = new pA(t), n.parentLocale = Tr[e], Tr[e] = n), Ml(e);
  } else
    Tr[e] != null && (Tr[e].parentLocale != null ? (Tr[e] = Tr[e].parentLocale, e === Ml() && Ml(e)) : Tr[e] != null && delete Tr[e]);
  return Tr[e];
}
function Ws(e) {
  var t;
  if (e && e._locale && e._locale._abbr && (e = e._locale._abbr), !e)
    return $p;
  if (!To(e)) {
    if (t = bv(e), t)
      return t;
    e = [e];
  }
  return e_e(e);
}
function r_e() {
  return IC(Tr);
}
function CA(e) {
  var t, n = e._a;
  return n && dn(e).overflow === -2 && (t = n[Ds] < 0 || n[Ds] > 11 ? Ds : n[Bo] < 1 || n[Bo] > bA(n[Li], n[Ds]) ? Bo : n[ai] < 0 || n[ai] > 24 || n[ai] === 24 && (n[vo] !== 0 || n[Is] !== 0 || n[Iu] !== 0) ? ai : n[vo] < 0 || n[vo] > 59 ? vo : n[Is] < 0 || n[Is] > 59 ? Is : n[Iu] < 0 || n[Iu] > 999 ? Iu : -1, dn(e)._overflowDayOfYear && (t < Li || t > Bo) && (t = Bo), dn(e)._overflowWeeks && t === -1 && (t = sge), dn(e)._overflowWeekday && t === -1 && (t = lge), dn(e).overflow = t), e;
}
var i_e = /^\s*((?:[+-]\d{6}|\d{4})-(?:\d\d-\d\d|W\d\d-\d|W\d\d|\d\d\d|\d\d))(?:(T| )(\d\d(?::\d\d(?::\d\d(?:[.,]\d+)?)?)?)([+-]\d\d(?::?\d\d)?|\s*Z)?)?$/, a_e = /^\s*((?:[+-]\d{6}|\d{4})(?:\d\d\d\d|W\d\d\d|W\d\d|\d\d\d|\d\d|))(?:(T| )(\d\d(?:\d\d(?:\d\d(?:[.,]\d+)?)?)?)([+-]\d\d(?::?\d\d)?|\s*Z)?)?$/, o_e = /Z|[+-]\d\d(?::?\d\d)?/, zh = [
  ["YYYYYY-MM-DD", /[+-]\d{6}-\d\d-\d\d/],
  ["YYYY-MM-DD", /\d{4}-\d\d-\d\d/],
  ["GGGG-[W]WW-E", /\d{4}-W\d\d-\d/],
  ["GGGG-[W]WW", /\d{4}-W\d\d/, !1],
  ["YYYY-DDD", /\d{4}-\d{3}/],
  ["YYYY-MM", /\d{4}-\d\d/, !1],
  ["YYYYYYMMDD", /[+-]\d{10}/],
  ["YYYYMMDD", /\d{8}/],
  ["GGGG[W]WWE", /\d{4}W\d{3}/],
  ["GGGG[W]WW", /\d{4}W\d{2}/, !1],
  ["YYYYDDD", /\d{7}/],
  ["YYYYMM", /\d{6}/, !1],
  ["YYYY", /\d{4}/, !1]
], hT = [
  ["HH:mm:ss.SSSS", /\d\d:\d\d:\d\d\.\d+/],
  ["HH:mm:ss,SSSS", /\d\d:\d\d:\d\d,\d+/],
  ["HH:mm:ss", /\d\d:\d\d:\d\d/],
  ["HH:mm", /\d\d:\d\d/],
  ["HHmmss.SSSS", /\d\d\d\d\d\d\.\d+/],
  ["HHmmss,SSSS", /\d\d\d\d\d\d,\d+/],
  ["HHmmss", /\d\d\d\d\d\d/],
  ["HHmm", /\d\d\d\d/],
  ["HH", /\d\d/]
], s_e = /^\/?Date\((-?\d+)/i, l_e = /^(?:(Mon|Tue|Wed|Thu|Fri|Sat|Sun),?\s)?(\d{1,2})\s(Jan|Feb|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|Dec)\s(\d{2,4})\s(\d\d):(\d\d)(?::(\d\d))?\s(?:(UT|GMT|[ECMP][SD]T)|([Zz])|([+-]\d{4}))$/, u_e = {
  UT: 0,
  GMT: 0,
  EDT: -4 * 60,
  EST: -5 * 60,
  CDT: -5 * 60,
  CST: -6 * 60,
  MDT: -6 * 60,
  MST: -7 * 60,
  PDT: -7 * 60,
  PST: -8 * 60
};
function u4(e) {
  var t, n, r = e._i, i = i_e.exec(r) || a_e.exec(r), a, o, s, l, u = zh.length, c = hT.length;
  if (i) {
    for (dn(e).iso = !0, t = 0, n = u; t < n; t++)
      if (zh[t][1].exec(i[1])) {
        o = zh[t][0], a = zh[t][2] !== !1;
        break;
      }
    if (o == null) {
      e._isValid = !1;
      return;
    }
    if (i[3]) {
      for (t = 0, n = c; t < n; t++)
        if (hT[t][1].exec(i[3])) {
          s = (i[2] || " ") + hT[t][0];
          break;
        }
      if (s == null) {
        e._isValid = !1;
        return;
      }
    }
    if (!a && s != null) {
      e._isValid = !1;
      return;
    }
    if (i[4])
      if (o_e.exec(i[4]))
        l = "Z";
      else {
        e._isValid = !1;
        return;
      }
    e._f = o + (s || "") + (l || ""), OA(e);
  } else
    e._isValid = !1;
}
function c_e(e, t, n, r, i, a) {
  var o = [
    d_e(e),
    J6.indexOf(t),
    parseInt(n, 10),
    parseInt(r, 10),
    parseInt(i, 10)
  ];
  return a && o.push(parseInt(a, 10)), o;
}
function d_e(e) {
  var t = parseInt(e, 10);
  return t <= 49 ? 2e3 + t : t <= 999 ? 1900 + t : t;
}
function f_e(e) {
  return e.replace(/\([^()]*\)|[\n\t]/g, " ").replace(/(\s\s+)/g, " ").replace(/^\s\s*/, "").replace(/\s\s*$/, "");
}
function p_e(e, t, n) {
  if (e) {
    var r = a4.indexOf(e), i = new Date(
      t[0],
      t[1],
      t[2]
    ).getDay();
    if (r !== i)
      return dn(n).weekdayMismatch = !0, n._isValid = !1, !1;
  }
  return !0;
}
function m_e(e, t, n) {
  if (e)
    return u_e[e];
  if (t)
    return 0;
  var r = parseInt(n, 10), i = r % 100, a = (r - i) / 100;
  return a * 60 + i;
}
function c4(e) {
  var t = l_e.exec(f_e(e._i)), n;
  if (t) {
    if (n = c_e(
      t[4],
      t[3],
      t[2],
      t[5],
      t[6],
      t[7]
    ), !p_e(t[1], n, e))
      return;
    e._a = n, e._tzm = m_e(t[8], t[9], t[10]), e._d = Fp.apply(null, e._a), e._d.setUTCMinutes(e._d.getUTCMinutes() - e._tzm), dn(e).rfc2822 = !0;
  } else
    e._isValid = !1;
}
function h_e(e) {
  var t = s_e.exec(e._i);
  if (t !== null) {
    e._d = /* @__PURE__ */ new Date(+t[1]);
    return;
  }
  if (u4(e), e._isValid === !1)
    delete e._isValid;
  else
    return;
  if (c4(e), e._isValid === !1)
    delete e._isValid;
  else
    return;
  e._strict ? e._isValid = !1 : Ge.createFromInputFallback(e);
}
Ge.createFromInputFallback = to(
  "value provided is not in a recognized RFC2822 or ISO format. moment construction falls back to js Date(), which is not reliable across all browsers and versions. Non RFC2822/ISO date formats are discouraged. Please refer to http://momentjs.com/guides/#/warnings/js-date/ for more info.",
  function(e) {
    e._d = /* @__PURE__ */ new Date(e._i + (e._useUTC ? " UTC" : ""));
  }
);
function Fc(e, t, n) {
  return e ?? t ?? n;
}
function g_e(e) {
  var t = new Date(Ge.now());
  return e._useUTC ? [
    t.getUTCFullYear(),
    t.getUTCMonth(),
    t.getUTCDate()
  ] : [t.getFullYear(), t.getMonth(), t.getDate()];
}
function AA(e) {
  var t, n, r = [], i, a, o;
  if (!e._d) {
    for (i = g_e(e), e._w && e._a[Bo] == null && e._a[Ds] == null && __e(e), e._dayOfYear != null && (o = Fc(e._a[Li], i[Li]), (e._dayOfYear > tp(o) || e._dayOfYear === 0) && (dn(e)._overflowDayOfYear = !0), n = Fp(o, 0, e._dayOfYear), e._a[Ds] = n.getUTCMonth(), e._a[Bo] = n.getUTCDate()), t = 0; t < 3 && e._a[t] == null; ++t)
      e._a[t] = r[t] = i[t];
    for (; t < 7; t++)
      e._a[t] = r[t] = e._a[t] == null ? t === 2 ? 1 : 0 : e._a[t];
    e._a[ai] === 24 && e._a[vo] === 0 && e._a[Is] === 0 && e._a[Iu] === 0 && (e._nextDay = !0, e._a[ai] = 0), e._d = (e._useUTC ? Fp : Tge).apply(
      null,
      r
    ), a = e._useUTC ? e._d.getUTCDay() : e._d.getDay(), e._tzm != null && e._d.setUTCMinutes(e._d.getUTCMinutes() - e._tzm), e._nextDay && (e._a[ai] = 24), e._w && typeof e._w.d < "u" && e._w.d !== a && (dn(e).weekdayMismatch = !0);
  }
}
function __e(e) {
  var t, n, r, i, a, o, s, l, u;
  t = e._w, t.GG != null || t.W != null || t.E != null ? (a = 1, o = 4, n = Fc(
    t.GG,
    e._a[Li],
    Bp(hr(), 1, 4).year
  ), r = Fc(t.W, 1), i = Fc(t.E, 1), (i < 1 || i > 7) && (l = !0)) : (a = e._locale._week.dow, o = e._locale._week.doy, u = Bp(hr(), a, o), n = Fc(t.gg, e._a[Li], u.year), r = Fc(t.w, u.week), t.d != null ? (i = t.d, (i < 0 || i > 6) && (l = !0)) : t.e != null ? (i = t.e + a, (t.e < 0 || t.e > 6) && (l = !0)) : i = a), r < 1 || r > Fs(n, a, o) ? dn(e)._overflowWeeks = !0 : l != null ? dn(e)._overflowWeekday = !0 : (s = i4(n, r, i, a, o), e._a[Li] = s.year, e._dayOfYear = s.dayOfYear);
}
Ge.ISO_8601 = function() {
};
Ge.RFC_2822 = function() {
};
function OA(e) {
  if (e._f === Ge.ISO_8601) {
    u4(e);
    return;
  }
  if (e._f === Ge.RFC_2822) {
    c4(e);
    return;
  }
  e._a = [], dn(e).empty = !0;
  var t = "" + e._i, n, r, i, a, o, s = t.length, l = 0, u, c;
  for (i = V6(e._f, e._locale).match(mA) || [], c = i.length, n = 0; n < c; n++)
    a = i[n], r = (t.match(ige(a, e)) || [])[0], r && (o = t.substr(0, t.indexOf(r)), o.length > 0 && dn(e).unusedInput.push(o), t = t.slice(
      t.indexOf(r) + r.length
    ), l += r.length), td[a] ? (r ? dn(e).empty = !1 : dn(e).unusedTokens.push(a), oge(a, r, e)) : e._strict && !r && dn(e).unusedTokens.push(a);
  dn(e).charsLeftOver = s - l, t.length > 0 && dn(e).unusedInput.push(t), e._a[ai] <= 12 && dn(e).bigHour === !0 && e._a[ai] > 0 && (dn(e).bigHour = void 0), dn(e).parsedDateParts = e._a.slice(0), dn(e).meridiem = e._meridiem, e._a[ai] = v_e(
    e._locale,
    e._a[ai],
    e._meridiem
  ), u = dn(e).era, u !== null && (e._a[Li] = e._locale.erasConvertYear(u, e._a[Li])), AA(e), CA(e);
}
function v_e(e, t, n) {
  var r;
  return n == null ? t : e.meridiemHour != null ? e.meridiemHour(t, n) : (e.isPM != null && (r = e.isPM(n), r && t < 12 && (t += 12), !r && t === 12 && (t = 0)), t);
}
function b_e(e) {
  var t, n, r, i, a, o, s = !1, l = e._f.length;
  if (l === 0) {
    dn(e).invalidFormat = !0, e._d = /* @__PURE__ */ new Date(NaN);
    return;
  }
  for (i = 0; i < l; i++)
    a = 0, o = !1, t = fA({}, e), e._useUTC != null && (t._useUTC = e._useUTC), t._f = e._f[i], OA(t), dA(t) && (o = !0), a += dn(t).charsLeftOver, a += dn(t).unusedTokens.length * 10, dn(t).score = a, s ? a < r && (r = a, n = t) : (r == null || a < r || o) && (r = a, n = t, o && (s = !0));
  xl(e, n || t);
}
function E_e(e) {
  if (!e._d) {
    var t = hA(e._i), n = t.day === void 0 ? t.date : t.day;
    e._a = Y6(
      [t.year, t.month, n, t.hour, t.minute, t.second, t.millisecond],
      function(r) {
        return r && parseInt(r, 10);
      }
    ), AA(e);
  }
}
function S_e(e) {
  var t = new _m(CA(d4(e)));
  return t._nextDay && (t.add(1, "d"), t._nextDay = void 0), t;
}
function d4(e) {
  var t = e._i, n = e._f;
  return e._locale = e._locale || Ws(e._l), t === null || n === void 0 && t === "" ? fv({ nullInput: !0 }) : (typeof t == "string" && (e._i = t = e._locale.preparse(t)), Co(t) ? new _m(CA(t)) : (gm(t) ? e._d = t : To(n) ? b_e(e) : n ? OA(e) : y_e(e), dA(e) || (e._d = null), e));
}
function y_e(e) {
  var t = e._i;
  ra(t) ? e._d = new Date(Ge.now()) : gm(t) ? e._d = new Date(t.valueOf()) : typeof t == "string" ? h_e(e) : To(t) ? (e._a = Y6(t.slice(0), function(n) {
    return parseInt(n, 10);
  }), AA(e)) : Bu(t) ? E_e(e) : qs(t) ? e._d = new Date(t) : Ge.createFromInputFallback(e);
}
function f4(e, t, n, r, i) {
  var a = {};
  return (t === !0 || t === !1) && (r = t, t = void 0), (n === !0 || n === !1) && (r = n, n = void 0), (Bu(e) && cA(e) || To(e) && e.length === 0) && (e = void 0), a._isAMomentObject = !0, a._useUTC = a._isUTC = i, a._l = n, a._i = e, a._f = t, a._strict = r, S_e(a);
}
function hr(e, t, n, r) {
  return f4(e, t, n, r, !1);
}
var T_e = to(
  "moment().min is deprecated, use moment.max instead. http://momentjs.com/guides/#/warnings/min-max/",
  function() {
    var e = hr.apply(null, arguments);
    return this.isValid() && e.isValid() ? e < this ? this : e : fv();
  }
), C_e = to(
  "moment().max is deprecated, use moment.min instead. http://momentjs.com/guides/#/warnings/min-max/",
  function() {
    var e = hr.apply(null, arguments);
    return this.isValid() && e.isValid() ? e > this ? this : e : fv();
  }
);
function p4(e, t) {
  var n, r;
  if (t.length === 1 && To(t[0]) && (t = t[0]), !t.length)
    return hr();
  for (n = t[0], r = 1; r < t.length; ++r)
    (!t[r].isValid() || t[r][e](n)) && (n = t[r]);
  return n;
}
function A_e() {
  var e = [].slice.call(arguments, 0);
  return p4("isBefore", e);
}
function O_e() {
  var e = [].slice.call(arguments, 0);
  return p4("isAfter", e);
}
var R_e = function() {
  return Date.now ? Date.now() : +/* @__PURE__ */ new Date();
}, xf = [
  "year",
  "quarter",
  "month",
  "week",
  "day",
  "hour",
  "minute",
  "second",
  "millisecond"
];
function w_e(e) {
  var t, n = !1, r, i = xf.length;
  for (t in e)
    if (Ln(e, t) && !(Br.call(xf, t) !== -1 && (e[t] == null || !isNaN(e[t]))))
      return !1;
  for (r = 0; r < i; ++r)
    if (e[xf[r]]) {
      if (n)
        return !1;
      parseFloat(e[xf[r]]) !== yn(e[xf[r]]) && (n = !0);
    }
  return !0;
}
function x_e() {
  return this._isValid;
}
function N_e() {
  return wo(NaN);
}
function Ev(e) {
  var t = hA(e), n = t.year || 0, r = t.quarter || 0, i = t.month || 0, a = t.week || t.isoWeek || 0, o = t.day || 0, s = t.hour || 0, l = t.minute || 0, u = t.second || 0, c = t.millisecond || 0;
  this._isValid = w_e(t), this._milliseconds = +c + u * 1e3 + // 1000
  l * 6e4 + // 1000 * 60
  s * 1e3 * 60 * 60, this._days = +o + a * 7, this._months = +i + r * 3 + n * 12, this._data = {}, this._locale = Ws(), this._bubble();
}
function vg(e) {
  return e instanceof Ev;
}
function kC(e) {
  return e < 0 ? Math.round(-1 * e) * -1 : Math.round(e);
}
function D_e(e, t, n) {
  var r = Math.min(e.length, t.length), i = Math.abs(e.length - t.length), a = 0, o;
  for (o = 0; o < r; o++)
    yn(e[o]) !== yn(t[o]) && a++;
  return a + i;
}
function m4(e, t) {
  Lt(e, 0, 0, function() {
    var n = this.utcOffset(), r = "+";
    return n < 0 && (n = -n, r = "-"), r + Qo(~~(n / 60), 2) + t + Qo(~~n % 60, 2);
  });
}
m4("Z", ":");
m4("ZZ", "");
Et("Z", _v);
Et("ZZ", _v);
Wn(["Z", "ZZ"], function(e, t, n) {
  n._useUTC = !0, n._tzm = RA(_v, e);
});
var I_e = /([\+\-]|\d\d)/gi;
function RA(e, t) {
  var n = (t || "").match(e), r, i, a;
  return n === null ? null : (r = n[n.length - 1] || [], i = (r + "").match(I_e) || ["-", 0, 0], a = +(i[1] * 60) + yn(i[2]), a === 0 ? 0 : i[0] === "+" ? a : -a);
}
function wA(e, t) {
  var n, r;
  return t._isUTC ? (n = t.clone(), r = (Co(e) || gm(e) ? e.valueOf() : hr(e).valueOf()) - n.valueOf(), n._d.setTime(n._d.valueOf() + r), Ge.updateOffset(n, !1), n) : hr(e).local();
}
function MC(e) {
  return -Math.round(e._d.getTimezoneOffset());
}
Ge.updateOffset = function() {
};
function L_e(e, t, n) {
  var r = this._offset || 0, i;
  if (!this.isValid())
    return e != null ? this : NaN;
  if (e != null) {
    if (typeof e == "string") {
      if (e = RA(_v, e), e === null)
        return this;
    } else Math.abs(e) < 16 && !n && (e = e * 60);
    return !this._isUTC && t && (i = MC(this)), this._offset = e, this._isUTC = !0, i != null && this.add(i, "m"), r !== e && (!t || this._changeInProgress ? _4(
      this,
      wo(e - r, "m"),
      1,
      !1
    ) : this._changeInProgress || (this._changeInProgress = !0, Ge.updateOffset(this, !0), this._changeInProgress = null)), this;
  } else
    return this._isUTC ? r : MC(this);
}
function k_e(e, t) {
  return e != null ? (typeof e != "string" && (e = -e), this.utcOffset(e, t), this) : -this.utcOffset();
}
function M_e(e) {
  return this.utcOffset(0, e);
}
function P_e(e) {
  return this._isUTC && (this.utcOffset(0, e), this._isUTC = !1, e && this.subtract(MC(this), "m")), this;
}
function F_e() {
  if (this._tzm != null)
    this.utcOffset(this._tzm, !1, !0);
  else if (typeof this._i == "string") {
    var e = RA(nge, this._i);
    e != null ? this.utcOffset(e) : this.utcOffset(0, !0);
  }
  return this;
}
function B_e(e) {
  return this.isValid() ? (e = e ? hr(e).utcOffset() : 0, (this.utcOffset() - e) % 60 === 0) : !1;
}
function $_e() {
  return this.utcOffset() > this.clone().month(0).utcOffset() || this.utcOffset() > this.clone().month(5).utcOffset();
}
function U_e() {
  if (!ra(this._isDSTShifted))
    return this._isDSTShifted;
  var e = {}, t;
  return fA(e, this), e = d4(e), e._a ? (t = e._isUTC ? is(e._a) : hr(e._a), this._isDSTShifted = this.isValid() && D_e(e._a, t.toArray()) > 0) : this._isDSTShifted = !1, this._isDSTShifted;
}
function q_e() {
  return this.isValid() ? !this._isUTC : !1;
}
function G_e() {
  return this.isValid() ? this._isUTC : !1;
}
function h4() {
  return this.isValid() ? this._isUTC && this._offset === 0 : !1;
}
var Y_e = /^(-|\+)?(?:(\d*)[. ])?(\d+):(\d+)(?::(\d+)(\.\d*)?)?$/, H_e = /^(-|\+)?P(?:([-+]?[0-9,.]*)Y)?(?:([-+]?[0-9,.]*)M)?(?:([-+]?[0-9,.]*)W)?(?:([-+]?[0-9,.]*)D)?(?:T(?:([-+]?[0-9,.]*)H)?(?:([-+]?[0-9,.]*)M)?(?:([-+]?[0-9,.]*)S)?)?$/;
function wo(e, t) {
  var n = e, r = null, i, a, o;
  return vg(e) ? n = {
    ms: e._milliseconds,
    d: e._days,
    M: e._months
  } : qs(e) || !isNaN(+e) ? (n = {}, t ? n[t] = +e : n.milliseconds = +e) : (r = Y_e.exec(e)) ? (i = r[1] === "-" ? -1 : 1, n = {
    y: 0,
    d: yn(r[Bo]) * i,
    h: yn(r[ai]) * i,
    m: yn(r[vo]) * i,
    s: yn(r[Is]) * i,
    ms: yn(kC(r[Iu] * 1e3)) * i
    // the millisecond decimal point is included in the match
  }) : (r = H_e.exec(e)) ? (i = r[1] === "-" ? -1 : 1, n = {
    y: hu(r[2], i),
    M: hu(r[3], i),
    w: hu(r[4], i),
    d: hu(r[5], i),
    h: hu(r[6], i),
    m: hu(r[7], i),
    s: hu(r[8], i)
  }) : n == null ? n = {} : typeof n == "object" && ("from" in n || "to" in n) && (o = z_e(
    hr(n.from),
    hr(n.to)
  ), n = {}, n.ms = o.milliseconds, n.M = o.months), a = new Ev(n), vg(e) && Ln(e, "_locale") && (a._locale = e._locale), vg(e) && Ln(e, "_isValid") && (a._isValid = e._isValid), a;
}
wo.fn = Ev.prototype;
wo.invalid = N_e;
function hu(e, t) {
  var n = e && parseFloat(e.replace(",", "."));
  return (isNaN(n) ? 0 : n) * t;
}
function D2(e, t) {
  var n = {};
  return n.months = t.month() - e.month() + (t.year() - e.year()) * 12, e.clone().add(n.months, "M").isAfter(t) && --n.months, n.milliseconds = +t - +e.clone().add(n.months, "M"), n;
}
function z_e(e, t) {
  var n;
  return e.isValid() && t.isValid() ? (t = wA(t, e), e.isBefore(t) ? n = D2(e, t) : (n = D2(t, e), n.milliseconds = -n.milliseconds, n.months = -n.months), n) : { milliseconds: 0, months: 0 };
}
function g4(e, t) {
  return function(n, r) {
    var i, a;
    return r !== null && !isNaN(+r) && (z6(
      t,
      "moment()." + t + "(period, number) is deprecated. Please use moment()." + t + "(number, period). See http://momentjs.com/guides/#/warnings/add-inverted-param/ for more info."
    ), a = n, n = r, r = a), i = wo(n, r), _4(this, i, e), this;
  };
}
function _4(e, t, n, r) {
  var i = t._milliseconds, a = kC(t._days), o = kC(t._months);
  e.isValid() && (r = r ?? !0, o && t4(e, Pp(e, "Month") + o * n), a && Z6(e, "Date", Pp(e, "Date") + a * n), i && e._d.setTime(e._d.valueOf() + i * n), r && Ge.updateOffset(e, a || o));
}
var V_e = g4(1, "add"), W_e = g4(-1, "subtract");
function v4(e) {
  return typeof e == "string" || e instanceof String;
}
function K_e(e) {
  return Co(e) || gm(e) || v4(e) || qs(e) || Q_e(e) || j_e(e) || e === null || e === void 0;
}
function j_e(e) {
  var t = Bu(e) && !cA(e), n = !1, r = [
    "years",
    "year",
    "y",
    "months",
    "month",
    "M",
    "days",
    "day",
    "d",
    "dates",
    "date",
    "D",
    "hours",
    "hour",
    "h",
    "minutes",
    "minute",
    "m",
    "seconds",
    "second",
    "s",
    "milliseconds",
    "millisecond",
    "ms"
  ], i, a, o = r.length;
  for (i = 0; i < o; i += 1)
    a = r[i], n = n || Ln(e, a);
  return t && n;
}
function Q_e(e) {
  var t = To(e), n = !1;
  return t && (n = e.filter(function(r) {
    return !qs(r) && v4(e);
  }).length === 0), t && n;
}
function X_e(e) {
  var t = Bu(e) && !cA(e), n = !1, r = [
    "sameDay",
    "nextDay",
    "lastDay",
    "nextWeek",
    "lastWeek",
    "sameElse"
  ], i, a;
  for (i = 0; i < r.length; i += 1)
    a = r[i], n = n || Ln(e, a);
  return t && n;
}
function Z_e(e, t) {
  var n = e.diff(t, "days", !0);
  return n < -6 ? "sameElse" : n < -1 ? "lastWeek" : n < 0 ? "lastDay" : n < 1 ? "sameDay" : n < 2 ? "nextDay" : n < 7 ? "nextWeek" : "sameElse";
}
function J_e(e, t) {
  arguments.length === 1 && (arguments[0] ? K_e(arguments[0]) ? (e = arguments[0], t = void 0) : X_e(arguments[0]) && (t = arguments[0], e = void 0) : (e = void 0, t = void 0));
  var n = e || hr(), r = wA(n, this).startOf("day"), i = Ge.calendarFormat(this, r) || "sameElse", a = t && (as(t[i]) ? t[i].call(this, n) : t[i]);
  return this.format(
    a || this.localeData().calendar(i, this, hr(n))
  );
}
function eve() {
  return new _m(this);
}
function tve(e, t) {
  var n = Co(e) ? e : hr(e);
  return this.isValid() && n.isValid() ? (t = no(t) || "millisecond", t === "millisecond" ? this.valueOf() > n.valueOf() : n.valueOf() < this.clone().startOf(t).valueOf()) : !1;
}
function nve(e, t) {
  var n = Co(e) ? e : hr(e);
  return this.isValid() && n.isValid() ? (t = no(t) || "millisecond", t === "millisecond" ? this.valueOf() < n.valueOf() : this.clone().endOf(t).valueOf() < n.valueOf()) : !1;
}
function rve(e, t, n, r) {
  var i = Co(e) ? e : hr(e), a = Co(t) ? t : hr(t);
  return this.isValid() && i.isValid() && a.isValid() ? (r = r || "()", (r[0] === "(" ? this.isAfter(i, n) : !this.isBefore(i, n)) && (r[1] === ")" ? this.isBefore(a, n) : !this.isAfter(a, n))) : !1;
}
function ive(e, t) {
  var n = Co(e) ? e : hr(e), r;
  return this.isValid() && n.isValid() ? (t = no(t) || "millisecond", t === "millisecond" ? this.valueOf() === n.valueOf() : (r = n.valueOf(), this.clone().startOf(t).valueOf() <= r && r <= this.clone().endOf(t).valueOf())) : !1;
}
function ave(e, t) {
  return this.isSame(e, t) || this.isAfter(e, t);
}
function ove(e, t) {
  return this.isSame(e, t) || this.isBefore(e, t);
}
function sve(e, t, n) {
  var r, i, a;
  if (!this.isValid())
    return NaN;
  if (r = wA(e, this), !r.isValid())
    return NaN;
  switch (i = (r.utcOffset() - this.utcOffset()) * 6e4, t = no(t), t) {
    case "year":
      a = bg(this, r) / 12;
      break;
    case "month":
      a = bg(this, r);
      break;
    case "quarter":
      a = bg(this, r) / 3;
      break;
    case "second":
      a = (this - r) / 1e3;
      break;
    case "minute":
      a = (this - r) / 6e4;
      break;
    case "hour":
      a = (this - r) / 36e5;
      break;
    case "day":
      a = (this - r - i) / 864e5;
      break;
    case "week":
      a = (this - r - i) / 6048e5;
      break;
    default:
      a = this - r;
  }
  return n ? a : Qa(a);
}
function bg(e, t) {
  if (e.date() < t.date())
    return -bg(t, e);
  var n = (t.year() - e.year()) * 12 + (t.month() - e.month()), r = e.clone().add(n, "months"), i, a;
  return t - r < 0 ? (i = e.clone().add(n - 1, "months"), a = (t - r) / (r - i)) : (i = e.clone().add(n + 1, "months"), a = (t - r) / (i - r)), -(n + a) || 0;
}
Ge.defaultFormat = "YYYY-MM-DDTHH:mm:ssZ";
Ge.defaultFormatUtc = "YYYY-MM-DDTHH:mm:ss[Z]";
function lve() {
  return this.clone().locale("en").format("ddd MMM DD YYYY HH:mm:ss [GMT]ZZ");
}
function uve(e) {
  if (!this.isValid())
    return null;
  var t = e !== !0, n = t ? this.clone().utc() : this;
  return n.year() < 0 || n.year() > 9999 ? _g(
    n,
    t ? "YYYYYY-MM-DD[T]HH:mm:ss.SSS[Z]" : "YYYYYY-MM-DD[T]HH:mm:ss.SSSZ"
  ) : as(Date.prototype.toISOString) ? t ? this.toDate().toISOString() : new Date(this.valueOf() + this.utcOffset() * 60 * 1e3).toISOString().replace("Z", _g(n, "Z")) : _g(
    n,
    t ? "YYYY-MM-DD[T]HH:mm:ss.SSS[Z]" : "YYYY-MM-DD[T]HH:mm:ss.SSSZ"
  );
}
function cve() {
  if (!this.isValid())
    return "moment.invalid(/* " + this._i + " */)";
  var e = "moment", t = "", n, r, i, a;
  return this.isLocal() || (e = this.utcOffset() === 0 ? "moment.utc" : "moment.parseZone", t = "Z"), n = "[" + e + '("]', r = 0 <= this.year() && this.year() <= 9999 ? "YYYY" : "YYYYYY", i = "-MM-DD[T]HH:mm:ss.SSS", a = t + '[")]', this.format(n + r + i + a);
}
function dve(e) {
  e || (e = this.isUtc() ? Ge.defaultFormatUtc : Ge.defaultFormat);
  var t = _g(this, e);
  return this.localeData().postformat(t);
}
function fve(e, t) {
  return this.isValid() && (Co(e) && e.isValid() || hr(e).isValid()) ? wo({ to: this, from: e }).locale(this.locale()).humanize(!t) : this.localeData().invalidDate();
}
function pve(e) {
  return this.from(hr(), e);
}
function mve(e, t) {
  return this.isValid() && (Co(e) && e.isValid() || hr(e).isValid()) ? wo({ from: this, to: e }).locale(this.locale()).humanize(!t) : this.localeData().invalidDate();
}
function hve(e) {
  return this.to(hr(), e);
}
function b4(e) {
  var t;
  return e === void 0 ? this._locale._abbr : (t = Ws(e), t != null && (this._locale = t), this);
}
var E4 = to(
  "moment().lang() is deprecated. Instead, use moment().localeData() to get the language configuration. Use moment().locale() to change languages.",
  function(e) {
    return e === void 0 ? this.localeData() : this.locale(e);
  }
);
function S4() {
  return this._locale;
}
var l_ = 1e3, nd = 60 * l_, u_ = 60 * nd, y4 = (365 * 400 + 97) * 24 * u_;
function rd(e, t) {
  return (e % t + t) % t;
}
function T4(e, t, n) {
  return e < 100 && e >= 0 ? new Date(e + 400, t, n) - y4 : new Date(e, t, n).valueOf();
}
function C4(e, t, n) {
  return e < 100 && e >= 0 ? Date.UTC(e + 400, t, n) - y4 : Date.UTC(e, t, n);
}
function gve(e) {
  var t, n;
  if (e = no(e), e === void 0 || e === "millisecond" || !this.isValid())
    return this;
  switch (n = this._isUTC ? C4 : T4, e) {
    case "year":
      t = n(this.year(), 0, 1);
      break;
    case "quarter":
      t = n(
        this.year(),
        this.month() - this.month() % 3,
        1
      );
      break;
    case "month":
      t = n(this.year(), this.month(), 1);
      break;
    case "week":
      t = n(
        this.year(),
        this.month(),
        this.date() - this.weekday()
      );
      break;
    case "isoWeek":
      t = n(
        this.year(),
        this.month(),
        this.date() - (this.isoWeekday() - 1)
      );
      break;
    case "day":
    case "date":
      t = n(this.year(), this.month(), this.date());
      break;
    case "hour":
      t = this._d.valueOf(), t -= rd(
        t + (this._isUTC ? 0 : this.utcOffset() * nd),
        u_
      );
      break;
    case "minute":
      t = this._d.valueOf(), t -= rd(t, nd);
      break;
    case "second":
      t = this._d.valueOf(), t -= rd(t, l_);
      break;
  }
  return this._d.setTime(t), Ge.updateOffset(this, !0), this;
}
function _ve(e) {
  var t, n;
  if (e = no(e), e === void 0 || e === "millisecond" || !this.isValid())
    return this;
  switch (n = this._isUTC ? C4 : T4, e) {
    case "year":
      t = n(this.year() + 1, 0, 1) - 1;
      break;
    case "quarter":
      t = n(
        this.year(),
        this.month() - this.month() % 3 + 3,
        1
      ) - 1;
      break;
    case "month":
      t = n(this.year(), this.month() + 1, 1) - 1;
      break;
    case "week":
      t = n(
        this.year(),
        this.month(),
        this.date() - this.weekday() + 7
      ) - 1;
      break;
    case "isoWeek":
      t = n(
        this.year(),
        this.month(),
        this.date() - (this.isoWeekday() - 1) + 7
      ) - 1;
      break;
    case "day":
    case "date":
      t = n(this.year(), this.month(), this.date() + 1) - 1;
      break;
    case "hour":
      t = this._d.valueOf(), t += u_ - rd(
        t + (this._isUTC ? 0 : this.utcOffset() * nd),
        u_
      ) - 1;
      break;
    case "minute":
      t = this._d.valueOf(), t += nd - rd(t, nd) - 1;
      break;
    case "second":
      t = this._d.valueOf(), t += l_ - rd(t, l_) - 1;
      break;
  }
  return this._d.setTime(t), Ge.updateOffset(this, !0), this;
}
function vve() {
  return this._d.valueOf() - (this._offset || 0) * 6e4;
}
function bve() {
  return Math.floor(this.valueOf() / 1e3);
}
function Eve() {
  return new Date(this.valueOf());
}
function Sve() {
  var e = this;
  return [
    e.year(),
    e.month(),
    e.date(),
    e.hour(),
    e.minute(),
    e.second(),
    e.millisecond()
  ];
}
function yve() {
  var e = this;
  return {
    years: e.year(),
    months: e.month(),
    date: e.date(),
    hours: e.hours(),
    minutes: e.minutes(),
    seconds: e.seconds(),
    milliseconds: e.milliseconds()
  };
}
function Tve() {
  return this.isValid() ? this.toISOString() : null;
}
function Cve() {
  return dA(this);
}
function Ave() {
  return xl({}, dn(this));
}
function Ove() {
  return dn(this).overflow;
}
function Rve() {
  return {
    input: this._i,
    format: this._f,
    locale: this._locale,
    isUTC: this._isUTC,
    strict: this._strict
  };
}
Lt("N", 0, 0, "eraAbbr");
Lt("NN", 0, 0, "eraAbbr");
Lt("NNN", 0, 0, "eraAbbr");
Lt("NNNN", 0, 0, "eraName");
Lt("NNNNN", 0, 0, "eraNarrow");
Lt("y", ["y", 1], "yo", "eraYear");
Lt("y", ["yy", 2], 0, "eraYear");
Lt("y", ["yyy", 3], 0, "eraYear");
Lt("y", ["yyyy", 4], 0, "eraYear");
Et("N", xA);
Et("NN", xA);
Et("NNN", xA);
Et("NNNN", Bve);
Et("NNNNN", $ve);
Wn(
  ["N", "NN", "NNN", "NNNN", "NNNNN"],
  function(e, t, n, r) {
    var i = n._locale.erasParse(e, r, n._strict);
    i ? dn(n).era = i : dn(n).invalidEra = e;
  }
);
Et("y", Dd);
Et("yy", Dd);
Et("yyy", Dd);
Et("yyyy", Dd);
Et("yo", Uve);
Wn(["y", "yy", "yyy", "yyyy"], Li);
Wn(["yo"], function(e, t, n, r) {
  var i;
  n._locale._eraYearOrdinalRegex && (i = e.match(n._locale._eraYearOrdinalRegex)), n._locale.eraYearOrdinalParse ? t[Li] = n._locale.eraYearOrdinalParse(e, i) : t[Li] = parseInt(e, 10);
});
function wve(e, t) {
  var n, r, i, a = this._eras || Ws("en")._eras;
  for (n = 0, r = a.length; n < r; ++n) {
    switch (typeof a[n].since) {
      case "string":
        i = Ge(a[n].since).startOf("day"), a[n].since = i.valueOf();
        break;
    }
    switch (typeof a[n].until) {
      case "undefined":
        a[n].until = 1 / 0;
        break;
      case "string":
        i = Ge(a[n].until).startOf("day").valueOf(), a[n].until = i.valueOf();
        break;
    }
  }
  return a;
}
function xve(e, t, n) {
  var r, i, a = this.eras(), o, s, l;
  for (e = e.toUpperCase(), r = 0, i = a.length; r < i; ++r)
    if (o = a[r].name.toUpperCase(), s = a[r].abbr.toUpperCase(), l = a[r].narrow.toUpperCase(), n)
      switch (t) {
        case "N":
        case "NN":
        case "NNN":
          if (s === e)
            return a[r];
          break;
        case "NNNN":
          if (o === e)
            return a[r];
          break;
        case "NNNNN":
          if (l === e)
            return a[r];
          break;
      }
    else if ([o, s, l].indexOf(e) >= 0)
      return a[r];
}
function Nve(e, t) {
  var n = e.since <= e.until ? 1 : -1;
  return t === void 0 ? Ge(e.since).year() : Ge(e.since).year() + (t - e.offset) * n;
}
function Dve() {
  var e, t, n, r = this.localeData().eras();
  for (e = 0, t = r.length; e < t; ++e)
    if (n = this.clone().startOf("day").valueOf(), r[e].since <= n && n <= r[e].until || r[e].until <= n && n <= r[e].since)
      return r[e].name;
  return "";
}
function Ive() {
  var e, t, n, r = this.localeData().eras();
  for (e = 0, t = r.length; e < t; ++e)
    if (n = this.clone().startOf("day").valueOf(), r[e].since <= n && n <= r[e].until || r[e].until <= n && n <= r[e].since)
      return r[e].narrow;
  return "";
}
function Lve() {
  var e, t, n, r = this.localeData().eras();
  for (e = 0, t = r.length; e < t; ++e)
    if (n = this.clone().startOf("day").valueOf(), r[e].since <= n && n <= r[e].until || r[e].until <= n && n <= r[e].since)
      return r[e].abbr;
  return "";
}
function kve() {
  var e, t, n, r, i = this.localeData().eras();
  for (e = 0, t = i.length; e < t; ++e)
    if (n = i[e].since <= i[e].until ? 1 : -1, r = this.clone().startOf("day").valueOf(), i[e].since <= r && r <= i[e].until || i[e].until <= r && r <= i[e].since)
      return (this.year() - Ge(i[e].since).year()) * n + i[e].offset;
  return this.year();
}
function Mve(e) {
  return Ln(this, "_erasNameRegex") || NA.call(this), e ? this._erasNameRegex : this._erasRegex;
}
function Pve(e) {
  return Ln(this, "_erasAbbrRegex") || NA.call(this), e ? this._erasAbbrRegex : this._erasRegex;
}
function Fve(e) {
  return Ln(this, "_erasNarrowRegex") || NA.call(this), e ? this._erasNarrowRegex : this._erasRegex;
}
function xA(e, t) {
  return t.erasAbbrRegex(e);
}
function Bve(e, t) {
  return t.erasNameRegex(e);
}
function $ve(e, t) {
  return t.erasNarrowRegex(e);
}
function Uve(e, t) {
  return t._eraYearOrdinalRegex || Dd;
}
function NA() {
  var e = [], t = [], n = [], r = [], i, a, o, s, l, u = this.eras();
  for (i = 0, a = u.length; i < a; ++i)
    o = Ps(u[i].name), s = Ps(u[i].abbr), l = Ps(u[i].narrow), t.push(o), e.push(s), n.push(l), r.push(o), r.push(s), r.push(l);
  this._erasRegex = new RegExp("^(" + r.join("|") + ")", "i"), this._erasNameRegex = new RegExp("^(" + t.join("|") + ")", "i"), this._erasAbbrRegex = new RegExp("^(" + e.join("|") + ")", "i"), this._erasNarrowRegex = new RegExp(
    "^(" + n.join("|") + ")",
    "i"
  );
}
Lt(0, ["gg", 2], 0, function() {
  return this.weekYear() % 100;
});
Lt(0, ["GG", 2], 0, function() {
  return this.isoWeekYear() % 100;
});
function Sv(e, t) {
  Lt(0, [e, e.length], 0, t);
}
Sv("gggg", "weekYear");
Sv("ggggg", "weekYear");
Sv("GGGG", "isoWeekYear");
Sv("GGGGG", "isoWeekYear");
Et("G", gv);
Et("g", gv);
Et("GG", gr, ka);
Et("gg", gr, ka);
Et("GGGG", _A, gA);
Et("gggg", _A, gA);
Et("GGGGG", hv, pv);
Et("ggggg", hv, pv);
bm(
  ["gggg", "ggggg", "GGGG", "GGGGG"],
  function(e, t, n, r) {
    t[r.substr(0, 2)] = yn(e);
  }
);
bm(["gg", "GG"], function(e, t, n, r) {
  t[r] = Ge.parseTwoDigitYear(e);
});
function qve(e) {
  return A4.call(
    this,
    e,
    this.week(),
    this.weekday() + this.localeData()._week.dow,
    this.localeData()._week.dow,
    this.localeData()._week.doy
  );
}
function Gve(e) {
  return A4.call(
    this,
    e,
    this.isoWeek(),
    this.isoWeekday(),
    1,
    4
  );
}
function Yve() {
  return Fs(this.year(), 1, 4);
}
function Hve() {
  return Fs(this.isoWeekYear(), 1, 4);
}
function zve() {
  var e = this.localeData()._week;
  return Fs(this.year(), e.dow, e.doy);
}
function Vve() {
  var e = this.localeData()._week;
  return Fs(this.weekYear(), e.dow, e.doy);
}
function A4(e, t, n, r, i) {
  var a;
  return e == null ? Bp(this, r, i).year : (a = Fs(e, r, i), t > a && (t = a), Wve.call(this, e, t, n, r, i));
}
function Wve(e, t, n, r, i) {
  var a = i4(e, t, n, r, i), o = Fp(a.year, 0, a.dayOfYear);
  return this.year(o.getUTCFullYear()), this.month(o.getUTCMonth()), this.date(o.getUTCDate()), this;
}
Lt("Q", 0, "Qo", "quarter");
Et("Q", W6);
Wn("Q", function(e, t) {
  t[Ds] = (yn(e) - 1) * 3;
});
function Kve(e) {
  return e == null ? Math.ceil((this.month() + 1) / 3) : this.month((e - 1) * 3 + this.month() % 3);
}
Lt("D", ["DD", 2], "Do", "date");
Et("D", gr, Id);
Et("DD", gr, ka);
Et("Do", function(e, t) {
  return e ? t._dayOfMonthOrdinalParse || t._ordinalParse : t._dayOfMonthOrdinalParseLenient;
});
Wn(["D", "DD"], Bo);
Wn("Do", function(e, t) {
  t[Bo] = yn(e.match(gr)[0]);
});
var O4 = Ld("Date", !0);
Lt("DDD", ["DDDD", 3], "DDDo", "dayOfYear");
Et("DDD", mv);
Et("DDDD", K6);
Wn(["DDD", "DDDD"], function(e, t, n) {
  n._dayOfYear = yn(e);
});
function jve(e) {
  var t = Math.round(
    (this.clone().startOf("day") - this.clone().startOf("year")) / 864e5
  ) + 1;
  return e == null ? t : this.add(e - t, "d");
}
Lt("m", ["mm", 2], 0, "minute");
Et("m", gr, vA);
Et("mm", gr, ka);
Wn(["m", "mm"], vo);
var Qve = Ld("Minutes", !1);
Lt("s", ["ss", 2], 0, "second");
Et("s", gr, vA);
Et("ss", gr, ka);
Wn(["s", "ss"], Is);
var Xve = Ld("Seconds", !1);
Lt("S", 0, 0, function() {
  return ~~(this.millisecond() / 100);
});
Lt(0, ["SS", 2], 0, function() {
  return ~~(this.millisecond() / 10);
});
Lt(0, ["SSS", 3], 0, "millisecond");
Lt(0, ["SSSS", 4], 0, function() {
  return this.millisecond() * 10;
});
Lt(0, ["SSSSS", 5], 0, function() {
  return this.millisecond() * 100;
});
Lt(0, ["SSSSSS", 6], 0, function() {
  return this.millisecond() * 1e3;
});
Lt(0, ["SSSSSSS", 7], 0, function() {
  return this.millisecond() * 1e4;
});
Lt(0, ["SSSSSSSS", 8], 0, function() {
  return this.millisecond() * 1e5;
});
Lt(0, ["SSSSSSSSS", 9], 0, function() {
  return this.millisecond() * 1e6;
});
Et("S", mv, W6);
Et("SS", mv, ka);
Et("SSS", mv, K6);
var Nl, R4;
for (Nl = "SSSS"; Nl.length <= 9; Nl += "S")
  Et(Nl, Dd);
function Zve(e, t) {
  t[Iu] = yn(("0." + e) * 1e3);
}
for (Nl = "S"; Nl.length <= 9; Nl += "S")
  Wn(Nl, Zve);
R4 = Ld("Milliseconds", !1);
Lt("z", 0, 0, "zoneAbbr");
Lt("zz", 0, 0, "zoneName");
function Jve() {
  return this._isUTC ? "UTC" : "";
}
function ebe() {
  return this._isUTC ? "Coordinated Universal Time" : "";
}
var Xe = _m.prototype;
Xe.add = V_e;
Xe.calendar = J_e;
Xe.clone = eve;
Xe.diff = sve;
Xe.endOf = _ve;
Xe.format = dve;
Xe.from = fve;
Xe.fromNow = pve;
Xe.to = mve;
Xe.toNow = hve;
Xe.get = cge;
Xe.invalidAt = Ove;
Xe.isAfter = tve;
Xe.isBefore = nve;
Xe.isBetween = rve;
Xe.isSame = ive;
Xe.isSameOrAfter = ave;
Xe.isSameOrBefore = ove;
Xe.isValid = Cve;
Xe.lang = E4;
Xe.locale = b4;
Xe.localeData = S4;
Xe.max = C_e;
Xe.min = T_e;
Xe.parsingFlags = Ave;
Xe.set = dge;
Xe.startOf = gve;
Xe.subtract = W_e;
Xe.toArray = Sve;
Xe.toObject = yve;
Xe.toDate = Eve;
Xe.toISOString = uve;
Xe.inspect = cve;
typeof Symbol < "u" && Symbol.for != null && (Xe[Symbol.for("nodejs.util.inspect.custom")] = function() {
  return "Moment<" + this.format() + ">";
});
Xe.toJSON = Tve;
Xe.toString = lve;
Xe.unix = bve;
Xe.valueOf = vve;
Xe.creationData = Rve;
Xe.eraName = Dve;
Xe.eraNarrow = Ive;
Xe.eraAbbr = Lve;
Xe.eraYear = kve;
Xe.year = X6;
Xe.isLeapYear = uge;
Xe.weekYear = qve;
Xe.isoWeekYear = Gve;
Xe.quarter = Xe.quarters = Kve;
Xe.month = n4;
Xe.daysInMonth = Ege;
Xe.week = Xe.weeks = wge;
Xe.isoWeek = Xe.isoWeeks = xge;
Xe.weeksInYear = zve;
Xe.weeksInWeekYear = Vve;
Xe.isoWeeksInYear = Yve;
Xe.isoWeeksInISOWeekYear = Hve;
Xe.date = O4;
Xe.day = Xe.days = Gge;
Xe.weekday = Yge;
Xe.isoWeekday = Hge;
Xe.dayOfYear = jve;
Xe.hour = Xe.hours = Xge;
Xe.minute = Xe.minutes = Qve;
Xe.second = Xe.seconds = Xve;
Xe.millisecond = Xe.milliseconds = R4;
Xe.utcOffset = L_e;
Xe.utc = M_e;
Xe.local = P_e;
Xe.parseZone = F_e;
Xe.hasAlignedHourOffset = B_e;
Xe.isDST = $_e;
Xe.isLocal = q_e;
Xe.isUtcOffset = G_e;
Xe.isUtc = h4;
Xe.isUTC = h4;
Xe.zoneAbbr = Jve;
Xe.zoneName = ebe;
Xe.dates = to(
  "dates accessor is deprecated. Use date instead.",
  O4
);
Xe.months = to(
  "months accessor is deprecated. Use month instead",
  n4
);
Xe.years = to(
  "years accessor is deprecated. Use year instead",
  X6
);
Xe.zone = to(
  "moment().zone is deprecated, use moment().utcOffset instead. http://momentjs.com/guides/#/warnings/zone/",
  k_e
);
Xe.isDSTShifted = to(
  "isDSTShifted is deprecated. See http://momentjs.com/guides/#/warnings/dst-shifted/ for more information",
  U_e
);
function tbe(e) {
  return hr(e * 1e3);
}
function nbe() {
  return hr.apply(null, arguments).parseZone();
}
function w4(e) {
  return e;
}
var kn = pA.prototype;
kn.calendar = qhe;
kn.longDateFormat = zhe;
kn.invalidDate = Whe;
kn.ordinal = Qhe;
kn.preparse = w4;
kn.postformat = w4;
kn.relativeTime = Zhe;
kn.pastFuture = Jhe;
kn.set = $he;
kn.eras = wve;
kn.erasParse = xve;
kn.erasConvertYear = Nve;
kn.erasAbbrRegex = Pve;
kn.erasNameRegex = Mve;
kn.erasNarrowRegex = Fve;
kn.months = gge;
kn.monthsShort = _ge;
kn.monthsParse = bge;
kn.monthsRegex = yge;
kn.monthsShortRegex = Sge;
kn.week = Cge;
kn.firstDayOfYear = Rge;
kn.firstDayOfWeek = Oge;
kn.weekdays = Fge;
kn.weekdaysMin = $ge;
kn.weekdaysShort = Bge;
kn.weekdaysParse = qge;
kn.weekdaysRegex = zge;
kn.weekdaysShortRegex = Vge;
kn.weekdaysMinRegex = Wge;
kn.isPM = jge;
kn.meridiem = Zge;
function c_(e, t, n, r) {
  var i = Ws(), a = is().set(r, t);
  return i[n](a, e);
}
function x4(e, t, n) {
  if (qs(e) && (t = e, e = void 0), e = e || "", t != null)
    return c_(e, t, n, "month");
  var r, i = [];
  for (r = 0; r < 12; r++)
    i[r] = c_(e, r, n, "month");
  return i;
}
function DA(e, t, n, r) {
  typeof e == "boolean" ? (qs(t) && (n = t, t = void 0), t = t || "") : (t = e, n = t, e = !1, qs(t) && (n = t, t = void 0), t = t || "");
  var i = Ws(), a = e ? i._week.dow : 0, o, s = [];
  if (n != null)
    return c_(t, (n + a) % 7, r, "day");
  for (o = 0; o < 7; o++)
    s[o] = c_(t, (o + a) % 7, r, "day");
  return s;
}
function rbe(e, t) {
  return x4(e, t, "months");
}
function ibe(e, t) {
  return x4(e, t, "monthsShort");
}
function abe(e, t, n) {
  return DA(e, t, n, "weekdays");
}
function obe(e, t, n) {
  return DA(e, t, n, "weekdaysShort");
}
function sbe(e, t, n) {
  return DA(e, t, n, "weekdaysMin");
}
Ml("en", {
  eras: [
    {
      since: "0001-01-01",
      until: 1 / 0,
      offset: 1,
      name: "Anno Domini",
      narrow: "AD",
      abbr: "AD"
    },
    {
      since: "0000-12-31",
      until: -1 / 0,
      offset: 1,
      name: "Before Christ",
      narrow: "BC",
      abbr: "BC"
    }
  ],
  dayOfMonthOrdinalParse: /\d{1,2}(th|st|nd|rd)/,
  ordinal: function(e) {
    var t = e % 10, n = yn(e % 100 / 10) === 1 ? "th" : t === 1 ? "st" : t === 2 ? "nd" : t === 3 ? "rd" : "th";
    return e + n;
  }
});
Ge.lang = to(
  "moment.lang is deprecated. Use moment.locale instead.",
  Ml
);
Ge.langData = to(
  "moment.langData is deprecated. Use moment.localeData instead.",
  Ws
);
var Cs = Math.abs;
function lbe() {
  var e = this._data;
  return this._milliseconds = Cs(this._milliseconds), this._days = Cs(this._days), this._months = Cs(this._months), e.milliseconds = Cs(e.milliseconds), e.seconds = Cs(e.seconds), e.minutes = Cs(e.minutes), e.hours = Cs(e.hours), e.months = Cs(e.months), e.years = Cs(e.years), this;
}
function N4(e, t, n, r) {
  var i = wo(t, n);
  return e._milliseconds += r * i._milliseconds, e._days += r * i._days, e._months += r * i._months, e._bubble();
}
function ube(e, t) {
  return N4(this, e, t, 1);
}
function cbe(e, t) {
  return N4(this, e, t, -1);
}
function I2(e) {
  return e < 0 ? Math.floor(e) : Math.ceil(e);
}
function dbe() {
  var e = this._milliseconds, t = this._days, n = this._months, r = this._data, i, a, o, s, l;
  return e >= 0 && t >= 0 && n >= 0 || e <= 0 && t <= 0 && n <= 0 || (e += I2(PC(n) + t) * 864e5, t = 0, n = 0), r.milliseconds = e % 1e3, i = Qa(e / 1e3), r.seconds = i % 60, a = Qa(i / 60), r.minutes = a % 60, o = Qa(a / 60), r.hours = o % 24, t += Qa(o / 24), l = Qa(D4(t)), n += l, t -= I2(PC(l)), s = Qa(n / 12), n %= 12, r.days = t, r.months = n, r.years = s, this;
}
function D4(e) {
  return e * 4800 / 146097;
}
function PC(e) {
  return e * 146097 / 4800;
}
function fbe(e) {
  if (!this.isValid())
    return NaN;
  var t, n, r = this._milliseconds;
  if (e = no(e), e === "month" || e === "quarter" || e === "year")
    switch (t = this._days + r / 864e5, n = this._months + D4(t), e) {
      case "month":
        return n;
      case "quarter":
        return n / 3;
      case "year":
        return n / 12;
    }
  else
    switch (t = this._days + Math.round(PC(this._months)), e) {
      case "week":
        return t / 7 + r / 6048e5;
      case "day":
        return t + r / 864e5;
      case "hour":
        return t * 24 + r / 36e5;
      case "minute":
        return t * 1440 + r / 6e4;
      case "second":
        return t * 86400 + r / 1e3;
      case "millisecond":
        return Math.floor(t * 864e5) + r;
      default:
        throw new Error("Unknown unit " + e);
    }
}
function Ks(e) {
  return function() {
    return this.as(e);
  };
}
var I4 = Ks("ms"), pbe = Ks("s"), mbe = Ks("m"), hbe = Ks("h"), gbe = Ks("d"), _be = Ks("w"), vbe = Ks("M"), bbe = Ks("Q"), Ebe = Ks("y"), Sbe = I4;
function ybe() {
  return wo(this);
}
function Tbe(e) {
  return e = no(e), this.isValid() ? this[e + "s"]() : NaN;
}
function ec(e) {
  return function() {
    return this.isValid() ? this._data[e] : NaN;
  };
}
var Cbe = ec("milliseconds"), Abe = ec("seconds"), Obe = ec("minutes"), Rbe = ec("hours"), wbe = ec("days"), xbe = ec("months"), Nbe = ec("years");
function Dbe() {
  return Qa(this.days() / 7);
}
var ws = Math.round, Vc = {
  ss: 44,
  // a few seconds to seconds
  s: 45,
  // seconds to minute
  m: 45,
  // minutes to hour
  h: 22,
  // hours to day
  d: 26,
  // days to month/week
  w: null,
  // weeks to month
  M: 11
  // months to year
};
function Ibe(e, t, n, r, i) {
  return i.relativeTime(t || 1, !!n, e, r);
}
function Lbe(e, t, n, r) {
  var i = wo(e).abs(), a = ws(i.as("s")), o = ws(i.as("m")), s = ws(i.as("h")), l = ws(i.as("d")), u = ws(i.as("M")), c = ws(i.as("w")), d = ws(i.as("y")), f = a <= n.ss && ["s", a] || a < n.s && ["ss", a] || o <= 1 && ["m"] || o < n.m && ["mm", o] || s <= 1 && ["h"] || s < n.h && ["hh", s] || l <= 1 && ["d"] || l < n.d && ["dd", l];
  return n.w != null && (f = f || c <= 1 && ["w"] || c < n.w && ["ww", c]), f = f || u <= 1 && ["M"] || u < n.M && ["MM", u] || d <= 1 && ["y"] || ["yy", d], f[2] = t, f[3] = +e > 0, f[4] = r, Ibe.apply(null, f);
}
function kbe(e) {
  return e === void 0 ? ws : typeof e == "function" ? (ws = e, !0) : !1;
}
function Mbe(e, t) {
  return Vc[e] === void 0 ? !1 : t === void 0 ? Vc[e] : (Vc[e] = t, e === "s" && (Vc.ss = t - 1), !0);
}
function Pbe(e, t) {
  if (!this.isValid())
    return this.localeData().invalidDate();
  var n = !1, r = Vc, i, a;
  return typeof e == "object" && (t = e, e = !1), typeof e == "boolean" && (n = e), typeof t == "object" && (r = Object.assign({}, Vc, t), t.s != null && t.ss == null && (r.ss = t.s - 1)), i = this.localeData(), a = Lbe(this, !n, r, i), n && (a = i.pastFuture(+this, a)), i.postformat(a);
}
var gT = Math.abs;
function xc(e) {
  return (e > 0) - (e < 0) || +e;
}
function yv() {
  if (!this.isValid())
    return this.localeData().invalidDate();
  var e = gT(this._milliseconds) / 1e3, t = gT(this._days), n = gT(this._months), r, i, a, o, s = this.asSeconds(), l, u, c, d;
  return s ? (r = Qa(e / 60), i = Qa(r / 60), e %= 60, r %= 60, a = Qa(n / 12), n %= 12, o = e ? e.toFixed(3).replace(/\.?0+$/, "") : "", l = s < 0 ? "-" : "", u = xc(this._months) !== xc(s) ? "-" : "", c = xc(this._days) !== xc(s) ? "-" : "", d = xc(this._milliseconds) !== xc(s) ? "-" : "", l + "P" + (a ? u + a + "Y" : "") + (n ? u + n + "M" : "") + (t ? c + t + "D" : "") + (i || r || e ? "T" : "") + (i ? d + i + "H" : "") + (r ? d + r + "M" : "") + (e ? d + o + "S" : "")) : "P0D";
}
var wn = Ev.prototype;
wn.isValid = x_e;
wn.abs = lbe;
wn.add = ube;
wn.subtract = cbe;
wn.as = fbe;
wn.asMilliseconds = I4;
wn.asSeconds = pbe;
wn.asMinutes = mbe;
wn.asHours = hbe;
wn.asDays = gbe;
wn.asWeeks = _be;
wn.asMonths = vbe;
wn.asQuarters = bbe;
wn.asYears = Ebe;
wn.valueOf = Sbe;
wn._bubble = dbe;
wn.clone = ybe;
wn.get = Tbe;
wn.milliseconds = Cbe;
wn.seconds = Abe;
wn.minutes = Obe;
wn.hours = Rbe;
wn.days = wbe;
wn.weeks = Dbe;
wn.months = xbe;
wn.years = Nbe;
wn.humanize = Pbe;
wn.toISOString = yv;
wn.toString = yv;
wn.toJSON = yv;
wn.locale = b4;
wn.localeData = S4;
wn.toIsoString = to(
  "toIsoString() is deprecated. Please use toISOString() instead (notice the capitals)",
  yv
);
wn.lang = E4;
Lt("X", 0, 0, "unix");
Lt("x", 0, 0, "valueOf");
Et("x", gv);
Et("X", rge);
Wn("X", function(e, t, n) {
  n._d = new Date(parseFloat(e) * 1e3);
});
Wn("x", function(e, t, n) {
  n._d = new Date(yn(e));
});
//! moment.js
Ge.version = "2.30.1";
Fhe(hr);
Ge.fn = Xe;
Ge.min = A_e;
Ge.max = O_e;
Ge.now = R_e;
Ge.utc = is;
Ge.unix = tbe;
Ge.months = rbe;
Ge.isDate = gm;
Ge.locale = Ml;
Ge.invalid = fv;
Ge.duration = wo;
Ge.isMoment = Co;
Ge.weekdays = abe;
Ge.parseZone = nbe;
Ge.localeData = Ws;
Ge.isDuration = vg;
Ge.monthsShort = ibe;
Ge.weekdaysMin = sbe;
Ge.defineLocale = TA;
Ge.updateLocale = n_e;
Ge.locales = r_e;
Ge.weekdaysShort = obe;
Ge.normalizeUnits = no;
Ge.relativeTimeRounding = kbe;
Ge.relativeTimeThreshold = Mbe;
Ge.calendarFormat = Z_e;
Ge.prototype = Xe;
Ge.HTML5_FMT = {
  DATETIME_LOCAL: "YYYY-MM-DDTHH:mm",
  // <input type="datetime-local" />
  DATETIME_LOCAL_SECONDS: "YYYY-MM-DDTHH:mm:ss",
  // <input type="datetime-local" step="1" />
  DATETIME_LOCAL_MS: "YYYY-MM-DDTHH:mm:ss.SSS",
  // <input type="datetime-local" step="0.001" />
  DATE: "YYYY-MM-DD",
  // <input type="date" />
  TIME: "HH:mm",
  // <input type="time" />
  TIME_SECONDS: "HH:mm:ss",
  // <input type="time" step="1" />
  TIME_MS: "HH:mm:ss.SSS",
  // <input type="time" step="0.001" />
  WEEK: "GGGG-[W]WW",
  // <input type="week" />
  MONTH: "YYYY-MM"
  // <input type="month" />
};
/*!
 * Vueform v1.7.3 (https://github.com/vueform/vueform)
 * Copyright (c) 2024 Adam Berecz <adam@vueform.com>
 * Licensed under the MIT License
 */
function L2(e, t) {
  var n = Object.keys(e);
  if (Object.getOwnPropertySymbols) {
    var r = Object.getOwnPropertySymbols(e);
    t && (r = r.filter(function(i) {
      return Object.getOwnPropertyDescriptor(e, i).enumerable;
    })), n.push.apply(n, r);
  }
  return n;
}
function mt(e) {
  for (var t = 1; t < arguments.length; t++) {
    var n = arguments[t] != null ? arguments[t] : {};
    t % 2 ? L2(Object(n), !0).forEach(function(r) {
      L4(e, r, n[r]);
    }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(n)) : L2(Object(n)).forEach(function(r) {
      Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(n, r));
    });
  }
  return e;
}
function Fbe(e, t) {
  if (typeof e != "object" || !e) return e;
  var n = e[Symbol.toPrimitive];
  if (n !== void 0) {
    var r = n.call(e, t || "default");
    if (typeof r != "object") return r;
    throw new TypeError("@@toPrimitive must return a primitive value.");
  }
  return (t === "string" ? String : Number)(e);
}
function Bbe(e) {
  var t = Fbe(e, "string");
  return typeof t == "symbol" ? t : String(t);
}
function k2(e, t, n, r, i, a, o) {
  try {
    var s = e[a](o), l = s.value;
  } catch (u) {
    n(u);
    return;
  }
  s.done ? t(l) : Promise.resolve(l).then(r, i);
}
function ht(e) {
  return function() {
    var t = this, n = arguments;
    return new Promise(function(r, i) {
      var a = e.apply(t, n);
      function o(l) {
        k2(a, r, i, o, s, "next", l);
      }
      function s(l) {
        k2(a, r, i, o, s, "throw", l);
      }
      o(void 0);
    });
  };
}
function L4(e, t, n) {
  return t = Bbe(t), t in e ? Object.defineProperty(e, t, {
    value: n,
    enumerable: !0,
    configurable: !0,
    writable: !0
  }) : e[t] = n, e;
}
var Vh = typeof globalThis < "u" ? globalThis : typeof window < "u" ? window : typeof global < "u" ? global : typeof self < "u" ? self : {};
function $be(e) {
  return e && e.__esModule && Object.prototype.hasOwnProperty.call(e, "default") ? e.default : e;
}
var k4 = { exports: {} };
function Ube(e, t) {
  for (var n = -1, r = e == null ? 0 : e.length; ++n < r && t(e[n], n, e) !== !1; )
    ;
  return e;
}
var M4 = Ube;
function qbe(e) {
  return function(t, n, r) {
    for (var i = -1, a = Object(t), o = r(t), s = o.length; s--; ) {
      var l = o[e ? s : ++i];
      if (n(a[l], l, a) === !1)
        break;
    }
    return t;
  };
}
var Gbe = qbe, Ybe = Gbe, Hbe = Ybe(), P4 = Hbe;
function zbe(e, t) {
  for (var n = -1, r = Array(e); ++n < e; )
    r[n] = t(n);
  return r;
}
var Vbe = zbe, Wbe = typeof Vh == "object" && Vh && Vh.Object === Object && Vh, F4 = Wbe, Kbe = F4, jbe = typeof self == "object" && self && self.Object === Object && self, Qbe = Kbe || jbe || Function("return this")(), os = Qbe, Xbe = os, Zbe = Xbe.Symbol, kd = Zbe, M2 = kd, B4 = Object.prototype, Jbe = B4.hasOwnProperty, e0e = B4.toString, Nf = M2 ? M2.toStringTag : void 0;
function t0e(e) {
  var t = Jbe.call(e, Nf), n = e[Nf];
  try {
    e[Nf] = void 0;
    var r = !0;
  } catch {
  }
  var i = e0e.call(e);
  return r && (t ? e[Nf] = n : delete e[Nf]), i;
}
var n0e = t0e, r0e = Object.prototype, i0e = r0e.toString;
function a0e(e) {
  return i0e.call(e);
}
var o0e = a0e, P2 = kd, s0e = n0e, l0e = o0e, u0e = "[object Null]", c0e = "[object Undefined]", F2 = P2 ? P2.toStringTag : void 0;
function d0e(e) {
  return e == null ? e === void 0 ? c0e : u0e : F2 && F2 in Object(e) ? s0e(e) : l0e(e);
}
var tc = d0e;
function f0e(e) {
  return e != null && typeof e == "object";
}
var ss = f0e, p0e = tc, m0e = ss, h0e = "[object Arguments]";
function g0e(e) {
  return m0e(e) && p0e(e) == h0e;
}
var _0e = g0e, B2 = _0e, v0e = ss, $4 = Object.prototype, b0e = $4.hasOwnProperty, E0e = $4.propertyIsEnumerable, S0e = B2(/* @__PURE__ */ function() {
  return arguments;
}()) ? B2 : function(e) {
  return v0e(e) && b0e.call(e, "callee") && !E0e.call(e, "callee");
}, Em = S0e, y0e = Array.isArray, At = y0e, Wu = { exports: {} };
function T0e() {
  return !1;
}
var C0e = T0e;
(function(e, t) {
  var n = os, r = C0e, i = t && !t.nodeType && t, a = i && !0 && e && !e.nodeType && e, o = a && a.exports === i, s = o ? n.Buffer : void 0, l = s ? s.isBuffer : void 0, u = l || r;
  e.exports = u;
})(Wu, Wu.exports);
var A0e = 9007199254740991, O0e = /^(?:0|[1-9]\d*)$/;
function R0e(e, t) {
  var n = typeof e;
  return t = t ?? A0e, !!t && (n == "number" || n != "symbol" && O0e.test(e)) && e > -1 && e % 1 == 0 && e < t;
}
var Tv = R0e, w0e = 9007199254740991;
function x0e(e) {
  return typeof e == "number" && e > -1 && e % 1 == 0 && e <= w0e;
}
var IA = x0e, N0e = tc, D0e = IA, I0e = ss, L0e = "[object Arguments]", k0e = "[object Array]", M0e = "[object Boolean]", P0e = "[object Date]", F0e = "[object Error]", B0e = "[object Function]", $0e = "[object Map]", U0e = "[object Number]", q0e = "[object Object]", G0e = "[object RegExp]", Y0e = "[object Set]", H0e = "[object String]", z0e = "[object WeakMap]", V0e = "[object ArrayBuffer]", W0e = "[object DataView]", K0e = "[object Float32Array]", j0e = "[object Float64Array]", Q0e = "[object Int8Array]", X0e = "[object Int16Array]", Z0e = "[object Int32Array]", J0e = "[object Uint8Array]", eEe = "[object Uint8ClampedArray]", tEe = "[object Uint16Array]", nEe = "[object Uint32Array]", mr = {};
mr[K0e] = mr[j0e] = mr[Q0e] = mr[X0e] = mr[Z0e] = mr[J0e] = mr[eEe] = mr[tEe] = mr[nEe] = !0;
mr[L0e] = mr[k0e] = mr[V0e] = mr[M0e] = mr[W0e] = mr[P0e] = mr[F0e] = mr[B0e] = mr[$0e] = mr[U0e] = mr[q0e] = mr[G0e] = mr[Y0e] = mr[H0e] = mr[z0e] = !1;
function rEe(e) {
  return I0e(e) && D0e(e.length) && !!mr[N0e(e)];
}
var iEe = rEe;
function aEe(e) {
  return function(t) {
    return e(t);
  };
}
var Sm = aEe, Up = { exports: {} };
(function(e, t) {
  var n = F4, r = t && !t.nodeType && t, i = r && !0 && e && !e.nodeType && e, a = i && i.exports === r, o = a && n.process, s = function() {
    try {
      var l = i && i.require && i.require("util").types;
      return l || o && o.binding && o.binding("util");
    } catch {
    }
  }();
  e.exports = s;
})(Up, Up.exports);
var oEe = iEe, sEe = Sm, $2 = Up.exports, U2 = $2 && $2.isTypedArray, lEe = U2 ? sEe(U2) : oEe, Cv = lEe, uEe = Vbe, cEe = Em, dEe = At, fEe = Wu.exports, pEe = Tv, mEe = Cv, hEe = Object.prototype, gEe = hEe.hasOwnProperty;
function _Ee(e, t) {
  var n = dEe(e), r = !n && cEe(e), i = !n && !r && fEe(e), a = !n && !r && !i && mEe(e), o = n || r || i || a, s = o ? uEe(e.length, String) : [], l = s.length;
  for (var u in e)
    (t || gEe.call(e, u)) && !(o && // Safari 9 has enumerable `arguments.length` in strict mode.
    (u == "length" || // Node.js 0.10 has enumerable non-index properties on buffers.
    i && (u == "offset" || u == "parent") || // PhantomJS 2 has enumerable non-index properties on typed arrays.
    a && (u == "buffer" || u == "byteLength" || u == "byteOffset") || // Skip index properties.
    pEe(u, l))) && s.push(u);
  return s;
}
var U4 = _Ee, vEe = Object.prototype;
function bEe(e) {
  var t = e && e.constructor, n = typeof t == "function" && t.prototype || vEe;
  return e === n;
}
var Av = bEe;
function EEe(e, t) {
  return function(n) {
    return e(t(n));
  };
}
var q4 = EEe, SEe = q4, yEe = SEe(Object.keys, Object), TEe = yEe, CEe = Av, AEe = TEe, OEe = Object.prototype, REe = OEe.hasOwnProperty;
function wEe(e) {
  if (!CEe(e))
    return AEe(e);
  var t = [];
  for (var n in Object(e))
    REe.call(e, n) && n != "constructor" && t.push(n);
  return t;
}
var G4 = wEe;
function xEe(e) {
  var t = typeof e;
  return e != null && (t == "object" || t == "function");
}
var Ma = xEe, NEe = tc, DEe = Ma, IEe = "[object AsyncFunction]", LEe = "[object Function]", kEe = "[object GeneratorFunction]", MEe = "[object Proxy]";
function PEe(e) {
  if (!DEe(e))
    return !1;
  var t = NEe(e);
  return t == LEe || t == kEe || t == IEe || t == MEe;
}
var LA = PEe, FEe = LA, BEe = IA;
function $Ee(e) {
  return e != null && BEe(e.length) && !FEe(e);
}
var js = $Ee, UEe = U4, qEe = G4, GEe = js;
function YEe(e) {
  return GEe(e) ? UEe(e) : qEe(e);
}
var si = YEe, HEe = P4, zEe = si;
function VEe(e, t) {
  return e && HEe(e, t, zEe);
}
var Y4 = VEe, WEe = js;
function KEe(e, t) {
  return function(n, r) {
    if (n == null)
      return n;
    if (!WEe(n))
      return e(n, r);
    for (var i = n.length, a = t ? i : -1, o = Object(n); (t ? a-- : ++a < i) && r(o[a], a, o) !== !1; )
      ;
    return n;
  };
}
var jEe = KEe, QEe = Y4, XEe = jEe, ZEe = XEe(QEe), ym = ZEe;
function JEe(e) {
  return e;
}
var Tm = JEe, eSe = Tm;
function tSe(e) {
  return typeof e == "function" ? e : eSe;
}
var nSe = tSe, rSe = M4, iSe = ym, aSe = nSe, oSe = At;
function sSe(e, t) {
  var n = oSe(e) ? rSe : iSe;
  return n(e, aSe(t));
}
var lSe = sSe;
(function(e) {
  e.exports = lSe;
})(k4);
var Te = /* @__PURE__ */ $be(k4.exports);
function uSe() {
  this.__data__ = [], this.size = 0;
}
var cSe = uSe;
function dSe(e, t) {
  return e === t || e !== e && t !== t;
}
var Cm = dSe, fSe = Cm;
function pSe(e, t) {
  for (var n = e.length; n--; )
    if (fSe(e[n][0], t))
      return n;
  return -1;
}
var Ov = pSe, mSe = Ov, hSe = Array.prototype, gSe = hSe.splice;
function _Se(e) {
  var t = this.__data__, n = mSe(t, e);
  if (n < 0)
    return !1;
  var r = t.length - 1;
  return n == r ? t.pop() : gSe.call(t, n, 1), --this.size, !0;
}
var vSe = _Se, bSe = Ov;
function ESe(e) {
  var t = this.__data__, n = bSe(t, e);
  return n < 0 ? void 0 : t[n][1];
}
var SSe = ESe, ySe = Ov;
function TSe(e) {
  return ySe(this.__data__, e) > -1;
}
var CSe = TSe, ASe = Ov;
function OSe(e, t) {
  var n = this.__data__, r = ASe(n, e);
  return r < 0 ? (++this.size, n.push([e, t])) : n[r][1] = t, this;
}
var RSe = OSe, wSe = cSe, xSe = vSe, NSe = SSe, DSe = CSe, ISe = RSe;
function Md(e) {
  var t = -1, n = e == null ? 0 : e.length;
  for (this.clear(); ++t < n; ) {
    var r = e[t];
    this.set(r[0], r[1]);
  }
}
Md.prototype.clear = wSe;
Md.prototype.delete = xSe;
Md.prototype.get = NSe;
Md.prototype.has = DSe;
Md.prototype.set = ISe;
var Rv = Md, LSe = Rv;
function kSe() {
  this.__data__ = new LSe(), this.size = 0;
}
var MSe = kSe;
function PSe(e) {
  var t = this.__data__, n = t.delete(e);
  return this.size = t.size, n;
}
var FSe = PSe;
function BSe(e) {
  return this.__data__.get(e);
}
var $Se = BSe;
function USe(e) {
  return this.__data__.has(e);
}
var qSe = USe, GSe = os, YSe = GSe["__core-js_shared__"], HSe = YSe, _T = HSe, q2 = function() {
  var e = /[^.]+$/.exec(_T && _T.keys && _T.keys.IE_PROTO || "");
  return e ? "Symbol(src)_1." + e : "";
}();
function zSe(e) {
  return !!q2 && q2 in e;
}
var VSe = zSe, WSe = Function.prototype, KSe = WSe.toString;
function jSe(e) {
  if (e != null) {
    try {
      return KSe.call(e);
    } catch {
    }
    try {
      return e + "";
    } catch {
    }
  }
  return "";
}
var H4 = jSe, QSe = LA, XSe = VSe, ZSe = Ma, JSe = H4, eye = /[\\^$.*+?()[\]{}|]/g, tye = /^\[object .+?Constructor\]$/, nye = Function.prototype, rye = Object.prototype, iye = nye.toString, aye = rye.hasOwnProperty, oye = RegExp(
  "^" + iye.call(aye).replace(eye, "\\$&").replace(/hasOwnProperty|(function).*?(?=\\\()| for .+?(?=\\\])/g, "$1.*?") + "$"
);
function sye(e) {
  if (!ZSe(e) || XSe(e))
    return !1;
  var t = QSe(e) ? oye : tye;
  return t.test(JSe(e));
}
var lye = sye;
function uye(e, t) {
  return e == null ? void 0 : e[t];
}
var cye = uye, dye = lye, fye = cye;
function pye(e, t) {
  var n = fye(e, t);
  return dye(n) ? n : void 0;
}
var nc = pye, mye = nc, hye = os, gye = mye(hye, "Map"), kA = gye, _ye = nc, vye = _ye(Object, "create"), wv = vye, G2 = wv;
function bye() {
  this.__data__ = G2 ? G2(null) : {}, this.size = 0;
}
var Eye = bye;
function Sye(e) {
  var t = this.has(e) && delete this.__data__[e];
  return this.size -= t ? 1 : 0, t;
}
var yye = Sye, Tye = wv, Cye = "__lodash_hash_undefined__", Aye = Object.prototype, Oye = Aye.hasOwnProperty;
function Rye(e) {
  var t = this.__data__;
  if (Tye) {
    var n = t[e];
    return n === Cye ? void 0 : n;
  }
  return Oye.call(t, e) ? t[e] : void 0;
}
var wye = Rye, xye = wv, Nye = Object.prototype, Dye = Nye.hasOwnProperty;
function Iye(e) {
  var t = this.__data__;
  return xye ? t[e] !== void 0 : Dye.call(t, e);
}
var Lye = Iye, kye = wv, Mye = "__lodash_hash_undefined__";
function Pye(e, t) {
  var n = this.__data__;
  return this.size += this.has(e) ? 0 : 1, n[e] = kye && t === void 0 ? Mye : t, this;
}
var Fye = Pye, Bye = Eye, $ye = yye, Uye = wye, qye = Lye, Gye = Fye;
function Pd(e) {
  var t = -1, n = e == null ? 0 : e.length;
  for (this.clear(); ++t < n; ) {
    var r = e[t];
    this.set(r[0], r[1]);
  }
}
Pd.prototype.clear = Bye;
Pd.prototype.delete = $ye;
Pd.prototype.get = Uye;
Pd.prototype.has = qye;
Pd.prototype.set = Gye;
var Yye = Pd, Y2 = Yye, Hye = Rv, zye = kA;
function Vye() {
  this.size = 0, this.__data__ = {
    hash: new Y2(),
    map: new (zye || Hye)(),
    string: new Y2()
  };
}
var Wye = Vye;
function Kye(e) {
  var t = typeof e;
  return t == "string" || t == "number" || t == "symbol" || t == "boolean" ? e !== "__proto__" : e === null;
}
var jye = Kye, Qye = jye;
function Xye(e, t) {
  var n = e.__data__;
  return Qye(t) ? n[typeof t == "string" ? "string" : "hash"] : n.map;
}
var xv = Xye, Zye = xv;
function Jye(e) {
  var t = Zye(this, e).delete(e);
  return this.size -= t ? 1 : 0, t;
}
var eTe = Jye, tTe = xv;
function nTe(e) {
  return tTe(this, e).get(e);
}
var rTe = nTe, iTe = xv;
function aTe(e) {
  return iTe(this, e).has(e);
}
var oTe = aTe, sTe = xv;
function lTe(e, t) {
  var n = sTe(this, e), r = n.size;
  return n.set(e, t), this.size += n.size == r ? 0 : 1, this;
}
var uTe = lTe, cTe = Wye, dTe = eTe, fTe = rTe, pTe = oTe, mTe = uTe;
function Fd(e) {
  var t = -1, n = e == null ? 0 : e.length;
  for (this.clear(); ++t < n; ) {
    var r = e[t];
    this.set(r[0], r[1]);
  }
}
Fd.prototype.clear = cTe;
Fd.prototype.delete = dTe;
Fd.prototype.get = fTe;
Fd.prototype.has = pTe;
Fd.prototype.set = mTe;
var MA = Fd, hTe = Rv, gTe = kA, _Te = MA, vTe = 200;
function bTe(e, t) {
  var n = this.__data__;
  if (n instanceof hTe) {
    var r = n.__data__;
    if (!gTe || r.length < vTe - 1)
      return r.push([e, t]), this.size = ++n.size, this;
    n = this.__data__ = new _Te(r);
  }
  return n.set(e, t), this.size = n.size, this;
}
var ETe = bTe, STe = Rv, yTe = MSe, TTe = FSe, CTe = $Se, ATe = qSe, OTe = ETe;
function Bd(e) {
  var t = this.__data__ = new STe(e);
  this.size = t.size;
}
Bd.prototype.clear = yTe;
Bd.prototype.delete = TTe;
Bd.prototype.get = CTe;
Bd.prototype.has = ATe;
Bd.prototype.set = OTe;
var Nv = Bd, RTe = nc, wTe = function() {
  try {
    var e = RTe(Object, "defineProperty");
    return e({}, "", {}), e;
  } catch {
  }
}(), z4 = wTe, H2 = z4;
function xTe(e, t, n) {
  t == "__proto__" && H2 ? H2(e, t, {
    configurable: !0,
    enumerable: !0,
    value: n,
    writable: !0
  }) : e[t] = n;
}
var Dv = xTe, NTe = Dv, DTe = Cm;
function ITe(e, t, n) {
  (n !== void 0 && !DTe(e[t], n) || n === void 0 && !(t in e)) && NTe(e, t, n);
}
var V4 = ITe, d_ = { exports: {} };
(function(e, t) {
  var n = os, r = t && !t.nodeType && t, i = r && !0 && e && !e.nodeType && e, a = i && i.exports === r, o = a ? n.Buffer : void 0, s = o ? o.allocUnsafe : void 0;
  function l(u, c) {
    if (c)
      return u.slice();
    var d = u.length, f = s ? s(d) : new u.constructor(d);
    return u.copy(f), f;
  }
  e.exports = l;
})(d_, d_.exports);
var LTe = os, kTe = LTe.Uint8Array, W4 = kTe, z2 = W4;
function MTe(e) {
  var t = new e.constructor(e.byteLength);
  return new z2(t).set(new z2(e)), t;
}
var PA = MTe, PTe = PA;
function FTe(e, t) {
  var n = t ? PTe(e.buffer) : e.buffer;
  return new e.constructor(n, e.byteOffset, e.length);
}
var K4 = FTe;
function BTe(e, t) {
  var n = -1, r = e.length;
  for (t || (t = Array(r)); ++n < r; )
    t[n] = e[n];
  return t;
}
var FA = BTe, $Te = Ma, V2 = Object.create, UTe = /* @__PURE__ */ function() {
  function e() {
  }
  return function(t) {
    if (!$Te(t))
      return {};
    if (V2)
      return V2(t);
    e.prototype = t;
    var n = new e();
    return e.prototype = void 0, n;
  };
}(), qTe = UTe, GTe = q4, YTe = GTe(Object.getPrototypeOf, Object), BA = YTe, HTe = qTe, zTe = BA, VTe = Av;
function WTe(e) {
  return typeof e.constructor == "function" && !VTe(e) ? HTe(zTe(e)) : {};
}
var j4 = WTe, KTe = js, jTe = ss;
function QTe(e) {
  return jTe(e) && KTe(e);
}
var Iv = QTe, XTe = tc, ZTe = BA, JTe = ss, eCe = "[object Object]", tCe = Function.prototype, nCe = Object.prototype, Q4 = tCe.toString, rCe = nCe.hasOwnProperty, iCe = Q4.call(Object);
function aCe(e) {
  if (!JTe(e) || XTe(e) != eCe)
    return !1;
  var t = ZTe(e);
  if (t === null)
    return !0;
  var n = rCe.call(t, "constructor") && t.constructor;
  return typeof n == "function" && n instanceof n && Q4.call(n) == iCe;
}
var jn = aCe;
function oCe(e, t) {
  if (!(t === "constructor" && typeof e[t] == "function") && t != "__proto__")
    return e[t];
}
var X4 = oCe, sCe = Dv, lCe = Cm, uCe = Object.prototype, cCe = uCe.hasOwnProperty;
function dCe(e, t, n) {
  var r = e[t];
  (!(cCe.call(e, t) && lCe(r, n)) || n === void 0 && !(t in e)) && sCe(e, t, n);
}
var $A = dCe, fCe = $A, pCe = Dv;
function mCe(e, t, n, r) {
  var i = !n;
  n || (n = {});
  for (var a = -1, o = t.length; ++a < o; ) {
    var s = t[a], l = r ? r(n[s], e[s], s, n, e) : void 0;
    l === void 0 && (l = e[s]), i ? pCe(n, s, l) : fCe(n, s, l);
  }
  return n;
}
var $d = mCe;
function hCe(e) {
  var t = [];
  if (e != null)
    for (var n in Object(e))
      t.push(n);
  return t;
}
var gCe = hCe, _Ce = Ma, vCe = Av, bCe = gCe, ECe = Object.prototype, SCe = ECe.hasOwnProperty;
function yCe(e) {
  if (!_Ce(e))
    return bCe(e);
  var t = vCe(e), n = [];
  for (var r in e)
    r == "constructor" && (t || !SCe.call(e, r)) || n.push(r);
  return n;
}
var TCe = yCe, CCe = U4, ACe = TCe, OCe = js;
function RCe(e) {
  return OCe(e) ? CCe(e, !0) : ACe(e);
}
var Am = RCe, wCe = $d, xCe = Am;
function NCe(e) {
  return wCe(e, xCe(e));
}
var DCe = NCe, W2 = V4, ICe = d_.exports, LCe = K4, kCe = FA, MCe = j4, K2 = Em, j2 = At, PCe = Iv, FCe = Wu.exports, BCe = LA, $Ce = Ma, UCe = jn, qCe = Cv, Q2 = X4, GCe = DCe;
function YCe(e, t, n, r, i, a, o) {
  var s = Q2(e, n), l = Q2(t, n), u = o.get(l);
  if (u) {
    W2(e, n, u);
    return;
  }
  var c = a ? a(s, l, n + "", e, t, o) : void 0, d = c === void 0;
  if (d) {
    var f = j2(l), h = !f && FCe(l), m = !f && !h && qCe(l);
    c = l, f || h || m ? j2(s) ? c = s : PCe(s) ? c = kCe(s) : h ? (d = !1, c = ICe(l, !0)) : m ? (d = !1, c = LCe(l, !0)) : c = [] : UCe(l) || K2(l) ? (c = s, K2(s) ? c = GCe(s) : (!$Ce(s) || BCe(s)) && (c = MCe(l))) : d = !1;
  }
  d && (o.set(l, c), i(c, l, r, a, o), o.delete(l)), W2(e, n, c);
}
var HCe = YCe, zCe = Nv, VCe = V4, WCe = P4, KCe = HCe, jCe = Ma, QCe = Am, XCe = X4;
function Z4(e, t, n, r, i) {
  e !== t && WCe(t, function(a, o) {
    if (i || (i = new zCe()), jCe(a))
      KCe(e, t, o, n, Z4, r, i);
    else {
      var s = r ? r(XCe(e, o), a, o + "", e, t, i) : void 0;
      s === void 0 && (s = a), VCe(e, o, s);
    }
  }, QCe);
}
var ZCe = Z4;
function JCe(e, t, n) {
  switch (n.length) {
    case 0:
      return e.call(t);
    case 1:
      return e.call(t, n[0]);
    case 2:
      return e.call(t, n[0], n[1]);
    case 3:
      return e.call(t, n[0], n[1], n[2]);
  }
  return e.apply(t, n);
}
var e1e = JCe, t1e = e1e, X2 = Math.max;
function n1e(e, t, n) {
  return t = X2(t === void 0 ? e.length - 1 : t, 0), function() {
    for (var r = arguments, i = -1, a = X2(r.length - t, 0), o = Array(a); ++i < a; )
      o[i] = r[t + i];
    i = -1;
    for (var s = Array(t + 1); ++i < t; )
      s[i] = r[i];
    return s[t] = n(o), t1e(e, this, s);
  };
}
var J4 = n1e;
function r1e(e) {
  return function() {
    return e;
  };
}
var i1e = r1e, a1e = i1e, Z2 = z4, o1e = Tm, s1e = Z2 ? function(e, t) {
  return Z2(e, "toString", {
    configurable: !0,
    enumerable: !1,
    value: a1e(t),
    writable: !0
  });
} : o1e, l1e = s1e, u1e = 800, c1e = 16, d1e = Date.now;
function f1e(e) {
  var t = 0, n = 0;
  return function() {
    var r = d1e(), i = c1e - (r - n);
    if (n = r, i > 0) {
      if (++t >= u1e)
        return arguments[0];
    } else
      t = 0;
    return e.apply(void 0, arguments);
  };
}
var p1e = f1e, m1e = l1e, h1e = p1e, g1e = h1e(m1e), e$ = g1e, _1e = Tm, v1e = J4, b1e = e$;
function E1e(e, t) {
  return b1e(v1e(e, t, _1e), e + "");
}
var Om = E1e, S1e = Cm, y1e = js, T1e = Tv, C1e = Ma;
function A1e(e, t, n) {
  if (!C1e(n))
    return !1;
  var r = typeof t;
  return (r == "number" ? y1e(n) && T1e(t, n.length) : r == "string" && t in n) ? S1e(n[t], e) : !1;
}
var UA = A1e, O1e = Om, R1e = UA;
function w1e(e) {
  return O1e(function(t, n) {
    var r = -1, i = n.length, a = i > 1 ? n[i - 1] : void 0, o = i > 2 ? n[2] : void 0;
    for (a = e.length > 3 && typeof a == "function" ? (i--, a) : void 0, o && R1e(n[0], n[1], o) && (a = i < 3 ? void 0 : a, i = 1), t = Object(t); ++r < i; ) {
      var s = n[r];
      s && e(t, s, r, a);
    }
    return t;
  });
}
var x1e = w1e, N1e = ZCe, D1e = x1e, I1e = D1e(function(e, t, n) {
  N1e(e, t, n);
}), Ls = I1e;
function L1e(e, t) {
  for (var n = -1, r = e == null ? 0 : e.length; ++n < r; )
    if (t(e[n], n, e))
      return !0;
  return !1;
}
var t$ = L1e, k1e = "__lodash_hash_undefined__";
function M1e(e) {
  return this.__data__.set(e, k1e), this;
}
var P1e = M1e;
function F1e(e) {
  return this.__data__.has(e);
}
var B1e = F1e, $1e = MA, U1e = P1e, q1e = B1e;
function f_(e) {
  var t = -1, n = e == null ? 0 : e.length;
  for (this.__data__ = new $1e(); ++t < n; )
    this.add(e[t]);
}
f_.prototype.add = f_.prototype.push = U1e;
f_.prototype.has = q1e;
var qA = f_;
function G1e(e, t) {
  return e.has(t);
}
var GA = G1e, Y1e = qA, H1e = t$, z1e = GA, V1e = 1, W1e = 2;
function K1e(e, t, n, r, i, a) {
  var o = n & V1e, s = e.length, l = t.length;
  if (s != l && !(o && l > s))
    return !1;
  var u = a.get(e), c = a.get(t);
  if (u && c)
    return u == t && c == e;
  var d = -1, f = !0, h = n & W1e ? new Y1e() : void 0;
  for (a.set(e, t), a.set(t, e); ++d < s; ) {
    var m = e[d], v = t[d];
    if (r)
      var b = o ? r(v, m, d, t, e, a) : r(m, v, d, e, t, a);
    if (b !== void 0) {
      if (b)
        continue;
      f = !1;
      break;
    }
    if (h) {
      if (!H1e(t, function(y, g) {
        if (!z1e(h, g) && (m === y || i(m, y, n, r, a)))
          return h.push(g);
      })) {
        f = !1;
        break;
      }
    } else if (!(m === v || i(m, v, n, r, a))) {
      f = !1;
      break;
    }
  }
  return a.delete(e), a.delete(t), f;
}
var n$ = K1e;
function j1e(e) {
  var t = -1, n = Array(e.size);
  return e.forEach(function(r, i) {
    n[++t] = [i, r];
  }), n;
}
var Q1e = j1e;
function X1e(e) {
  var t = -1, n = Array(e.size);
  return e.forEach(function(r) {
    n[++t] = r;
  }), n;
}
var YA = X1e, J2 = kd, eM = W4, Z1e = Cm, J1e = n$, eAe = Q1e, tAe = YA, nAe = 1, rAe = 2, iAe = "[object Boolean]", aAe = "[object Date]", oAe = "[object Error]", sAe = "[object Map]", lAe = "[object Number]", uAe = "[object RegExp]", cAe = "[object Set]", dAe = "[object String]", fAe = "[object Symbol]", pAe = "[object ArrayBuffer]", mAe = "[object DataView]", tM = J2 ? J2.prototype : void 0, vT = tM ? tM.valueOf : void 0;
function hAe(e, t, n, r, i, a, o) {
  switch (n) {
    case mAe:
      if (e.byteLength != t.byteLength || e.byteOffset != t.byteOffset)
        return !1;
      e = e.buffer, t = t.buffer;
    case pAe:
      return !(e.byteLength != t.byteLength || !a(new eM(e), new eM(t)));
    case iAe:
    case aAe:
    case lAe:
      return Z1e(+e, +t);
    case oAe:
      return e.name == t.name && e.message == t.message;
    case uAe:
    case dAe:
      return e == t + "";
    case sAe:
      var s = eAe;
    case cAe:
      var l = r & nAe;
      if (s || (s = tAe), e.size != t.size && !l)
        return !1;
      var u = o.get(e);
      if (u)
        return u == t;
      r |= rAe, o.set(e, t);
      var c = J1e(s(e), s(t), r, i, a, o);
      return o.delete(e), c;
    case fAe:
      if (vT)
        return vT.call(e) == vT.call(t);
  }
  return !1;
}
var gAe = hAe;
function _Ae(e, t) {
  for (var n = -1, r = t.length, i = e.length; ++n < r; )
    e[i + n] = t[n];
  return e;
}
var Lv = _Ae, vAe = Lv, bAe = At;
function EAe(e, t, n) {
  var r = t(e);
  return bAe(e) ? r : vAe(r, n(e));
}
var r$ = EAe;
function SAe(e, t) {
  for (var n = -1, r = e == null ? 0 : e.length, i = 0, a = []; ++n < r; ) {
    var o = e[n];
    t(o, n, e) && (a[i++] = o);
  }
  return a;
}
var i$ = SAe;
function yAe() {
  return [];
}
var a$ = yAe, TAe = i$, CAe = a$, AAe = Object.prototype, OAe = AAe.propertyIsEnumerable, nM = Object.getOwnPropertySymbols, RAe = nM ? function(e) {
  return e == null ? [] : (e = Object(e), TAe(nM(e), function(t) {
    return OAe.call(e, t);
  }));
} : CAe, HA = RAe, wAe = r$, xAe = HA, NAe = si;
function DAe(e) {
  return wAe(e, NAe, xAe);
}
var o$ = DAe, rM = o$, IAe = 1, LAe = Object.prototype, kAe = LAe.hasOwnProperty;
function MAe(e, t, n, r, i, a) {
  var o = n & IAe, s = rM(e), l = s.length, u = rM(t), c = u.length;
  if (l != c && !o)
    return !1;
  for (var d = l; d--; ) {
    var f = s[d];
    if (!(o ? f in t : kAe.call(t, f)))
      return !1;
  }
  var h = a.get(e), m = a.get(t);
  if (h && m)
    return h == t && m == e;
  var v = !0;
  a.set(e, t), a.set(t, e);
  for (var b = o; ++d < l; ) {
    f = s[d];
    var y = e[f], g = t[f];
    if (r)
      var E = o ? r(g, y, f, t, e, a) : r(y, g, f, e, t, a);
    if (!(E === void 0 ? y === g || i(y, g, n, r, a) : E)) {
      v = !1;
      break;
    }
    b || (b = f == "constructor");
  }
  if (v && !b) {
    var S = e.constructor, C = t.constructor;
    S != C && "constructor" in e && "constructor" in t && !(typeof S == "function" && S instanceof S && typeof C == "function" && C instanceof C) && (v = !1);
  }
  return a.delete(e), a.delete(t), v;
}
var PAe = MAe, FAe = nc, BAe = os, $Ae = FAe(BAe, "DataView"), UAe = $Ae, qAe = nc, GAe = os, YAe = qAe(GAe, "Promise"), HAe = YAe, zAe = nc, VAe = os, WAe = zAe(VAe, "Set"), s$ = WAe, KAe = nc, jAe = os, QAe = KAe(jAe, "WeakMap"), XAe = QAe, FC = UAe, BC = kA, $C = HAe, UC = s$, qC = XAe, l$ = tc, Ud = H4, iM = "[object Map]", ZAe = "[object Object]", aM = "[object Promise]", oM = "[object Set]", sM = "[object WeakMap]", lM = "[object DataView]", JAe = Ud(FC), eOe = Ud(BC), tOe = Ud($C), nOe = Ud(UC), rOe = Ud(qC), Au = l$;
(FC && Au(new FC(new ArrayBuffer(1))) != lM || BC && Au(new BC()) != iM || $C && Au($C.resolve()) != aM || UC && Au(new UC()) != oM || qC && Au(new qC()) != sM) && (Au = function(e) {
  var t = l$(e), n = t == ZAe ? e.constructor : void 0, r = n ? Ud(n) : "";
  if (r)
    switch (r) {
      case JAe:
        return lM;
      case eOe:
        return iM;
      case tOe:
        return aM;
      case nOe:
        return oM;
      case rOe:
        return sM;
    }
  return t;
});
var Rm = Au, bT = Nv, iOe = n$, aOe = gAe, oOe = PAe, uM = Rm, cM = At, dM = Wu.exports, sOe = Cv, lOe = 1, fM = "[object Arguments]", pM = "[object Array]", Wh = "[object Object]", uOe = Object.prototype, mM = uOe.hasOwnProperty;
function cOe(e, t, n, r, i, a) {
  var o = cM(e), s = cM(t), l = o ? pM : uM(e), u = s ? pM : uM(t);
  l = l == fM ? Wh : l, u = u == fM ? Wh : u;
  var c = l == Wh, d = u == Wh, f = l == u;
  if (f && dM(e)) {
    if (!dM(t))
      return !1;
    o = !0, c = !1;
  }
  if (f && !c)
    return a || (a = new bT()), o || sOe(e) ? iOe(e, t, n, r, i, a) : aOe(e, t, l, n, r, i, a);
  if (!(n & lOe)) {
    var h = c && mM.call(e, "__wrapped__"), m = d && mM.call(t, "__wrapped__");
    if (h || m) {
      var v = h ? e.value() : e, b = m ? t.value() : t;
      return a || (a = new bT()), i(v, b, n, r, a);
    }
  }
  return f ? (a || (a = new bT()), oOe(e, t, n, r, i, a)) : !1;
}
var dOe = cOe, fOe = dOe, hM = ss;
function u$(e, t, n, r, i) {
  return e === t ? !0 : e == null || t == null || !hM(e) && !hM(t) ? e !== e && t !== t : fOe(e, t, n, r, u$, i);
}
var zA = u$, pOe = Nv, mOe = zA, hOe = 1, gOe = 2;
function _Oe(e, t, n, r) {
  var i = n.length, a = i, o = !r;
  if (e == null)
    return !a;
  for (e = Object(e); i--; ) {
    var s = n[i];
    if (o && s[2] ? s[1] !== e[s[0]] : !(s[0] in e))
      return !1;
  }
  for (; ++i < a; ) {
    s = n[i];
    var l = s[0], u = e[l], c = s[1];
    if (o && s[2]) {
      if (u === void 0 && !(l in e))
        return !1;
    } else {
      var d = new pOe();
      if (r)
        var f = r(u, c, l, e, t, d);
      if (!(f === void 0 ? mOe(c, u, hOe | gOe, r, d) : f))
        return !1;
    }
  }
  return !0;
}
var vOe = _Oe, bOe = Ma;
function EOe(e) {
  return e === e && !bOe(e);
}
var c$ = EOe, SOe = c$, yOe = si;
function TOe(e) {
  for (var t = yOe(e), n = t.length; n--; ) {
    var r = t[n], i = e[r];
    t[n] = [r, i, SOe(i)];
  }
  return t;
}
var COe = TOe;
function AOe(e, t) {
  return function(n) {
    return n == null ? !1 : n[e] === t && (t !== void 0 || e in Object(n));
  };
}
var d$ = AOe, OOe = vOe, ROe = COe, wOe = d$;
function xOe(e) {
  var t = ROe(e);
  return t.length == 1 && t[0][2] ? wOe(t[0][0], t[0][1]) : function(n) {
    return n === e || OOe(n, e, t);
  };
}
var NOe = xOe, DOe = tc, IOe = ss, LOe = "[object Symbol]";
function kOe(e) {
  return typeof e == "symbol" || IOe(e) && DOe(e) == LOe;
}
var wm = kOe, MOe = At, POe = wm, FOe = /\.|\[(?:[^[\]]*|(["'])(?:(?!\1)[^\\]|\\.)*?\1)\]/, BOe = /^\w*$/;
function $Oe(e, t) {
  if (MOe(e))
    return !1;
  var n = typeof e;
  return n == "number" || n == "symbol" || n == "boolean" || e == null || POe(e) ? !0 : BOe.test(e) || !FOe.test(e) || t != null && e in Object(t);
}
var VA = $Oe, f$ = MA, UOe = "Expected a function";
function WA(e, t) {
  if (typeof e != "function" || t != null && typeof t != "function")
    throw new TypeError(UOe);
  var n = function() {
    var r = arguments, i = t ? t.apply(this, r) : r[0], a = n.cache;
    if (a.has(i))
      return a.get(i);
    var o = e.apply(this, r);
    return n.cache = a.set(i, o) || a, o;
  };
  return n.cache = new (WA.Cache || f$)(), n;
}
WA.Cache = f$;
var qOe = WA, GOe = qOe, YOe = 500;
function HOe(e) {
  var t = GOe(e, function(r) {
    return n.size === YOe && n.clear(), r;
  }), n = t.cache;
  return t;
}
var zOe = HOe, VOe = zOe, WOe = /[^.[\]]+|\[(?:(-?\d+(?:\.\d+)?)|(["'])((?:(?!\2)[^\\]|\\.)*?)\2)\]|(?=(?:\.|\[\])(?:\.|\[\]|$))/g, KOe = /\\(\\)?/g, jOe = VOe(function(e) {
  var t = [];
  return e.charCodeAt(0) === 46 && t.push(""), e.replace(WOe, function(n, r, i, a) {
    t.push(i ? a.replace(KOe, "$1") : r || n);
  }), t;
}), QOe = jOe;
function XOe(e, t) {
  for (var n = -1, r = e == null ? 0 : e.length, i = Array(r); ++n < r; )
    i[n] = t(e[n], n, e);
  return i;
}
var qd = XOe, gM = kd, ZOe = qd, JOe = At, eRe = wm, tRe = 1 / 0, _M = gM ? gM.prototype : void 0, vM = _M ? _M.toString : void 0;
function p$(e) {
  if (typeof e == "string")
    return e;
  if (JOe(e))
    return ZOe(e, p$) + "";
  if (eRe(e))
    return vM ? vM.call(e) : "";
  var t = e + "";
  return t == "0" && 1 / e == -tRe ? "-0" : t;
}
var kv = p$, nRe = kv;
function rRe(e) {
  return e == null ? "" : nRe(e);
}
var zl = rRe, iRe = At, aRe = VA, oRe = QOe, sRe = zl;
function lRe(e, t) {
  return iRe(e) ? e : aRe(e, t) ? [e] : oRe(sRe(e));
}
var Gd = lRe, uRe = wm, cRe = 1 / 0;
function dRe(e) {
  if (typeof e == "string" || uRe(e))
    return e;
  var t = e + "";
  return t == "0" && 1 / e == -cRe ? "-0" : t;
}
var Yd = dRe, fRe = Gd, pRe = Yd;
function mRe(e, t) {
  t = fRe(t, e);
  for (var n = 0, r = t.length; e != null && n < r; )
    e = e[pRe(t[n++])];
  return n && n == r ? e : void 0;
}
var xm = mRe, hRe = xm;
function gRe(e, t, n) {
  var r = e == null ? void 0 : hRe(e, t);
  return r === void 0 ? n : r;
}
var $r = gRe;
function _Re(e, t) {
  return e != null && t in Object(e);
}
var vRe = _Re, bRe = Gd, ERe = Em, SRe = At, yRe = Tv, TRe = IA, CRe = Yd;
function ARe(e, t, n) {
  t = bRe(t, e);
  for (var r = -1, i = t.length, a = !1; ++r < i; ) {
    var o = CRe(t[r]);
    if (!(a = e != null && n(e, o)))
      break;
    e = e[o];
  }
  return a || ++r != i ? a : (i = e == null ? 0 : e.length, !!i && TRe(i) && yRe(o, i) && (SRe(e) || ERe(e)));
}
var ORe = ARe, RRe = vRe, wRe = ORe;
function xRe(e, t) {
  return e != null && wRe(e, t, RRe);
}
var m$ = xRe, NRe = zA, DRe = $r, IRe = m$, LRe = VA, kRe = c$, MRe = d$, PRe = Yd, FRe = 1, BRe = 2;
function $Re(e, t) {
  return LRe(e) && kRe(t) ? MRe(PRe(e), t) : function(n) {
    var r = DRe(n, e);
    return r === void 0 && r === t ? IRe(n, e) : NRe(t, r, FRe | BRe);
  };
}
var URe = $Re;
function qRe(e) {
  return function(t) {
    return t == null ? void 0 : t[e];
  };
}
var GRe = qRe, YRe = xm;
function HRe(e) {
  return function(t) {
    return YRe(t, e);
  };
}
var zRe = HRe, VRe = GRe, WRe = zRe, KRe = VA, jRe = Yd;
function QRe(e) {
  return KRe(e) ? VRe(jRe(e)) : WRe(e);
}
var XRe = QRe, ZRe = NOe, JRe = URe, ewe = Tm, twe = At, nwe = XRe;
function rwe(e) {
  return typeof e == "function" ? e : e == null ? ewe : typeof e == "object" ? twe(e) ? JRe(e[0], e[1]) : ZRe(e) : nwe(e);
}
var Qs = rwe, iwe = ym;
function awe(e, t) {
  var n;
  return iwe(e, function(r, i, a) {
    return n = t(r, i, a), !n;
  }), !!n;
}
var owe = awe, swe = t$, lwe = Qs, uwe = owe, cwe = At, dwe = UA;
function fwe(e, t, n) {
  var r = cwe(e) ? swe : uwe;
  return n && dwe(e, t, n) && (t = void 0), r(e, lwe(t));
}
var hn = fwe, pwe = G4, mwe = Rm, hwe = Em, gwe = At, _we = js, vwe = Wu.exports, bwe = Av, Ewe = Cv, Swe = "[object Map]", ywe = "[object Set]", Twe = Object.prototype, Cwe = Twe.hasOwnProperty;
function Awe(e) {
  if (e == null)
    return !0;
  if (_we(e) && (gwe(e) || typeof e == "string" || typeof e.splice == "function" || vwe(e) || Ewe(e) || hwe(e)))
    return !e.length;
  var t = mwe(e);
  if (t == Swe || t == ywe)
    return !e.size;
  if (bwe(e))
    return !pwe(e).length;
  for (var n in e)
    if (Cwe.call(e, n))
      return !1;
  return !0;
}
var np = Awe;
function Owe(e, t, n) {
  var r = -1, i = e.length;
  t < 0 && (t = -t > i ? 0 : i + t), n = n > i ? i : n, n < 0 && (n += i), i = t > n ? 0 : n - t >>> 0, t >>>= 0;
  for (var a = Array(i); ++r < i; )
    a[r] = e[r + t];
  return a;
}
var h$ = Owe, Rwe = h$;
function wwe(e, t, n) {
  var r = e.length;
  return n = n === void 0 ? r : n, !t && n >= r ? e : Rwe(e, t, n);
}
var g$ = wwe, xwe = "\\ud800-\\udfff", Nwe = "\\u0300-\\u036f", Dwe = "\\ufe20-\\ufe2f", Iwe = "\\u20d0-\\u20ff", Lwe = Nwe + Dwe + Iwe, kwe = "\\ufe0e\\ufe0f", Mwe = "\\u200d", Pwe = RegExp("[" + Mwe + xwe + Lwe + kwe + "]");
function Fwe(e) {
  return Pwe.test(e);
}
var _$ = Fwe;
function Bwe(e) {
  return e.split("");
}
var $we = Bwe, v$ = "\\ud800-\\udfff", Uwe = "\\u0300-\\u036f", qwe = "\\ufe20-\\ufe2f", Gwe = "\\u20d0-\\u20ff", Ywe = Uwe + qwe + Gwe, Hwe = "\\ufe0e\\ufe0f", zwe = "[" + v$ + "]", GC = "[" + Ywe + "]", YC = "\\ud83c[\\udffb-\\udfff]", Vwe = "(?:" + GC + "|" + YC + ")", b$ = "[^" + v$ + "]", E$ = "(?:\\ud83c[\\udde6-\\uddff]){2}", S$ = "[\\ud800-\\udbff][\\udc00-\\udfff]", Wwe = "\\u200d", y$ = Vwe + "?", T$ = "[" + Hwe + "]?", Kwe = "(?:" + Wwe + "(?:" + [b$, E$, S$].join("|") + ")" + T$ + y$ + ")*", jwe = T$ + y$ + Kwe, Qwe = "(?:" + [b$ + GC + "?", GC, E$, S$, zwe].join("|") + ")", Xwe = RegExp(YC + "(?=" + YC + ")|" + Qwe + jwe, "g");
function Zwe(e) {
  return e.match(Xwe) || [];
}
var Jwe = Zwe, exe = $we, txe = _$, nxe = Jwe;
function rxe(e) {
  return txe(e) ? nxe(e) : exe(e);
}
var C$ = rxe, ixe = g$, axe = _$, oxe = C$, sxe = zl;
function lxe(e) {
  return function(t) {
    t = sxe(t);
    var n = axe(t) ? oxe(t) : void 0, r = n ? n[0] : t.charAt(0), i = n ? ixe(n, 1).join("") : t.slice(1);
    return r[e]() + i;
  };
}
var A$ = lxe, uxe = A$, cxe = uxe("toUpperCase"), Hd = cxe, dxe = ym;
function fxe(e, t) {
  var n = [];
  return dxe(e, function(r, i, a) {
    t(r, i, a) && n.push(r);
  }), n;
}
var pxe = fxe, mxe = i$, hxe = pxe, gxe = Qs, _xe = At;
function vxe(e, t) {
  var n = _xe(e) ? mxe : hxe;
  return n(e, gxe(t));
}
var KA = vxe, bxe = $d, Exe = si;
function Sxe(e, t) {
  return e && bxe(t, Exe(t), e);
}
var yxe = Sxe, Txe = $d, Cxe = Am;
function Axe(e, t) {
  return e && Txe(t, Cxe(t), e);
}
var Oxe = Axe, Rxe = $d, wxe = HA;
function xxe(e, t) {
  return Rxe(e, wxe(e), t);
}
var Nxe = xxe, Dxe = Lv, Ixe = BA, Lxe = HA, kxe = a$, Mxe = Object.getOwnPropertySymbols, Pxe = Mxe ? function(e) {
  for (var t = []; e; )
    Dxe(t, Lxe(e)), e = Ixe(e);
  return t;
} : kxe, O$ = Pxe, Fxe = $d, Bxe = O$;
function $xe(e, t) {
  return Fxe(e, Bxe(e), t);
}
var Uxe = $xe, qxe = r$, Gxe = O$, Yxe = Am;
function Hxe(e) {
  return qxe(e, Yxe, Gxe);
}
var R$ = Hxe, zxe = Object.prototype, Vxe = zxe.hasOwnProperty;
function Wxe(e) {
  var t = e.length, n = new e.constructor(t);
  return t && typeof e[0] == "string" && Vxe.call(e, "index") && (n.index = e.index, n.input = e.input), n;
}
var Kxe = Wxe, jxe = PA;
function Qxe(e, t) {
  var n = t ? jxe(e.buffer) : e.buffer;
  return new e.constructor(n, e.byteOffset, e.byteLength);
}
var Xxe = Qxe, Zxe = /\w*$/;
function Jxe(e) {
  var t = new e.constructor(e.source, Zxe.exec(e));
  return t.lastIndex = e.lastIndex, t;
}
var eNe = Jxe, bM = kd, EM = bM ? bM.prototype : void 0, SM = EM ? EM.valueOf : void 0;
function tNe(e) {
  return SM ? Object(SM.call(e)) : {};
}
var nNe = tNe, rNe = PA, iNe = Xxe, aNe = eNe, oNe = nNe, sNe = K4, lNe = "[object Boolean]", uNe = "[object Date]", cNe = "[object Map]", dNe = "[object Number]", fNe = "[object RegExp]", pNe = "[object Set]", mNe = "[object String]", hNe = "[object Symbol]", gNe = "[object ArrayBuffer]", _Ne = "[object DataView]", vNe = "[object Float32Array]", bNe = "[object Float64Array]", ENe = "[object Int8Array]", SNe = "[object Int16Array]", yNe = "[object Int32Array]", TNe = "[object Uint8Array]", CNe = "[object Uint8ClampedArray]", ANe = "[object Uint16Array]", ONe = "[object Uint32Array]";
function RNe(e, t, n) {
  var r = e.constructor;
  switch (t) {
    case gNe:
      return rNe(e);
    case lNe:
    case uNe:
      return new r(+e);
    case _Ne:
      return iNe(e, n);
    case vNe:
    case bNe:
    case ENe:
    case SNe:
    case yNe:
    case TNe:
    case CNe:
    case ANe:
    case ONe:
      return sNe(e, n);
    case cNe:
      return new r();
    case dNe:
    case mNe:
      return new r(e);
    case fNe:
      return aNe(e);
    case pNe:
      return new r();
    case hNe:
      return oNe(e);
  }
}
var wNe = RNe, xNe = Rm, NNe = ss, DNe = "[object Map]";
function INe(e) {
  return NNe(e) && xNe(e) == DNe;
}
var LNe = INe, kNe = LNe, MNe = Sm, yM = Up.exports, TM = yM && yM.isMap, PNe = TM ? MNe(TM) : kNe, FNe = PNe, BNe = Rm, $Ne = ss, UNe = "[object Set]";
function qNe(e) {
  return $Ne(e) && BNe(e) == UNe;
}
var GNe = qNe, YNe = GNe, HNe = Sm, CM = Up.exports, AM = CM && CM.isSet, zNe = AM ? HNe(AM) : YNe, VNe = zNe, WNe = Nv, KNe = M4, jNe = $A, QNe = yxe, XNe = Oxe, ZNe = d_.exports, JNe = FA, eDe = Nxe, tDe = Uxe, nDe = o$, rDe = R$, iDe = Rm, aDe = Kxe, oDe = wNe, sDe = j4, lDe = At, uDe = Wu.exports, cDe = FNe, dDe = Ma, fDe = VNe, pDe = si, mDe = Am, hDe = 1, gDe = 2, _De = 4, w$ = "[object Arguments]", vDe = "[object Array]", bDe = "[object Boolean]", EDe = "[object Date]", SDe = "[object Error]", x$ = "[object Function]", yDe = "[object GeneratorFunction]", TDe = "[object Map]", CDe = "[object Number]", N$ = "[object Object]", ADe = "[object RegExp]", ODe = "[object Set]", RDe = "[object String]", wDe = "[object Symbol]", xDe = "[object WeakMap]", NDe = "[object ArrayBuffer]", DDe = "[object DataView]", IDe = "[object Float32Array]", LDe = "[object Float64Array]", kDe = "[object Int8Array]", MDe = "[object Int16Array]", PDe = "[object Int32Array]", FDe = "[object Uint8Array]", BDe = "[object Uint8ClampedArray]", $De = "[object Uint16Array]", UDe = "[object Uint32Array]", er = {};
er[w$] = er[vDe] = er[NDe] = er[DDe] = er[bDe] = er[EDe] = er[IDe] = er[LDe] = er[kDe] = er[MDe] = er[PDe] = er[TDe] = er[CDe] = er[N$] = er[ADe] = er[ODe] = er[RDe] = er[wDe] = er[FDe] = er[BDe] = er[$De] = er[UDe] = !0;
er[SDe] = er[x$] = er[xDe] = !1;
function Eg(e, t, n, r, i, a) {
  var o, s = t & hDe, l = t & gDe, u = t & _De;
  if (n && (o = i ? n(e, r, i, a) : n(e)), o !== void 0)
    return o;
  if (!dDe(e))
    return e;
  var c = lDe(e);
  if (c) {
    if (o = aDe(e), !s)
      return JNe(e, o);
  } else {
    var d = iDe(e), f = d == x$ || d == yDe;
    if (uDe(e))
      return ZNe(e, s);
    if (d == N$ || d == w$ || f && !i) {
      if (o = l || f ? {} : sDe(e), !s)
        return l ? tDe(e, XNe(o, e)) : eDe(e, QNe(o, e));
    } else {
      if (!er[d])
        return i ? e : {};
      o = oDe(e, d, s);
    }
  }
  a || (a = new WNe());
  var h = a.get(e);
  if (h)
    return h;
  a.set(e, o), fDe(e) ? e.forEach(function(b) {
    o.add(Eg(b, t, n, b, e, a));
  }) : cDe(e) && e.forEach(function(b, y) {
    o.set(y, Eg(b, t, n, y, e, a));
  });
  var m = u ? l ? rDe : nDe : l ? mDe : pDe, v = c ? void 0 : m(e);
  return KNe(v || e, function(b, y) {
    v && (y = b, b = e[y]), jNe(o, y, Eg(b, t, n, y, e, a));
  }), o;
}
var jA = Eg, qDe = jA, GDe = 1, YDe = 4;
function HDe(e) {
  return qDe(e, GDe | YDe);
}
var pn = HDe, zDe = $A, VDe = Gd, WDe = Tv, OM = Ma, KDe = Yd;
function jDe(e, t, n, r) {
  if (!OM(e))
    return e;
  t = VDe(t, e);
  for (var i = -1, a = t.length, o = a - 1, s = e; s != null && ++i < a; ) {
    var l = KDe(t[i]), u = n;
    if (l === "__proto__" || l === "constructor" || l === "prototype")
      return e;
    if (i != o) {
      var c = s[l];
      u = r ? r(c, l, s) : void 0, u === void 0 && (u = OM(c) ? c : WDe(t[i + 1]) ? [] : {});
    }
    zDe(s, l, u), s = s[l];
  }
  return e;
}
var D$ = jDe, QDe = D$;
function XDe(e, t, n) {
  return e == null ? e : QDe(e, t, n);
}
var Ru = XDe, RM = kd, ZDe = Em, JDe = At, wM = RM ? RM.isConcatSpreadable : void 0;
function eIe(e) {
  return JDe(e) || ZDe(e) || !!(wM && e && e[wM]);
}
var tIe = eIe, nIe = Lv, rIe = tIe;
function I$(e, t, n, r, i) {
  var a = -1, o = e.length;
  for (n || (n = rIe), i || (i = []); ++a < o; ) {
    var s = e[a];
    t > 0 && n(s) ? t > 1 ? I$(s, t - 1, n, r, i) : nIe(i, s) : r || (i[i.length] = s);
  }
  return i;
}
var rc = I$;
function iIe(e, t, n, r) {
  for (var i = e.length, a = n + (r ? 1 : -1); r ? a-- : ++a < i; )
    if (t(e[a], a, e))
      return a;
  return -1;
}
var QA = iIe;
function aIe(e) {
  return e !== e;
}
var oIe = aIe;
function sIe(e, t, n) {
  for (var r = n - 1, i = e.length; ++r < i; )
    if (e[r] === t)
      return r;
  return -1;
}
var lIe = sIe, uIe = QA, cIe = oIe, dIe = lIe;
function fIe(e, t, n) {
  return t === t ? dIe(e, t, n) : uIe(e, cIe, n);
}
var Mv = fIe, pIe = Mv;
function mIe(e, t) {
  var n = e == null ? 0 : e.length;
  return !!n && pIe(e, t, 0) > -1;
}
var L$ = mIe;
function hIe(e, t, n) {
  for (var r = -1, i = e == null ? 0 : e.length; ++r < i; )
    if (n(t, e[r]))
      return !0;
  return !1;
}
var k$ = hIe;
function gIe() {
}
var _Ie = gIe, ET = s$, vIe = _Ie, bIe = YA, EIe = 1 / 0, SIe = ET && 1 / bIe(new ET([, -0]))[1] == EIe ? function(e) {
  return new ET(e);
} : vIe, yIe = SIe, TIe = qA, CIe = L$, AIe = k$, OIe = GA, RIe = yIe, wIe = YA, xIe = 200;
function NIe(e, t, n) {
  var r = -1, i = CIe, a = e.length, o = !0, s = [], l = s;
  if (n)
    o = !1, i = AIe;
  else if (a >= xIe) {
    var u = t ? null : RIe(e);
    if (u)
      return wIe(u);
    o = !1, i = OIe, l = new TIe();
  } else
    l = t ? [] : s;
  e:
    for (; ++r < a; ) {
      var c = e[r], d = t ? t(c) : c;
      if (c = n || c !== 0 ? c : 0, o && d === d) {
        for (var f = l.length; f--; )
          if (l[f] === d)
            continue e;
        t && l.push(d), s.push(c);
      } else i(l, d, n) || (l !== s && l.push(d), s.push(c));
    }
  return s;
}
var DIe = NIe, IIe = rc, LIe = Om, kIe = DIe, MIe = Iv, PIe = LIe(function(e) {
  return kIe(IIe(e, 1, MIe, !0));
}), xM = PIe, FIe = rc, BIe = 1 / 0;
function $Ie(e) {
  var t = e == null ? 0 : e.length;
  return t ? FIe(e, BIe) : [];
}
var NM = $Ie, UIe = ["presets", "usePresets", "addClasses", "prependClasses", "removeClasses", "replaceClasses", "overrideClasses"], qIe = ["addClass", "removeClass", "replaceClass", "overrideClass"];
class Pv {
  constructor() {
    var t = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : {};
    this.options = t, this.shouldMergeTemplateClasses ? (this.componentClasses = this.templateClasses, this.merge({
      overrideClasses: {
        [this.component]: this.themeClasses
      }
    })) : this.componentClasses = this.templateClasses, this.merge(this.config), Te(t.merge, (n) => {
      this.merge(n);
    }), this.merge(this.locals || this.component$.value, !0), this.config.classHelpers && this.config.env !== "production" && this.merge({
      prependClasses: {
        [this.component]: this.getClassHelpers(this.componentClasses, [this.component])
      }
    });
  }
  get classes() {
    return new Proxy(this.componentClasses, {
      get: (t, n) => typeof n != "string" ? t[n] : this.getDynamicClasses(t, n)
    });
  }
  get config() {
    return this.options.config || {};
  }
  get component() {
    return this.options.component;
  }
  get component$() {
    return this.options.component$;
  }
  get locals() {
    return this.options.locals;
  }
  get view() {
    return this.options.view;
  }
  get theme() {
    return this.options.theme;
  }
  get presets() {
    return this.config.presets;
  }
  get templates() {
    return this.options.templates || {};
  }
  get template() {
    return this.view && this.templates["".concat(this.component, "_").concat(this.view)] ? this.templates["".concat(this.component, "_").concat(this.view)] : this.templates[this.component] || {};
  }
  get themeClasses() {
    return pn(this.toArray(this.view && this.theme.classes["".concat(this.component, "_").concat(this.view)] ? this.theme.classes["".concat(this.component, "_").concat(this.view)] : this.theme.classes[this.component]));
  }
  get templateClasses() {
    return pn(this.toArray(this.defaultClasses));
  }
  get shouldMergeTemplateClasses() {
    var t = typeof this.template.data == "function" && this.template.data().merge !== void 0 ? this.template.data().merge : this.component$.value.merge;
    return t !== void 0 ? t : !1;
  }
  get defaultClasses() {
    return typeof this.template.data == "function" && this.template.data().defaultClasses ? this.template.data().defaultClasses : this.component$.value.defaultClasses;
  }
  get mainClass() {
    var t = typeof this.template.data == "function" && this.template.data().defaultClasses ? this.template.data().defaultClasses : this.component$.value.defaultClasses;
    return Object.keys(t)[0];
  }
  merge(t) {
    var n = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : !1;
    Te(this.pick(t, n ? qIe : UIe), (r, i) => {
      switch (i) {
        case "addClasses":
        case "prependClasses":
        case "overrideClasses":
          if (!r || r[this.component] === void 0)
            return;
          this.mergeComponentClasses(this.toArray(r[this.component]), i);
          break;
        case "removeClasses":
        case "replaceClasses":
          if (!r || r[this.component] === void 0)
            return;
          this.mergeComponentClasses(r[this.component], i);
          break;
        case "addClass":
        case "removeClass":
        case "replaceClass":
        case "overrideClass":
          if (!r)
            return;
          typeof r == "string" || Array.isArray(r) ? (Array.isArray(r) || (r = r.length > 0 ? r.split(" ") : []), this.mergeComponentClasses({
            [this.mainClass]: r
          }, "".concat(i, "es"))) : i === "replaceClass" ? this.mergeComponentClasses(r, "".concat(i, "es")) : jn(r) && this.mergeComponentClasses(this.toArray(r), "".concat(i, "es"));
          break;
        case "presets":
        case "usePresets":
          if (!Array.isArray(r))
            return;
          Te(r, (a) => {
            this.merge(this.presets[a]);
          });
          break;
      }
    });
  }
  mergeComponentClasses(t, n) {
    Te(t, (r, i) => {
      this[n](r, [i]);
    });
  }
  addClasses(t, n) {
    var r = $r(this.componentClasses, n.join("."));
    t.length == 1 && !t[0] || (jn(r) ? Te(t, (i, a) => {
      this.addClasses(i, n.concat(a));
    }) : Ru(this.componentClasses, n.join("."), xM(r, t)));
  }
  prependClasses(t, n) {
    var r = $r(this.componentClasses, n.join("."));
    t.length == 1 && !t[0] || (jn(r) ? Te(t, (i, a) => {
      this.prependClasses(i, n.concat(a));
    }) : Ru(this.componentClasses, n.join("."), xM(t, r)));
  }
  removeClasses(t, n) {
    var r = $r(this.componentClasses, n.join("."));
    jn(r) ? Te(t, (i, a) => {
      this.removeClasses(i, n.concat(a));
    }) : Array.isArray(r) && Ru(this.componentClasses, n.join("."), r.filter((i) => typeof i != "string" || t.indexOf(i) === -1));
  }
  replaceClasses(t, n) {
    var r = $r(this.componentClasses, n.join("."));
    if (Array.isArray(t)) {
      var i = {};
      t.forEach((a) => {
        i = mt(mt({}, i), a);
      }), t = i;
    }
    jn(r) ? Te(t, (a, o) => {
      this.replaceClasses(a, n.concat(o));
    }) : Array.isArray(r) && Ru(this.componentClasses, n.join("."), r.map((a) => typeof a != "string" || Object.keys(t).indexOf(a) === -1 ? a : t[a]));
  }
  overrideClasses(t, n) {
    var r = $r(this.componentClasses, n.join("."));
    jn(r) ? Te(t, (i, a) => {
      this.overrideClasses(i, n.concat(a));
    }) : Ru(this.componentClasses, n.join("."), t);
  }
  toArray(t) {
    var n = {};
    return Te(t, (r, i) => {
      n[i] = this.classesToArray(r, [i]);
    }), n;
  }
  classesToArray(t, n) {
    var r, i = t, a = n ? $r(this.componentClasses, n.join(".")) : void 0;
    if (typeof t == "string")
      i = t.length > 0 ? t.split(" ") : [];
    else if (jn(t))
      a && Array.isArray(a) ? i = [t] : (!a || jn(a)) && (i = {}, Te(t, (o, s) => {
        i[s] = this.classesToArray(o, n.concat([s]));
      }));
    else if (typeof t == "boolean" || typeof t == "object" && ["ComputedRefImpl", "RefImpl"].indexOf(t == null || (r = t.constructor) === null || r === void 0 ? void 0 : r.name) !== -1)
      throw Error("Cannot add conditional class to ".concat(this.component, ": '").concat(n.join("."), "'"));
    return i;
  }
  getDynamicClasses(t, n, r) {
    r || (r = t);
    var i = Array.isArray(t[n]) ? NM(t[n]) : t[n];
    return t["$".concat(n)] ? NM(t["$".concat(n)](r, this.component$.value)) : (jn(i) && (i = pn(i), Te(i, (a, o) => {
      i[o] = this.getDynamicClasses(i, o, t);
    })), i);
  }
  getClassHelpers(t, n) {
    var r = {};
    return Te(t, (i, a) => {
      a.match(/[$]/) || (jn(i) ? r[a] = this.getClassHelpers(t[a], n.concat([a])) : r[a] = ["".concat(n.join("."), ".").concat(a, "-->")]);
    }), r;
  }
  pick(t, n) {
    var r = {};
    return t && Te(n, (i) => {
      i in t && (r[i] = t[i]);
    }), r;
  }
}
var M$ = function e(t, n, r) {
  return n === void 0 && (n = new FormData()), r === void 0 && (r = ""), At(t) ? Te(t, (i, a) => {
    e(i, n, r + "[" + a + "]");
  }) : jn(t) ? Te(t, (i, a) => {
    e(i, n, r ? r + "[" + a + "]" : a);
  }) : n.append(r, t === null ? "" : t), n;
}, GIe = qd;
function YIe(e, t) {
  return GIe(t, function(n) {
    return e[n];
  });
}
var HIe = YIe, zIe = HIe, VIe = si;
function WIe(e) {
  return e == null ? [] : zIe(e, VIe(e));
}
var ql = WIe;
function ki(e, t) {
  return HC.apply(this, arguments);
}
function HC() {
  return HC = ht(function* (e, t) {
    for (var n = 0; n < (jn(e) ? ql(e) : e).length; n++) {
      var r = jn(e) ? si(e)[n] : n;
      yield t(e[r], r, e);
    }
  }), HC.apply(this, arguments);
}
var KIe = Dv, jIe = Y4, QIe = Qs;
function XIe(e, t) {
  var n = {};
  return t = QIe(t), jIe(e, function(r, i, a) {
    KIe(n, i, t(r, i, a));
  }), n;
}
var ZIe = XIe, JIe = zA;
function eLe(e, t) {
  return JIe(e, t);
}
var zd = eLe, tLe = function(t) {
  return {
    lastModified: t.lastModified,
    name: t.name,
    size: t.size,
    type: t.type
  };
}, DM = function e(t) {
  return t instanceof File ? tLe(t) : t instanceof Date ? t.toString() : Array.isArray(t) ? t.map(e) : typeof t == "object" && t !== null ? ZIe(t, e) : t;
};
function Vl(e, t) {
  return zd(DM(e), DM(t));
}
function Df(e, t) {
  return e.appContext !== void 0 ? typeof e.appContext.app.component(t) != "string" : !!e.proxy.$root.$options.components[t];
}
var P$ = (e) => {
  var t = [];
  return e.forEach((n) => {
    t.push(n.path), n.children && P$(n.children).forEach((r) => {
      t.push(r);
    });
  }), t;
}, nLe = function e(t, n) {
  var r = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : "", i = (o) => {
    var s = t[o], l = r.length ? "".concat(r, ".").concat(o) : o, u = {
      name: o,
      path: l,
      type: s.type
    };
    return ["group", "object"].indexOf(s.type) !== -1 && Object.keys(s.schema || {}).length && (u.children = e(s.schema, null, l)), s.type === "list" && Object.keys((s == null ? void 0 : s.element) || {}).length && (u.children = e({
      0: s.element
    }, null, l)), u;
  }, a = [];
  return n && Object.keys(n).length ? Object.values(n).forEach((o) => {
    o.elements.forEach((s) => {
      a.push(i(s));
    });
  }) : Object.keys(t).forEach((o) => {
    a.push(i(o));
  }), a;
}, rLe = zl, iLe = Hd;
function aLe(e) {
  return iLe(rLe(e).toLowerCase());
}
var oLe = aLe;
function sLe(e, t, n, r) {
  var i = -1, a = e == null ? 0 : e.length;
  for (r && a && (n = e[++i]); ++i < a; )
    n = t(n, e[i], i, e);
  return n;
}
var F$ = sLe;
function lLe(e) {
  return function(t) {
    return e == null ? void 0 : e[t];
  };
}
var uLe = lLe, cLe = uLe, dLe = {
  // Latin-1 Supplement block.
  À: "A",
  Á: "A",
  Â: "A",
  Ã: "A",
  Ä: "A",
  Å: "A",
  à: "a",
  á: "a",
  â: "a",
  ã: "a",
  ä: "a",
  å: "a",
  Ç: "C",
  ç: "c",
  Ð: "D",
  ð: "d",
  È: "E",
  É: "E",
  Ê: "E",
  Ë: "E",
  è: "e",
  é: "e",
  ê: "e",
  ë: "e",
  Ì: "I",
  Í: "I",
  Î: "I",
  Ï: "I",
  ì: "i",
  í: "i",
  î: "i",
  ï: "i",
  Ñ: "N",
  ñ: "n",
  Ò: "O",
  Ó: "O",
  Ô: "O",
  Õ: "O",
  Ö: "O",
  Ø: "O",
  ò: "o",
  ó: "o",
  ô: "o",
  õ: "o",
  ö: "o",
  ø: "o",
  Ù: "U",
  Ú: "U",
  Û: "U",
  Ü: "U",
  ù: "u",
  ú: "u",
  û: "u",
  ü: "u",
  Ý: "Y",
  ý: "y",
  ÿ: "y",
  Æ: "Ae",
  æ: "ae",
  Þ: "Th",
  þ: "th",
  ß: "ss",
  // Latin Extended-A block.
  Ā: "A",
  Ă: "A",
  Ą: "A",
  ā: "a",
  ă: "a",
  ą: "a",
  Ć: "C",
  Ĉ: "C",
  Ċ: "C",
  Č: "C",
  ć: "c",
  ĉ: "c",
  ċ: "c",
  č: "c",
  Ď: "D",
  Đ: "D",
  ď: "d",
  đ: "d",
  Ē: "E",
  Ĕ: "E",
  Ė: "E",
  Ę: "E",
  Ě: "E",
  ē: "e",
  ĕ: "e",
  ė: "e",
  ę: "e",
  ě: "e",
  Ĝ: "G",
  Ğ: "G",
  Ġ: "G",
  Ģ: "G",
  ĝ: "g",
  ğ: "g",
  ġ: "g",
  ģ: "g",
  Ĥ: "H",
  Ħ: "H",
  ĥ: "h",
  ħ: "h",
  Ĩ: "I",
  Ī: "I",
  Ĭ: "I",
  Į: "I",
  İ: "I",
  ĩ: "i",
  ī: "i",
  ĭ: "i",
  į: "i",
  ı: "i",
  Ĵ: "J",
  ĵ: "j",
  Ķ: "K",
  ķ: "k",
  ĸ: "k",
  Ĺ: "L",
  Ļ: "L",
  Ľ: "L",
  Ŀ: "L",
  Ł: "L",
  ĺ: "l",
  ļ: "l",
  ľ: "l",
  ŀ: "l",
  ł: "l",
  Ń: "N",
  Ņ: "N",
  Ň: "N",
  Ŋ: "N",
  ń: "n",
  ņ: "n",
  ň: "n",
  ŋ: "n",
  Ō: "O",
  Ŏ: "O",
  Ő: "O",
  ō: "o",
  ŏ: "o",
  ő: "o",
  Ŕ: "R",
  Ŗ: "R",
  Ř: "R",
  ŕ: "r",
  ŗ: "r",
  ř: "r",
  Ś: "S",
  Ŝ: "S",
  Ş: "S",
  Š: "S",
  ś: "s",
  ŝ: "s",
  ş: "s",
  š: "s",
  Ţ: "T",
  Ť: "T",
  Ŧ: "T",
  ţ: "t",
  ť: "t",
  ŧ: "t",
  Ũ: "U",
  Ū: "U",
  Ŭ: "U",
  Ů: "U",
  Ű: "U",
  Ų: "U",
  ũ: "u",
  ū: "u",
  ŭ: "u",
  ů: "u",
  ű: "u",
  ų: "u",
  Ŵ: "W",
  ŵ: "w",
  Ŷ: "Y",
  ŷ: "y",
  Ÿ: "Y",
  Ź: "Z",
  Ż: "Z",
  Ž: "Z",
  ź: "z",
  ż: "z",
  ž: "z",
  Ĳ: "IJ",
  ĳ: "ij",
  Œ: "Oe",
  œ: "oe",
  ŉ: "'n",
  ſ: "s"
}, fLe = cLe(dLe), pLe = fLe, mLe = pLe, hLe = zl, gLe = /[\xc0-\xd6\xd8-\xf6\xf8-\xff\u0100-\u017f]/g, _Le = "\\u0300-\\u036f", vLe = "\\ufe20-\\ufe2f", bLe = "\\u20d0-\\u20ff", ELe = _Le + vLe + bLe, SLe = "[" + ELe + "]", yLe = RegExp(SLe, "g");
function TLe(e) {
  return e = hLe(e), e && e.replace(gLe, mLe).replace(yLe, "");
}
var CLe = TLe, ALe = /[^\x00-\x2f\x3a-\x40\x5b-\x60\x7b-\x7f]+/g;
function OLe(e) {
  return e.match(ALe) || [];
}
var RLe = OLe, wLe = /[a-z][A-Z]|[A-Z]{2}[a-z]|[0-9][a-zA-Z]|[a-zA-Z][0-9]|[^a-zA-Z0-9 ]/;
function xLe(e) {
  return wLe.test(e);
}
var NLe = xLe, B$ = "\\ud800-\\udfff", DLe = "\\u0300-\\u036f", ILe = "\\ufe20-\\ufe2f", LLe = "\\u20d0-\\u20ff", kLe = DLe + ILe + LLe, $$ = "\\u2700-\\u27bf", U$ = "a-z\\xdf-\\xf6\\xf8-\\xff", MLe = "\\xac\\xb1\\xd7\\xf7", PLe = "\\x00-\\x2f\\x3a-\\x40\\x5b-\\x60\\x7b-\\xbf", FLe = "\\u2000-\\u206f", BLe = " \\t\\x0b\\f\\xa0\\ufeff\\n\\r\\u2028\\u2029\\u1680\\u180e\\u2000\\u2001\\u2002\\u2003\\u2004\\u2005\\u2006\\u2007\\u2008\\u2009\\u200a\\u202f\\u205f\\u3000", q$ = "A-Z\\xc0-\\xd6\\xd8-\\xde", $Le = "\\ufe0e\\ufe0f", G$ = MLe + PLe + FLe + BLe, Y$ = "['’]", IM = "[" + G$ + "]", ULe = "[" + kLe + "]", H$ = "\\d+", qLe = "[" + $$ + "]", z$ = "[" + U$ + "]", V$ = "[^" + B$ + G$ + H$ + $$ + U$ + q$ + "]", GLe = "\\ud83c[\\udffb-\\udfff]", YLe = "(?:" + ULe + "|" + GLe + ")", HLe = "[^" + B$ + "]", W$ = "(?:\\ud83c[\\udde6-\\uddff]){2}", K$ = "[\\ud800-\\udbff][\\udc00-\\udfff]", Bc = "[" + q$ + "]", zLe = "\\u200d", LM = "(?:" + z$ + "|" + V$ + ")", VLe = "(?:" + Bc + "|" + V$ + ")", kM = "(?:" + Y$ + "(?:d|ll|m|re|s|t|ve))?", MM = "(?:" + Y$ + "(?:D|LL|M|RE|S|T|VE))?", j$ = YLe + "?", Q$ = "[" + $Le + "]?", WLe = "(?:" + zLe + "(?:" + [HLe, W$, K$].join("|") + ")" + Q$ + j$ + ")*", KLe = "\\d*(?:1st|2nd|3rd|(?![123])\\dth)(?=\\b|[A-Z_])", jLe = "\\d*(?:1ST|2ND|3RD|(?![123])\\dTH)(?=\\b|[a-z_])", QLe = Q$ + j$ + WLe, XLe = "(?:" + [qLe, W$, K$].join("|") + ")" + QLe, ZLe = RegExp([
  Bc + "?" + z$ + "+" + kM + "(?=" + [IM, Bc, "$"].join("|") + ")",
  VLe + "+" + MM + "(?=" + [IM, Bc + LM, "$"].join("|") + ")",
  Bc + "?" + LM + "+" + kM,
  Bc + "+" + MM,
  jLe,
  KLe,
  H$,
  XLe
].join("|"), "g");
function JLe(e) {
  return e.match(ZLe) || [];
}
var eke = JLe, tke = RLe, nke = NLe, rke = zl, ike = eke;
function ake(e, t, n) {
  return e = rke(e), t = n ? void 0 : t, t === void 0 ? nke(e) ? ike(e) : tke(e) : e.match(t) || [];
}
var oke = ake, ske = F$, lke = CLe, uke = oke, cke = "['’]", dke = RegExp(cke, "g");
function fke(e) {
  return function(t) {
    return ske(uke(lke(t).replace(dke, "")), e, "");
  };
}
var pke = fke, mke = oLe, hke = pke, gke = hke(function(e, t, n) {
  return t = t.toLowerCase(), e + (n ? mke(t) : t);
}), p_ = gke, Mn = function(t, n, r) {
  var i = arguments.length > 3 && arguments[3] !== void 0 ? arguments[3] : {};
  if (!i.events)
    throw new Error("`events` option is required for useEvents");
  var a = he(i.events), o = he({}), s = (c, d) => {
    o.value[c] || (o.value[c] = []), o.value[c].push(d);
  }, l = (c) => {
    delete o.value[c];
  }, u = function() {
    var d = arguments[0], f = [].slice.call(arguments).splice(1);
    Te(o.value[d], (h) => {
      h(...f);
    }), (!o.value[d] || !o.value[d].length) && n.emit(...[d].concat(f));
  };
  return Te(a.value, (c) => {
    var d = t["on" + Hd(p_(c))];
    d && s(c, d);
  }), {
    events: a,
    listeners: o,
    on: s,
    off: l,
    fire: u
  };
};
function _ke(e, t, n) {
  var {
    value: r,
    modelValue: i,
    sync: a
  } = De(e), o = n.$this, s = o.$vueform.vueVersion === 3 ? i : r, l = he({}), u = he(s && s.value ? pn(s.value) : null), c = N(() => a.value && s && s.value !== void 0), d = N(() => pn(s.value || l.value)), f = (h, m) => {
    if (s.value)
      if (h) {
        var v = h.split("."), b = v.pop(), y = v.join(".") || null, g = y ? $r(s.value, y) : s.value;
        g !== void 0 && o.$set(g, b, m), u.value = pn(s.value);
      } else
        Te(m, (S, C) => {
          s.value !== void 0 && o.$set(s.value, C, S), u.value !== void 0 && o.$set(u.value, C, S);
        });
    else {
      var E = pn(s.value || l.value);
      h ? Ru(E, h, m) : E = Object.assign({}, E, m), l.value = E;
    }
  };
  return s && s.value && et(d, (h, m) => {
    Vl(h, m) || (l.value = h);
  }, {
    deep: !0,
    immediate: !1
  }), {
    model: d,
    internalData: l,
    intermediaryValue: u,
    externalValue: s,
    isSync: c,
    updateModel: f
  };
}
var vke = function(t, n) {
  var {
    schema: r,
    tabs: i,
    steps: a,
    size: o,
    view: s,
    views: l,
    addClass: u,
    removeClass: c,
    replaceClass: d,
    overrideClass: f,
    addClasses: h,
    removeClasses: m,
    replaceClasses: v,
    overrideClasses: b,
    presets: y,
    templates: g,
    theme: E,
    messages: S,
    columns: C,
    languages: T,
    formKey: O,
    endpoint: R,
    method: D,
    formData: q,
    language: $,
    locale: P,
    validateOn: Y,
    forceLabels: L,
    floatPlaceholders: x,
    multilingual: I,
    stepsControls: k,
    displayErrors: B,
    displayMessages: W,
    formatLoad: Z,
    formatData: V,
    prepare: K,
    default: ne,
    disabled: Ee,
    loading: oe,
    onChange: ae,
    onReset: pe,
    onClear: Se,
    onSubmit: Re,
    onSuccess: Ye,
    onError: nt,
    onLanguage: ut,
    onBeforeMount: Tt,
    onMounted: Ot,
    onBeforeUpdate: Xt,
    onUpdated: We,
    onBeforeUnmount: st,
    onUnmounted: Pt
  } = De(t), Ke = ["change", "reset", "clear", "submit", "success", "error", "language", "beforeCreate", "created", "beforeMount", "mounted", "beforeUpdate", "updated", "beforeUnmount", "unmounted"], Je = fi(), Be = Je.proxy, {
    events: pt,
    listeners: ft,
    fire: Ze,
    on: _t,
    off: St
  } = Mn(t, n, {
    form$: Be
  }, {
    events: Ke
  }), {
    externalValue: we,
    model: je,
    internalData: yt,
    intermediaryValue: Rt,
    isSync: sn,
    updateModel: me
  } = _ke(t, n, {
    $this: Be,
    fire: Ze
  }), He = he({}), tt = he(null), ot = he(null), xn = he(!0), kt = he(!0), Dn = he({}), gn = he(!1), Vn = he(!1), X = he(null), te = he({}), _e = he(!1), M = he(Df(Je, "FormMessages")), G = he(Df(Je, "FormErrors")), j = he(Df(Je, "FormLanguages")), ce = he(Df(Je, "FormTabs")), be = he(Df(Je, "FormSteps")), Ie = N(() => Be), Ue = N(() => Be.$vueform), Ve = N(() => Ue.value), dt = N(() => xe.value.locale || Ue.value.i18n.locale), Pe = N(() => Be.$vueform.services), xe = N(() => {
    var Le = {
      schema: Mt.value,
      tabs: Jt.value,
      steps: xr.value
    }, it = {
      columns: C,
      languages: T,
      language: $,
      theme: E,
      method: D,
      validateOn: Y,
      messages: S,
      formKey: O,
      multilingual: I,
      formatLoad: Z,
      formatData: V,
      prepare: K,
      default: ne,
      formData: q,
      templates: g,
      addClass: u,
      removeClass: c,
      replaceClass: d,
      overrideClass: f,
      addClasses: h,
      removeClasses: m,
      replaceClasses: v,
      overrideClasses: b,
      presets: y,
      size: o,
      view: s,
      views: l,
      locale: P
    }, qt = {
      stepsControls: k,
      displayErrors: B,
      displayMessages: W,
      forceLabels: L,
      disabled: Ee,
      loading: oe,
      floatPlaceholders: x,
      endpoint: R,
      onChange: ae.value,
      onReset: pe.value,
      onClear: Se.value,
      onSubmit: Re.value,
      onSuccess: Ye.value,
      onError: nt.value,
      onLanguage: ut.value,
      onBeforeMount: Tt.value,
      onMounted: Ot.value,
      onBeforeUpdate: Xt.value,
      onUpdated: We.value,
      onBeforeUnmount: st.value,
      onUnmounted: Pt.value
    }, Pn = {
      languages: Ue.value.config.languages,
      language: Ue.value.config.language,
      endpoint: typeof Ue.value.config.endpoints.submit == "function" ? Ue.value.config.endpoints.submit : Ue.value.config.endpoints.submit.url,
      method: typeof Ue.value.config.endpoints.submit == "function" ? null : Ue.value.config.endpoints.submit.method,
      validateOn: Ue.value.config.validateOn,
      displayErrors: Ue.value.config.displayErrors,
      displayMessages: Ue.value.config.displayMessages,
      forceLabels: Ue.value.config.forceLabels,
      floatPlaceholders: Ue.value.config.floatPlaceholders,
      formData: Ue.value.config.formData,
      theme: Ue.value.theme,
      view: Ue.value.config.view,
      views: {},
      columns: {},
      size: null,
      addClass: null,
      removeClass: null,
      replaceClass: null,
      overrideClass: null,
      addClasses: {},
      removeClasses: {},
      replaceClasses: {},
      overrideClasses: {},
      presets: [],
      templates: {},
      messages: {},
      default: {},
      formKey: null,
      formatLoad: null,
      formatData: null,
      prepare: null,
      multilingual: !1,
      stepsControls: !0,
      disabled: !1,
      loading: !1
    };
    return Te(it, (_n, jt) => {
      Le[jt] = te.value[jt] !== void 0 ? te.value[jt] : (_n && _n.value ? _n.value : void 0) || Pn[jt];
    }), Te(qt, (_n, jt) => {
      Le[jt] = te.value[jt] !== void 0 ? te.value[jt] : _n && _n.value !== null ? _n.value : Pn[jt];
    }), Le;
  }), Mt = N(() => {
    var Le, it = Zt.value;
    return Object.keys(xr.value).length > 0 && (Le = xr.value), Object.keys(Jt.value).length > 0 && (Le = Jt.value), Le && (it = {}, Te(Le, (qt) => {
      Te(qt.elements, (Pn) => {
        Zt.value[Pn] && (it[Pn] = Zt.value[Pn]);
      });
    }), Te(Object.keys(Zt.value), (qt) => {
      it[qt] === void 0 && (it[qt] = Zt.value[qt]);
    })), it;
  }), Zt = N(() => Ls({}, r && r.value ? r.value : {}, te.value.schema || {})), Jt = N(() => Ls({}, i && i.value ? i.value : {}, te.value.tabs || {})), xr = N(() => Ls({}, a && a.value ? a.value : {}, te.value.steps || {})), Un = N(() => nLe(Zt.value, el.value ? Jt.value : xr.value)), pi = N(() => P$(Un.value)), Cr = N(() => {
    var Le = {};
    return Te(He.value, (it) => {
      it.isStatic || (Le = Object.assign({}, Le, it.data));
    }), Le;
  }), ti = N(() => {
    var Le = {};
    return Te(He.value, (it) => {
      it.isStatic || (Le = Object.assign({}, Le, it.requestData));
    }), V.value ? V.value(Le) : Le;
  }), Si = N(() => hn(He.value, (Le) => Le.isStatic === !1 && Le.available === !0 && Le.dirty === !0)), yi = N(() => hn(He.value, (Le) => Le.isStatic === !1 && Le.available === !0 && Le.invalid === !0)), vt = N(() => hn(He.value, (Le) => Le.isStatic === !1 && Le.available === !0 && Le.debouncing === !0)), ue = N(() => hn(He.value, (Le) => Le.isStatic === !1 && Le.available === !0 && Le.pending === !0)), Q = N(() => !hn(He.value, (Le) => Le.isStatic === !1 && Le.available === !0 && Le.validated === !1)), ye = N(() => hn(He.value, (Le) => Le.isStatic === !1 && Le.available === !0 && Le.busy === !0) || gn.value || Vn.value || Jd.value), ct = N(() => {
    var Le = [];
    return Te(KA(He.value, {
      available: !0,
      isStatic: !1
    }), (it) => {
      Te(it.errors, (qt) => {
        Le.push(qt);
      });
    }), Le;
  }), en = N(() => Dn.value.errors), Rn = N(() => en.value.length > 0), Nr = N(() => Rn.value && xe.value.displayErrors && G.value), mi = N(() => Dn.value.messages), ha = N(() => mi.value.length > 0), Er = N(() => ha.value && xe.value.displayMessages && M.value), ds = N(() => xe.value.multilingual), Js = N(() => ds.value && j.value), Zd = N(() => yi.value && Kl.value || ye.value || xe.value.disabled), Jd = N(() => xe.value.loading), Kl = N(() => xe.value.validateOn.split("|").indexOf("change") !== -1), Ym = N(() => xe.value.validateOn.split("|").indexOf("step") !== -1), jl = N(() => !np(xe.value.steps)), ef = N(() => jl.value && be.value), tf = N(() => jl.value && xe.value.stepsControls && be.value), el = N(() => !np(xe.value.tabs)), Hm = N(() => el.value && ce.value), tl = N(() => {
    var Le = {};
    return Te(Ue.value.config.usePresets.concat(xe.value.presets), (it) => {
      var qt = Ue.value.config.presets[it];
      !qt || !qt.templates || (Le = Object.assign({}, Le, qt.templates));
    }), Object.assign({}, xe.value.theme, {
      // Add registered component to theme (or overwrite)
      templates: Object.assign({}, xe.value.theme.templates, Ue.value.templates, Le, xe.value.templates || {})
    });
  }), io = N(() => tl.value.templates), nf = N(() => No.value && io.value["Vueform_".concat(No.value)] ? io.value["Vueform_".concat(No.value)] : io.value.Vueform), zm = N(() => new Pv({
    component: "Vueform",
    component$: Ie,
    theme: tl.value,
    config: Ue.value.config,
    templates: io.value,
    view: No.value,
    locals: xe.value,
    merge: [xe.value]
  }).classes), oc = N(() => {
    var Le;
    return xe.value.size ? Le = xe.value.size : Te(Ue.value.config.usePresets.concat(xe.value.presets), (it) => {
      var qt = Ue.value.config.presets[it];
      !qt || !qt.size || (Le = qt.size);
    }), Le || (Le = Ue.value.config.size), Le;
  }), Ql = N(() => {
    var Le = Ue.value.config.views;
    return Te(Ue.value.config.usePresets.concat(xe.value.presets), (it) => {
      var qt = Ue.value.config.presets[it];
      !qt || !qt.views || (Le = Object.assign({}, Le, qt.views));
    }), Le = Object.assign({}, Le, xe.value.views), Le;
  }), No = N(() => xe.value.view ? xe.value.view : Ql.value.Vueform), sc = N(() => {
    var Le = Be.$vueform.i18n, it = Le.locales, qt = P.value || Le.locale, Pn = Le.fallbackLocale || "en";
    return qt ? Ls({}, it[Pn], it[qt]) : it[Pn];
  }), Xl = function(it) {
    var qt = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : null;
    if (qt) {
      au(qt).update(it);
      return;
    }
    Te(He.value, (Pn) => {
      Pn.isStatic || it[Pn.name] === void 0 && !Pn.flat || Pn.update(Pn.flat ? it : it[Pn.name]);
    });
  }, Zl = /* @__PURE__ */ function() {
    var Le = ht(function* (it) {
      var qt = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : !1;
      ot.value !== null && ot.value.enableAllSteps();
      var Pn = qt && xe.value.formatLoad !== null ? xe.value.formatLoad(it) : it;
      yield ki(He.value, /* @__PURE__ */ function() {
        var _n = ht(function* (jt) {
          if (!jt.isStatic) {
            var ol = jt.flat ? Pn : Pn[jt.name];
            if (ol === void 0) {
              jt.clear();
              return;
            }
            yield jt.load(ol, qt);
          }
        });
        return function(jt) {
          return _n.apply(this, arguments);
        };
      }());
    });
    return function(qt) {
      return Le.apply(this, arguments);
    };
  }(), Jl = () => {
    Te(He.value, (Le) => {
      Le.isStatic || Le.reset();
    }), ot.value !== null && ot.value.reset(), tt.value !== null && tt.value.reset(), Ze("reset");
  }, Do = () => {
    Te(He.value, (Le) => {
      Le.isStatic || Le.clear();
    }), ot.value !== null && ot.value.reset(), tt.value !== null && tt.value.reset(), Ze("clear");
  }, lc = () => {
    Te(He.value, (Le) => {
      Le.isStatic || Le.clean();
    });
  }, uc = () => {
    Dn.value && Dn.value.clear(), Te(He.value, (Le) => {
      Le.isStatic || Le.clearMessages();
    });
  }, eu = /* @__PURE__ */ function() {
    var Le = ht(function* () {
      if (!(!yi.value && Q.value && Kl.value)) {
        var it = Object.values(He.value).filter((qt) => qt.available && !qt.isStatic && (!qt.validated || !Kl.value));
        yield ki(it, /* @__PURE__ */ function() {
          var qt = ht(function* (Pn) {
            yield Pn.validate();
          });
          return function(Pn) {
            return qt.apply(this, arguments);
          };
        }());
      }
    });
    return function() {
      return Le.apply(this, arguments);
    };
  }(), nl = () => {
    Te(He.value, (Le) => {
      Le.isStatic || Le.resetValidators();
    });
  }, rl = /* @__PURE__ */ function() {
    var Le = ht(function* () {
      if (!Zd.value && (yield eu(), !yi.value)) {
        Vn.value = !0;
        try {
          yield nu(), typeof xe.value.prepare == "function" && (yield xe.value.prepare(Ie.value)), typeof Be.$vueform.config.beforeSend == "function" && (yield Be.$vueform.config.beforeSend(Ie.value));
        } catch (it) {
          Ze("error", it, {
            type: "prepare"
          }, Ie.value), console.error(it);
          return;
        } finally {
          Vn.value = !1;
        }
        Ze("submit", Ie.value), xe.value.endpoint && tu();
      }
    });
    return function() {
      return Le.apply(this, arguments);
    };
  }(), tu = /* @__PURE__ */ function() {
    var Le = ht(function* () {
      gn.value = !0;
      var it = {};
      try {
        var qt, Pn;
        nl();
        var _n = xe.value.formData(Ie.value);
        if (typeof xe.value.endpoint == "function")
          it = yield xe.value.endpoint(_n, Ie.value);
        else {
          var jt, ol, Zv = ((jt = Be.$vueform.config.endpoints[xe.value.endpoint]) === null || jt === void 0 ? void 0 : jt.url) || xe.value.endpoint, Km = ((ol = Be.$vueform.config.endpoints[xe.value.endpoint]) === null || ol === void 0 ? void 0 : ol.method) || xe.value.method;
          it = yield Pe.value.axios.request({
            url: Zv,
            method: Km.toLowerCase(),
            [Km.toLowerCase() === "get" ? "params" : "data"]: _n
          });
        }
        if (it && !(it instanceof Promise)) {
          var ao;
          (ao = it) !== null && ao !== void 0 && (ao = ao.data) !== null && ao !== void 0 && (ao = ao.payload) !== null && ao !== void 0 && ao.updates && Xl(it.data.payload.updates);
        }
        ((qt = it) === null || qt === void 0 ? void 0 : qt.status) >= 200 && ((Pn = it) === null || Pn === void 0 ? void 0 : Pn.status) < 300 ? Ze("success", it, Ie.value) : Ze("error", {
          response: it
        }, {
          type: "submit"
        }, Ie.value);
      } catch (fc) {
        fc.response && Ze("response", fc.response, Ie.value), Ze("error", fc, {
          type: "submit"
        }, Ie.value), console.error(fc);
        return;
      } finally {
        gn.value = !1;
      }
      Ze("response", it, Ie.value);
    });
    return function() {
      return Le.apply(this, arguments);
    };
  }(), nu = /* @__PURE__ */ function() {
    var Le = ht(function* () {
      try {
        yield ki(He.value, /* @__PURE__ */ function() {
          var it = ht(function* (qt) {
            qt.prepare && (yield qt.prepare());
          });
          return function(qt) {
            return it.apply(this, arguments);
          };
        }());
      } catch (it) {
        throw new Error(it);
      }
    });
    return function() {
      return Le.apply(this, arguments);
    };
  }(), cc = () => {
    xn.value = !1;
  }, il = () => {
    xn.value = !0;
  }, ru = () => {
    kt.value = !0;
  }, iu = () => {
    kt.value = !1;
  }, al = (Le) => {
    X.value = Le, Ze("language", Le);
  }, dc = () => {
    rl();
  }, Vm = (Le) => M$(Le), au = (Le, it) => {
    if (it === void 0 && (it = He.value), np(it) || !Le)
      return null;
    var qt = String(Le).match(/^[^.]+\./);
    if (qt) {
      var Pn = qt[0].replace(".", "");
      return it[Pn] ? au(Le.replace(qt[0], ""), it[Pn].children$) : null;
    } else if (it[Le] !== void 0)
      return it[Le];
    return null;
  }, rf = (Le) => {
    var it;
    return /\.+/.test(Le) ? ((it = au(Le.match(/.*(?=\.)/)[0])) === null || it === void 0 ? void 0 : it.children$) || {} : He.value;
  }, Wm = () => {
    Dn.value = new Pe.value.messageBag(ct);
  };
  return aa("form$", Ie), aa("theme", tl), aa("Size", oc), aa("Views", Ql), aa("translations", sc), aa("config$", Ve), Wm(), al(xe.value.language), Gu(() => {
    te.value = Be.vueform || {}, Te(Ke, (Le) => {
      var it = xe.value["on" + Hd(Le)];
      it && _t(Le, it);
    }), Ze("beforeMount", Be);
  }), On(() => {
    _e.value = !0, et(Cr, (Le, it) => {
      Vl(Le, it) || (Ze("change", Le, it, Be), we && we.value !== void 0 && (n.emit("input", Le), n.emit("update:modelValue", Le)));
    }, {
      deep: !0,
      immediate: !1
    }), we && we.value !== void 0 && JSON.stringify(we.value) !== JSON.stringify(Cr.value) && (n.emit("input", Cr.value), n.emit("update:modelValue", Cr.value)), Ze("mounted", Be);
  }), iF(() => Ze("beforeUpdate", Be)), aF(() => Ze("updated", Be)), pa(() => Ze("beforeUnmount", Be)), l1(() => Ze("unmounted", Be)), et(N(() => xe.value.language), (Le, it) => {
    Le && al(Le);
  }), {
    tabs$: tt,
    steps$: ot,
    elements$: He,
    options: xe,
    validation: xn,
    conditions: kt,
    messageBag: Dn,
    selectedLanguage: X,
    submitting: gn,
    preparing: Vn,
    events: pt,
    listeners: ft,
    internalData: yt,
    data: Cr,
    requestData: ti,
    dirty: Si,
    invalid: yi,
    debouncing: vt,
    pending: ue,
    validated: Q,
    busy: ye,
    formErrors: en,
    formMessages: mi,
    isDisabled: Zd,
    isLoading: Jd,
    shouldValidateOnChange: Kl,
    shouldValidateOnStep: Ym,
    hasSteps: jl,
    hasTabs: el,
    hasErrors: Rn,
    hasMessages: ha,
    isMultilingual: ds,
    showErrors: Nr,
    showMessages: Er,
    showLanguages: Js,
    showSteps: ef,
    showTabs: Hm,
    showStepsControls: tf,
    classes: zm,
    Templates: io,
    template: nf,
    extendedTheme: tl,
    Size: oc,
    View: No,
    Views: Ql,
    form$: Ie,
    model: je,
    intermediaryValue: Rt,
    userConfig: te,
    isSync: sn,
    tree: Un,
    flatTree: pi,
    translations: sc,
    locale$: dt,
    prepareElements: nu,
    updateModel: me,
    update: Xl,
    load: Zl,
    reset: Jl,
    clear: Do,
    clean: lc,
    clearMessages: uc,
    validate: eu,
    resetValidators: nl,
    convertFormData: Vm,
    submit: rl,
    send: tu,
    disableValidation: cc,
    enableValidation: il,
    enableConditions: ru,
    disableConditions: iu,
    setLanguage: al,
    handleSubmit: dc,
    el$: au,
    siblings$: rf,
    initMessageBag: Wm,
    fire: Ze,
    on: _t,
    off: St,
    messagesRegistered: M,
    errorsRegistered: G,
    languagesRegistered: j,
    tabsRegistered: ce,
    stepsRegistered: be
  };
}, rr = function(t, n, r) {
  var i = n.name, a = r.form$, o = r.el$, s = r.component$ || r.el$, l = r.theme, u = r.Templates, c = r.View, d = N(() => new Pv({
    component: i.value,
    component$: s,
    theme: l.value,
    config: a.value.$vueform.config,
    templates: u.value,
    view: c.value,
    merge: [a.value.options, o.value]
  })), f = N(() => {
    var h;
    return mt({}, (h = d.value) === null || h === void 0 ? void 0 : h.classes);
  });
  return {
    classes: f,
    classesInstance: d
  };
}, Fv = {
  name: "Vueform",
  emits: ["input", "update:modelValue", "change", "reset", "clear", "submit", "success", "error", "response", "language", "beforeCreate", "created", "beforeMount", "mounted", "beforeUpdate", "updated", "beforeUnmount", "unmounted"],
  slots: ["default", "empty"],
  setup: (e, t) => {
    t.emits = ["input", "update:modelValue", "change", "reset", "clear", "submit", "success", "error", "response", "language", "beforeCreate", "created", "beforeMount", "mounted", "beforeUpdate", "updated", "beforeUnmount", "unmounted"], t.name = he("Vueform");
    var {
      tabs$: n,
      steps$: r,
      elements$: i,
      options: a,
      validation: o,
      conditions: s,
      messageBag: l,
      selectedLanguage: u,
      submitting: c,
      preparing: d,
      events: f,
      listeners: h,
      internalData: m,
      data: v,
      requestData: b,
      dirty: y,
      invalid: g,
      debouncing: E,
      pending: S,
      validated: C,
      busy: T,
      formErrors: O,
      formMessages: R,
      isDisabled: D,
      isLoading: q,
      shouldValidateOnChange: $,
      shouldValidateOnStep: P,
      hasSteps: Y,
      hasTabs: L,
      hasErrors: x,
      hasMessages: I,
      isMultilingual: k,
      showErrors: B,
      showMessages: W,
      showLanguages: Z,
      showSteps: V,
      showTabs: K,
      showStepsControls: ne,
      classes: Ee,
      Templates: oe,
      template: ae,
      extendedTheme: pe,
      Size: Se,
      View: Re,
      Views: Ye,
      form$: nt,
      model: ut,
      intermediaryValue: Tt,
      userConfig: Ot,
      isSync: Xt,
      tree: We,
      flatTree: st,
      translations: Pt,
      locale$: Ke,
      prepareElements: Je,
      updateModel: Be,
      update: pt,
      load: ft,
      reset: Ze,
      clear: _t,
      clean: St,
      clearMessages: we,
      validate: je,
      resetValidators: yt,
      convertFormData: Rt,
      submit: sn,
      send: me,
      disableValidation: He,
      enableValidation: tt,
      enableConditions: ot,
      disableConditions: xn,
      setLanguage: kt,
      handleSubmit: Dn,
      el$: gn,
      siblings$: Vn,
      initMessageBag: X,
      fire: te,
      on: _e,
      off: M,
      messagesRegistered: G,
      errorsRegistered: j,
      languagesRegistered: ce,
      tabsRegistered: be,
      stepsRegistered: Ie
    } = vke(e, t);
    return {
      tabs$: n,
      steps$: r,
      elements$: i,
      options: a,
      validation: o,
      conditions: s,
      messageBag: l,
      selectedLanguage: u,
      submitting: c,
      preparing: d,
      events: f,
      listeners: h,
      internalData: m,
      data: v,
      requestData: b,
      dirty: y,
      invalid: g,
      debouncing: E,
      pending: S,
      validated: C,
      busy: T,
      formErrors: O,
      formMessages: R,
      isDisabled: D,
      isLoading: q,
      shouldValidateOnChange: $,
      shouldValidateOnStep: P,
      hasSteps: Y,
      hasTabs: L,
      hasErrors: x,
      hasMessages: I,
      isMultilingual: k,
      showErrors: B,
      showMessages: W,
      showLanguages: Z,
      showSteps: V,
      showTabs: K,
      showStepsControls: ne,
      classes: Ee,
      Templates: oe,
      template: ae,
      extendedTheme: pe,
      Size: Se,
      View: Re,
      Views: Ye,
      form$: nt,
      model: ut,
      intermediaryValue: Tt,
      userConfig: Ot,
      isSync: Xt,
      tree: We,
      flatTree: st,
      translations: Pt,
      locale$: Ke,
      prepareElements: Je,
      updateModel: Be,
      update: pt,
      load: ft,
      reset: Ze,
      clear: _t,
      clean: St,
      clearMessages: we,
      validate: je,
      resetValidators: yt,
      convertFormData: Rt,
      submit: sn,
      send: me,
      disableValidation: He,
      enableValidation: tt,
      enableConditions: ot,
      disableConditions: xn,
      setLanguage: kt,
      handleSubmit: Dn,
      el$: gn,
      siblings$: Vn,
      initMessageBag: X,
      fire: te,
      on: _e,
      off: M,
      messagesRegistered: G,
      errorsRegistered: j,
      languagesRegistered: ce,
      tabsRegistered: be,
      stepsRegistered: Ie
    };
  },
  props: {
    schema: {
      type: Object,
      required: !1,
      default: null
    },
    name: {
      type: String,
      required: !1,
      default: null,
      private: !0
    },
    tabs: {
      type: Object,
      required: !1,
      default: null
    },
    steps: {
      type: Object,
      required: !1,
      default: null
    },
    stepsControls: {
      type: Boolean,
      required: !1,
      default: null,
      "@default": !0
    },
    validateOn: {
      type: String,
      required: !1,
      default: null
    },
    displayErrors: {
      type: Boolean,
      required: !1,
      default: null
    },
    displayMessages: {
      type: Boolean,
      required: !1,
      default: null
    },
    messages: {
      type: Object,
      required: !1,
      default: null
    },
    endpoint: {
      type: [String, Boolean, Function],
      required: !1,
      default: null
    },
    method: {
      type: String,
      required: !1,
      default: null
    },
    prepare: {
      type: Function,
      required: !1,
      default: null
    },
    formKey: {
      type: [String, Number],
      required: !1,
      default: null
    },
    formData: {
      type: Function,
      required: !1,
      default: null
    },
    value: {
      type: Object,
      required: !1,
      default: void 0
    },
    modelValue: {
      type: Object,
      required: !1,
      default: void 0
    },
    sync: {
      type: Boolean,
      required: !1,
      default: !1
    },
    default: {
      type: Object,
      required: !1,
      default: null
    },
    formatData: {
      type: Function,
      required: !1,
      default: null
    },
    formatLoad: {
      type: Function,
      required: !1,
      default: null
    },
    loading: {
      type: Boolean,
      required: !1,
      default: null
    },
    disabled: {
      type: Boolean,
      required: !1,
      default: null
    },
    columns: {
      type: Object,
      required: !1,
      default: null
    },
    forceLabels: {
      type: Boolean,
      required: !1,
      default: null
    },
    floatPlaceholders: {
      type: Boolean,
      required: !1,
      default: null
    },
    size: {
      required: !1,
      type: [String],
      default: null
    },
    view: {
      required: !1,
      type: [String],
      default: null
    },
    views: {
      required: !1,
      type: [Object],
      default: null
    },
    addClasses: {
      required: !1,
      type: [Object],
      default: null
    },
    addClass: {
      required: !1,
      type: [Array, Object, String],
      default: null
    },
    removeClasses: {
      required: !1,
      type: [Object],
      default: null
    },
    removeClass: {
      required: !1,
      type: [Array, Object],
      default: null
    },
    replaceClasses: {
      required: !1,
      type: [Object],
      default: null
    },
    replaceClass: {
      required: !1,
      type: [Object],
      default: null
    },
    overrideClasses: {
      required: !1,
      type: [Object],
      default: null
    },
    overrideClass: {
      required: !1,
      type: [Array, Object, String],
      default: null
    },
    templates: {
      type: Object,
      required: !1,
      default: null
    },
    presets: {
      required: !1,
      type: [Array],
      default: null
    },
    multilingual: {
      type: Boolean,
      required: !1,
      default: null
    },
    languages: {
      type: Object,
      required: !1,
      default: null
    },
    language: {
      type: String,
      required: !1,
      default: null
    },
    locale: {
      type: String,
      required: !1,
      default: null
    },
    onChange: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    },
    onReset: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    },
    onClear: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    },
    onSubmit: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    },
    onSuccess: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    },
    onError: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    },
    onLanguage: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    },
    onBeforeMount: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    },
    onMounted: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    },
    onBeforeUpdate: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    },
    onUpdated: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    },
    onBeforeUnmount: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    },
    onUnmounted: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    }
  },
  render() {
    return this.template.render.apply(this, arguments);
  }
  // staticRenderFns() {
  //   return this.templates.Vueform.staticRenderFns
  // }
}, bke = ym, Eke = js;
function Ske(e, t) {
  var n = -1, r = Eke(e) ? Array(e.length) : [];
  return bke(e, function(i, a, o) {
    r[++n] = t(i, a, o);
  }), r;
}
var X$ = Ske, yke = qd, Tke = Qs, Cke = X$, Ake = At;
function Oke(e, t) {
  var n = Ake(e) ? yke : Cke;
  return n(e, Tke(t));
}
var Ku = Oke, Rke = tc, wke = At, xke = ss, Nke = "[object String]";
function Dke(e) {
  return typeof e == "string" || !wke(e) && xke(e) && Rke(e) == Nke;
}
var Bv = Dke, Ike = /\s/;
function Lke(e) {
  for (var t = e.length; t-- && Ike.test(e.charAt(t)); )
    ;
  return t;
}
var kke = Lke, Mke = kke, Pke = /^\s+/;
function Fke(e) {
  return e && e.slice(0, Mke(e) + 1).replace(Pke, "");
}
var Z$ = Fke, Bke = Mv;
function $ke(e, t) {
  for (var n = e.length; n-- && Bke(t, e[n], 0) > -1; )
    ;
  return n;
}
var Uke = $ke, qke = Mv;
function Gke(e, t) {
  for (var n = -1, r = e.length; ++n < r && qke(t, e[n], 0) > -1; )
    ;
  return n;
}
var Yke = Gke, Hke = kv, zke = Z$, Vke = g$, Wke = Uke, Kke = Yke, PM = C$, jke = zl;
function Qke(e, t, n) {
  if (e = jke(e), e && (n || t === void 0))
    return zke(e);
  if (!e || !(t = Hke(t)))
    return e;
  var r = PM(e), i = PM(t), a = Kke(r, i), o = Wke(r, i) + 1;
  return Vke(r, a, o).join("");
}
var Xke = Qke, Kt = class {
  constructor(e, t) {
    var n;
    this.rule = e, this.attributes = e.attributes || {}, this.conditions = e.conditions || [], this.dependents = e.dependents || [], this.element$ = t.element$, this.form$ = ((n = t.element$) === null || n === void 0 ? void 0 : n.form$) || {}, this.numeric = t.numeric || !1, this.elementMessages = t.element$.messages, this.invalid = !1, this.pending = !1, this.debouncer = null, this.lastValue = null, this.watchers = {}, this.dependents.forEach((r) => {
      et(N(() => $r(this.form$.data, r)), () => {
        this.element$.validated && (this.name === "nullable" ? this.element$.validate() : this.revalidate());
      });
    }), et(N(() => t.element$.messages), (r, i) => {
      zd(r, i) || (this.elementMessages = t.element$.messages);
    }, {
      deep: !0
    }), this.init();
  }
  get name() {
    return this.rule.name;
  }
  get failing() {
    return this.invalid;
  }
  get defaultMessage() {
    return this.form$.translations.vueform.defaultMessage;
  }
  get message() {
    var e, t = "";
    return this.elementMessages[this.name] ? t = this.elementMessages[this.name] : this.form$.options.messages[this.name] ? t = this.form$.options.messages[this.name] : this.name !== "_class" && ((e = this.form$.translations.validation) === null || e === void 0 ? void 0 : e[this.name]) !== void 0 ? (t = this.form$.translations.validation[this.name], jn(t) && (t = t[this.messageType])) : t = this.defaultMessage, Te(Ku(t.match(/:\w+/g), (n) => n.replace(":", "")), (n) => {
      t = t.replace(":".concat(n), this.messageParams[n]);
    }), Te(Ku(t.match(/{[^}]+/g), (n) => n.replace("{", "")), (n) => {
      t = t.replace("{".concat(n, "}"), this.messageParams[n]);
    }), t;
  }
  get messageType() {
    return this.isNumeric ? "numeric" : this.isFile ? "file" : this.isArray ? "array" : "string";
  }
  get messageParams() {
    return {
      attribute: this.attributeName
    };
  }
  get attributeName() {
    return this.element$.genericName;
  }
  get type() {
    return this.isNumeric ? "numeric" : this.isFile ? "file" : this.isArray ? "array" : "string";
  }
  get isNumeric() {
    return hn(this.element$.Validators, {
      name: "numeric"
    }) || hn(this.element$.Validators, {
      name: "integer"
    });
  }
  get isNullable() {
    var e = !1;
    return Te(this.element$.Validators, (t) => {
      if (t.name === "nullable") {
        if (!t.conditions.length) {
          e = !0;
          return;
        }
        e = t.conditions(this.form$, this, this.element$);
      }
    }), e;
  }
  get isFile() {
    return this.element$.isFileType;
  }
  get isArray() {
    return this.element$.isArrayType;
  }
  get isAsync() {
    return !1;
  }
  get debounce() {
    return this.attributes.debounce ? this.attributes.debounce : this.element$.debounce ? this.element$.debounce : !1;
  }
  get debouncing() {
    return this.debouncer !== null;
  }
  init() {
  }
  validate(e) {
    var t = this;
    return ht(function* () {
      if (e === void 0) {
        var n;
        e = (n = t.element$) === null || n === void 0 ? void 0 : n.value;
      }
      if (t.form$.validation) {
        if (t.isNullable && !t.filled(e)) {
          t.invalid = !1;
          return;
        }
        if (t.conditions.length && !t.conditions(t.form$, t, t.element$)) {
          t.invalid = !1;
          return;
        }
        t.debounce && t.filled(e) ? yield t._validateWithDebounce(e) : (t.debounce && t.debouncer && clearTimeout(t.debouncer), yield t._validate(e));
      }
    })();
  }
  reset() {
    this.invalid = !1;
  }
  watch(e) {
    Array.isArray(e) || (e = [e]), e.forEach((t) => {
      this.addWatcher(t);
    });
  }
  addWatcher(e) {
    this.watchers[e] || (this.watchers[e] = et(N(() => $r(this.form$.data, e)), () => {
      this.revalidate();
    }));
  }
  revalidate() {
    this.element$.Validators.forEach((e) => {
      e.rule.name === this.rule.name && e.validate();
    });
  }
  watchOther() {
    this.form$.$nextTick(() => {
      this.other$ && this.form$.$watch(() => {
        var e;
        return (e = this.other$) === null || e === void 0 ? void 0 : e.value;
      }, () => {
        this.element$.validated && this.element$.validate();
      });
    });
  }
  size(e) {
    if (this.isNumeric) {
      if (!isNaN(e)) {
        var t = parseFloat(e);
        return Number.isInteger(t) ? parseInt(e) : t;
      }
      return null;
    } else {
      if (this.isFile)
        return e ? e.size / 1e3 : 0;
      if (this.isArray)
        return e.length;
      if (e === null)
        return 0;
      if (e === void 0)
        return 0;
      if (e === "")
        return 0;
    }
    return String(e).length;
  }
  filled(e) {
    return e === void 0 || e === null && e !== this.element$.trueValue || e === this.element$.falseValue || this.isNumeric && e === 0 || Bv(e) && Xke(e) === "" || At(e) && e.length < 1 ? !1 : !(e instanceof File && e.name === "");
  }
  _validate(e) {
    var t = this;
    return ht(function* () {
      t.isAsync ? yield t._validateAsync(e) : t._validateSync(e);
    })();
  }
  _validateAsync(e) {
    var t = this;
    return ht(function* () {
      t.lastValue = e, t.pending = !0;
      var n = yield t.check(e);
      Vl(t.lastValue, e) && (t.invalid = !n, t.pending = !1);
    })();
  }
  _validateSync(e) {
    this.invalid = !this.check(e);
  }
  _validateWithDebounce(e) {
    var t = this;
    return ht(function* () {
      return new Promise((n, r) => {
        t.debouncer && (n(), clearTimeout(t.debouncer)), t.debouncer = setTimeout(/* @__PURE__ */ ht(function* () {
          yield t._validate(e), t.debouncer = null, n();
        }), t.debounce);
      });
    })();
  }
};
function Zke(e) {
  var t = e == null ? 0 : e.length;
  return t ? e[t - 1] : void 0;
}
var Jke = Zke, e2e = xm, t2e = h$;
function n2e(e, t) {
  return t.length < 2 ? e : e2e(e, t2e(t, 0, -1));
}
var r2e = n2e, i2e = Gd, a2e = Jke, o2e = r2e, s2e = Yd;
function l2e(e, t) {
  return t = i2e(t, e), e = o2e(e, t), e == null || delete e[s2e(a2e(t))];
}
var u2e = l2e, c2e = jn;
function d2e(e) {
  return c2e(e) ? void 0 : e;
}
var f2e = d2e, p2e = rc;
function m2e(e) {
  var t = e == null ? 0 : e.length;
  return t ? p2e(e, 1) : [];
}
var h2e = m2e, g2e = h2e, _2e = J4, v2e = e$;
function b2e(e) {
  return v2e(_2e(e, void 0, g2e), e + "");
}
var J$ = b2e, E2e = qd, S2e = jA, y2e = u2e, T2e = Gd, C2e = $d, A2e = f2e, O2e = J$, R2e = R$, w2e = 1, x2e = 2, N2e = 4, D2e = O2e(function(e, t) {
  var n = {};
  if (e == null)
    return n;
  var r = !1;
  t = E2e(t, function(a) {
    return a = T2e(a, e), r || (r = a.length > 1), a;
  }), C2e(e, R2e(e), n), r && (n = S2e(n, w2e | x2e | N2e, A2e));
  for (var i = t.length; i--; )
    y2e(n, t[i]);
  return n;
}), FM = D2e, I2e = xm, L2e = D$, k2e = Gd;
function M2e(e, t, n) {
  for (var r = -1, i = t.length, a = {}; ++r < i; ) {
    var o = t[r], s = I2e(e, o);
    n(s, o) && L2e(a, k2e(o, e), s);
  }
  return a;
}
var P2e = M2e, F2e = P2e, B2e = m$;
function $2e(e, t) {
  return F2e(e, t, function(n, r) {
    return B2e(e, r);
  });
}
var U2e = $2e, q2e = U2e, G2e = J$, Y2e = G2e(function(e, t) {
  return e == null ? {} : q2e(e, t);
}), H2e = Y2e, z2e = qA, V2e = L$, W2e = k$, K2e = qd, j2e = Sm, Q2e = GA, X2e = 200;
function Z2e(e, t, n, r) {
  var i = -1, a = V2e, o = !0, s = e.length, l = [], u = t.length;
  if (!s)
    return l;
  n && (t = K2e(t, j2e(n))), r ? (a = W2e, o = !1) : t.length >= X2e && (a = Q2e, o = !1, t = new z2e(t));
  e:
    for (; ++i < s; ) {
      var c = e[i], d = n == null ? c : n(c);
      if (c = r || c !== 0 ? c : 0, o && d === d) {
        for (var f = u; f--; )
          if (t[f] === d)
            continue e;
        l.push(c);
      } else a(t, d, r) || l.push(c);
    }
  return l;
}
var eU = Z2e, J2e = eU, eMe = Om, tMe = Iv, nMe = eMe(function(e, t) {
  return tMe(e) ? J2e(e, t) : [];
}), rMe = nMe, iMe = qp;
qp.flatten = qp;
qp.unflatten = rU;
function tU(e) {
  return e && e.constructor && typeof e.constructor.isBuffer == "function" && e.constructor.isBuffer(e);
}
function nU(e) {
  return e;
}
function qp(e, t) {
  t = t || {};
  const n = t.delimiter || ".", r = t.maxDepth, i = t.transformKey || nU, a = {};
  function o(s, l, u) {
    u = u || 1, Object.keys(s).forEach(function(c) {
      const d = s[c], f = t.safe && Array.isArray(d), h = Object.prototype.toString.call(d), m = tU(d), v = h === "[object Object]" || h === "[object Array]", b = l ? l + n + i(c) : i(c);
      if (!f && !m && v && Object.keys(d).length && (!t.maxDepth || u < r))
        return o(d, b, u + 1);
      a[b] = d;
    });
  }
  return o(e), a;
}
function rU(e, t) {
  t = t || {};
  const n = t.delimiter || ".", r = t.overwrite || !1, i = t.transformKey || nU, a = {};
  if (tU(e) || Object.prototype.toString.call(e) !== "[object Object]")
    return e;
  function s(c) {
    const d = Number(c);
    return isNaN(d) || c.indexOf(".") !== -1 || t.object ? c : d;
  }
  function l(c, d, f) {
    return Object.keys(f).reduce(function(h, m) {
      return h[c + n + m] = f[m], h;
    }, d);
  }
  function u(c) {
    const d = Object.prototype.toString.call(c), f = d === "[object Array]", h = d === "[object Object]";
    if (c) {
      if (f)
        return !c.length;
      if (h)
        return !Object.keys(c).length;
    } else return !0;
  }
  return e = Object.keys(e).reduce(function(c, d) {
    const f = Object.prototype.toString.call(e[d]);
    return !(f === "[object Object]" || f === "[object Array]") || u(e[d]) ? (c[d] = e[d], c) : l(
      d,
      c,
      qp(e[d], t)
    );
  }, {}), Object.keys(e).forEach(function(c) {
    const d = c.split(n).map(i);
    let f = s(d.shift()), h = s(d[0]), m = a;
    for (; h !== void 0; ) {
      if (f === "__proto__")
        return;
      const v = Object.prototype.toString.call(m[f]), b = v === "[object Object]" || v === "[object Array]";
      if (!r && !b && typeof m[f] < "u")
        return;
      (r && !b || !r && m[f] == null) && (m[f] = typeof h == "number" && !t.object ? [] : {}), m = m[f], d.length > 0 && (f = s(d.shift()), h = s(d[0]));
    }
    m[f] = rU(e[c], t);
  }), a;
}
var aMe = eU, oMe = rc, sMe = Om, BM = Iv, lMe = sMe(function(e, t) {
  return BM(e) ? aMe(e, oMe(t, 1, BM, !0)) : [];
}), XA = lMe;
function $M(e, t) {
  if (!t.apply && XA(Object.keys(t), ["config", "install"]).length > 0)
    return !0;
  var n = t.apply;
  Array.isArray(n) || (n = [n]);
  var r = !1;
  return Te(n, (i) => {
    if (typeof i == "string" && i === e)
      return r = !0, !1;
    if (typeof i == "object" && i instanceof RegExp && e.match(i))
      return r = !0, !1;
  }), r;
}
var uMe = "@vueform/vueform", cMe = "1.7.3", dMe = "Open-Source Form Framework for Vue", fMe = "https://vueform.com", pMe = "MIT", mMe = [
  {
    name: "Adam Berecz",
    email: "adam@vueform.com"
  }
], hMe = [
  "./themes/tailwind/templates/**/*.vue",
  "./themes/vueform/templates/**/*.vue"
], gMe = "./dist/index.mjs", _Me = "./dist/index.mjs", vMe = "./types/index.d.ts", bMe = {
  ".": {
    types: "./types/index.d.ts",
    default: "./dist/index.mjs"
  },
  "./core": {
    types: "./types/index.d.ts",
    default: "./dist/core.mjs"
  },
  "./core.js": {
    types: "./types/index.d.ts",
    default: "./dist/core.mjs"
  },
  "./element": "./element.mjs",
  "./element.js": "./element.mjs",
  "./plugin": "./plugin.mjs",
  "./plugin.js": "./plugin.mjs",
  "./locales/*.js": "./locales/*/index.mjs",
  "./locales/*": "./locales/*/index.mjs",
  "./src/*": "./src/*",
  "./types/*": "./types/*",
  "./dist/*.js": "./dist/*.mjs",
  "./dist/*": "./dist/*.mjs",
  "./dist/*.css": "./dist/*.css",
  "./tailwind": "./tailwind.js",
  "./tailwind.js": "./tailwind.js",
  "./vite": "./vite.js",
  "./vite.js": "./vite.js",
  "./vite.d.ts": "./vite.d.ts",
  "./tailwind-prefixer": "./tailwind-prefixer.js",
  "./tailwind-prefixer.js": "./tailwind-prefixer.js",
  "./postcss.config": "./postcss.config.js",
  "./postcss.config.js": "./postcss.config.js",
  "./tailwind.config": "./tailwind.config.js",
  "./tailwind.config.js": "./tailwind.config.js",
  "./package.json": "./package.json",
  "./themes/blank/templates/*": "./themes/blank/templates/*",
  "./themes/blank/*": "./themes/blank/*.mjs",
  "./themes/blank/*.js": "./themes/blank/*.mjs",
  "./themes/bootstrap/css/*": "./themes/bootstrap/css/*",
  "./themes/bootstrap/scss/*": "./themes/bootstrap/scss/*",
  "./themes/bootstrap/*": "./themes/bootstrap/*.mjs",
  "./themes/bootstrap/*.js": "./themes/bootstrap/*.mjs",
  "./themes/bootstrap.js": "./themes/bootstrap/index.mjs",
  "./themes/material/css/*": "./themes/material/css/*",
  "./themes/material/scss/*": "./themes/material/scss/*",
  "./themes/material/*": "./themes/material/*.mjs",
  "./themes/material/*.js": "./themes/material/*.mjs",
  "./themes/material.js": "./themes/material/index.mjs",
  "./themes/tailwind/templates/*": "./themes/tailwind/templates/*",
  "./themes/tailwind/*": "./themes/tailwind/*.mjs",
  "./themes/tailwind/*.js": "./themes/tailwind/*.mjs",
  "./themes/tailwind.js": "./themes/tailwind/index.mjs",
  "./themes/tailwind-material/css/*": "./themes/tailwind-material/css/*",
  "./themes/tailwind-material/scss/*": "./themes/tailwind-material/scss/*",
  "./themes/tailwind-material/*": "./themes/tailwind-material/*.mjs",
  "./themes/tailwind-material/*.js": "./themes/tailwind-material/*.mjs",
  "./themes/tailwind-material.js": "./themes/tailwind-material/index.mjs",
  "./themes/vueform/css/*": "./themes/vueform/css/*",
  "./themes/vueform/scss/*": "./themes/vueform/scss/*",
  "./themes/vueform/templates/*": "./themes/vueform/templates/*",
  "./themes/vueform/*": "./themes/vueform/*.mjs",
  "./themes/vueform/*.js": "./themes/vueform/*.mjs",
  "./themes/vueform.js": "./themes/vueform/index.mjs",
  "./themes/*": {
    types: "./dist/*.d.mts",
    default: "./themes/*/index.mjs"
  }
}, EMe = {
  build: "npm run build3 && npm run build2",
  build2: "node ./scripts/pre-build-vue2 && rollup --config build/rollup.vue2.config.js && node ./scripts/post-build-vue2",
  build3: "rollup --config build/rollup.config.js",
  test: 'npm run generate:elements-base && NODE_OPTIONS="--max_old_space_size=5120 --no-experimental-fetch" VUE=3 jest --config=./tests/jest.config.js',
  "generate:types": "npx babel-node  scripts/generate-types.js --presets @babel/preset-env",
  "generate:common-features": "npx babel-node scripts/generate-common-features.js --presets @babel/preset-env",
  "generate:element-features": "npx babel-node scripts/generate-element-features.js --presets @babel/preset-env",
  "generate:elements-base": "npx babel-node scripts/generate-elements-base.js --presets @babel/preset-env",
  "generate:elements": "npx babel-node scripts/generate-elements.js --presets @babel/preset-env",
  "generate:components": "npx babel-node scripts/generate-components.js --presets @babel/preset-env",
  generate: "npm run generate:common-features; npm run generate:element-features; npm run generate:elements-base; npm run generate:elements; npm run generate:components; npm run generate:types",
  "fix-locales": "npx babel-node --presets @babel/preset-env ./scripts/fix-locales.js"
}, SMe = {
  "@babel/core": "^7.2.2",
  "@babel/node": "^7.12.10",
  "@babel/preset-env": "^7.3.1",
  "@rollup/plugin-alias": "^5.1.0",
  "@rollup/plugin-babel": "^5.3.0",
  "@rollup/plugin-commonjs": "^22.0.1",
  "@rollup/plugin-json": "^4.1.0",
  "@rollup/plugin-node-resolve": "^13.0.6",
  "@testing-library/jest-dom": "^5.11.5",
  "@vue/compiler-sfc": "^3.0.0",
  "@vue/test-utils": "2.0.0-rc.16",
  autoprefixer: "^9",
  autosize: "^6.0.1",
  "babel-core": "^7.0.0-bridge.0",
  "babel-loader": "^8.0.5",
  "core-js": "^3.10.1",
  "css-loader": "^2.1.0",
  flat: "^5.0.2",
  flatpickr: "^4.6.13",
  "flush-promises": "^1.0.2",
  "html-loader": "^1.3.2",
  jest: "^27.3.1",
  "jest-canvas-mock": "^2.3.1",
  "jest-environment-jsdom-sixteen": "^1.0.3",
  "jest-transform-stub": "^2.0.0",
  "json-loader": "^0.5.7",
  locutus: "^2.0.16",
  "module-alias": "^2.2.3",
  moxios: "^0.4.0",
  "mutationobserver-shim": "^0.3.7",
  ncp: "^2.0.0",
  "rollup-plugin-license": "^3.2.0",
  "rollup-plugin-postcss": "^4.0.1",
  "rollup-plugin-terser": "^7.0.2",
  "rollup-plugin-vue": "^6.0.0",
  "rollup-plugin-vue2": "npm:rollup-plugin-vue@^5.1.9",
  "sass-loader": "^7.1.0",
  sortablejs: "^1.15.0",
  tailwindcss: "npm:@tailwindcss/postcss7-compat@^2.0.2",
  vue: "3.3.13",
  "vue-jest": "npm:@vue/vue3-jest@^27.0.0-alpha.1",
  "vue-loader": "^15.10.0",
  "vue-template-compiler": "^2.7.8",
  vue2: "npm:vue@^2.7.0"
}, yMe = {
  "@popperjs/core": "^2.11.8",
  "@vueform/multiselect": "^2.6.3",
  "@vueform/slider": "^2.1.7",
  lodash: "^4.17.21",
  "@vueform/toggle": "^2.1.3",
  axios: "^1.5.0",
  color: "^4.2.3",
  "mini-svg-data-uri": "^1.4.4",
  moment: "^2.29.4",
  nouislider: "^15.7.1",
  sass: "^1.66.1",
  trix: "^1.0.5",
  wnumb: "^1.2.0"
}, TMe = {
  private: !1,
  name: uMe,
  version: cMe,
  description: dMe,
  homepage: fMe,
  license: pMe,
  authors: mMe,
  sideEffects: hMe,
  main: gMe,
  module: _Me,
  types: vMe,
  exports: bMe,
  scripts: EMe,
  devDependencies: SMe,
  dependencies: yMe
}, CMe = rc, AMe = Ku;
function OMe(e, t) {
  return CMe(AMe(e, t), 1);
}
var RMe = OMe, Ur = function(t) {
  return t === void 0 || typeof t != "string" ? t : t.match(/^-*\d+$/) ? parseInt(t, 10) : t.match(/^\d+\.\d+$/) ? parseFloat(t) : t;
}, UM = (e) => {
  var t = () => e.split(":")[0], n = () => {
    var r = e.split(":");
    if (r.length <= 1)
      return null;
    var i = {}, a = r[0];
    r.shift();
    var o = r.join(":");
    return ["regex", "not_regex"].indexOf(a) !== -1 ? (i[0] = o, i) : (Te(o.split(","), (s, l) => {
      var u = s.split("=");
      u.length <= 1 ? i[l] = Ur(s) : i[u[0]] = Ur(u[1]);
    }), i);
  };
  return {
    name: t(),
    attributes: n()
  };
};
function Ho(e, t) {
  return t.match(/\.([0-9]+)(?![a-zA-Z]+)/g) && t.match(/\.([0-9]+)(?![a-zA-Z]+)/g).forEach((n) => {
    e = e.replace(".*", n);
  }), e;
}
var wMe = Z$, qM = Ma, xMe = wm, GM = NaN, NMe = /^[-+]0x[0-9a-f]+$/i, DMe = /^0b[01]+$/i, IMe = /^0o[0-7]+$/i, LMe = parseInt;
function kMe(e) {
  if (typeof e == "number")
    return e;
  if (xMe(e))
    return GM;
  if (qM(e)) {
    var t = typeof e.valueOf == "function" ? e.valueOf() : e;
    e = qM(t) ? t + "" : t;
  }
  if (typeof e != "string")
    return e === 0 ? e : +e;
  e = wMe(e);
  var n = DMe.test(e);
  return n || IMe.test(e) ? LMe(e.slice(2), n ? 2 : 8) : NMe.test(e) ? GM : +e;
}
var MMe = kMe, PMe = MMe, YM = 1 / 0, FMe = 17976931348623157e292;
function BMe(e) {
  if (!e)
    return e === 0 ? e : 0;
  if (e = PMe(e), e === YM || e === -YM) {
    var t = e < 0 ? -1 : 1;
    return t * FMe;
  }
  return e === e ? e : 0;
}
var $Me = BMe, UMe = $Me;
function qMe(e) {
  var t = UMe(e), n = t % 1;
  return t === t ? n ? t - n : t : 0;
}
var Nm = qMe, GMe = Mv, YMe = js, HMe = Bv, zMe = Nm, VMe = ql, WMe = Math.max;
function KMe(e, t, n, r) {
  e = YMe(e) ? e : VMe(e), n = n && !r ? zMe(n) : 0;
  var i = e.length;
  return n < 0 && (n = WMe(i + n, 0)), HMe(e) ? n <= i && e.indexOf(t, n) > -1 : !!i && GMe(e, t, n) > -1;
}
var ST = KMe;
function jMe(e, t, n) {
  return e === e && (n !== void 0 && (e = e <= n ? e : n), t !== void 0 && (e = e >= t ? e : t)), e;
}
var iU = jMe, QMe = iU, XMe = kv, ZMe = Nm, JMe = zl;
function ePe(e, t, n) {
  return e = JMe(e), n = n == null ? 0 : QMe(ZMe(n), 0, e.length), t = XMe(t), e.slice(n, n + t.length) == t;
}
var tPe = ePe, nPe = iU, rPe = kv, iPe = Nm, aPe = zl;
function oPe(e, t, n) {
  e = aPe(e), t = rPe(t);
  var r = e.length;
  n = n === void 0 ? r : nPe(iPe(n), 0, r);
  var i = n;
  return n -= t.length, n >= 0 && e.slice(n, i) == t;
}
var sPe = oPe;
function aU(e, t, n, r) {
  if (!t)
    return !1;
  switch (e = Array.isArray(e) ? e.map((o) => Ur(o)) : Ur(e), n = Array.isArray(n) ? n.map((o) => Ur(o)) : Ur(n), t.toLowerCase()) {
    case ">":
      return At(e) ? e.every((o) => o > n) : e > n;
    case ">=":
      return At(e) ? e.every((o) => o >= n) : e >= n;
    case "<":
      return At(e) ? e.every((o) => o < n) : e < n;
    case "<=":
      return At(e) ? e.every((o) => o <= n) : e <= n;
    case "between":
      return e > n[0] && e < n[1];
    case "empty":
      if (At(e))
        return !e.length;
      if (e && e instanceof File)
        return !1;
      if (e && typeof e == "object") {
        var i = Object.values(e);
        return !i.length || i.every((o) => ["", null, void 0].indexOf(o) !== -1);
      } else
        return ["", null, void 0].indexOf(e) !== -1;
    case "not_empty":
      if (At(e))
        return !!e.length;
      if (e && e instanceof File)
        return !0;
      if (e && typeof e == "object") {
        var a = Object.values(e);
        return a.length && a.some((o) => ["", null, void 0].indexOf(o) === -1);
      } else
        return ["", null, void 0].indexOf(e) === -1;
    case "==":
    case "in":
      return At(n) ? At(e) ? n.length ? e.filter((o) => ST(n, o)).length > 0 : !e.length : n.indexOf(e) !== -1 : At(e) ? e.indexOf(n) !== -1 : e == n;
    case "!=":
    case "not_in":
      return At(n) ? At(e) ? n.length ? e.filter((o) => ST(n, o)).length == 0 : !!e.length : n.indexOf(e) === -1 : At(e) ? e.indexOf(n) === -1 : e != n;
    case "today":
      return At(e) || (e = [e]), e.length && e.every((o) => Ge(o, r.valueDateFormat).isSame(Ge(), "day"));
    case "before":
      return At(e) || (e = [e]), e.length && e.every((o) => {
        var s = Ge(o, r.valueDateFormat);
        return s.isValid() && s.isBefore(Ge(n === "today" ? void 0 : n), "day");
      });
    case "after":
      return At(e) || (e = [e]), e.length && e.every((o) => {
        var s = Ge(o, r.valueDateFormat);
        return s.isValid() && s.isAfter(Ge(n === "today" ? void 0 : n), "day");
      });
    case "^":
      return tPe(e, n);
    case "$":
      return sPe(e, n);
    case "*":
      return ST(e, n);
  }
}
var lPe = class {
  constructor(e, t) {
    this.form$ = t, this.element$ = t.el$(e);
  }
  get rules() {
    var e = Object.assign({}, this.form$.$vueform.services.validation.rules, this.form$.$vueform.rules);
    return !e.in && e.in_ && (e.in = e.in_), e;
  }
  makeAll(e) {
    var t = this.parseRules(e);
    return t.length == 0 ? [] : Ku(t, (n) => this.make(n));
  }
  make(e) {
    var t = typeof e == "function" ? e : this.rules[e.name];
    if (!t)
      throw new Error("Unknown rule: '".concat(e.name, "'"));
    return new t(e, {
      element$: this.element$
    });
  }
  parseRules(e) {
    return At(e) || (e = e.split("|")), RMe(e, (t) => typeof t == "function" ? t : this.isConditional(t) ? this.parseConditional(t) : this.parse(t));
  }
  parse(e) {
    return UM(e);
  }
  isConditional(e) {
    return jn(e);
  }
  parseConditional(e) {
    var t = ql(e)[0];
    Array.isArray(t[0]) || (t = [t]);
    var n = mt(mt({}, UM(si(e)[0])), {}, {
      conditions: (r, i, a) => t.every((o) => At(o) ? At(o[0]) ? o.some((s) => At(s) ? this.createConditionFromArray(s)(r, i, a) : o(r, i, a)) : this.createConditionFromArray(o)(r, i, a) : o(r, i, a)),
      dependents: []
    });
    return t.forEach((r) => {
      At(r) && (At(r[0]) ? r.forEach((i) => {
        At(i) && n.dependents.push(Ho(i[0], this.element$.path));
      }) : n.dependents.push(Ho(r[0], this.element$.path)));
    }), n;
  }
  createConditionFromArray(e) {
    var t = Ho(e[0], this.element$.path), n = e.length == 3 || ["empty", "not_empty", "today"].indexOf(e[1]) !== -1 ? e[1] : "==", r = e.length == 3 ? e[2] : ["empty", "not_empty", "today"].indexOf(e[1]) === -1 ? e[1] : !0;
    return (i, a, o) => {
      var s = $r(i.requestData, t), l = r;
      return aU(s, n, l, this.element$);
    };
  }
};
class oU extends Kt {
  check(t) {
    return ["yes", "on", "1", 1, !0, "true"].indexOf(t) !== -1;
  }
}
class sU extends Kt {
  get isAsync() {
    return !0;
  }
  check(t) {
    var n = this;
    return ht(function* () {
      var r = n.form$.$vueform.config.endpoints.activeUrl, i = typeof r != "function" ? r.method : null, a;
      return typeof r == "function" ? a = yield r(t, n.element$, n.form$) : a = yield n.form$.$vueform.services.axios.request({
        url: r.url,
        method: i,
        [i.toLowerCase() === "get" ? "params" : "data"]: {
          url: t
        }
      }), a.data;
    })();
  }
}
class Dm extends Kt {
  get messageParams() {
    return {
      attribute: this.attributeName,
      date: this.date.format(this.format)
    };
  }
  get param() {
    return this.attributes[0];
  }
  get format() {
    return ["date", "dates"].indexOf(this.element$.type) !== -1 && this.element$.valueFormat ? this.element$.valueFormat : "YYYY-MM-DD";
  }
  get otherFormat() {
    return this.dateType != "element" ? this.format : ["date", "dates"].indexOf(this.other$.type) !== -1 && this.other$.valueFormat ? this.other$.valueFormat : this.format;
  }
  get otherPath() {
    return this.dateType != "element" ? null : this.param;
  }
  get other$() {
    return this.dateType != "element" ? {} : this.form$.el$(this.param);
  }
  get date() {
    var t = "";
    switch (this.dateType) {
      case "relative":
        this.param === "today" && (t = Ge().startOf("day")), this.param === "tomorrow" && (t = Ge().startOf("day").add(1, "days")), this.param === "yesterday" && (t = Ge().startOf("day").subtract(1, "days"));
        break;
      case "element":
        t = Ge(this.other$.value, this.otherFormat);
        break;
      case "absolute":
        t = Ge(this.param, this.format);
        break;
    }
    return t;
  }
  get dateType() {
    return ["today", "tomorrow", "yesterday"].indexOf(this.param) !== -1 ? "relative" : this.form$.el$(this.param) ? "element" : "absolute";
  }
  init() {
    this.form$.$nextTick(() => {
      this.dateType == "element" && this.watchOther();
    });
  }
  check(t) {
    if (At(t)) {
      var n = !0;
      return Te(t, (r) => {
        this.checkDate(r) || (n = !1);
      }), n;
    }
    return this.checkDate(t);
  }
  checkDate(t) {
    return Ge(t, this.format).isAfter(Ge(this.date, this.otherFormat));
  }
}
class lU extends Dm {
  checkDate(t) {
    return Ge(t, this.format).isSameOrAfter(Ge(this.date, this.otherFormat));
  }
}
class uU extends Kt {
  check(t) {
    return /^[\u0041-\u005A\u0061-\u007A\u00AA\u00B5\u00BA\u00C0-\u00D6\u00D8-\u00F6\u00F8-\u02C1\u02C6-\u02D1\u02E0-\u02E4\u02EC\u02EE\u0370-\u0374\u0376\u0377\u037A-\u037D\u0386\u0388-\u038A\u038C\u038E-\u03A1\u03A3-\u03F5\u03F7-\u0481\u048A-\u0527\u0531-\u0556\u0559\u0561-\u0587\u05D0-\u05EA\u05F0-\u05F2\u0620-\u064A\u066E\u066F\u0671-\u06D3\u06D5\u06E5\u06E6\u06EE\u06EF\u06FA-\u06FC\u06FF\u0710\u0712-\u072F\u074D-\u07A5\u07B1\u07CA-\u07EA\u07F4\u07F5\u07FA\u0800-\u0815\u081A\u0824\u0828\u0840-\u0858\u08A0\u08A2-\u08AC\u0904-\u0939\u093D\u0950\u0958-\u0961\u0971-\u0977\u0979-\u097F\u0985-\u098C\u098F\u0990\u0993-\u09A8\u09AA-\u09B0\u09B2\u09B6-\u09B9\u09BD\u09CE\u09DC\u09DD\u09DF-\u09E1\u09F0\u09F1\u0A05-\u0A0A\u0A0F\u0A10\u0A13-\u0A28\u0A2A-\u0A30\u0A32\u0A33\u0A35\u0A36\u0A38\u0A39\u0A59-\u0A5C\u0A5E\u0A72-\u0A74\u0A85-\u0A8D\u0A8F-\u0A91\u0A93-\u0AA8\u0AAA-\u0AB0\u0AB2\u0AB3\u0AB5-\u0AB9\u0ABD\u0AD0\u0AE0\u0AE1\u0B05-\u0B0C\u0B0F\u0B10\u0B13-\u0B28\u0B2A-\u0B30\u0B32\u0B33\u0B35-\u0B39\u0B3D\u0B5C\u0B5D\u0B5F-\u0B61\u0B71\u0B83\u0B85-\u0B8A\u0B8E-\u0B90\u0B92-\u0B95\u0B99\u0B9A\u0B9C\u0B9E\u0B9F\u0BA3\u0BA4\u0BA8-\u0BAA\u0BAE-\u0BB9\u0BD0\u0C05-\u0C0C\u0C0E-\u0C10\u0C12-\u0C28\u0C2A-\u0C33\u0C35-\u0C39\u0C3D\u0C58\u0C59\u0C60\u0C61\u0C85-\u0C8C\u0C8E-\u0C90\u0C92-\u0CA8\u0CAA-\u0CB3\u0CB5-\u0CB9\u0CBD\u0CDE\u0CE0\u0CE1\u0CF1\u0CF2\u0D05-\u0D0C\u0D0E-\u0D10\u0D12-\u0D3A\u0D3D\u0D4E\u0D60\u0D61\u0D7A-\u0D7F\u0D85-\u0D96\u0D9A-\u0DB1\u0DB3-\u0DBB\u0DBD\u0DC0-\u0DC6\u0E01-\u0E30\u0E32\u0E33\u0E40-\u0E46\u0E81\u0E82\u0E84\u0E87\u0E88\u0E8A\u0E8D\u0E94-\u0E97\u0E99-\u0E9F\u0EA1-\u0EA3\u0EA5\u0EA7\u0EAA\u0EAB\u0EAD-\u0EB0\u0EB2\u0EB3\u0EBD\u0EC0-\u0EC4\u0EC6\u0EDC-\u0EDF\u0F00\u0F40-\u0F47\u0F49-\u0F6C\u0F88-\u0F8C\u1000-\u102A\u103F\u1050-\u1055\u105A-\u105D\u1061\u1065\u1066\u106E-\u1070\u1075-\u1081\u108E\u10A0-\u10C5\u10C7\u10CD\u10D0-\u10FA\u10FC-\u1248\u124A-\u124D\u1250-\u1256\u1258\u125A-\u125D\u1260-\u1288\u128A-\u128D\u1290-\u12B0\u12B2-\u12B5\u12B8-\u12BE\u12C0\u12C2-\u12C5\u12C8-\u12D6\u12D8-\u1310\u1312-\u1315\u1318-\u135A\u1380-\u138F\u13A0-\u13F4\u1401-\u166C\u166F-\u167F\u1681-\u169A\u16A0-\u16EA\u1700-\u170C\u170E-\u1711\u1720-\u1731\u1740-\u1751\u1760-\u176C\u176E-\u1770\u1780-\u17B3\u17D7\u17DC\u1820-\u1877\u1880-\u18A8\u18AA\u18B0-\u18F5\u1900-\u191C\u1950-\u196D\u1970-\u1974\u1980-\u19AB\u19C1-\u19C7\u1A00-\u1A16\u1A20-\u1A54\u1AA7\u1B05-\u1B33\u1B45-\u1B4B\u1B83-\u1BA0\u1BAE\u1BAF\u1BBA-\u1BE5\u1C00-\u1C23\u1C4D-\u1C4F\u1C5A-\u1C7D\u1CE9-\u1CEC\u1CEE-\u1CF1\u1CF5\u1CF6\u1D00-\u1DBF\u1E00-\u1F15\u1F18-\u1F1D\u1F20-\u1F45\u1F48-\u1F4D\u1F50-\u1F57\u1F59\u1F5B\u1F5D\u1F5F-\u1F7D\u1F80-\u1FB4\u1FB6-\u1FBC\u1FBE\u1FC2-\u1FC4\u1FC6-\u1FCC\u1FD0-\u1FD3\u1FD6-\u1FDB\u1FE0-\u1FEC\u1FF2-\u1FF4\u1FF6-\u1FFC\u2071\u207F\u2090-\u209C\u2102\u2107\u210A-\u2113\u2115\u2119-\u211D\u2124\u2126\u2128\u212A-\u212D\u212F-\u2139\u213C-\u213F\u2145-\u2149\u214E\u2183\u2184\u2C00-\u2C2E\u2C30-\u2C5E\u2C60-\u2CE4\u2CEB-\u2CEE\u2CF2\u2CF3\u2D00-\u2D25\u2D27\u2D2D\u2D30-\u2D67\u2D6F\u2D80-\u2D96\u2DA0-\u2DA6\u2DA8-\u2DAE\u2DB0-\u2DB6\u2DB8-\u2DBE\u2DC0-\u2DC6\u2DC8-\u2DCE\u2DD0-\u2DD6\u2DD8-\u2DDE\u2E2F\u3005\u3006\u3031-\u3035\u303B\u303C\u3041-\u3096\u309D-\u309F\u30A1-\u30FA\u30FC-\u30FF\u3105-\u312D\u3131-\u318E\u31A0-\u31BA\u31F0-\u31FF\u3400-\u4DB5\u4E00-\u9FCC\uA000-\uA48C\uA4D0-\uA4FD\uA500-\uA60C\uA610-\uA61F\uA62A\uA62B\uA640-\uA66E\uA67F-\uA697\uA6A0-\uA6E5\uA717-\uA71F\uA722-\uA788\uA78B-\uA78E\uA790-\uA793\uA7A0-\uA7AA\uA7F8-\uA801\uA803-\uA805\uA807-\uA80A\uA80C-\uA822\uA840-\uA873\uA882-\uA8B3\uA8F2-\uA8F7\uA8FB\uA90A-\uA925\uA930-\uA946\uA960-\uA97C\uA984-\uA9B2\uA9CF\uAA00-\uAA28\uAA40-\uAA42\uAA44-\uAA4B\uAA60-\uAA76\uAA7A\uAA80-\uAAAF\uAAB1\uAAB5\uAAB6\uAAB9-\uAABD\uAAC0\uAAC2\uAADB-\uAADD\uAAE0-\uAAEA\uAAF2-\uAAF4\uAB01-\uAB06\uAB09-\uAB0E\uAB11-\uAB16\uAB20-\uAB26\uAB28-\uAB2E\uABC0-\uABE2\uAC00-\uD7A3\uD7B0-\uD7C6\uD7CB-\uD7FB\uF900-\uFA6D\uFA70-\uFAD9\uFB00-\uFB06\uFB13-\uFB17\uFB1D\uFB1F-\uFB28\uFB2A-\uFB36\uFB38-\uFB3C\uFB3E\uFB40\uFB41\uFB43\uFB44\uFB46-\uFBB1\uFBD3-\uFD3D\uFD50-\uFD8F\uFD92-\uFDC7\uFDF0-\uFDFB\uFE70-\uFE74\uFE76-\uFEFC\uFF21-\uFF3A\uFF41-\uFF5A\uFF66-\uFFBE\uFFC2-\uFFC7\uFFCA-\uFFCF\uFFD2-\uFFD7\uFFDA-\uFFDC]*$/.test(t);
  }
}
class cU extends Kt {
  check(t) {
    return /^[0-9-_\u0041-\u005A\u0061-\u007A\u00AA\u00B5\u00BA\u00C0-\u00D6\u00D8-\u00F6\u00F8-\u02C1\u02C6-\u02D1\u02E0-\u02E4\u02EC\u02EE\u0370-\u0374\u0376\u0377\u037A-\u037D\u0386\u0388-\u038A\u038C\u038E-\u03A1\u03A3-\u03F5\u03F7-\u0481\u048A-\u0527\u0531-\u0556\u0559\u0561-\u0587\u05D0-\u05EA\u05F0-\u05F2\u0620-\u064A\u066E\u066F\u0671-\u06D3\u06D5\u06E5\u06E6\u06EE\u06EF\u06FA-\u06FC\u06FF\u0710\u0712-\u072F\u074D-\u07A5\u07B1\u07CA-\u07EA\u07F4\u07F5\u07FA\u0800-\u0815\u081A\u0824\u0828\u0840-\u0858\u08A0\u08A2-\u08AC\u0904-\u0939\u093D\u0950\u0958-\u0961\u0971-\u0977\u0979-\u097F\u0985-\u098C\u098F\u0990\u0993-\u09A8\u09AA-\u09B0\u09B2\u09B6-\u09B9\u09BD\u09CE\u09DC\u09DD\u09DF-\u09E1\u09F0\u09F1\u0A05-\u0A0A\u0A0F\u0A10\u0A13-\u0A28\u0A2A-\u0A30\u0A32\u0A33\u0A35\u0A36\u0A38\u0A39\u0A59-\u0A5C\u0A5E\u0A72-\u0A74\u0A85-\u0A8D\u0A8F-\u0A91\u0A93-\u0AA8\u0AAA-\u0AB0\u0AB2\u0AB3\u0AB5-\u0AB9\u0ABD\u0AD0\u0AE0\u0AE1\u0B05-\u0B0C\u0B0F\u0B10\u0B13-\u0B28\u0B2A-\u0B30\u0B32\u0B33\u0B35-\u0B39\u0B3D\u0B5C\u0B5D\u0B5F-\u0B61\u0B71\u0B83\u0B85-\u0B8A\u0B8E-\u0B90\u0B92-\u0B95\u0B99\u0B9A\u0B9C\u0B9E\u0B9F\u0BA3\u0BA4\u0BA8-\u0BAA\u0BAE-\u0BB9\u0BD0\u0C05-\u0C0C\u0C0E-\u0C10\u0C12-\u0C28\u0C2A-\u0C33\u0C35-\u0C39\u0C3D\u0C58\u0C59\u0C60\u0C61\u0C85-\u0C8C\u0C8E-\u0C90\u0C92-\u0CA8\u0CAA-\u0CB3\u0CB5-\u0CB9\u0CBD\u0CDE\u0CE0\u0CE1\u0CF1\u0CF2\u0D05-\u0D0C\u0D0E-\u0D10\u0D12-\u0D3A\u0D3D\u0D4E\u0D60\u0D61\u0D7A-\u0D7F\u0D85-\u0D96\u0D9A-\u0DB1\u0DB3-\u0DBB\u0DBD\u0DC0-\u0DC6\u0E01-\u0E30\u0E32\u0E33\u0E40-\u0E46\u0E81\u0E82\u0E84\u0E87\u0E88\u0E8A\u0E8D\u0E94-\u0E97\u0E99-\u0E9F\u0EA1-\u0EA3\u0EA5\u0EA7\u0EAA\u0EAB\u0EAD-\u0EB0\u0EB2\u0EB3\u0EBD\u0EC0-\u0EC4\u0EC6\u0EDC-\u0EDF\u0F00\u0F40-\u0F47\u0F49-\u0F6C\u0F88-\u0F8C\u1000-\u102A\u103F\u1050-\u1055\u105A-\u105D\u1061\u1065\u1066\u106E-\u1070\u1075-\u1081\u108E\u10A0-\u10C5\u10C7\u10CD\u10D0-\u10FA\u10FC-\u1248\u124A-\u124D\u1250-\u1256\u1258\u125A-\u125D\u1260-\u1288\u128A-\u128D\u1290-\u12B0\u12B2-\u12B5\u12B8-\u12BE\u12C0\u12C2-\u12C5\u12C8-\u12D6\u12D8-\u1310\u1312-\u1315\u1318-\u135A\u1380-\u138F\u13A0-\u13F4\u1401-\u166C\u166F-\u167F\u1681-\u169A\u16A0-\u16EA\u1700-\u170C\u170E-\u1711\u1720-\u1731\u1740-\u1751\u1760-\u176C\u176E-\u1770\u1780-\u17B3\u17D7\u17DC\u1820-\u1877\u1880-\u18A8\u18AA\u18B0-\u18F5\u1900-\u191C\u1950-\u196D\u1970-\u1974\u1980-\u19AB\u19C1-\u19C7\u1A00-\u1A16\u1A20-\u1A54\u1AA7\u1B05-\u1B33\u1B45-\u1B4B\u1B83-\u1BA0\u1BAE\u1BAF\u1BBA-\u1BE5\u1C00-\u1C23\u1C4D-\u1C4F\u1C5A-\u1C7D\u1CE9-\u1CEC\u1CEE-\u1CF1\u1CF5\u1CF6\u1D00-\u1DBF\u1E00-\u1F15\u1F18-\u1F1D\u1F20-\u1F45\u1F48-\u1F4D\u1F50-\u1F57\u1F59\u1F5B\u1F5D\u1F5F-\u1F7D\u1F80-\u1FB4\u1FB6-\u1FBC\u1FBE\u1FC2-\u1FC4\u1FC6-\u1FCC\u1FD0-\u1FD3\u1FD6-\u1FDB\u1FE0-\u1FEC\u1FF2-\u1FF4\u1FF6-\u1FFC\u2071\u207F\u2090-\u209C\u2102\u2107\u210A-\u2113\u2115\u2119-\u211D\u2124\u2126\u2128\u212A-\u212D\u212F-\u2139\u213C-\u213F\u2145-\u2149\u214E\u2183\u2184\u2C00-\u2C2E\u2C30-\u2C5E\u2C60-\u2CE4\u2CEB-\u2CEE\u2CF2\u2CF3\u2D00-\u2D25\u2D27\u2D2D\u2D30-\u2D67\u2D6F\u2D80-\u2D96\u2DA0-\u2DA6\u2DA8-\u2DAE\u2DB0-\u2DB6\u2DB8-\u2DBE\u2DC0-\u2DC6\u2DC8-\u2DCE\u2DD0-\u2DD6\u2DD8-\u2DDE\u2E2F\u3005\u3006\u3031-\u3035\u303B\u303C\u3041-\u3096\u309D-\u309F\u30A1-\u30FA\u30FC-\u30FF\u3105-\u312D\u3131-\u318E\u31A0-\u31BA\u31F0-\u31FF\u3400-\u4DB5\u4E00-\u9FCC\uA000-\uA48C\uA4D0-\uA4FD\uA500-\uA60C\uA610-\uA61F\uA62A\uA62B\uA640-\uA66E\uA67F-\uA697\uA6A0-\uA6E5\uA717-\uA71F\uA722-\uA788\uA78B-\uA78E\uA790-\uA793\uA7A0-\uA7AA\uA7F8-\uA801\uA803-\uA805\uA807-\uA80A\uA80C-\uA822\uA840-\uA873\uA882-\uA8B3\uA8F2-\uA8F7\uA8FB\uA90A-\uA925\uA930-\uA946\uA960-\uA97C\uA984-\uA9B2\uA9CF\uAA00-\uAA28\uAA40-\uAA42\uAA44-\uAA4B\uAA60-\uAA76\uAA7A\uAA80-\uAAAF\uAAB1\uAAB5\uAAB6\uAAB9-\uAABD\uAAC0\uAAC2\uAADB-\uAADD\uAAE0-\uAAEA\uAAF2-\uAAF4\uAB01-\uAB06\uAB09-\uAB0E\uAB11-\uAB16\uAB20-\uAB26\uAB28-\uAB2E\uABC0-\uABE2\uAC00-\uD7A3\uD7B0-\uD7C6\uD7CB-\uD7FB\uF900-\uFA6D\uFA70-\uFAD9\uFB00-\uFB06\uFB13-\uFB17\uFB1D\uFB1F-\uFB28\uFB2A-\uFB36\uFB38-\uFB3C\uFB3E\uFB40\uFB41\uFB43\uFB44\uFB46-\uFBB1\uFBD3-\uFD3D\uFD50-\uFD8F\uFD92-\uFDC7\uFDF0-\uFDFB\uFE70-\uFE74\uFE76-\uFEFC\uFF21-\uFF3A\uFF41-\uFF5A\uFF66-\uFFBE\uFFC2-\uFFC7\uFFCA-\uFFCF\uFFD2-\uFFD7\uFFDA-\uFFDC]*$/.test(t);
  }
}
class dU extends Kt {
  check(t) {
    return /^[0-9\u0041-\u005A\u0061-\u007A\u00AA\u00B5\u00BA\u00C0-\u00D6\u00D8-\u00F6\u00F8-\u02C1\u02C6-\u02D1\u02E0-\u02E4\u02EC\u02EE\u0370-\u0374\u0376\u0377\u037A-\u037D\u0386\u0388-\u038A\u038C\u038E-\u03A1\u03A3-\u03F5\u03F7-\u0481\u048A-\u0527\u0531-\u0556\u0559\u0561-\u0587\u05D0-\u05EA\u05F0-\u05F2\u0620-\u064A\u066E\u066F\u0671-\u06D3\u06D5\u06E5\u06E6\u06EE\u06EF\u06FA-\u06FC\u06FF\u0710\u0712-\u072F\u074D-\u07A5\u07B1\u07CA-\u07EA\u07F4\u07F5\u07FA\u0800-\u0815\u081A\u0824\u0828\u0840-\u0858\u08A0\u08A2-\u08AC\u0904-\u0939\u093D\u0950\u0958-\u0961\u0971-\u0977\u0979-\u097F\u0985-\u098C\u098F\u0990\u0993-\u09A8\u09AA-\u09B0\u09B2\u09B6-\u09B9\u09BD\u09CE\u09DC\u09DD\u09DF-\u09E1\u09F0\u09F1\u0A05-\u0A0A\u0A0F\u0A10\u0A13-\u0A28\u0A2A-\u0A30\u0A32\u0A33\u0A35\u0A36\u0A38\u0A39\u0A59-\u0A5C\u0A5E\u0A72-\u0A74\u0A85-\u0A8D\u0A8F-\u0A91\u0A93-\u0AA8\u0AAA-\u0AB0\u0AB2\u0AB3\u0AB5-\u0AB9\u0ABD\u0AD0\u0AE0\u0AE1\u0B05-\u0B0C\u0B0F\u0B10\u0B13-\u0B28\u0B2A-\u0B30\u0B32\u0B33\u0B35-\u0B39\u0B3D\u0B5C\u0B5D\u0B5F-\u0B61\u0B71\u0B83\u0B85-\u0B8A\u0B8E-\u0B90\u0B92-\u0B95\u0B99\u0B9A\u0B9C\u0B9E\u0B9F\u0BA3\u0BA4\u0BA8-\u0BAA\u0BAE-\u0BB9\u0BD0\u0C05-\u0C0C\u0C0E-\u0C10\u0C12-\u0C28\u0C2A-\u0C33\u0C35-\u0C39\u0C3D\u0C58\u0C59\u0C60\u0C61\u0C85-\u0C8C\u0C8E-\u0C90\u0C92-\u0CA8\u0CAA-\u0CB3\u0CB5-\u0CB9\u0CBD\u0CDE\u0CE0\u0CE1\u0CF1\u0CF2\u0D05-\u0D0C\u0D0E-\u0D10\u0D12-\u0D3A\u0D3D\u0D4E\u0D60\u0D61\u0D7A-\u0D7F\u0D85-\u0D96\u0D9A-\u0DB1\u0DB3-\u0DBB\u0DBD\u0DC0-\u0DC6\u0E01-\u0E30\u0E32\u0E33\u0E40-\u0E46\u0E81\u0E82\u0E84\u0E87\u0E88\u0E8A\u0E8D\u0E94-\u0E97\u0E99-\u0E9F\u0EA1-\u0EA3\u0EA5\u0EA7\u0EAA\u0EAB\u0EAD-\u0EB0\u0EB2\u0EB3\u0EBD\u0EC0-\u0EC4\u0EC6\u0EDC-\u0EDF\u0F00\u0F40-\u0F47\u0F49-\u0F6C\u0F88-\u0F8C\u1000-\u102A\u103F\u1050-\u1055\u105A-\u105D\u1061\u1065\u1066\u106E-\u1070\u1075-\u1081\u108E\u10A0-\u10C5\u10C7\u10CD\u10D0-\u10FA\u10FC-\u1248\u124A-\u124D\u1250-\u1256\u1258\u125A-\u125D\u1260-\u1288\u128A-\u128D\u1290-\u12B0\u12B2-\u12B5\u12B8-\u12BE\u12C0\u12C2-\u12C5\u12C8-\u12D6\u12D8-\u1310\u1312-\u1315\u1318-\u135A\u1380-\u138F\u13A0-\u13F4\u1401-\u166C\u166F-\u167F\u1681-\u169A\u16A0-\u16EA\u1700-\u170C\u170E-\u1711\u1720-\u1731\u1740-\u1751\u1760-\u176C\u176E-\u1770\u1780-\u17B3\u17D7\u17DC\u1820-\u1877\u1880-\u18A8\u18AA\u18B0-\u18F5\u1900-\u191C\u1950-\u196D\u1970-\u1974\u1980-\u19AB\u19C1-\u19C7\u1A00-\u1A16\u1A20-\u1A54\u1AA7\u1B05-\u1B33\u1B45-\u1B4B\u1B83-\u1BA0\u1BAE\u1BAF\u1BBA-\u1BE5\u1C00-\u1C23\u1C4D-\u1C4F\u1C5A-\u1C7D\u1CE9-\u1CEC\u1CEE-\u1CF1\u1CF5\u1CF6\u1D00-\u1DBF\u1E00-\u1F15\u1F18-\u1F1D\u1F20-\u1F45\u1F48-\u1F4D\u1F50-\u1F57\u1F59\u1F5B\u1F5D\u1F5F-\u1F7D\u1F80-\u1FB4\u1FB6-\u1FBC\u1FBE\u1FC2-\u1FC4\u1FC6-\u1FCC\u1FD0-\u1FD3\u1FD6-\u1FDB\u1FE0-\u1FEC\u1FF2-\u1FF4\u1FF6-\u1FFC\u2071\u207F\u2090-\u209C\u2102\u2107\u210A-\u2113\u2115\u2119-\u211D\u2124\u2126\u2128\u212A-\u212D\u212F-\u2139\u213C-\u213F\u2145-\u2149\u214E\u2183\u2184\u2C00-\u2C2E\u2C30-\u2C5E\u2C60-\u2CE4\u2CEB-\u2CEE\u2CF2\u2CF3\u2D00-\u2D25\u2D27\u2D2D\u2D30-\u2D67\u2D6F\u2D80-\u2D96\u2DA0-\u2DA6\u2DA8-\u2DAE\u2DB0-\u2DB6\u2DB8-\u2DBE\u2DC0-\u2DC6\u2DC8-\u2DCE\u2DD0-\u2DD6\u2DD8-\u2DDE\u2E2F\u3005\u3006\u3031-\u3035\u303B\u303C\u3041-\u3096\u309D-\u309F\u30A1-\u30FA\u30FC-\u30FF\u3105-\u312D\u3131-\u318E\u31A0-\u31BA\u31F0-\u31FF\u3400-\u4DB5\u4E00-\u9FCC\uA000-\uA48C\uA4D0-\uA4FD\uA500-\uA60C\uA610-\uA61F\uA62A\uA62B\uA640-\uA66E\uA67F-\uA697\uA6A0-\uA6E5\uA717-\uA71F\uA722-\uA788\uA78B-\uA78E\uA790-\uA793\uA7A0-\uA7AA\uA7F8-\uA801\uA803-\uA805\uA807-\uA80A\uA80C-\uA822\uA840-\uA873\uA882-\uA8B3\uA8F2-\uA8F7\uA8FB\uA90A-\uA925\uA930-\uA946\uA960-\uA97C\uA984-\uA9B2\uA9CF\uAA00-\uAA28\uAA40-\uAA42\uAA44-\uAA4B\uAA60-\uAA76\uAA7A\uAA80-\uAAAF\uAAB1\uAAB5\uAAB6\uAAB9-\uAABD\uAAC0\uAAC2\uAADB-\uAADD\uAAE0-\uAAEA\uAAF2-\uAAF4\uAB01-\uAB06\uAB09-\uAB0E\uAB11-\uAB16\uAB20-\uAB26\uAB28-\uAB2E\uABC0-\uABE2\uAC00-\uD7A3\uD7B0-\uD7C6\uD7CB-\uD7FB\uF900-\uFA6D\uFA70-\uFAD9\uFB00-\uFB06\uFB13-\uFB17\uFB1D\uFB1F-\uFB28\uFB2A-\uFB36\uFB38-\uFB3C\uFB3E\uFB40\uFB41\uFB43\uFB44\uFB46-\uFBB1\uFBD3-\uFD3D\uFD50-\uFD8F\uFD92-\uFDC7\uFDF0-\uFDFB\uFE70-\uFE74\uFE76-\uFEFC\uFF21-\uFF3A\uFF41-\uFF5A\uFF66-\uFFBE\uFFC2-\uFFC7\uFFCA-\uFFCF\uFFD2-\uFFD7\uFFDA-\uFFDC]*$/.test(t);
  }
}
class fU extends Kt {
  check(t) {
    return At(t);
  }
}
class pU extends Dm {
  checkDate(t) {
    return Ge(t, this.format).isBefore(Ge(this.date, this.otherFormat));
  }
}
class mU extends Dm {
  checkDate(t) {
    return Ge(t, this.format).isSameOrBefore(Ge(this.date, this.otherFormat));
  }
}
class hU extends Kt {
  get messageParams() {
    return {
      attribute: this.attributeName,
      min: this.min,
      max: this.max
    };
  }
  get min() {
    return this.attributes[0];
  }
  get max() {
    return this.attributes[1];
  }
  check(t) {
    if (!t)
      return !0;
    var n = this.size(t);
    return n >= this.min && n <= this.max;
  }
}
class gU extends Kt {
  check(t) {
    var n = [!0, !1, 0, 1, "0", "1"];
    return n.indexOf(t) !== -1;
  }
}
class _U extends Kt {
  get messageParams() {
    return {
      attribute: this.attributeName,
      other: this.other$.genericName
    };
  }
  get otherPath() {
    return "".concat(this.element$.path, "_confirmation");
  }
  get other$() {
    return this.form$.el$(Ho(this.otherPath, this.element$.path));
  }
  init() {
    this.watchOther();
  }
  check(t) {
    return this.filled(this.other$.value) ? t == this.other$.value : !0;
  }
}
var If = "[ \\t]+", gu = "[ \\t]*", _u = "(?:([ap])\\.?m\\.?([\\t ]|$))", Po = "(2[0-4]|[01]?[0-9])", Lf = "([01][0-9]|2[0-4])", Nc = "(0?[1-9]|1[0-2])", Rs = "([0-5]?[0-9])", Mo = "([0-5][0-9])", Kh = "(60|[0-5]?[0-9])", As = "(60|[0-5][0-9])", HM = "(?:\\.([0-9]+))", vU = "sunday|monday|tuesday|wednesday|thursday|friday|saturday", bU = "sun|mon|tue|wed|thu|fri|sat", EU = vU + "|" + bU + "|weekdays?", zM = "first|second|third|fourth|fifth|sixth|seventh|eighth?|ninth|tenth|eleventh|twelfth", yT = "next|last|previous|this", VM = "(?:second|sec|minute|min|hour|day|fortnight|forthnight|month|year)s?|weeks|" + EU, kf = "([0-9]{1,4})", uPe = "([0-9]{2})", Ai = "([0-9]{4})", cPe = "([+-]?[0-9]{4})", _l = "(1[0-2]|0?[0-9])", vu = "(0[0-9]|1[0-2])", Va = "(?:(3[01]|[0-2]?[0-9])(?:st|nd|rd|th)?)", Os = "(0[0-9]|[1-2][0-9]|3[01])", SU = "january|february|march|april|may|june|july|august|september|october|november|december", qf = "jan|feb|mar|apr|may|jun|jul|aug|sept?|oct|nov|dec", dPe = "i[vx]|vi{0,3}|xi{0,2}|i{1,3}", $c = "(" + SU + "|" + qf + "|" + dPe + ")", TT = "((?:GMT)?([+-])" + Po + ":?" + Rs + "?)", fPe = "\\(?([a-zA-Z]{1,6})\\)?", pPe = "(00[1-9]|0[1-9][0-9]|[12][0-9][0-9]|3[0-5][0-9]|36[0-6])", mPe = "(0[1-9]|[1-4][0-9]|5[0-3])", Mf = $c + "[ .\\t-]*" + Va + "[,.stndrh\\t ]*";
function bu(e, t) {
  switch (t = t && t.toLowerCase(), t) {
    case "a":
      e += e === 12 ? -12 : 0;
      break;
    case "p":
      e += e !== 12 ? 12 : 0;
      break;
  }
  return e;
}
function Eu(e) {
  var t = +e;
  return e.length < 4 && t < 100 && (t += t < 70 ? 2e3 : 1900), t;
}
function ta(e) {
  return {
    jan: 0,
    january: 0,
    i: 0,
    feb: 1,
    february: 1,
    ii: 1,
    mar: 2,
    march: 2,
    iii: 2,
    apr: 3,
    april: 3,
    iv: 3,
    may: 4,
    v: 4,
    jun: 5,
    june: 5,
    vi: 5,
    jul: 6,
    july: 6,
    vii: 6,
    aug: 7,
    august: 7,
    viii: 7,
    sep: 8,
    sept: 8,
    september: 8,
    ix: 8,
    oct: 9,
    october: 9,
    x: 9,
    nov: 10,
    november: 10,
    xi: 10,
    dec: 11,
    december: 11,
    xii: 11
  }[e.toLowerCase()];
}
function CT(e) {
  var t = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : 0, n = {
    mon: 1,
    monday: 1,
    tue: 2,
    tuesday: 2,
    wed: 3,
    wednesday: 3,
    thu: 4,
    thursday: 4,
    fri: 5,
    friday: 5,
    sat: 6,
    saturday: 6,
    sun: 0,
    sunday: 0
  };
  return n[e.toLowerCase()] || t;
}
function hPe(e) {
  var t = {
    last: -1,
    previous: -1,
    this: 0,
    first: 1,
    next: 1,
    second: 2,
    third: 3,
    fourth: 4,
    fifth: 5,
    sixth: 6,
    seventh: 7,
    eight: 8,
    eighth: 8,
    ninth: 9,
    tenth: 10,
    eleventh: 11,
    twelfth: 12
  }, n = {
    this: 1
  }, r = e.toLowerCase();
  return {
    amount: t[r],
    behavior: n[r] || 0
  };
}
function AT(e, t) {
  var n = /(?:GMT)?([+-])(\d+)(:?)(\d{0,2})/i;
  if (e = e && e.match(n), !e)
    return t;
  var r = e[1] === "-" ? -1 : 1, i = +e[2], a = +e[4];
  return !e[4] && !e[3] && (a = Math.floor(i % 100), i = Math.floor(i / 100)), r * (i * 60 + a) * 60;
}
var gPe = {
  acdt: 37800,
  acst: 34200,
  addt: -7200,
  adt: -10800,
  aedt: 39600,
  aest: 36e3,
  ahdt: -32400,
  ahst: -36e3,
  akdt: -28800,
  akst: -32400,
  amt: -13840,
  apt: -10800,
  ast: -14400,
  awdt: 32400,
  awst: 28800,
  awt: -10800,
  bdst: 7200,
  bdt: -36e3,
  bmt: -14309,
  bst: 3600,
  cast: 34200,
  cat: 7200,
  cddt: -14400,
  cdt: -18e3,
  cemt: 10800,
  cest: 7200,
  cet: 3600,
  cmt: -15408,
  cpt: -18e3,
  cst: -21600,
  cwt: -18e3,
  chst: 36e3,
  dmt: -1521,
  eat: 10800,
  eddt: -10800,
  edt: -14400,
  eest: 10800,
  eet: 7200,
  emt: -26248,
  ept: -14400,
  est: -18e3,
  ewt: -14400,
  ffmt: -14660,
  fmt: -4056,
  gdt: 39600,
  gmt: 0,
  gst: 36e3,
  hdt: -34200,
  hkst: 32400,
  hkt: 28800,
  hmt: -19776,
  hpt: -34200,
  hst: -36e3,
  hwt: -34200,
  iddt: 14400,
  idt: 10800,
  imt: 25025,
  ist: 7200,
  jdt: 36e3,
  jmt: 8440,
  jst: 32400,
  kdt: 36e3,
  kmt: 5736,
  kst: 30600,
  lst: 9394,
  mddt: -18e3,
  mdst: 16279,
  mdt: -21600,
  mest: 7200,
  met: 3600,
  mmt: 9017,
  mpt: -21600,
  msd: 14400,
  msk: 10800,
  mst: -25200,
  mwt: -21600,
  nddt: -5400,
  ndt: -9052,
  npt: -9e3,
  nst: -12600,
  nwt: -9e3,
  nzdt: 46800,
  nzmt: 41400,
  nzst: 43200,
  pddt: -21600,
  pdt: -25200,
  pkst: 21600,
  pkt: 18e3,
  plmt: 25590,
  pmt: -13236,
  ppmt: -17340,
  ppt: -25200,
  pst: -28800,
  pwt: -25200,
  qmt: -18840,
  rmt: 5794,
  sast: 7200,
  sdmt: -16800,
  sjmt: -20173,
  smt: -13884,
  sst: -39600,
  tbmt: 10751,
  tmt: 12344,
  uct: 0,
  utc: 0,
  wast: 7200,
  wat: 3600,
  wemt: 7200,
  west: 3600,
  wet: 0,
  wib: 25200,
  wita: 28800,
  wit: 32400,
  wmt: 5040,
  yddt: -25200,
  ydt: -28800,
  ypt: -28800,
  yst: -32400,
  ywt: -28800,
  a: 3600,
  b: 7200,
  c: 10800,
  d: 14400,
  e: 18e3,
  f: 21600,
  g: 25200,
  h: 28800,
  i: 32400,
  k: 36e3,
  l: 39600,
  m: 43200,
  n: -3600,
  o: -7200,
  p: -10800,
  q: -14400,
  r: -18e3,
  s: -21600,
  t: -25200,
  u: -28800,
  v: -32400,
  w: -36e3,
  x: -39600,
  y: -43200,
  z: 0
}, wt = {
  yesterday: {
    regex: /^yesterday/i,
    name: "yesterday",
    callback: function() {
      return this.rd -= 1, this.resetTime();
    }
  },
  now: {
    regex: /^now/i,
    name: "now"
    // do nothing
  },
  noon: {
    regex: /^noon/i,
    name: "noon",
    callback: function() {
      return this.resetTime() && this.time(12, 0, 0, 0);
    }
  },
  midnightOrToday: {
    regex: /^(midnight|today)/i,
    name: "midnight | today",
    callback: function() {
      return this.resetTime();
    }
  },
  tomorrow: {
    regex: /^tomorrow/i,
    name: "tomorrow",
    callback: function() {
      return this.rd += 1, this.resetTime();
    }
  },
  timestamp: {
    regex: /^@(-?\d+)/i,
    name: "timestamp",
    callback: function(t, n) {
      return this.rs += +n, this.y = 1970, this.m = 0, this.d = 1, this.dates = 0, this.resetTime() && this.zone(0);
    }
  },
  firstOrLastDay: {
    regex: /^(first|last) day of/i,
    name: "firstdayof | lastdayof",
    callback: function(t, n) {
      n.toLowerCase() === "first" ? this.firstOrLastDayOfMonth = 1 : this.firstOrLastDayOfMonth = -1;
    }
  },
  backOrFrontOf: {
    regex: RegExp("^(back|front) of " + Po + gu + _u + "?", "i"),
    name: "backof | frontof",
    callback: function(t, n, r, i) {
      var a = n.toLowerCase() === "back", o = +r, s = 15;
      return a || (o -= 1, s = 45), o = bu(o, i), this.resetTime() && this.time(o, s, 0, 0);
    }
  },
  weekdayOf: {
    regex: RegExp("^(" + zM + "|" + yT + ")" + If + "(" + vU + "|" + bU + ")" + If + "of", "i"),
    name: "weekdayof"
    // todo
  },
  mssqltime: {
    regex: RegExp("^" + Nc + ":" + Mo + ":" + As + "[:.]([0-9]+)" + _u, "i"),
    name: "mssqltime",
    callback: function(t, n, r, i, a, o) {
      return this.time(bu(+n, o), +r, +i, +a.substr(0, 3));
    }
  },
  timeLong12: {
    regex: RegExp("^" + Nc + "[:.]" + Rs + "[:.]" + As + gu + _u, "i"),
    name: "timelong12",
    callback: function(t, n, r, i, a) {
      return this.time(bu(+n, a), +r, +i, 0);
    }
  },
  timeShort12: {
    regex: RegExp("^" + Nc + "[:.]" + Mo + gu + _u, "i"),
    name: "timeshort12",
    callback: function(t, n, r, i) {
      return this.time(bu(+n, i), +r, 0, 0);
    }
  },
  timeTiny12: {
    regex: RegExp("^" + Nc + gu + _u, "i"),
    name: "timetiny12",
    callback: function(t, n, r) {
      return this.time(bu(+n, r), 0, 0, 0);
    }
  },
  soap: {
    regex: RegExp("^" + Ai + "-" + vu + "-" + Os + "T" + Lf + ":" + Mo + ":" + As + HM + TT + "?", "i"),
    name: "soap",
    callback: function(t, n, r, i, a, o, s, l, u) {
      return this.ymd(+n, r - 1, +i) && this.time(+a, +o, +s, +l.substr(0, 3)) && this.zone(AT(u));
    }
  },
  wddx: {
    regex: RegExp("^" + Ai + "-" + _l + "-" + Va + "T" + Po + ":" + Rs + ":" + Kh),
    name: "wddx",
    callback: function(t, n, r, i, a, o, s) {
      return this.ymd(+n, r - 1, +i) && this.time(+a, +o, +s, 0);
    }
  },
  exif: {
    regex: RegExp("^" + Ai + ":" + vu + ":" + Os + " " + Lf + ":" + Mo + ":" + As, "i"),
    name: "exif",
    callback: function(t, n, r, i, a, o, s) {
      return this.ymd(+n, r - 1, +i) && this.time(+a, +o, +s, 0);
    }
  },
  xmlRpc: {
    regex: RegExp("^" + Ai + vu + Os + "T" + Po + ":" + Mo + ":" + As),
    name: "xmlrpc",
    callback: function(t, n, r, i, a, o, s) {
      return this.ymd(+n, r - 1, +i) && this.time(+a, +o, +s, 0);
    }
  },
  xmlRpcNoColon: {
    regex: RegExp("^" + Ai + vu + Os + "[Tt]" + Po + Mo + As),
    name: "xmlrpcnocolon",
    callback: function(t, n, r, i, a, o, s) {
      return this.ymd(+n, r - 1, +i) && this.time(+a, +o, +s, 0);
    }
  },
  clf: {
    regex: RegExp("^" + Va + "/(" + qf + ")/" + Ai + ":" + Lf + ":" + Mo + ":" + As + If + TT, "i"),
    name: "clf",
    callback: function(t, n, r, i, a, o, s, l) {
      return this.ymd(+i, ta(r), +n) && this.time(+a, +o, +s, 0) && this.zone(AT(l));
    }
  },
  iso8601long: {
    regex: RegExp("^t?" + Po + "[:.]" + Rs + "[:.]" + Kh + HM, "i"),
    name: "iso8601long",
    callback: function(t, n, r, i, a) {
      return this.time(+n, +r, +i, +a.substr(0, 3));
    }
  },
  dateTextual: {
    regex: RegExp("^" + $c + "[ .\\t-]*" + Va + "[,.stndrh\\t ]+" + kf, "i"),
    name: "datetextual",
    callback: function(t, n, r, i) {
      return this.ymd(Eu(i), ta(n), +r);
    }
  },
  pointedDate4: {
    regex: RegExp("^" + Va + "[.\\t-]" + _l + "[.-]" + Ai),
    name: "pointeddate4",
    callback: function(t, n, r, i) {
      return this.ymd(+i, r - 1, +n);
    }
  },
  pointedDate2: {
    regex: RegExp("^" + Va + "[.\\t]" + _l + "\\." + uPe),
    name: "pointeddate2",
    callback: function(t, n, r, i) {
      return this.ymd(Eu(i), r - 1, +n);
    }
  },
  timeLong24: {
    regex: RegExp("^t?" + Po + "[:.]" + Rs + "[:.]" + Kh),
    name: "timelong24",
    callback: function(t, n, r, i) {
      return this.time(+n, +r, +i, 0);
    }
  },
  dateNoColon: {
    regex: RegExp("^" + Ai + vu + Os),
    name: "datenocolon",
    callback: function(t, n, r, i) {
      return this.ymd(+n, r - 1, +i);
    }
  },
  pgydotd: {
    regex: RegExp("^" + Ai + "\\.?" + pPe),
    name: "pgydotd",
    callback: function(t, n, r) {
      return this.ymd(+n, 0, +r);
    }
  },
  timeShort24: {
    regex: RegExp("^t?" + Po + "[:.]" + Rs, "i"),
    name: "timeshort24",
    callback: function(t, n, r) {
      return this.time(+n, +r, 0, 0);
    }
  },
  iso8601noColon: {
    regex: RegExp("^t?" + Lf + Mo + As, "i"),
    name: "iso8601nocolon",
    callback: function(t, n, r, i) {
      return this.time(+n, +r, +i, 0);
    }
  },
  iso8601dateSlash: {
    // eventhough the trailing slash is optional in PHP
    // here it's mandatory and inputs without the slash
    // are handled by dateslash
    regex: RegExp("^" + Ai + "/" + vu + "/" + Os + "/"),
    name: "iso8601dateslash",
    callback: function(t, n, r, i) {
      return this.ymd(+n, r - 1, +i);
    }
  },
  dateSlash: {
    regex: RegExp("^" + Ai + "/" + _l + "/" + Va),
    name: "dateslash",
    callback: function(t, n, r, i) {
      return this.ymd(+n, r - 1, +i);
    }
  },
  american: {
    regex: RegExp("^" + _l + "/" + Va + "/" + kf),
    name: "american",
    callback: function(t, n, r, i) {
      return this.ymd(Eu(i), n - 1, +r);
    }
  },
  americanShort: {
    regex: RegExp("^" + _l + "/" + Va),
    name: "americanshort",
    callback: function(t, n, r) {
      return this.ymd(this.y, n - 1, +r);
    }
  },
  gnuDateShortOrIso8601date2: {
    // iso8601date2 is complete subset of gnudateshort
    regex: RegExp("^" + kf + "-" + _l + "-" + Va),
    name: "gnudateshort | iso8601date2",
    callback: function(t, n, r, i) {
      return this.ymd(Eu(n), r - 1, +i);
    }
  },
  iso8601date4: {
    regex: RegExp("^" + cPe + "-" + vu + "-" + Os),
    name: "iso8601date4",
    callback: function(t, n, r, i) {
      return this.ymd(+n, r - 1, +i);
    }
  },
  gnuNoColon: {
    regex: RegExp("^t?" + Lf + Mo, "i"),
    name: "gnunocolon",
    callback: function(t, n, r) {
      switch (this.times) {
        case 0:
          return this.time(+n, +r, 0, this.f);
        case 1:
          return this.y = n * 100 + +r, this.times++, !0;
        default:
          return !1;
      }
    }
  },
  gnuDateShorter: {
    regex: RegExp("^" + Ai + "-" + _l),
    name: "gnudateshorter",
    callback: function(t, n, r) {
      return this.ymd(+n, r - 1, 1);
    }
  },
  pgTextReverse: {
    // note: allowed years are from 32-9999
    // years below 32 should be treated as days in datefull
    regex: RegExp("^(\\d{3,4}|[4-9]\\d|3[2-9])-(" + qf + ")-" + Os, "i"),
    name: "pgtextreverse",
    callback: function(t, n, r, i) {
      return this.ymd(Eu(n), ta(r), +i);
    }
  },
  dateFull: {
    regex: RegExp("^" + Va + "[ \\t.-]*" + $c + "[ \\t.-]*" + kf, "i"),
    name: "datefull",
    callback: function(t, n, r, i) {
      return this.ymd(Eu(i), ta(r), +n);
    }
  },
  dateNoDay: {
    regex: RegExp("^" + $c + "[ .\\t-]*" + Ai, "i"),
    name: "datenoday",
    callback: function(t, n, r) {
      return this.ymd(+r, ta(n), 1);
    }
  },
  dateNoDayRev: {
    regex: RegExp("^" + Ai + "[ .\\t-]*" + $c, "i"),
    name: "datenodayrev",
    callback: function(t, n, r) {
      return this.ymd(+n, ta(r), 1);
    }
  },
  pgTextShort: {
    regex: RegExp("^(" + qf + ")-" + Os + "-" + kf, "i"),
    name: "pgtextshort",
    callback: function(t, n, r, i) {
      return this.ymd(Eu(i), ta(n), +r);
    }
  },
  dateNoYear: {
    regex: RegExp("^" + Mf, "i"),
    name: "datenoyear",
    callback: function(t, n, r) {
      return this.ymd(this.y, ta(n), +r);
    }
  },
  dateNoYearRev: {
    regex: RegExp("^" + Va + "[ .\\t-]*" + $c, "i"),
    name: "datenoyearrev",
    callback: function(t, n, r) {
      return this.ymd(this.y, ta(r), +n);
    }
  },
  isoWeekDay: {
    regex: RegExp("^" + Ai + "-?W" + mPe + "(?:-?([0-7]))?"),
    name: "isoweekday | isoweek",
    callback: function(t, n, r, i) {
      if (i = i ? +i : 1, !this.ymd(+n, 0, 1))
        return !1;
      var a = new Date(this.y, this.m, this.d).getDay();
      a = 0 - (a > 4 ? a - 7 : a), this.rd += a + (r - 1) * 7 + i;
    }
  },
  relativeText: {
    regex: RegExp("^(" + zM + "|" + yT + ")" + If + "(" + VM + ")", "i"),
    name: "relativetext",
    callback: function(t, n, r) {
      var i = hPe(n), a = i.amount;
      switch (r.toLowerCase()) {
        case "sec":
        case "secs":
        case "second":
        case "seconds":
          this.rs += a;
          break;
        case "min":
        case "mins":
        case "minute":
        case "minutes":
          this.ri += a;
          break;
        case "hour":
        case "hours":
          this.rh += a;
          break;
        case "day":
        case "days":
          this.rd += a;
          break;
        case "fortnight":
        case "fortnights":
        case "forthnight":
        case "forthnights":
          this.rd += a * 14;
          break;
        case "week":
        case "weeks":
          this.rd += a * 7;
          break;
        case "month":
        case "months":
          this.rm += a;
          break;
        case "year":
        case "years":
          this.ry += a;
          break;
        case "mon":
        case "monday":
        case "tue":
        case "tuesday":
        case "wed":
        case "wednesday":
        case "thu":
        case "thursday":
        case "fri":
        case "friday":
        case "sat":
        case "saturday":
        case "sun":
        case "sunday":
          this.resetTime(), this.weekday = CT(r, 7), this.weekdayBehavior = 1, this.rd += (a > 0 ? a - 1 : a) * 7;
          break;
      }
    }
  },
  relative: {
    regex: RegExp("^([+-]*)[ \\t]*(\\d+)" + gu + "(" + VM + "|week)", "i"),
    name: "relative",
    callback: function(t, n, r, i) {
      var a = n.replace(/[^-]/g, "").length, o = +r * Math.pow(-1, a);
      switch (i.toLowerCase()) {
        case "sec":
        case "secs":
        case "second":
        case "seconds":
          this.rs += o;
          break;
        case "min":
        case "mins":
        case "minute":
        case "minutes":
          this.ri += o;
          break;
        case "hour":
        case "hours":
          this.rh += o;
          break;
        case "day":
        case "days":
          this.rd += o;
          break;
        case "fortnight":
        case "fortnights":
        case "forthnight":
        case "forthnights":
          this.rd += o * 14;
          break;
        case "week":
        case "weeks":
          this.rd += o * 7;
          break;
        case "month":
        case "months":
          this.rm += o;
          break;
        case "year":
        case "years":
          this.ry += o;
          break;
        case "mon":
        case "monday":
        case "tue":
        case "tuesday":
        case "wed":
        case "wednesday":
        case "thu":
        case "thursday":
        case "fri":
        case "friday":
        case "sat":
        case "saturday":
        case "sun":
        case "sunday":
          this.resetTime(), this.weekday = CT(i, 7), this.weekdayBehavior = 1, this.rd += (o > 0 ? o - 1 : o) * 7;
          break;
      }
    }
  },
  dayText: {
    regex: RegExp("^(" + EU + ")", "i"),
    name: "daytext",
    callback: function(t, n) {
      this.resetTime(), this.weekday = CT(n, 0), this.weekdayBehavior !== 2 && (this.weekdayBehavior = 1);
    }
  },
  relativeTextWeek: {
    regex: RegExp("^(" + yT + ")" + If + "week", "i"),
    name: "relativetextweek",
    callback: function(t, n) {
      switch (this.weekdayBehavior = 2, n.toLowerCase()) {
        case "this":
          this.rd += 0;
          break;
        case "next":
          this.rd += 7;
          break;
        case "last":
        case "previous":
          this.rd -= 7;
          break;
      }
      isNaN(this.weekday) && (this.weekday = 1);
    }
  },
  monthFullOrMonthAbbr: {
    regex: RegExp("^(" + SU + "|" + qf + ")", "i"),
    name: "monthfull | monthabbr",
    callback: function(t, n) {
      return this.ymd(this.y, ta(n), this.d);
    }
  },
  tzCorrection: {
    regex: RegExp("^" + TT, "i"),
    name: "tzcorrection",
    callback: function(t) {
      return this.zone(AT(t));
    }
  },
  tzAbbr: {
    regex: RegExp("^" + fPe),
    name: "tzabbr",
    callback: function(t, n) {
      var r = gPe[n.toLowerCase()];
      return isNaN(r) ? !1 : this.zone(r);
    }
  },
  ago: {
    regex: /^ago/i,
    name: "ago",
    callback: function() {
      this.ry = -this.ry, this.rm = -this.rm, this.rd = -this.rd, this.rh = -this.rh, this.ri = -this.ri, this.rs = -this.rs, this.rf = -this.rf;
    }
  },
  year4: {
    regex: RegExp("^" + Ai),
    name: "year4",
    callback: function(t, n) {
      return this.y = +n, !0;
    }
  },
  whitespace: {
    regex: /^[ .,\t]+/,
    name: "whitespace"
    // do nothing
  },
  dateShortWithTimeLong: {
    regex: RegExp("^" + Mf + "t?" + Po + "[:.]" + Rs + "[:.]" + Kh, "i"),
    name: "dateshortwithtimelong",
    callback: function(t, n, r, i, a, o) {
      return this.ymd(this.y, ta(n), +r) && this.time(+i, +a, +o, 0);
    }
  },
  dateShortWithTimeLong12: {
    regex: RegExp("^" + Mf + Nc + "[:.]" + Rs + "[:.]" + As + gu + _u, "i"),
    name: "dateshortwithtimelong12",
    callback: function(t, n, r, i, a, o, s) {
      return this.ymd(this.y, ta(n), +r) && this.time(bu(+i, s), +a, +o, 0);
    }
  },
  dateShortWithTimeShort: {
    regex: RegExp("^" + Mf + "t?" + Po + "[:.]" + Rs, "i"),
    name: "dateshortwithtimeshort",
    callback: function(t, n, r, i, a) {
      return this.ymd(this.y, ta(n), +r) && this.time(+i, +a, 0, 0);
    }
  },
  dateShortWithTimeShort12: {
    regex: RegExp("^" + Mf + Nc + "[:.]" + Mo + gu + _u, "i"),
    name: "dateshortwithtimeshort12",
    callback: function(t, n, r, i, a, o) {
      return this.ymd(this.y, ta(n), +r) && this.time(bu(+i, o), +a, 0, 0);
    }
  }
}, _Pe = {
  // date
  y: NaN,
  m: NaN,
  d: NaN,
  // time
  h: NaN,
  i: NaN,
  s: NaN,
  f: NaN,
  // relative shifts
  ry: 0,
  rm: 0,
  rd: 0,
  rh: 0,
  ri: 0,
  rs: 0,
  rf: 0,
  // weekday related shifts
  weekday: NaN,
  weekdayBehavior: 0,
  // first or last day of month
  // 0 none, 1 first, -1 last
  firstOrLastDayOfMonth: 0,
  // timezone correction in minutes
  z: NaN,
  // counters
  dates: 0,
  times: 0,
  zones: 0,
  // helper functions
  ymd: function(t, n, r) {
    return this.dates > 0 ? !1 : (this.dates++, this.y = t, this.m = n, this.d = r, !0);
  },
  time: function(t, n, r, i) {
    return this.times > 0 ? !1 : (this.times++, this.h = t, this.i = n, this.s = r, this.f = i, !0);
  },
  resetTime: function() {
    return this.h = 0, this.i = 0, this.s = 0, this.f = 0, this.times = 0, !0;
  },
  zone: function(t) {
    return this.zones <= 1 ? (this.zones++, this.z = t, !0) : !1;
  },
  toDate: function(t) {
    switch (this.dates && !this.times && (this.h = this.i = this.s = this.f = 0), isNaN(this.y) && (this.y = t.getFullYear()), isNaN(this.m) && (this.m = t.getMonth()), isNaN(this.d) && (this.d = t.getDate()), isNaN(this.h) && (this.h = t.getHours()), isNaN(this.i) && (this.i = t.getMinutes()), isNaN(this.s) && (this.s = t.getSeconds()), isNaN(this.f) && (this.f = t.getMilliseconds()), this.firstOrLastDayOfMonth) {
      case 1:
        this.d = 1;
        break;
      case -1:
        this.d = 0, this.m += 1;
        break;
    }
    if (!isNaN(this.weekday)) {
      var n = new Date(t.getTime());
      n.setFullYear(this.y, this.m, this.d), n.setHours(this.h, this.i, this.s, this.f);
      var r = n.getDay();
      if (this.weekdayBehavior === 2)
        r === 0 && this.weekday !== 0 && (this.weekday = -6), this.weekday === 0 && r !== 0 && (this.weekday = 7), this.d -= r, this.d += this.weekday;
      else {
        var i = this.weekday - r;
        (this.rd < 0 && i < 0 || this.rd >= 0 && i <= -this.weekdayBehavior) && (i += 7), this.weekday >= 0 ? this.d += i : this.d -= 7 - (Math.abs(this.weekday) - r), this.weekday = NaN;
      }
    }
    this.y += this.ry, this.m += this.rm, this.d += this.rd, this.h += this.rh, this.i += this.ri, this.s += this.rs, this.f += this.rf, this.ry = this.rm = this.rd = 0, this.rh = this.ri = this.rs = this.rf = 0;
    var a = new Date(t.getTime());
    switch (a.setFullYear(this.y, this.m, this.d), a.setHours(this.h, this.i, this.s, this.f), this.firstOrLastDayOfMonth) {
      case 1:
        a.setDate(1);
        break;
      case -1:
        a.setMonth(a.getMonth() + 1, 0);
        break;
    }
    return !isNaN(this.z) && a.getTimezoneOffset() !== this.z && (a.setUTCFullYear(a.getFullYear(), a.getMonth(), a.getDate()), a.setUTCHours(a.getHours(), a.getMinutes(), a.getSeconds() - this.z, a.getMilliseconds())), a;
  }
}, vPe = function(t, n) {
  n == null && (n = Math.floor(Date.now() / 1e3));
  for (var r = [
    wt.yesterday,
    wt.now,
    wt.noon,
    wt.midnightOrToday,
    wt.tomorrow,
    wt.timestamp,
    wt.firstOrLastDay,
    wt.backOrFrontOf,
    // formats.weekdayOf, // not yet implemented
    wt.timeTiny12,
    wt.timeShort12,
    wt.timeLong12,
    wt.mssqltime,
    wt.timeShort24,
    wt.timeLong24,
    wt.iso8601long,
    wt.gnuNoColon,
    wt.iso8601noColon,
    wt.americanShort,
    wt.american,
    wt.iso8601date4,
    wt.iso8601dateSlash,
    wt.dateSlash,
    wt.gnuDateShortOrIso8601date2,
    wt.gnuDateShorter,
    wt.dateFull,
    wt.pointedDate4,
    wt.pointedDate2,
    wt.dateNoDay,
    wt.dateNoDayRev,
    wt.dateTextual,
    wt.dateNoYear,
    wt.dateNoYearRev,
    wt.dateNoColon,
    wt.xmlRpc,
    wt.xmlRpcNoColon,
    wt.soap,
    wt.wddx,
    wt.exif,
    wt.pgydotd,
    wt.isoWeekDay,
    wt.pgTextShort,
    wt.pgTextReverse,
    wt.clf,
    wt.year4,
    wt.ago,
    wt.dayText,
    wt.relativeTextWeek,
    wt.relativeText,
    wt.monthFullOrMonthAbbr,
    wt.tzCorrection,
    wt.tzAbbr,
    wt.dateShortWithTimeShort12,
    wt.dateShortWithTimeLong12,
    wt.dateShortWithTimeShort,
    wt.dateShortWithTimeLong,
    wt.relative,
    wt.whitespace
  ], i = Object.create(_Pe); t.length; ) {
    for (var a = null, o = null, s = 0, l = r.length; s < l; s++) {
      var u = r[s], c = t.match(u.regex);
      c && (!a || c[0].length > a[0].length) && (a = c, o = u);
    }
    if (!o || o.callback && o.callback.apply(i, a) === !1)
      return !1;
    t = t.substr(a[0].length), o = null, a = null;
  }
  return Math.floor(i.toDate(new Date(n * 1e3)) / 1e3);
};
class yU extends Kt {
  check(t) {
    return !!vPe(t);
  }
}
class TU extends Kt {
  get messageParams() {
    return {
      attribute: this.attributeName,
      date: this.date
    };
  }
  get date() {
    return this.attributes[0];
  }
  check(t) {
    return t === this.date;
  }
}
class CU extends Kt {
  get messageParams() {
    return {
      attribute: this.attributeName,
      format: this.format
    };
  }
  get format() {
    return this.attributes[0];
  }
  check(t) {
    return t && Ge(t, this.format).format(this.format) === t;
  }
}
class AU extends Kt {
  get otherPath() {
    return this.attributes[0];
  }
  get other$() {
    return this.form$.el$(Ho(this.otherPath, this.element$.path));
  }
  get messageParams() {
    return {
      attribute: this.attributeName,
      other: this.other$.genericName
    };
  }
  init() {
    this.watchOther();
  }
  check(t) {
    return !this.filled(t) && !this.filled(this.other$.value) ? !0 : t != this.other$.value;
  }
}
class OU extends Kt {
  get messageParams() {
    return {
      attribute: this.attributeName,
      digits: this.digits
    };
  }
  get digits() {
    return this.attributes[0];
  }
  check(t) {
    return /^\d+$/.test(t) && t.toString().length == this.digits;
  }
}
class RU extends Kt {
  get messageParams() {
    return {
      attribute: this.attributeName,
      min: this.min,
      max: this.max
    };
  }
  get min() {
    return this.attributes[0];
  }
  get max() {
    return this.attributes[1];
  }
  check(t) {
    var n = t.toString().length;
    return /^\d+$/.test(t) && n >= this.min && n <= this.max;
  }
}
class wU extends Kt {
  get isAsync() {
    return !0;
  }
  readImage(t) {
    return ht(function* () {
      var n = new FileReader();
      return new Promise((r, i) => {
        n.onerror = () => {
          temporaryFileReader.abort(), i(new DOMException("File cannot be parsed."));
        }, n.onloadend = (a) => {
          r(a.target.result);
        }, n.readAsDataURL(t);
      });
    })();
  }
  loadImage(t) {
    var n = this;
    return ht(function* () {
      var r = yield n.readImage(t), i = new Image();
      return new Promise((a, o) => {
        i.onerror = () => {
          o(new DOMException("Image could not be loaded."));
        }, i.onload = (s) => {
          a(s.target);
        }, i.src = r;
      });
    })();
  }
  hasAttribute(t) {
    return Object.keys(this.attributes).map((n) => n.toLowerCase()).indexOf(t) !== -1;
  }
  check(t) {
    var n = this;
    return ht(function* () {
      if (n.isFile && !t)
        return !0;
      if (!n.isFile || !(t instanceof File))
        return !1;
      var r = yield n.loadImage(t);
      if (n.hasAttribute("min_width") && r.width < n.attributes.min_width || n.hasAttribute("max_width") && r.width > n.attributes.max_width || n.hasAttribute("min_height") && r.height < n.attributes.min_height || n.hasAttribute("max_height") && r.height > n.attributes.max_height || n.hasAttribute("width") && r.width != n.attributes.width || n.hasAttribute("height") && r.height != n.attributes.height)
        return !1;
      if (n.hasAttribute("ratio")) {
        var i = n.attributes.ratio, a = 1 / (Math.min(r.width, r.height) + 1), o = /\//.test(i) ? i.split("/")[0] : i, s = /\//.test(i) ? i.split("/")[1] : 1;
        if (Math.abs(o / s - r.width / r.height) > a)
          return !1;
      }
      return !0;
    })();
  }
}
function bPe(e, t) {
  return (e + "").replace(new RegExp("[.\\\\+*?\\[\\^\\]$(){}=!<>|:\\" + t + "-]", "g"), "\\$&");
}
function EPe(e, t, n, r, i) {
  return i(e, function(a, o, s) {
    n = r ? (r = !1, a) : t(n, a, o, s);
  }), n;
}
var SPe = EPe, yPe = F$, TPe = ym, CPe = Qs, APe = SPe, OPe = At;
function RPe(e, t, n) {
  var r = OPe(e) ? yPe : APe, i = arguments.length < 3;
  return r(e, CPe(t), n, i, TPe);
}
var wPe = RPe, xPe = function e(t) {
  var n = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : [];
  return Ma(t) ? wPe(t, (r, i, a) => Ls(r, e(i, [...n, a])), {}) : {
    [n.join(".")]: t
  };
};
class xU extends Kt {
  check(t) {
    var n = this.element$.path, r = n.replace(/\d+(?!\d+)/, "*"), i = n.match(/^[\w-]+/)[0], a = {
      [i]: this.form$.data[i]
    }, o = bPe(r, "#").replace("\\*", "[^.]+"), s = {};
    return Te(xPe(a), (l, u) => {
      u != n && u.match("^" + o + "$") !== null && (s[u] = l);
    }), ql(s).indexOf(t) === -1;
  }
}
class NU extends Kt {
  check(t) {
    var n = /^(([^<>()\[\]\\.,;:\s@"]+(\.[^<>()\[\]\\.,;:\s@"]+)*)|(".+"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/;
    return n.test(String(t).toLowerCase());
  }
}
class DU extends Kt {
  get isAsync() {
    return !0;
  }
  get requestParams() {
    var t = {};
    return Te(this.attributes, (n, r) => {
      var i = r;
      if (isNaN(r) || (i = n), i != "debounce") {
        var a = this.form$.el$(i);
        t[si(t).length] = a && r != 0 ? a.value : i;
      }
    }), t;
  }
  check(t) {
    var n = this;
    return ht(function* () {
      var r = n.element$.name, i = n.form$.$vueform.config.endpoints.exists, a = typeof i != "function" ? i.method : null, o;
      return typeof i == "function" ? o = yield i(t, r, n.requestParams, n.element$, n.form$) : (o = yield n.form$.$vueform.services.axios.request({
        url: i.url,
        method: a,
        [a.toLowerCase() === "get" ? "params" : "data"]: {
          params: n.requestParams,
          [r]: t,
          vueformFieldName: r,
          value: t,
          name: r
        }
      }), o = o.data), o;
    })();
  }
}
class IU extends Kt {
  check(t) {
    return (!t || t instanceof File) && this.isFile;
  }
}
class LU extends Kt {
  check(t) {
    return this.filled(t);
  }
}
class Im extends Kt {
  get messageParams() {
    return {
      attribute: this.attributeName,
      value: this.other$.value != null ? this.size(this.other$.value) : 0
    };
  }
  get otherPath() {
    return this.attributes[0];
  }
  get other$() {
    return this.form$.el$(Ho(this.otherPath, this.element$.path));
  }
  init() {
    this.watchOther();
  }
  check(t) {
    var n = this.other$.value;
    return this.compare(t, n);
  }
  compare(t, n) {
    var r = this.size(n);
    return r == 0 || this.size(t) > r;
  }
}
class kU extends Im {
  compare(t, n) {
    var r = this.size(n);
    return r == 0 || this.size(t) >= r;
  }
}
class MU extends Kt {
  check(t) {
    if (this.isFile && !t)
      return !0;
    if (!this.isFile || !(t instanceof File) || !t.name)
      return !1;
    var n = t.name.split(".").pop();
    return ["jpg", "jpeg", "png", "gif", "bmp", "svg", "webp"].indexOf(n) !== -1;
  }
}
class PU extends Kt {
  check(t) {
    return ql(this.attributes).indexOf(Ur(String(t).trim())) !== -1;
  }
}
class FU extends Kt {
  get messageParams() {
    return {
      attribute: this.attributeName,
      other: this.other$.genericName
    };
  }
  get other$() {
    return this.form$.el$(Ho(this.otherPath, this.element$.path));
  }
  get otherPath() {
    var t = this.attributes[0].match(/.*(?=\.\*)/);
    if (t === null)
      throw new Error("in_array rule's other attribute should end with .*");
    return t[0];
  }
  init() {
    this.watchOther();
  }
  check(t) {
    var n = this.other$.value;
    return n ? n.indexOf(t) !== -1 : !1;
  }
}
class BU extends Kt {
  check(t) {
    var n = Ur(String(t).trim());
    return n === parseInt(n, 10);
  }
}
var $U = function(t) {
  var n = /^(?:(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.){3}(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)(\/([0-9]|[1-2][0-9]|3[0-2]))?$/;
  return n.test(t);
};
class UU extends Kt {
  check(t) {
    return $U(t);
  }
}
var qU = function(t) {
  var n = /^\s*((([0-9A-Fa-f]{1,4}:){7}([0-9A-Fa-f]{1,4}|:))|(([0-9A-Fa-f]{1,4}:){6}(:[0-9A-Fa-f]{1,4}|((25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(\.(25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3})|:))|(([0-9A-Fa-f]{1,4}:){5}(((:[0-9A-Fa-f]{1,4}){1,2})|:((25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(\.(25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3})|:))|(([0-9A-Fa-f]{1,4}:){4}(((:[0-9A-Fa-f]{1,4}){1,3})|((:[0-9A-Fa-f]{1,4})?:((25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(\.(25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3}))|:))|(([0-9A-Fa-f]{1,4}:){3}(((:[0-9A-Fa-f]{1,4}){1,4})|((:[0-9A-Fa-f]{1,4}){0,2}:((25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(\.(25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3}))|:))|(([0-9A-Fa-f]{1,4}:){2}(((:[0-9A-Fa-f]{1,4}){1,5})|((:[0-9A-Fa-f]{1,4}){0,3}:((25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(\.(25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3}))|:))|(([0-9A-Fa-f]{1,4}:){1}(((:[0-9A-Fa-f]{1,4}){1,6})|((:[0-9A-Fa-f]{1,4}){0,4}:((25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(\.(25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3}))|:))|(:(((:[0-9A-Fa-f]{1,4}){1,7})|((:[0-9A-Fa-f]{1,4}){0,5}:((25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(\.(25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3}))|:)))(%.+)?\s*(\/(\d|\d\d|1[0-1]\d|12[0-8]))?$/;
  return n.test(t);
};
class GU extends Kt {
  check(t) {
    return qU(t);
  }
}
class YU extends Kt {
  check(t) {
    return $U(t) || qU(t);
  }
}
function NPe(e) {
  try {
    JSON.parse(e);
  } catch {
    return !1;
  }
  return !0;
}
let HU = class extends Kt {
  check(t) {
    return NPe(t);
  }
};
class zU extends Im {
  compare(t, n) {
    var r = this.size(t), i = this.size(n);
    return i == 0 && r == 0 || this.size(t) < i;
  }
}
class VU extends Im {
  compare(t, n) {
    var r = this.size(t), i = this.size(n);
    return i == 0 && r == 0 || this.size(t) <= i;
  }
}
let WU = class extends Kt {
  get messageParams() {
    return {
      attribute: this.attributeName,
      max: this.max
    };
  }
  get max() {
    return this.attributes[0];
  }
  check(t) {
    return t ? this.size(t) <= this.max : !0;
  }
};
class KU extends Kt {
  get messageParams() {
    return {
      attribute: this.attributeName,
      values: this.accepted.join(", ")
    };
  }
  get accepted() {
    return Object.values(this.attributes).map((t) => t.toLowerCase());
  }
  check(t) {
    if (this.isFile && !t)
      return !0;
    if (!this.isFile || !(t instanceof File) || !t.name)
      return !1;
    var n = t.name.split(".").pop();
    return this.accepted.indexOf(n.toLowerCase()) !== -1;
  }
}
class jU extends Kt {
  get messageParams() {
    return {
      attribute: this.attributeName,
      values: this.accepted.join(", ")
    };
  }
  get accepted() {
    return Object.values(this.attributes).map((t) => t.toLowerCase());
  }
  check(t) {
    return this.isFile && !t ? !0 : !this.isFile || !(t instanceof File) || !t.type ? !1 : this.accepted.indexOf(t.type.toLowerCase()) !== -1;
  }
}
class QU extends Kt {
  get messageParams() {
    return {
      attribute: this.attributeName,
      min: this.min
    };
  }
  get min() {
    return this.attributes[0];
  }
  check(t) {
    return t ? this.size(t) >= this.min : !0;
  }
}
class XU extends Kt {
  check(t) {
    return ql(this.attributes).indexOf(t) === -1;
  }
}
class ZU extends Kt {
  check(t) {
    var n = new RegExp(this.attributes[0].replace(/^\/|\/[^\/]*$/g, ""));
    return !n.test(t);
  }
}
class JU extends Kt {
  check(t) {
    return !0;
  }
}
class e8 extends Kt {
  check(t) {
    return !isNaN(parseFloat(t)) && isFinite(t) && !/\s/.test(String(t)) && !String(t).match(/^0x[0-9a-f]+$/i);
  }
}
class t8 extends Kt {
  check(t) {
    var n = new RegExp(this.attributes[0].replace(/^\/|\/[^\/]*$/g, ""));
    return n.test(t);
  }
}
class n8 extends Kt {
  check(t) {
    return this.filled(t);
  }
}
class r8 extends Kt {
  get messageParams() {
    return {
      attribute: this.attributeName,
      other: this.other$.genericName
    };
  }
  get otherPath() {
    return this.attributes[0];
  }
  get other$() {
    return this.form$.el$(Ho(this.otherPath, this.element$.path));
  }
  init() {
    this.watchOther();
  }
  check(t) {
    return !this.filled(t) && !this.filled(this.other$.value) ? !0 : t == this.other$.value;
  }
}
class i8 extends Kt {
  get messageParams() {
    return {
      attribute: this.attributeName,
      size: this.size_
    };
  }
  get size_() {
    return this.attributes[0];
  }
  check(t) {
    return t ? this.size(t) == this.size_ : !0;
  }
}
class a8 extends Kt {
  check(t) {
    return Bv(t);
  }
}
class o8 extends Kt {
  check(t) {
    try {
      return Intl.DateTimeFormat(void 0, {
        timeZone: t
      }), !0;
    } catch {
      return !1;
    }
  }
}
let s8 = class extends Kt {
  get isAsync() {
    return !0;
  }
  get requestParams() {
    var t = {};
    return Te(this.attributes, (n, r) => {
      var i = r;
      if (isNaN(r) || (i = n), i != "debounce") {
        var a = this.form$.el$(i);
        t[si(t).length] = a && r != 0 ? a.value : i;
      }
    }), t;
  }
  check(t) {
    var n = this;
    return ht(function* () {
      var r = n.element$.name, i = n.form$.$vueform.config.endpoints.unique, a = typeof i != "function" ? i.method : null, o;
      return typeof i == "function" ? o = yield i(t, r, n.requestParams, n.element$, n.form$) : (o = yield n.form$.$vueform.services.axios.request({
        url: i.url,
        method: a,
        [a.toLowerCase() === "get" ? "params" : "data"]: {
          params: n.requestParams,
          name: r,
          value: t
        }
      }), o = o.data), o;
    })();
  }
};
class l8 extends Kt {
  check(t) {
    var n = new RegExp("^(?:(?:(?:https?|ftp):)?\\/\\/)(?:\\S+(?::\\S*)?@)?(?:(?!(?:10|127)(?:\\.\\d{1,3}){3})(?!(?:169\\.254|192\\.168)(?:\\.\\d{1,3}){2})(?!172\\.(?:1[6-9]|2\\d|3[0-1])(?:\\.\\d{1,3}){2})(?:[1-9]\\d?|1\\d\\d|2[01]\\d|22[0-3])(?:\\.(?:1?\\d{1,2}|2[0-4]\\d|25[0-5])){2}(?:\\.(?:[1-9]\\d?|1\\d\\d|2[0-4]\\d|25[0-4]))|(?:(?:[a-z0-9\\u00a1-\\uffff][a-z0-9\\u00a1-\\uffff_-]{0,62})?[a-z0-9\\u00a1-\\uffff]\\.)+(?:[a-z\\u00a1-\\uffff]{2,}\\.?))(?::\\d{2,5})?(?:[/?#]\\S*)?$", "i");
    return n.test(t);
  }
}
class u8 extends Kt {
  check(t) {
    var n = /^[\da-f]{8}-[\da-f]{4}-[\da-f]{4}-[\da-f]{4}-[\da-f]{12}$/i;
    return n.test(t);
  }
}
var DPe = {
  accepted: oU,
  active_url: sU,
  after: Dm,
  after_or_equal: lU,
  alpha: uU,
  alpha_dash: cU,
  alpha_num: dU,
  array: fU,
  before: pU,
  before_or_equal: mU,
  between: hU,
  boolean: gU,
  confirmed: _U,
  date: yU,
  date_equals: TU,
  date_format: CU,
  different: AU,
  digits: OU,
  digits_between: RU,
  dimensions: wU,
  distinct: xU,
  email: NU,
  exists: DU,
  file: IU,
  filled: LU,
  gt: Im,
  gte: kU,
  image: MU,
  in: PU,
  in_array: FU,
  integer: BU,
  ip: YU,
  ipv4: UU,
  ipv6: GU,
  json: HU,
  lt: zU,
  lte: VU,
  max: WU,
  mimes: KU,
  mimetypes: jU,
  min: QU,
  not_in: XU,
  not_regex: ZU,
  nullable: JU,
  numeric: e8,
  regex: t8,
  required: n8,
  same: r8,
  size: i8,
  string: a8,
  timezone: o8,
  unique: s8,
  url: l8,
  uuid: u8
}, IPe = /* @__PURE__ */ Object.freeze({
  __proto__: null,
  accepted: oU,
  active_url: sU,
  after: Dm,
  after_or_equal: lU,
  alpha: uU,
  alpha_dash: cU,
  alpha_num: dU,
  array: fU,
  before: pU,
  before_or_equal: mU,
  between: hU,
  boolean: gU,
  confirmed: _U,
  date: yU,
  date_equals: TU,
  date_format: CU,
  different: AU,
  digits: OU,
  digits_between: RU,
  dimensions: wU,
  distinct: xU,
  email: NU,
  exists: DU,
  file: IU,
  filled: LU,
  gt: Im,
  gte: kU,
  image: MU,
  in_: PU,
  in_array: FU,
  integer: BU,
  ip: YU,
  ipv4: UU,
  ipv6: GU,
  json: HU,
  lt: zU,
  lte: VU,
  max: WU,
  mimes: KU,
  mimetypes: jU,
  min: QU,
  not_in: XU,
  not_regex: ZU,
  nullable: JU,
  numeric: e8,
  regex: t8,
  required: n8,
  same: r8,
  size: i8,
  string: a8,
  timezone: o8,
  unique: s8,
  url: l8,
  uuid: u8,
  default: DPe
}), LPe = {
  factory: lPe,
  rules: {}
}, kPe = Lv, MPe = rc, PPe = FA, FPe = At;
function BPe() {
  var e = arguments.length;
  if (!e)
    return [];
  for (var t = Array(e - 1), n = arguments[0], r = e; r--; )
    t[r - 1] = arguments[r];
  return kPe(FPe(n) ? PPe(n) : [n], MPe(t, 1));
}
var m_ = BPe;
function $Pe(e) {
  return e && e.length ? e[0] : void 0;
}
var h_ = $Pe;
class UPe {
  constructor(t) {
    this.baseErrors = t, this.prepends = {
      errors: [],
      messages: []
    }, this.appends = {
      errors: [],
      messages: []
    };
  }
  get errors() {
    return m_(this.prepends.errors, this.baseErrors, this.appends.errors);
  }
  get messages() {
    return m_(this.prepends.messages, this.appends.messages);
  }
  /**
   * The first error
   * 
   * @type {string}
   */
  get error() {
    return h_(this.errors);
  }
  /**
   * The first message
   * 
   * @type {string}
   */
  get message() {
    return h_(this.messages);
  }
  prepend(t, n) {
    n === void 0 && (n = "error"), this.prepends[n == "error" ? "errors" : "messages"].unshift(t);
  }
  append(t, n) {
    n === void 0 && (n = "error"), this.appends[n == "error" ? "errors" : "messages"].push(t);
  }
  remove(t, n) {
    n === void 0 && (n = "any"), ["any", "error"].indexOf(n) !== -1 && (Te(this.prepends.errors, (r, i) => {
      r == t && this.rm("prepends", "errors", i);
    }), Te(this.appends.errors, (r, i) => {
      r == t && this.rm("appends", "errors", i);
    })), ["any", "message"].indexOf(n) !== -1 && (Te(this.prepends.messages, (r, i) => {
      r == t && this.rm("prepends", "messages", i);
    }), Te(this.appends.messages, (r, i) => {
      r == t && this.rm("appends", "messages", i);
    }));
  }
  rm(t, n, r) {
    this[t][n].splice(r, 1);
  }
  clear(t) {
    t === void 0 && (t = "all"), t == "all" ? (this.prepends = {
      errors: [],
      messages: []
    }, this.appends = {
      errors: [],
      messages: []
    }) : (this.prepends[t] = [], this.appends[t] = []);
  }
  clearPrepended(t) {
    t === void 0 && (t = "all"), t == "all" ? this.prepends = {
      errors: [],
      messages: []
    } : this.prepends[t] = [];
  }
  clearAppended(t) {
    t === void 0 && (t = "all"), t == "all" ? this.appends = {
      errors: [],
      messages: []
    } : this.appends[t] = [];
  }
}
var rp = /* @__PURE__ */ new Map();
function qPe(e) {
  var t = rp.get(e);
  t && t.destroy();
}
function GPe(e) {
  var t = rp.get(e);
  t && t.update();
}
var Gf = null;
typeof window > "u" ? ((Gf = function(e) {
  return e;
}).destroy = function(e) {
  return e;
}, Gf.update = function(e) {
  return e;
}) : ((Gf = function(e, t) {
  return e && Array.prototype.forEach.call(e.length ? e : [e], function(n) {
    return function(r) {
      if (r && r.nodeName && r.nodeName === "TEXTAREA" && !rp.has(r)) {
        var i, a = null, o = window.getComputedStyle(r), s = (i = r.value, function() {
          u({ testForHeightReduction: i === "" || !r.value.startsWith(i), restoreTextAlign: null }), i = r.value;
        }), l = (function(d) {
          r.removeEventListener("autosize:destroy", l), r.removeEventListener("autosize:update", c), r.removeEventListener("input", s), window.removeEventListener("resize", c), Object.keys(d).forEach(function(f) {
            return r.style[f] = d[f];
          }), rp.delete(r);
        }).bind(r, { height: r.style.height, resize: r.style.resize, textAlign: r.style.textAlign, overflowY: r.style.overflowY, overflowX: r.style.overflowX, wordWrap: r.style.wordWrap });
        r.addEventListener("autosize:destroy", l), r.addEventListener("autosize:update", c), r.addEventListener("input", s), window.addEventListener("resize", c), r.style.overflowX = "hidden", r.style.wordWrap = "break-word", rp.set(r, { destroy: l, update: c }), c();
      }
      function u(d) {
        var f, h, m = d.restoreTextAlign, v = m === void 0 ? null : m, b = d.testForHeightReduction, y = b === void 0 || b, g = o.overflowY;
        if (r.scrollHeight !== 0 && (o.resize === "vertical" ? r.style.resize = "none" : o.resize === "both" && (r.style.resize = "horizontal"), y && (f = function(S) {
          for (var C = []; S && S.parentNode && S.parentNode instanceof Element; ) S.parentNode.scrollTop && C.push([S.parentNode, S.parentNode.scrollTop]), S = S.parentNode;
          return function() {
            return C.forEach(function(T) {
              var O = T[0], R = T[1];
              O.style.scrollBehavior = "auto", O.scrollTop = R, O.style.scrollBehavior = null;
            });
          };
        }(r), r.style.height = ""), h = o.boxSizing === "content-box" ? r.scrollHeight - (parseFloat(o.paddingTop) + parseFloat(o.paddingBottom)) : r.scrollHeight + parseFloat(o.borderTopWidth) + parseFloat(o.borderBottomWidth), o.maxHeight !== "none" && h > parseFloat(o.maxHeight) ? (o.overflowY === "hidden" && (r.style.overflow = "scroll"), h = parseFloat(o.maxHeight)) : o.overflowY !== "hidden" && (r.style.overflow = "hidden"), r.style.height = h + "px", v && (r.style.textAlign = v), f && f(), a !== h && (r.dispatchEvent(new Event("autosize:resized", { bubbles: !0 })), a = h), g !== o.overflow && !v)) {
          var E = o.textAlign;
          o.overflow === "hidden" && (r.style.textAlign = E === "start" ? "end" : "start"), u({ restoreTextAlign: E, testForHeightReduction: !0 });
        }
      }
      function c() {
        u({ testForHeightReduction: !0, restoreTextAlign: null });
      }
    }(n);
  }), e;
}).destroy = function(e) {
  return e && Array.prototype.forEach.call(e.length ? e : [e], qPe), e;
}, Gf.update = function(e) {
  return e && Array.prototype.forEach.call(e.length ? e : [e], GPe), e;
});
var YPe = Gf;
class HPe {
  constructor() {
    this.autocomplete = null, this.autocompleteListener = null, this.options = {};
  }
  init(t, n, r) {
    window.google === void 0 || window.google.maps === void 0 || window.google.maps.places === void 0 || window.google.maps.places.Autocomplete, this.options = r, this.autocomplete = new window.google.maps.places.Autocomplete(t, r), this.autocompleteListener = this.autocomplete.addListener("place_changed", () => {
      var i = this.autocomplete.getPlace();
      n(this.formatValue(i), i);
    });
  }
  destroy() {
    window.google.maps.event.removeListener(this.autocompleteListener), window.google.maps.event.clearInstanceListeners(this.autocomplete);
    var t = document.querySelector(".pac-container");
    t && t.remove();
  }
  formatValue(t) {
    if (!jn(t))
      return t;
    var n = t.address_components, r = this.addressComponent(n, "street"), i = this.addressComponent(n, "street_number"), a = null;
    return r !== null && (a = r), i !== null && (a += (r !== null ? " " : "") + i), {
      country: this.addressComponent(n, "country"),
      country_code: this.addressComponent(n, "country_code"),
      state: this.addressComponent(n, "state"),
      state_code: this.addressComponent(n, "state_code"),
      city: this.addressComponent(n, "city"),
      zip: this.addressComponent(n, "zip"),
      address: a,
      formatted_address: t.formatted_address || null,
      lat: t.geometry.location.lat() || null,
      lng: t.geometry.location.lng() || null
    };
  }
  addressComponent(t, n) {
    var r = {
      country: {
        field: "country",
        type: "long_name"
      },
      country_code: {
        field: "country",
        type: "short_name"
      },
      state: {
        field: "administrative_area_level_1",
        type: "long_name"
      },
      state_code: {
        field: "administrative_area_level_1",
        type: "short_name"
      },
      city: {
        field: "locality",
        type: "long_name"
      },
      zip: {
        field: "postal_code",
        type: "long_name"
      },
      street: {
        field: "route",
        type: "long_name"
      },
      street_number: {
        field: "street_number",
        type: "long_name"
      }
    }, i = null;
    return Te(t, (a) => {
      if (a.types.indexOf(r[n].field) !== -1) {
        if (["state", "state_code"].indexOf(n) !== -1 && this.addressComponent(t, "country_code") != "US")
          return;
        i = a[r[n].type] || null;
      }
    }), i;
  }
}
class zPe {
  constructor() {
    this.places = null, this.options = {};
  }
  init(t, n, r) {
    if (window.places === void 0)
      throw new Error("Algolia Places API missing. Please include script in your project from https://community.algolia.com/places/documentation.html#cdn-script or install via npm and set to `window.places`.");
    this.options = r, this.places = window.places(Object.assign({}, {
      container: t
    }, r)), this.places.on("change", (i) => {
      n(this.formatValue(i.suggestion), i.suggestion);
    });
  }
  destroy() {
    this.places.destroy();
  }
  formatValue(t) {
    return jn(t) ? {
      country: t.country,
      country_code: t.countryCode ? t.countryCode.toUpperCase() : null,
      state: t.countryCode == "us" ? t.administrative : null,
      state_code: t.countryCode == "us" ? this.stateCode(t.administrative.toLowerCase()) : null,
      city: t.city,
      zip: t.postcode,
      address: t.name,
      formatted_address: t.value,
      lat: t.latlng.lat,
      lng: t.latlng.lng
    } : t;
  }
  stateCode(t) {
    var n = {
      AL: "alabama",
      AK: "alaska",
      AZ: "arizona",
      AR: "arkansas",
      CA: "california",
      CO: "colorado",
      CT: "connecticut",
      DE: "delaware",
      DC: "district of columbia",
      FL: "florida",
      GA: "georgia",
      HI: "hawaii",
      ID: "idaho",
      IL: "illinois",
      IN: "indiana",
      IA: "iowa",
      KS: "kansas",
      KY: "kentucky",
      LA: "louisiana",
      ME: "maine",
      MD: "maryland",
      MA: "massachusetts",
      MI: "michigan",
      MN: "minnesota",
      MS: "mississippi",
      MO: "missouri",
      MT: "montana",
      NE: "nebraska",
      NV: "nevada",
      NH: "new hampshire",
      NJ: "new Jersey",
      NM: "new Mexico",
      NY: "new york",
      NC: "north carolina",
      ND: "north dakota",
      OH: "ohio",
      OK: "oklahoma",
      OR: "oregon",
      PA: "pennsylvania",
      RI: "rhode Island",
      SC: "south carolina",
      SD: "south dakota",
      TN: "tennessee",
      TX: "texas",
      UT: "utah",
      VT: "vermont",
      VA: "virginia",
      WA: "washington",
      WV: "west virginia",
      WI: "wisconsin",
      WY: "wyoming"
    };
    return ql(n).indexOf(t) === -1 ? null : si(n)[ql(n).indexOf(t)];
  }
}
var VPe = {
  google: HPe,
  algolia: zPe
}, WPe = (e, t, n, r) => {
  var i = () => e(n, r), a = (l) => {
    var {
      conditionPath: u,
      operator: c,
      expected: d
    } = o(l), f = n.el$(u), h = !1;
    return f && t && Te(f.conditions, (m) => {
      Array.isArray(m) && m[0] == t && (h = !0);
    }), !f || !h && !f.available ? !1 : s(f.value, d, c);
  }, o = (l) => ({
    conditionPath: t ? Ho(l[0], t) : l[0],
    operator: l.length == 3 || ["empty", "not_empty", "today"].indexOf(l[1]) !== -1 ? l[1] : "==",
    expected: l.length == 3 ? l[2] : ["empty", "not_empty", "today"].indexOf(l[1]) === -1 ? l[1] : !0
  }), s = (l, u, c) => aU(l, c, u, r);
  if (typeof e == "function")
    return i();
  if (At(e) && At(e[0]))
    return e.reduce((l, u) => l || (At(u[0]) ? u.reduce((c, d) => c && a(d), !0) : a(u)), !1);
  if (At(e))
    return a(e);
  throw new Error("Condition must be a function or an array");
}, KPe = {
  check: WPe
};
class jPe {
  constructor(t) {
    this.locales = t.locales, this.locale = t.locale, this.fallbackLocale = t.fallbackLocale;
  }
  $t(t) {
    var n = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : {}, r = $r(this.locales[this.locale], t) || t;
    return r === t && (r = $r(this.locales[this.fallbackLocale], t) || t), Te(n, (i, a) => {
      r = r.replace(":" + a, i);
    }), Te(n, (i, a) => {
      r = r.replace("{" + a + "}", i);
    }), r;
  }
}
class QPe {
  constructor(t, n, r, i) {
    L4(this, "defaultBreakpoint", "default"), this.presets = i, this.configPresetColumns = this.serialize(this.columnsFromPresets(t.configPresetColumns) || {}), this.configColumns = this.serialize(t.configColumns || {}), this.formPresetColumns = this.serialize(this.columnsFromPresets(t.formPresetColumns) || {}), this.formColumns = this.serialize(t.formColumns || {}), this.presetColumns = this.serialize(this.columnsFromPresets(t.elementPresetColumns) || {}), this.columns = this.serialize(t.elementColumns || {}), this.hasLabel = n, this.getClass = r, this.cols = this.getCols();
  }
  get classes() {
    return {
      container: this.getClasses("container"),
      label: this.getClasses("label"),
      innerContainer: this.getClasses("innerContainer"),
      wrapper: this.getClasses("wrapper")
    };
  }
  serialize(t) {
    if (["number", "string"].indexOf(typeof t) !== -1)
      return {
        [this.defaultBreakpoint]: {
          container: t
        }
      };
    if (typeof t == "object" && ["container", "label", "wrapper"].indexOf(Object.keys(t)[0]) !== -1) {
      var n = {};
      return Te(t, (i, a) => {
        ["number", "string"].indexOf(typeof i) !== -1 ? (n[this.defaultBreakpoint] === void 0 && (n[this.defaultBreakpoint] = {}), n[this.defaultBreakpoint][a] = i) : Te(i, (o, s) => {
          n[s] === void 0 && (n[s] = {}), n[s][a] = o;
        });
      }), n;
    } else {
      var r = {};
      return Te(t, (i, a) => {
        ["number", "string"].indexOf(typeof i) !== -1 ? (r[a] === void 0 && (r[a] = {}), r[a].container = i) : r[a] = i;
      }), r;
    }
  }
  columnsFromPresets(t) {
    var n;
    return Te(t, (r) => {
      var i = this.presets[r];
      !i || !i.columns || (n = i.columns);
    }), n;
  }
  getNullClass() {
    return [this.getClass(this.defaultBreakpoint, 0)];
  }
  getClasses(t) {
    var n = [];
    return Object.keys(this.cols).forEach((r) => {
      var i;
      t === "innerContainer" ? (i = this.cols[r].label, i = i >= 12 || !this.hasLabel ? 12 : 12 - i) : (i = this.cols[r][t], t === "label" && !this.hasLabel && (i = 0)), i !== void 0 && !isNaN(i) && n.push(this.getClass(r, i));
    }), n;
  }
  getCols() {
    return Ls({}, {
      [this.defaultBreakpoint]: {
        container: 12,
        label: 12,
        wrapper: 12
      }
    }, this.configPresetColumns || {}, this.configColumns || {}, this.formPresetColumns || {}, this.formColumns || {}, this.presetColumns || {}, this.columns || {});
  }
}
var XPe = {
  /**
   * General
   */
  env: "development",
  plugins: [],
  elements: [],
  /**
   * Theme & layout
   */
  theme: {},
  templates: {},
  views: {},
  size: "md",
  addClasses: {},
  removeClasses: {},
  replaceClasses: {},
  overrideClasses: {},
  presets: {},
  usePresets: [],
  classHelpers: !1,
  columns: {},
  forceLabels: !1,
  floatPlaceholders: !0,
  displayErrors: !0,
  displayMessages: !0,
  breakpoints: ["sm", "md", "lg", "xl", "2xl"],
  /**
   * Localization
   */
  languages: {
    en: "English"
  },
  language: "en",
  locales: {},
  locale: null,
  fallbackLocale: "en",
  /**
   * Sorting
   */
  orderFrom: 1,
  /**
   * Validation
   */
  rules: {},
  validateOn: "change|step",
  /**
   * Submitting
   */
  endpoints: {
    submit: {
      url: "/vueform/process",
      method: "post"
    },
    uploadTempFile: {
      url: "/vueform/file/upload-temp",
      method: "post"
    },
    removeTempFile: {
      url: "/vueform/file/remove-temp",
      method: "post"
    },
    removeFile: {
      url: "/vueform/file/remove",
      method: "post"
    },
    attachment: {
      url: "/vueform/editor/attachment",
      method: "post"
    },
    activeUrl: {
      url: "/vueform/validators/active_url",
      method: "post"
    },
    unique: {
      url: "/vueform/validators/unique",
      method: "post"
    },
    exists: {
      url: "/vueform/validators/exists",
      method: "post"
    }
  },
  formData(e) {
    return e.convertFormData(mt(mt({}, e.requestData), e.formKey ? {
      formKey: e.formKey
    } : {}));
  },
  beforeSend: null,
  axios: {},
  /**
   * Location
   */
  locationProvider: "google",
  services: {
    algolia: {
      app_id: "",
      api_key: ""
    }
  }
};
function c8() {
  var e = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : XPe, t = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : {}, n = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : {}, r = class {
    constructor() {
      this.options = {
        config: FM(e, ["theme", "templates", "locales", "rules", "plugins"]),
        templates: e.templates || {},
        components: e.components || {},
        theme: e.theme || {},
        rules: mt(mt({}, n), e.rules || {}),
        locales: e.locales || {},
        plugins: e.plugins || [],
        i18n: null,
        vueVersion: null,
        services: {
          validation: LPe,
          axios: Jr,
          messageBag: UPe,
          autosize: YPe,
          location: VPe,
          condition: KPe,
          columns: QPe
        },
        version: TMe.version
      };
    }
    config(i) {
      Te(["theme", "templates", "locales", "rules"], (a) => {
        i[a] !== void 0 && (this.options[a] = Object.assign({}, this.options[a], i[a]));
      }), Te(["plugins", "components"], (a) => {
        i[a] !== void 0 && (this.options[a] = i[a]);
      }), Te(["languages", "services", "addClasses", "removeClasses", "replaceClasses", "overrideClasses", "presets", "views"], (a) => {
        i[a] !== void 0 && (this.options.config[a] = Object.assign({}, this.options.config[a], i[a]));
      }), Te(["endpoints"], (a) => {
        i[a] !== void 0 && (this.options.config[a] = Ls({}, this.options.config[a], i[a]));
      }), Te(["columns", "forceLabels", "displayErrors", "floatPlaceholders", "displayErrors", "displayMessages", "language", "locale", "fallbackLocale", "orderFrom", "validateOn", "formData", "beforeSend", "locationProvider", "classHelpers", "env", "usePresets", "plugins", "size", "apiKey"], (a) => {
        i[a] !== void 0 && (this.options.config[a] = i[a]);
      }), i.elements && (i.elements.forEach((a) => {
        t[a.name] = FM(a, ["render", "staticRenderFns", "components"]);
      }), i.elements.forEach((a) => {
        this.options.templates[a.name] === void 0 && (this.options.templates[a.name] = H2e(a, ["render", "staticRenderFns", "components"]));
      })), i.axios !== void 0 && (typeof i.axios == "function" ? this.options.services.axios = i.axios : this.options.config.axios = i.axios);
    }
    registerComponents(i) {
      Te(t, (a, o) => {
        if (a.register !== !1) {
          var s = mt({}, a);
          if (s.setup = (c, d) => {
            d = Object.assign({}, d, {
              name: he(o),
              emits: s.emits
            });
            var f = a.setup(c, d);
            return this.options.plugins.forEach((h) => {
              typeof h == "function" && (h = h()), h = Array.isArray(h) ? h : [h], h.forEach((m) => {
                var v = typeof m == "function" ? m() : m;
                v.setup && $M(o, v) && (f = v.setup(c, d, f));
              });
            }), f;
          }, s.components === void 0) {
            var l, u;
            s.components = ((l = this.options.templates[o]) === null || l === void 0 ? void 0 : l.components) || ((u = this.options.theme.templates[o]) === null || u === void 0 ? void 0 : u.components) || {};
          }
          s.render = function() {
            return this.template.render.apply(this, arguments);
          }, s.staticRenderFns = function() {
            return this.template.staticRenderFns;
          }, this.options.plugins.forEach((c) => {
            typeof c == "function" && (c = c()), c = Array.isArray(c) ? c : [c], c.forEach((d) => {
              var f = typeof d == "function" ? d() : d;
              Te(rMe(Object.keys(f), "setup", "apply", "config", "install"), (h) => {
                if (f[h] && $M(o, f))
                  if (Array.isArray(f[h])) {
                    var m = s[h] || [];
                    s[h] = m.concat(f[h]);
                  } else jn(f[h]) ? s[h] = Object.assign({}, s[h] || {}, f[h]) : s[h] = f[h];
              });
            });
          }), i.component(o, s);
        }
      });
    }
    initAxios() {
      var i = this.options.services.axios, a = this.options.config.axios, o = iMe(this.options.config.axios);
      Object.keys(o).forEach((s) => {
        var l = o[s];
        ["onUnauthenticated"].indexOf(s) === -1 && s.indexOf("csrfRequest.") === -1 && Ru(i.defaults, s, l);
      }), i.interceptors.response.use((s) => s, (s) => s.response ? new Promise((l, u) => {
        var c = s.response, d = c.config;
        [401, 419].indexOf(s.response.status) !== -1 ? a.csrfRequest && !d.CSRF ? i.request(mt(mt({}, a.csrfRequest), {}, {
          CSRF: !0
        })).then(() => {
          l(i.request(mt(mt({}, d), {}, {
            CSRF: !0
          })));
        }).catch((f) => {
          u(f);
        }) : a.onUnauthenticated ? a.onUnauthenticated(d) : u(s) : u(s);
      }) : Promise.reject(s));
    }
    initI18n() {
      this.options.i18n = new jPe({
        locales: this.options.locales,
        locale: this.options.config.locale,
        fallbackLocale: this.options.config.fallbackLocale
      });
    }
    install(i) {
      var a, o = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : {}, s = parseInt(i.version.split(".")[0]), l = parseInt(i.version.split(".")[1]);
      this.options.vueVersion = s;
      var u = o.plugins || [];
      u.forEach((f) => {
        typeof f == "function" && (f = f()), f = Array.isArray(f) ? f : [f], f.forEach((h) => {
          var m = typeof h == "function" ? h() : h;
          m.config && m.config(o);
        });
      }), o && this.config(o), this.options.plugins.forEach((f) => {
        typeof f == "function" && (f = f()), f = Array.isArray(f) ? f : [f], f.forEach((h) => {
          var m = typeof h == "function" ? h() : h;
          m.install && m.install(i, this.options);
        });
      }), typeof e.axios != "function" && this.initAxios(), this.initI18n(), Object.keys(this.options.components).forEach((f) => {
        t[f] = this.options.components[f];
      }), this.registerComponents(i);
      var c = ((a = this.options.theme) === null || a === void 0 ? void 0 : a.templates) || {};
      Object.keys(c).forEach((f) => {
        c[f] = Ll(c[f]);
      });
      var d = he(mt(mt({}, this.options), {}, {
        theme: mt(mt({}, this.options.theme), {}, {
          templates: c
        })
      }));
      switch (s) {
        case 2:
          i.config.ignoredElements = ["trix-editor"], i.config.unwrapInjectedRef = !0, i.prototype.$vueform || (i.prototype.$vueform = new Proxy(d, {
            get: (f, h, m) => f.value[h]
          })), i.__VUEFORM__ || (i.__VUEFORM__ = !0, i.mixin({
            methods: {
              __: (f, h) => (h || console.warn("DEPRECATED: __ method should be no longer used for translating labels, only if they contain variables. For general translation use form$.translation.TAG instead."), this.options.i18n.$t(f, h))
            }
          }));
          break;
        case 3:
          l < 3 && (i.config.unwrapInjectedRef = !0), i.config.globalProperties.$vueform = new Proxy(d, {
            get: (f, h, m) => f.value[h]
          }), i.provide("$vueform", d), i.mixin({
            methods: {
              $set(f, h, m) {
                f[h] = m;
              },
              $delete(f, h) {
                delete f[h];
              },
              __: (f, h) => (h || console.warn("DEPRECATED: __ method should be no longer used for translating labels, only if they contain variables. For general translation use form$.translation.TAG instead."), this.options.i18n.$t(f, h))
            }
          });
          break;
      }
    }
  };
  return new r();
}
var Hn = function(t, n, r) {
  var i = En("form$");
  return {
    form$: i
  };
}, zn = function(t, n, r) {
  var i = En("theme");
  return {
    theme: i
  };
}, d8 = function(t, n, r) {
  var i = En("Size");
  return {
    Size: i
  };
}, f8 = function(t, n, r) {
  var {
    view: i
  } = De(t), a = n.name, o = En("Views") || he({}), s = En("View", he(void 0)), l = N(() => i && i.value ? i.value : o.value[a.value] ? o.value[a.value] : s.value);
  return {
    View: l
  };
}, xo = function(t, n, r) {
  var i = n.name, {
    form$: a
  } = Hn(), {
    theme: o
  } = zn(), {
    Size: s
  } = d8(), {
    View: l
  } = f8(t, n), u = N(() => fi().proxy), c = N(() => new Pv({
    component: i.value,
    component$: u,
    theme: o.value,
    config: a.value.$vueform.config,
    templates: f.value,
    view: l.value,
    merge: [a.value.options]
  })), d = N(() => c.value.classes), f = N(() => o.value.templates), h = N(() => l.value && f.value["".concat(i.value, "_").concat(l.value)] ? f.value["".concat(i.value, "_").concat(l.value)] : f.value[i.value]);
  return {
    form$: a,
    theme: o,
    Size: s,
    View: l,
    classesInstance: c,
    classes: d,
    Templates: f,
    template: h
  };
}, p8 = {
  name: "FormErrors",
  props: {
    view: {
      required: !1,
      type: [String],
      default: void 0
    }
  },
  setup(e, t) {
    var {
      form$: n,
      Size: r,
      View: i,
      classesInstance: a,
      theme: o,
      classes: s,
      Templates: l,
      template: u
    } = xo(e, t), c = N(() => n.value.formErrors);
    return {
      form$: n,
      Size: r,
      View: i,
      classesInstance: a,
      theme: o,
      classes: s,
      Templates: l,
      template: u,
      errors: c
    };
  }
}, m8 = {
  name: "FormMessages",
  props: {
    view: {
      required: !1,
      type: [String],
      default: void 0
    }
  },
  setup(e, t) {
    var {
      form$: n,
      Size: r,
      View: i,
      classesInstance: a,
      theme: o,
      classes: s,
      Templates: l,
      template: u
    } = xo(e, t), c = N(() => n.value.formMessages);
    return {
      form$: n,
      Size: r,
      View: i,
      classesInstance: a,
      theme: o,
      classes: s,
      Templates: l,
      template: u,
      messages: c
    };
  }
}, h8 = {
  name: "FormLanguages",
  props: {
    view: {
      required: !1,
      type: [String],
      default: void 0
    }
  },
  setup(e, t) {
    var {
      form$: n,
      Size: r,
      View: i,
      classesInstance: a,
      theme: o,
      classes: s,
      Templates: l,
      template: u
    } = xo(e, t), c = N(() => n.value.selectedLanguage), d = N(() => n.value.options.languages), f = (m) => {
      n.value.setLanguage(m);
    }, h = (m) => {
      f(m);
    };
    return aa("View", i), {
      form$: n,
      Size: r,
      View: i,
      classesInstance: a,
      theme: o,
      classes: s,
      Templates: l,
      template: u,
      language: c,
      languages: d,
      select: f,
      handleSelect: h
    };
  }
}, g8 = {
  name: "FormLanguage",
  emits: ["select"],
  props: {
    language: {
      type: String,
      required: !0
    },
    code: {
      type: String,
      required: !0
    },
    view: {
      required: !1,
      type: [String],
      default: void 0
    }
  },
  setup(e, t) {
    var {
      code: n
    } = De(e), {
      form$: r,
      Size: i,
      View: a,
      classesInstance: o,
      theme: s,
      classes: l,
      Templates: u,
      template: c
    } = xo(e, t), d = N(() => r.value.selectedLanguage), f = N(() => d.value == n.value), h = () => {
      t.emit("select", n.value);
    };
    return {
      form$: r,
      Size: i,
      View: a,
      classesInstance: o,
      theme: s,
      selectedLanguage: d,
      selected: f,
      classes: l,
      Templates: u,
      template: c,
      select: h
    };
  }
}, ZPe = Qs, JPe = js, eFe = si;
function tFe(e) {
  return function(t, n, r) {
    var i = Object(t);
    if (!JPe(t)) {
      var a = ZPe(n);
      t = eFe(t), n = function(s) {
        return a(i[s], s, i);
      };
    }
    var o = e(t, n, r);
    return o > -1 ? i[a ? t[o] : o] : void 0;
  };
}
var _8 = tFe, nFe = QA, rFe = Qs, iFe = Nm, aFe = Math.max;
function oFe(e, t, n) {
  var r = e == null ? 0 : e.length;
  if (!r)
    return -1;
  var i = n == null ? 0 : iFe(n);
  return i < 0 && (i = aFe(r + i, 0)), nFe(e, rFe(t), i);
}
var sFe = oFe, lFe = _8, uFe = sFe, cFe = lFe(uFe), go = cFe, dFe = QA, fFe = Qs, pFe = Nm, mFe = Math.max, hFe = Math.min;
function gFe(e, t, n) {
  var r = e == null ? 0 : e.length;
  if (!r)
    return -1;
  var i = r - 1;
  return n !== void 0 && (i = pFe(n), i = n < 0 ? mFe(r + i, 0) : hFe(i, r - 1)), dFe(e, fFe(t), i, !0);
}
var _Fe = gFe, vFe = _8, bFe = _Fe, EFe = vFe(bFe), Sg = EFe, v8 = {
  name: "FormTabs",
  emits: ["select"],
  props: {
    view: {
      required: !1,
      type: [String],
      default: void 0
    }
  },
  setup(e, t) {
    var n = fi().proxy, {
      form$: r,
      Size: i,
      View: a,
      classesInstance: o,
      theme: s,
      classes: l,
      Templates: u,
      template: c
    } = xo(e, t), {
      events: d,
      listeners: f,
      on: h,
      off: m,
      fire: v
    } = Mn(e, t, {
      form$: r
    }, {
      events: t.emits
    }), b = he([]), y = he(!0), g = N(() => r.value.elements$), E = N(() => r.value.options.tabs), S = N(() => {
      var k = {};
      return Te(b.value, (B) => {
        k[B.name] = B;
      }), k;
    }), C = N(() => {
      var k = {};
      return Te(S.value, (B) => {
        B.visible && (k[B.name] = B);
      }), k;
    }), T = N(() => {
      var k = go(S.value, {
        active: !0
      });
      return k !== void 0 ? k : {};
    }), O = N(() => go(C.value, (k) => k.visible)), R = N(() => Object.values(C.value).pop()), D = N(() => go(C.value, (k) => k.index > T.value.index && k.visible)), q = N(() => Sg(C.value, (k) => k.index < T.value.index && k.visible)), $ = (k) => {
      var B = C.value[k];
      B.select();
    }, P = (k) => {
      var B = T.value;
      Te(g.value, (W) => {
        W.deactivate();
      }), Te(S.value, (W) => {
        W.deactivate();
      }), v("select", k, B);
    }, Y = (k) => go(S.value, {
      name: k
    }), L = () => {
      O.value.select();
    }, x = (k, B) => {
      k.tabs$ !== void 0 ? r.value.$set(k, "tabs$", n) : B(k.$parent, B);
    }, I = (k, B) => {
      k.tabs$ !== void 0 ? r.value.$set(k, "tabs$", null) : B(k.$parent, B);
    };
    return aa("View", a), et(g, (k, B) => {
      var W = XA(si(k), si(B));
      Te(W, (Z) => {
        g.value[Z].deactivate();
      });
    }, {
      deep: !1,
      lazy: !0
    }), et(E, /* @__PURE__ */ ht(function* () {
      yield Ut(), yield Ut(), (T.value === void 0 || T.value.index === void 0) && O.value && O.value.select();
    }), {
      deep: !0,
      lazy: !0
    }), et(E, (k) => {
      var B = [];
      Te(k, (W, Z) => {
        B.push(b.value[b.value.map((V) => Ur(V.name)).indexOf(Ur(Z))]);
      }), b.value = B;
    }, {
      flush: "post"
    }), Gu(() => {
      x(n.$parent, x);
    }), pa(() => {
      I(n.$parent, I);
    }), On(() => {
      Ut(() => {
        go(S.value, {
          active: !0
        }) || O.value.select();
      });
    }), {
      form$: r,
      Size: i,
      View: a,
      classesInstance: o,
      theme: s,
      tabs: E,
      elements$: g,
      tabs$Array: b,
      events: d,
      listeners: f,
      exists: y,
      classes: l,
      Templates: u,
      template: c,
      tabs$: S,
      visible$: C,
      current$: T,
      first$: O,
      last$: R,
      next$: D,
      previous$: q,
      goTo: $,
      select: P,
      tab$: Y,
      reset: L,
      on: h,
      off: m,
      fire: v
    };
  }
}, Qn = function(t, n, r) {
  var {
    parent: i,
    conditions: a
  } = De(t), o = r.form$, s = r.path || he(null), l = r.el$ || he(void 0), u = he(a.value), c = he({}), d = N(() => o.value.conditions ? i && i.value && i.value.available !== void 0 && !i.value.available ? !1 : !u.value || !u.value.length ? !0 : !hn(u.value, (v) => !o.value.$vueform.services.condition.check(v, s.value, o.value, l.value)) : !0), f = () => {
    u.value = Object.values(c.value).reduce((v, b) => v.concat(b), a.value);
  }, h = (v, b) => {
    c.value[v] = b, f();
  }, m = (v) => {
    delete c.value[v], f();
  };
  return {
    conditionList: u,
    available: d,
    additionalConditions: c,
    updateConditions: f,
    addConditions: h,
    removeConditions: m
  };
}, ZA = function(t, n, r) {
  var {
    conditionList: i,
    available: a,
    additionalConditions: o,
    addConditions: s,
    removeConditions: l
  } = Qn(t, n, r), {
    conditions: u
  } = De(t), c = r.children$Array, d = () => {
    i.value = Object.values(o.value).reduce((f, h) => f.concat(h), u.value), c.value.forEach((f) => {
      f.updateConditions();
    });
  };
  return {
    conditionList: i,
    available: a,
    updateConditions: d,
    addConditions: s,
    removeConditions: l
  };
}, SFe = ZA, yFe = ZA, {
  hasOwnProperty: w7e,
  toString: TFe
} = Object.prototype;
function WM(e) {
  return typeof e == "string" && e.trim().length > 0;
}
function CFe(e) {
  return typeof e == "function";
}
function AFe(e) {
  return Array.isArray(e) && e.length > 0;
}
function OFe(e) {
  return !!e;
}
function RFe(e) {
  return OFe(e) && e.nodeType === 1 && TFe.call(e).indexOf("Element") > -1;
}
function Gp(e) {
  return jn(e) && (WM(e.template) || CFe(e.render) || WM(e.el) || RFe(e.el) || Gp(e.extends) || AFe(e.mixins) && e.mixins.some((t) => Gp(t))) || typeof e == "function" && e.prototype && e.prototype.constructor.name === "VueComponent";
}
function oi(e, t, n) {
  var r = n.locale$ || t.i18n.locale;
  return r && e && typeof e == "object" ? (e == null ? void 0 : e[r]) || (e == null ? void 0 : e[r.toUpperCase()]) || (e == null ? void 0 : e[t.i18n.fallbackLocale]) || (e == null ? void 0 : e[t.i18n.fallbackLocale.toUpperCase()]) || (e == null ? void 0 : e[Object.keys(e)[0]]) || "" : e;
}
var $v = function(t, n, r) {
  var i = r.labelDefinition, a = r.component$ || he(null), o = En("form$"), s = En("config$"), l = N(() => i.value), u = N(() => typeof l.value == "function" && (!l.value.prototype || !l.value.prototype.constructor || l.value.prototype.constructor && l.value.prototype.constructor.name !== "VueComponent")), c = N(() => Gp(l.value)), d = N(() => {
    var f = u.value ? l.value(a.value) : l.value || null;
    return c.value || (f = oi(f, s.value, o.value)), f;
  });
  return {
    label: d,
    isLabelComponent: c
  };
}, b8 = {
  name: "FormTab",
  emits: ["activate", "inactivate"],
  slots: ["default"],
  props: {
    /**
     * Name of tab within [tabs](reference/frontend-form#prop-tabs) object.
     */
    name: {
      type: [String, Number],
      required: !0
    },
    label: {
      type: [String, Object, Function],
      required: !1,
      default: null
    },
    elements: {
      type: [Array],
      required: !1,
      default: () => []
    },
    conditions: {
      type: [Array],
      required: !1,
      default: () => []
    },
    addClass: {
      required: !1,
      type: [Array, Object, String],
      default: null
    },
    removeClass: {
      required: !1,
      type: [Array, Object],
      default: null
    },
    replaceClass: {
      required: !1,
      type: [Object],
      default: null
    },
    overrideClass: {
      required: !1,
      type: [Array, Object, String],
      default: null
    },
    view: {
      required: !1,
      type: [String],
      default: void 0
    },
    onActivate: {
      type: [Function],
      required: !1,
      default: null,
      private: !0
    },
    onInactivate: {
      type: [Function],
      required: !1,
      default: null,
      private: !0
    }
  },
  setup(e, t) {
    var {
      name: n,
      label: r,
      elements: i
    } = De(e), a = fi().proxy, {
      form$: o,
      Size: s,
      View: l,
      classesInstance: u,
      theme: c,
      classes: d,
      Templates: f,
      template: h
    } = xo(e, t), {
      available: m,
      conditionList: v,
      updateConditions: b
    } = Qn(e, t, {
      form$: o
    }), {
      isLabelComponent: y,
      label: g
    } = $v(e, t, {
      component$: o,
      labelDefinition: r
    }), {
      events: E,
      listeners: S,
      on: C,
      off: T,
      fire: O
    } = Mn(e, t, {
      form$: o
    }, {
      events: t.emits
    }), R = he(!1), D = he(g.value && typeof g.value == "object" ? Ll(g.value) : g.value), q = N(() => o.value.elements$), $ = N(() => o.value.tabs$), P = N(() => {
      var pe;
      return Object.keys(($ == null || (pe = $.value) === null || pe === void 0 ? void 0 : pe.tabs$) || /* istanbul ignore next: tab can not stand by itself */
      {}).indexOf(n.value);
    }), Y = N(() => P.value === 0), L = N(() => $.value.last$.name === n.value), x = N(() => KA(q.value, (pe, Se) => i.value.indexOf(Se) !== -1)), I = N(() => m.value), k = N(() => hn(x.value, {
      available: !0,
      invalid: !0
    })), B = N(() => o.value.tabs$.tabs$[n.value]), W = () => {
      var pe, Se;
      R.value || !((pe = $.value) !== null && pe !== void 0 && pe.select) || ((Se = $.value) === null || Se === void 0 || Se.select(B.value), Z());
    }, Z = () => {
      R.value || (R.value = !0, Te(x.value, (pe) => {
        pe.activate();
      }), O("activate"));
    }, V = () => {
      R.value && (R.value = !1, Te(x.value, (pe) => {
        pe.deactivate();
      }), O("inactivate"));
    }, K = () => {
      v.value.length != 0 && Object.values(x.value).forEach((pe) => {
        pe.addConditions("tab", v.value);
      });
    }, ne = () => {
      Object.values(x.value).forEach((pe) => {
        pe.removeConditions("tab");
      });
    }, Ee = () => {
      ne(), K();
    }, oe = (pe, Se) => {
      pe.tabs$Array ? pe.tabs$Array.push(a) : Se(pe.$parent, Se);
    }, ae = (pe, Se) => {
      pe.tabs$Array ? pe.tabs$Array.splice(pe.tabs$Array.map((Re) => Ur(Re.name)).indexOf(Ur(n.value)), 1) : Se(pe.$parent, Se);
    };
    return et(x, () => {
      R.value && Te(x.value, (pe) => {
        pe.activate();
      });
    }, {
      deep: !1,
      lazy: !0
    }), et(g, () => {
      D.value = g.value && typeof g.value == "object" ? Ll(g.value) : g.value;
    }), et(v, (pe, Se) => {
      pe != null && pe.length ? K() : ne();
    }), On(() => {
      Ut(() => {
        K();
      });
    }), Gu(() => {
      oe(a.$parent, oe);
    }), pa(() => {
      ne(), ae(a.$parent, ae);
    }), {
      form$: o,
      Size: s,
      View: l,
      classesInstance: u,
      theme: c,
      elements$: q,
      index: P,
      isFirst: Y,
      isLast: L,
      active: R,
      events: E,
      listeners: S,
      children$: x,
      visible: I,
      invalid: k,
      classes: d,
      Templates: f,
      template: h,
      available: m,
      isLabelComponent: y,
      tabLabel: D,
      tab$: B,
      tabs$: $,
      conditionList: v,
      select: W,
      activate: Z,
      deactivate: V,
      on: C,
      off: T,
      fire: O,
      addChildConditions: K,
      removeChildConditions: ne,
      resetChildConditions: Ee,
      updateConditions: b
    };
  }
}, E8 = {
  name: "FormSteps",
  emits: ["select", "next", "previous", "finish"],
  props: {
    view: {
      required: !1,
      type: [String],
      default: void 0
    }
  },
  setup(e, t) {
    var n = fi().proxy, {
      form$: r,
      Size: i,
      View: a,
      classesInstance: o,
      theme: s,
      classes: l,
      Templates: u,
      template: c
    } = xo(e, t), {
      events: d,
      listeners: f,
      on: h,
      off: m,
      fire: v
    } = Mn(e, t, {
      form$: r
    }, {
      events: t.emits
    }), b = he([]), y = he(null), g = he(!0), E = N(() => r.value.options.steps), S = N(() => r.value.elements$), C = N(() => hn($.value, {
      pending: !0
    })), T = N(() => hn($.value, {
      debouncing: !0
    })), O = N(() => hn($.value, {
      invalid: !0
    })), R = N(() => !hn($.value, {
      done: !1
    })), D = N(() => C.value || T.value), q = N(() => {
      var We = {};
      return Te(b.value, (st) => {
        We[st.name] = st;
      }), We;
    }), $ = N(() => {
      var We = {};
      return Te(q.value, (st) => {
        st.visible && (We[st.name] = st);
      }), We;
    }), P = N(() => go($.value, (We) => We.visible)), Y = N(() => Object.values($.value).pop()), L = N(() => {
      var We = go(q.value, {
        active: !0
      });
      return We !== void 0 ? We : {};
    }), x = N(() => go($.value, (We) => We.index > L.value.index && We.visible)), I = N(() => Sg($.value, (We) => We.index < L.value.index && We.visible)), k = N(() => go($.value, {
      invalid: !0
    })), B = N(() => go($.value, {
      done: !1
    })), W = N(() => Sg($.value, {
      isDisabled: !1
    })), Z = N(() => {
      var We = Sg($.value, {
        visible: !0
      });
      return !L.value || !We ? !1 : We.index === L.value.index;
    }), V = N(() => L.value.index === 0), K = function(st) {
      var Pt = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : !1, Ke = $.value[st];
      Ke.enable(), Ke.select(), Pt && Ut(() => {
        Tt();
      });
    }, ne = () => {
      v("next", x.value), x.value.enable(), x.value.select();
    }, Ee = () => {
      v("previous", I.value), I.value.select();
    }, oe = () => {
      Te(q.value, (We) => {
        We.complete();
      });
    }, ae = (We) => go($.value, {
      name: We
    }), pe = () => {
      Te(q.value, (We) => {
        We.uncomplete(), We.disable();
      }), P.value.enable(), P.value.select();
    }, Se = () => {
      Te(q.value, (We) => {
        We.enable();
      });
    }, Re = /* @__PURE__ */ function() {
      var We = ht(function* () {
        if (yield r.value.submit(), O.value) {
          k.value.select();
          return;
        }
        y.value = et(O, (st) => {
          st && k.value.select(), y.value();
        });
      });
      return function() {
        return We.apply(this, arguments);
      };
    }(), Ye = (We) => {
      var st = L.value;
      Te(S.value, (Pt) => {
        Pt.deactivate();
      }), Te(q.value, (Pt) => {
        Pt.deactivate();
      }), v("select", We, st);
    }, nt = (We) => {
      Te(q.value, (st) => {
        st.index <= We && st.visible && st.enable();
      });
    }, ut = () => {
      nt(L.value.index);
    }, Tt = () => {
      !W.value && !P.value || nt(W.value !== void 0 ? W.value.index : P.value.index);
    }, Ot = (We, st) => {
      We.steps$ !== void 0 ? r.value.$set(We, "steps$", n) : st(We.$parent, st);
    }, Xt = (We, st) => {
      We.steps$ !== void 0 ? r.value.$set(We, "steps$", null) : st(We.$parent, st);
    };
    return aa("View", a), et(S, (We, st) => {
      var Pt = XA(si(We), si(st));
      Te(Pt, (Ke) => {
        S.value[Ke].deactivate();
      });
    }, {
      deep: !1,
      lazy: !0
    }), et(E, () => {
      Ut(() => {
        W.value, L.value.index === void 0 && P.value && P.value.select();
      });
    }, {
      deep: !0,
      lazy: !0
    }), et(E, (We) => {
      var st = [];
      Te(We, (Pt, Ke) => {
        st.push(b.value[b.value.map((Je) => Ur(Je.name)).indexOf(Ur(Ke))]);
      }), b.value = st;
    }, {
      flush: "post"
    }), Gu(() => {
      Ot(n.$parent, Ot);
    }), pa(() => {
      Xt(n.$parent, Xt);
    }), On(() => {
      Ut(() => {
        (L.value === void 0 || L.value.index === void 0) && (P.value.enable(), P.value.select()), ut(), et($, () => {
          Tt();
        }, {
          flush: "post"
        });
      });
    }), {
      form$: r,
      Size: i,
      View: a,
      classesInstance: o,
      theme: s,
      steps: E,
      elements$: S,
      steps$Array: b,
      events: d,
      listeners: f,
      exists: g,
      classes: l,
      Templates: u,
      template: c,
      steps$: q,
      pending: C,
      debouncing: T,
      invalid: O,
      done: R,
      busy: D,
      visible$: $,
      first$: P,
      last$: Y,
      current$: L,
      next$: x,
      previous$: I,
      firstInvalid$: k,
      firstNonDone$: B,
      lastEnabled$: W,
      isAtLastStep: Z,
      isAtFirstStep: V,
      goTo: K,
      next: ne,
      previous: Ee,
      complete: oe,
      step$: ae,
      reset: pe,
      enableAllSteps: Se,
      submit: Re,
      select: Ye,
      enableUntil: nt,
      enableUntilCurrent: ut,
      enableUntilLastEnabled: Tt,
      on: h,
      off: m,
      fire: v
    };
  }
}, S8 = {
  name: "FormStepsControls",
  slots: ["previous", "next", "finish"],
  props: {
    labels: {
      type: Boolean,
      required: !1,
      default: !0
    },
    view: {
      required: !1,
      type: [String],
      default: void 0
    }
  },
  setup(e, t) {
    var {
      form$: n,
      Size: r,
      View: i,
      classesInstance: a,
      theme: o,
      classes: s,
      Templates: l,
      template: u
    } = xo(e, t);
    return aa("View", i), {
      form$: n,
      Size: r,
      View: i,
      classesInstance: a,
      theme: o,
      classes: s,
      Templates: l,
      template: u
    };
  }
}, y8 = {
  name: "FormStepsControl",
  slots: ["default"],
  props: {
    type: {
      type: [String],
      required: !0
    },
    labels: {
      type: [Boolean],
      required: !1,
      default: !0,
      private: !0
    },
    view: {
      required: !1,
      type: [String],
      default: void 0
    }
  },
  setup(e, t) {
    var {
      type: n,
      labels: r
    } = De(e), {
      form$: i,
      Size: a,
      View: o,
      classesInstance: s,
      theme: l,
      classes: u,
      Templates: c,
      template: d
    } = xo(e, t), f = N(() => {
      if (!r.value)
        return null;
      var R = b && b.value ? b.value.labels : (
        /* istanbul ignore next: failsafe only */
        null
      );
      switch (n.value) {
        case "previous":
          return R && R.previous ? R.previous : i.value.translations.vueform.steps.previous;
        case "next":
          return R && R.next ? R.next : i.value.translations.vueform.steps.next;
        case "finish":
          return R && R.finish ? R.finish : R && R.next ? R.next : i.value.translations.vueform.steps.finish;
      }
    }), {
      isLabelComponent: h,
      label: m
    } = $v(e, t, {
      component$: i,
      labelDefinition: f
    }), v = N(() => i.value.steps$), b = N(() => v.value ? v.value.current$ : (
      /* istanbul ignore next: failsafe only */
      void 0
    )), y = N(() => {
      var R = b && b.value ? b.value.buttons : (
        /* istanbul ignore next: failsafe only */
        null
      );
      switch (n.value) {
        case "previous":
          return R ? R.previous !== !1 : !0;
        case "next":
          return v.value && !v.value.isAtLastStep && (!R || R.next !== !1);
        case "finish":
          return v.value && v.value.isAtLastStep;
      }
    }), g = N(() => {
      switch (n.value) {
        case "previous":
          return v.value && v.value.isAtFirstStep;
        case "next":
          return b.value !== void 0 && b.value.index !== void 0 && // only disable next because of invalidity
          // if element validations are triggered on
          // change, otherwise it might occur that the
          // step has invalid fields, which values have
          // changed to valid, but still marked as invalid
          (b.value.invalid && i.value.shouldValidateOnChange || b.value.busy || i.value.isLoading);
        case "finish":
          return v.value.invalid && i.value.shouldValidateOnChange || v.value.busy || i.value.submitting || i.value.isDisabled || i.value.isLoading;
      }
    }), E = N(() => n.value === "previous" ? !1 : i.value.isLoading || i.value.submitting), S = () => {
      v.value.previous();
    }, C = /* @__PURE__ */ function() {
      var R = ht(function* () {
        i.value.shouldValidateOnStep && (yield b.value.validate()), !b.value.invalid && (b.value.complete(), v.value.next());
      });
      return function() {
        return R.apply(this, arguments);
      };
    }(), T = /* @__PURE__ */ function() {
      var R = ht(function* () {
        v.value.fire("finish"), v.value.complete(), v.value.submit();
      });
      return function() {
        return R.apply(this, arguments);
      };
    }(), O = (R) => {
      switch (n.value) {
        case "previous":
          S();
          break;
        case "next":
          C(), (R.key === "Enter" || R.key === " ") && Ut(() => {
            Ut(() => {
              var D, q = b == null || (D = b.value.children$) === null || D === void 0 ? void 0 : D.find(($) => {
                var P;
                return $.name === (b == null || (P = b.value.elements) === null || P === void 0 ? void 0 : P[0]);
              });
              q && q.focus();
            });
          });
          break;
        case "finish":
          T();
          break;
      }
    };
    return {
      form$: i,
      Size: a,
      View: o,
      classesInstance: s,
      theme: l,
      steps$: v,
      classes: u,
      Templates: c,
      template: d,
      visible: y,
      isDisabled: g,
      isLoading: E,
      current$: b,
      label: m,
      isLabelComponent: h,
      previous: S,
      next: C,
      finish: T,
      handleClick: O
    };
  }
}, T8 = {
  name: "FormStep",
  emits: ["activate", "inactivate", "enable", "disable", "complete"],
  slots: ["default"],
  props: {
    name: {
      type: [String, Number],
      required: !0
    },
    label: {
      type: [String, Object, Function],
      required: !1,
      default: null
    },
    labels: {
      type: [Object],
      required: !1,
      default: () => ({})
    },
    buttons: {
      type: [Object],
      required: !1,
      default: () => ({})
    },
    elements: {
      type: [Array],
      required: !1,
      default: () => []
    },
    conditions: {
      type: [Array],
      required: !1,
      default: () => []
    },
    addClass: {
      required: !1,
      type: [Array, Object, String],
      default: null
    },
    removeClass: {
      required: !1,
      type: [Array, Object],
      default: null
    },
    replaceClass: {
      required: !1,
      type: [Object],
      default: null
    },
    overrideClass: {
      required: !1,
      type: [Array, Object, String],
      default: null
    },
    view: {
      required: !1,
      type: [String],
      default: void 0
    },
    onActivate: {
      type: [Function],
      required: !1,
      default: null,
      private: !0
    },
    onInactivate: {
      type: [Function],
      required: !1,
      default: null,
      private: !0
    },
    onDisable: {
      type: [Function],
      required: !1,
      default: null,
      private: !0
    },
    onEnable: {
      type: [Function],
      required: !1,
      default: null,
      private: !0
    }
  },
  setup(e, t) {
    var {
      name: n,
      label: r,
      elements: i
    } = De(e), a = fi().proxy, {
      form$: o,
      Size: s,
      View: l,
      classesInstance: u,
      theme: c,
      classes: d,
      Templates: f,
      template: h
    } = xo(e, t), {
      available: m,
      conditionList: v,
      updateConditions: b
    } = Qn(e, t, {
      form$: o
    }), {
      isLabelComponent: y,
      label: g
    } = $v(e, t, {
      component$: o,
      labelDefinition: r
    }), {
      events: E,
      listeners: S,
      on: C,
      off: T,
      fire: O
    } = Mn(e, t, {
      form$: o
    }, {
      events: t.emits
    }), R = he(g.value && typeof g.value == "object" ? Ll(g.value) : g.value), D = he(!1), q = he(!0), $ = he(!1), P = N(() => o.value.elements$), Y = N(() => o.value.steps$ || /* istanbul ignore next: failsafe only, step can not exist by itself */
    {}), L = N(() => r.value), x = N(() => {
      var Je;
      return Object.keys((Y == null || (Je = Y.value) === null || Je === void 0 ? void 0 : Je.steps$) || /* istanbul ignore next: failsafe only, step can not exist by itself */
      {}).indexOf(n.value);
    }), I = N(() => x.value === 0), k = N(() => Y.value.last$.name === n.value), B = N(() => KA(P.value, (Je, Be) => i.value.indexOf(Be) !== -1)), W = N(() => m.value), Z = N(() => hn(B.value, {
      available: !0,
      invalid: !0
    })), V = N(() => hn(B.value, {
      available: !0,
      pending: !0
    })), K = N(() => hn(B.value, {
      available: !0,
      debouncing: !0
    })), ne = N(() => !hn(B.value, {
      available: !0,
      validated: !1
    })), Ee = N(() => V.value || K.value), oe = N(() => $.value && ne.value && !Z.value && !V.value), ae = N(() => {
      var Je;
      return (Je = o.value.steps$) === null || Je === void 0 ? void 0 : Je.steps$[n.value];
    }), pe = /* @__PURE__ */ function() {
      var Je = ht(function* () {
        ne.value && !Z.value && o.value.shouldValidateOnChange || (yield ki(B.value, /* @__PURE__ */ function() {
          var Be = ht(function* (pt) {
            (!pt.validated || pt.invalid || !o.value.shouldValidateOnChange) && pt.available && !pt.isStatic && (yield pt.validate());
          });
          return function(pt) {
            return Be.apply(this, arguments);
          };
        }()));
      });
      return function() {
        return Je.apply(this, arguments);
      };
    }(), Se = () => {
      D.value || (D.value = !0, O("activate"));
    }, Re = () => {
      D.value && (D.value = !1, O("inactivate"));
    }, Ye = () => {
      q.value && (q.value = !1, O("enable"));
    }, nt = () => {
      q.value || (q.value = !0, O("disable"));
    }, ut = () => {
      $.value || ($.value = !0, O("complete"));
    }, Tt = () => {
      $.value = !1;
    }, Ot = () => {
      var Je, Be;
      q.value || !((Je = Y.value) !== null && Je !== void 0 && Je.select) || ((Be = Y.value) === null || Be === void 0 || Be.select(ae.value), Te(B.value, (pt) => {
        pt.activate();
      }), Se());
    }, Xt = () => {
      v.value.length != 0 && Object.values(B.value).forEach((Je) => {
        Je.addConditions("step", v.value);
      });
    }, We = () => {
      Object.values(B.value).forEach((Je) => {
        Je.removeConditions("step");
      });
    }, st = () => {
      We(), Xt();
    }, Pt = (Je, Be) => {
      Je.steps$Array ? Je.steps$Array.push(a) : Be(Je.$parent, Be);
    }, Ke = (Je, Be) => {
      Je.steps$Array ? Je.steps$Array.splice(Je.steps$Array.map((pt) => Ur(pt.name)).indexOf(Ur(n.value)), 1) : Be(Je.$parent, Be);
    };
    return et(W, (Je) => {
      Je && x.value < o.value.steps$.current$.index && Ye();
    }), et(B, () => {
      D.value && Te(B.value, (Je) => {
        Je.activate();
      });
    }, {
      deep: !1,
      lazy: !0
    }), et(g, () => {
      R.value = g.value && typeof g.value == "object" ? Ll(g.value) : g.value;
    }), et(v, (Je, Be) => {
      Je != null && Je.length ? Xt() : We();
    }), On(() => {
      Ut(() => {
        Xt();
      });
    }), Gu(() => {
      Pt(a.$parent, Pt);
    }), pa(() => {
      We(), Ke(a.$parent, Ke);
    }), {
      form$: o,
      Size: s,
      View: l,
      classesInstance: u,
      theme: c,
      steps$: Y,
      elements$: P,
      active: D,
      isDisabled: q,
      isFirst: I,
      isLast: k,
      completed: $,
      events: E,
      listeners: S,
      children$: B,
      visible: W,
      invalid: Z,
      pending: V,
      classes: d,
      Templates: f,
      template: h,
      available: m,
      baseLabel: L,
      debouncing: K,
      validated: ne,
      busy: Ee,
      done: oe,
      step$: ae,
      isLabelComponent: y,
      stepLabel: R,
      index: x,
      conditionList: v,
      validate: pe,
      activate: Se,
      deactivate: Re,
      enable: Ye,
      disable: nt,
      complete: ut,
      uncomplete: Tt,
      select: Ot,
      on: C,
      off: T,
      fire: O,
      addChildConditions: Xt,
      removeChildConditions: We,
      resetChildConditions: st,
      updateConditions: b
    };
  }
}, Lm = function(t, n, r) {
  var i = (a) => "".concat(Hd(p_(a.type)), "Element");
  return {
    component: i
  };
}, JA = {
  name: "FormElements",
  slots: ["default"],
  props: {
    view: {
      required: !1,
      type: [String],
      default: void 0
    }
  },
  setup(e, t) {
    var {
      form$: n,
      Size: r,
      View: i,
      classesInstance: a,
      theme: o,
      classes: s,
      Templates: l,
      template: u
    } = xo(e, t), {
      component: c
    } = Lm(), d = N(() => n.value.options.schema);
    return {
      form$: n,
      Size: r,
      View: i,
      classesInstance: a,
      theme: o,
      classes: s,
      Templates: l,
      template: u,
      schema: d,
      component: c
    };
  }
}, wFe = function(t, n, r) {
  var i = En("el$");
  return {
    el$: i
  };
}, bi = function(t, n, r) {
  var i = n.name, {
    form$: a
  } = Hn(), {
    el$: o
  } = wFe(), {
    theme: s
  } = zn(), {
    Size: l
  } = d8(), {
    View: u
  } = f8(t, n), c = N(() => fi().proxy), d = N(() => new Pv({
    component: i.value,
    component$: c,
    theme: s.value,
    config: a.value.$vueform.config,
    templates: h.value,
    view: u.value,
    merge: [a.value.options, o.value]
  })), f = N(() => d.value.classes), h = N(() => o.value.Templates), m = N(() => u.value && h.value["".concat(i.value, "_").concat(u.value)] ? h.value["".concat(i.value, "_").concat(u.value)] : h.value[i.value]);
  return {
    el$: o,
    form$: a,
    theme: s,
    Size: l,
    View: u,
    classesInstance: d,
    classes: f,
    Templates: h,
    template: m
  };
}, C8 = {
  name: "ElementLayout",
  slots: ["field", "label", "info", "description", "before", "between", "after"],
  props: {
    multiple: {
      type: [Boolean],
      required: !1,
      default: !1
    },
    view: {
      type: [String],
      required: !1,
      default: void 0
    }
  },
  setup(e, t) {
    var {
      form$: n,
      el$: r,
      Size: i,
      View: a,
      classesInstance: o,
      classes: s,
      Templates: l,
      template: u,
      theme: c
    } = bi(e, t), d = N(() => r.value.visible);
    return {
      el$: r,
      form$: n,
      Size: i,
      View: a,
      classesInstance: o,
      theme: c,
      Templates: l,
      template: u,
      classes: s,
      visible: d
    };
  }
}, A8 = {
  name: "ElementLayoutInline",
  slots: ["field", "label", "info", "description", "before", "between", "after"],
  setup(e, t) {
    var {
      form$: n,
      el$: r,
      Size: i,
      View: a,
      classesInstance: o,
      classes: s,
      Templates: l,
      template: u,
      theme: c
    } = bi(e, t), d = N(() => r.value.visible);
    return {
      el$: r,
      form$: n,
      Size: i,
      View: a,
      classesInstance: o,
      theme: c,
      Templates: l,
      template: u,
      classes: s,
      visible: d
      // hasLabel,
    };
  }
}, O8 = {
  name: "ElementLoader",
  setup(e, t) {
    var {
      el$: n,
      form$: r,
      Size: i,
      View: a,
      classesInstance: o,
      classes: s,
      Templates: l,
      template: u,
      theme: c
    } = bi(e, t);
    return {
      el$: n,
      form$: r,
      Size: i,
      View: a,
      classesInstance: o,
      theme: c,
      classes: s,
      Templates: l,
      template: u
    };
  }
}, R8 = {
  name: "ElementLabelFloating",
  props: {
    visible: {
      type: Boolean,
      default: !1
    }
  },
  setup(e, t) {
    var {
      el$: n,
      form$: r,
      Size: i,
      View: a,
      classesInstance: o,
      classes: s,
      Templates: l,
      template: u,
      theme: c
    } = bi(e, t), d = En("config$"), f = N(() => oi(n.value.floating || /* istanbul ignore next: tested, but not covered */
    (r.value.options.floatPlaceholders ? n.value.placeholder : null), d.value, r.value));
    return {
      el$: n,
      form$: r,
      Size: i,
      View: a,
      classesInstance: o,
      theme: c,
      classes: s,
      Templates: l,
      template: u,
      floating: f
    };
  }
}, w8 = {
  name: "ElementLabel",
  slots: ["default", "info"],
  setup(e, t) {
    var {
      el$: n,
      form$: r,
      Size: i,
      View: a,
      classesInstance: o,
      classes: s,
      Templates: l,
      template: u,
      theme: c
    } = bi(e, t), {
      label: d,
      isLabelComponent: f
    } = $v(e, t, {
      labelDefinition: N(() => n.value.label),
      component$: n
    }), h = N(() => n.value.fieldId), m = N(() => n.value.labelId), v = N(() => n.value.hasLabel), b = N(() => {
      var y, g, E;
      return !!((y = n.value.slots) !== null && y !== void 0 && y.label || (g = n.value.$slots) !== null && g !== void 0 && g.label || /* istanbul ignore next: Vue2 is not checked */
      r.value.$vueform.vueVersion === 2 && (E = n.value.$scopedSlots) !== null && E !== void 0 && E.label);
    });
    return {
      el$: n,
      form$: r,
      Size: i,
      View: a,
      classesInstance: o,
      theme: c,
      classes: s,
      Templates: l,
      template: u,
      label: d,
      isLabelComponent: f,
      name: h,
      id: m,
      hasLabel: v,
      isSlot: b
    };
  }
};
function jh(e) {
  var t = e.getBoundingClientRect();
  return t.top >= 0 && t.left >= 0 && t.bottom <= (window.innerHeight || document.documentElement.clientHeight) && t.right <= (window.innerWidth || document.documentElement.clientWidth);
}
var x8 = {
  name: "ElementInfo",
  slots: ["default"],
  setup(e, t) {
    var {
      el$: n,
      form$: r,
      Size: i,
      View: a,
      classesInstance: o,
      classes: s,
      Templates: l,
      template: u,
      theme: c
    } = bi(e, t), d = En("config$"), f = he(n.value.infoPosition), h = N(() => oi(n.value.info, d.value, r.value)), m = N(() => n.value.infoId), v = N(() => {
      var y, g, E;
      return !!((y = n.value.slots) !== null && y !== void 0 && y.info || (g = n.value.$slots) !== null && g !== void 0 && g.info || /* istanbul ignore next: Vue2 is not checked */
      r.value.$vueform.vueVersion === 2 && (E = n.value.$scopedSlots) !== null && E !== void 0 && E.info);
    }), b = /* @__PURE__ */ function() {
      var y = ht(function* (g) {
        if (f.value === n.value.infoPosition) {
          yield Ut();
          var E = g.target.querySelector("div");
          E && (jh(E) || (f.value = "right"), yield Ut(), jh(E) || (f.value = "top"), yield Ut(), jh(E) || (f.value = "left"), yield Ut(), jh(E) || (f.value = "bottom"));
        }
      });
      return function(E) {
        return y.apply(this, arguments);
      };
    }();
    return {
      el$: n,
      form$: r,
      Size: i,
      View: a,
      classesInstance: o,
      theme: c,
      classes: s,
      Templates: l,
      template: u,
      info: h,
      isSlot: v,
      position: f,
      id: m,
      handleMouseOver: b
    };
  }
}, N8 = {
  name: "ElementDescription",
  slots: ["default"],
  setup(e, t) {
    var {
      el$: n,
      form$: r,
      Size: i,
      View: a,
      classesInstance: o,
      classes: s,
      Templates: l,
      template: u,
      theme: c
    } = bi(e, t), d = En("config$"), f = N(() => oi(n.value.description, d.value, r.value)), h = N(() => n.value.descriptionId), m = N(() => {
      var v, b, y;
      return !!((v = n.value.slots) !== null && v !== void 0 && v.description || (b = n.value.$slots) !== null && b !== void 0 && b.description || /* istanbul ignore next: Vue2 is not checked */
      r.value.$vueform.vueVersion === 2 && (y = n.value.$scopedSlots) !== null && y !== void 0 && y.description);
    });
    return {
      el$: n,
      form$: r,
      Size: i,
      View: a,
      classesInstance: o,
      theme: c,
      classes: s,
      Templates: l,
      template: u,
      description: f,
      isSlot: m,
      id: h
    };
  }
}, D8 = {
  name: "ElementError",
  setup(e, t) {
    var {
      el$: n,
      form$: r,
      Size: i,
      View: a,
      classesInstance: o,
      classes: s,
      Templates: l,
      template: u,
      theme: c
    } = bi(e, t), d = N(() => n.value.error), f = N(() => n.value.errorId);
    return {
      el$: n,
      form$: r,
      Size: i,
      View: a,
      classesInstance: o,
      theme: c,
      classes: s,
      Templates: l,
      template: u,
      error: d,
      id: f
    };
  }
}, I8 = {
  name: "ElementMessage",
  setup(e, t) {
    var {
      el$: n,
      form$: r,
      Size: i,
      View: a,
      classesInstance: o,
      classes: s,
      Templates: l,
      template: u,
      theme: c
    } = bi(e, t), d = N(() => n.value.messageBag ? n.value.messageBag.message : (
      /* istanbul ignore next: messageBag itself will always be defined */
      null
    ));
    return {
      el$: n,
      form$: r,
      Size: i,
      View: a,
      classesInstance: o,
      theme: c,
      classes: s,
      Templates: l,
      template: u,
      message: d
    };
  }
}, L8 = {
  name: "ElementText",
  slots: ["default"],
  props: {
    type: {
      type: String,
      required: !0
    }
  },
  setup(e, t) {
    var {
      type: n
    } = De(e), {
      el$: r,
      form$: i,
      Size: a,
      View: o,
      classesInstance: s,
      classes: l,
      Templates: u,
      template: c,
      theme: d
    } = bi(e, t), f = En("config$"), h = N(() => oi(r.value[n.value], f.value, i.value)), m = N(() => {
      var v, b, y;
      return !!((v = r.value.slots) !== null && v !== void 0 && v[n.value] || (b = r.value.$slots) !== null && b !== void 0 && b[n.value] || /* istanbul ignore next: Vue2 is not checked */
      i.value.$vueform.vueVersion === 2 && (y = r.value.$scopedSlots) !== null && y !== void 0 && y[n.value]);
    });
    return {
      el$: r,
      form$: i,
      Size: a,
      View: o,
      classesInstance: s,
      theme: d,
      classes: l,
      Templates: u,
      template: c,
      content: h,
      isSlot: m
    };
  }
}, k8 = {
  name: "DragAndDrop",
  emits: ["click", "drop"],
  props: {
    title: {
      type: String,
      required: !0
    },
    description: {
      type: String,
      required: !0
    },
    disabled: {
      type: Boolean,
      required: !1,
      default: !1
    }
  },
  setup(e, t) {
    var {
      disabled: n
    } = De(e), {
      el$: r,
      form$: i,
      Size: a,
      View: o,
      classesInstance: s,
      classes: l,
      Templates: u,
      template: c,
      theme: d
    } = bi(e, t), f = he(!1), h = he(null), m = () => {
      t.emit("click");
    };
    return On(() => {
      Te(["drag", "dragstart", "dragend", "dragover", "dragenter", "dragleave", "drop"], (v) => {
        h.value.addEventListener(v, (b) => {
          b.preventDefault(), b.stopPropagation();
        });
      }), h.value.addEventListener("drop", (v) => {
        n.value || (t.emit("drop", v), f.value = !1);
      }), h.value.addEventListener("dragover", (v) => {
        n.value || f.value !== !0 && (f.value = !0);
      }), h.value.addEventListener("dragleave", (v) => {
        n.value || (f.value = !1);
      }), h.value.addEventListener("dragend", (v) => {
        n.value || (f.value = !1);
      });
    }), {
      el$: r,
      form$: i,
      Size: a,
      View: o,
      classesInstance: s,
      classes: l,
      Templates: u,
      template: c,
      theme: d,
      dragging: f,
      area: h,
      handleClick: m
    };
  }
}, M8 = {
  name: "ElementAddon",
  slots: ["default"],
  props: {
    type: {
      required: !0,
      type: String
    }
  },
  setup(e, t) {
    var {
      type: n
    } = De(e), {
      form$: r,
      el$: i,
      Size: a,
      View: o,
      classesInstance: s,
      classes: l,
      Templates: u,
      template: c,
      theme: d
    } = bi(e, t), f = En("config$"), h = N(() => i.value.addons[n.value]), m = N(() => {
      var g = v.value ? h.value(i.value) : h.value || /* istanbul ignore next: failsafe */
      null;
      return b.value || (g = oi(g, f.value, r.value)), g;
    }), v = N(() => typeof h.value == "function" && (!h.value.prototype || !h.value.prototype.constructor || h.value.prototype.constructor && h.value.prototype.constructor.name !== "VueComponent")), b = N(() => Gp(h.value)), y = N(() => {
      var g, E, S;
      return !!((g = i.value.slots) !== null && g !== void 0 && g["addon-".concat(n.value)] || (E = i.value.$slots) !== null && E !== void 0 && E["addon-".concat(n.value)] || /* istanbul ignore next: Vue2 is not checked */
      r.value.$vueform.vueVersion === 2 && (S = i.value.$scopedSlots) !== null && S !== void 0 && S["addon-".concat(n.value)] || /* istanbul ignore next */
      i.value.slots["addon-".concat(n.value)]);
    });
    return {
      el$: i,
      form$: r,
      theme: d,
      Size: a,
      View: o,
      classesInstance: s,
      Templates: u,
      template: c,
      classes: l,
      addon: m,
      isAddonComponent: b,
      isSlot: y
    };
  }
}, OT = [
  "onChange",
  "onClose",
  "onDayCreate",
  "onDestroy",
  "onKeyDown",
  "onMonthChange",
  "onOpen",
  "onParseConfig",
  "onReady",
  "onValueUpdate",
  "onYearChange",
  "onPreCalendarPosition"
], id = {
  _disable: [],
  allowInput: !1,
  allowInvalidPreload: !1,
  altFormat: "F j, Y",
  altInput: !1,
  altInputClass: "form-control input",
  animate: typeof window == "object" && window.navigator.userAgent.indexOf("MSIE") === -1,
  ariaDateFormat: "F j, Y",
  autoFillDefaultTime: !0,
  clickOpens: !0,
  closeOnSelect: !0,
  conjunction: ", ",
  dateFormat: "Y-m-d",
  defaultHour: 12,
  defaultMinute: 0,
  defaultSeconds: 0,
  disable: [],
  disableMobile: !1,
  enableSeconds: !1,
  enableTime: !1,
  errorHandler: function(e) {
    return typeof console < "u" && console.warn(e);
  },
  getWeek: function(e) {
    var t = new Date(e.getTime());
    t.setHours(0, 0, 0, 0), t.setDate(t.getDate() + 3 - (t.getDay() + 6) % 7);
    var n = new Date(t.getFullYear(), 0, 4);
    return 1 + Math.round(((t.getTime() - n.getTime()) / 864e5 - 3 + (n.getDay() + 6) % 7) / 7);
  },
  hourIncrement: 1,
  ignoredFocusElements: [],
  inline: !1,
  locale: "default",
  minuteIncrement: 5,
  mode: "single",
  monthSelectorType: "dropdown",
  nextArrow: "<svg version='1.1' xmlns='http://www.w3.org/2000/svg' xmlns:xlink='http://www.w3.org/1999/xlink' viewBox='0 0 17 17'><g></g><path d='M13.207 8.472l-7.854 7.854-0.707-0.707 7.146-7.146-7.146-7.148 0.707-0.707 7.854 7.854z' /></svg>",
  noCalendar: !1,
  now: /* @__PURE__ */ new Date(),
  onChange: [],
  onClose: [],
  onDayCreate: [],
  onDestroy: [],
  onKeyDown: [],
  onMonthChange: [],
  onOpen: [],
  onParseConfig: [],
  onReady: [],
  onValueUpdate: [],
  onYearChange: [],
  onPreCalendarPosition: [],
  plugins: [],
  position: "auto",
  positionElement: void 0,
  prevArrow: "<svg version='1.1' xmlns='http://www.w3.org/2000/svg' xmlns:xlink='http://www.w3.org/1999/xlink' viewBox='0 0 17 17'><g></g><path d='M5.207 8.471l7.146 7.147-0.707 0.707-7.853-7.854 7.854-7.853 0.707 0.707-7.147 7.146z' /></svg>",
  shorthandCurrentMonth: !1,
  showMonths: 1,
  static: !1,
  time_24hr: !1,
  weekNumbers: !1,
  wrap: !1
}, Yp = {
  weekdays: {
    shorthand: ["Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat"],
    longhand: [
      "Sunday",
      "Monday",
      "Tuesday",
      "Wednesday",
      "Thursday",
      "Friday",
      "Saturday"
    ]
  },
  months: {
    shorthand: [
      "Jan",
      "Feb",
      "Mar",
      "Apr",
      "May",
      "Jun",
      "Jul",
      "Aug",
      "Sep",
      "Oct",
      "Nov",
      "Dec"
    ],
    longhand: [
      "January",
      "February",
      "March",
      "April",
      "May",
      "June",
      "July",
      "August",
      "September",
      "October",
      "November",
      "December"
    ]
  },
  daysInMonth: [31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31],
  firstDayOfWeek: 0,
  ordinal: function(e) {
    var t = e % 100;
    if (t > 3 && t < 21)
      return "th";
    switch (t % 10) {
      case 1:
        return "st";
      case 2:
        return "nd";
      case 3:
        return "rd";
      default:
        return "th";
    }
  },
  rangeSeparator: " to ",
  weekAbbreviation: "Wk",
  scrollTitle: "Scroll to increment",
  toggleTitle: "Click to toggle",
  amPM: ["AM", "PM"],
  yearAriaLabel: "Year",
  monthAriaLabel: "Month",
  hourAriaLabel: "Hour",
  minuteAriaLabel: "Minute",
  time_24hr: !1
}, ia = function(e, t) {
  return t === void 0 && (t = 2), ("000" + e).slice(t * -1);
}, Wa = function(e) {
  return e === !0 ? 1 : 0;
};
function KM(e, t) {
  var n;
  return function() {
    var r = this, i = arguments;
    clearTimeout(n), n = setTimeout(function() {
      return e.apply(r, i);
    }, t);
  };
}
var RT = function(e) {
  return e instanceof Array ? e : [e];
};
function qi(e, t, n) {
  if (n === !0)
    return e.classList.add(t);
  e.classList.remove(t);
}
function Bn(e, t, n) {
  var r = window.document.createElement(e);
  return t = t || "", n = n || "", r.className = t, n !== void 0 && (r.textContent = n), r;
}
function Qh(e) {
  for (; e.firstChild; )
    e.removeChild(e.firstChild);
}
function P8(e, t) {
  if (t(e))
    return e;
  if (e.parentNode)
    return P8(e.parentNode, t);
}
function Xh(e, t) {
  var n = Bn("div", "numInputWrapper"), r = Bn("input", "numInput " + e), i = Bn("span", "arrowUp"), a = Bn("span", "arrowDown");
  if (navigator.userAgent.indexOf("MSIE 9.0") === -1 ? r.type = "number" : (r.type = "text", r.pattern = "\\d*"), t !== void 0)
    for (var o in t)
      r.setAttribute(o, t[o]);
  return n.appendChild(r), n.appendChild(i), n.appendChild(a), n;
}
function ya(e) {
  try {
    if (typeof e.composedPath == "function") {
      var t = e.composedPath();
      return t[0];
    }
    return e.target;
  } catch {
    return e.target;
  }
}
var wT = function() {
}, g_ = function(e, t, n) {
  return n.months[t ? "shorthand" : "longhand"][e];
}, xFe = {
  D: wT,
  F: function(e, t, n) {
    e.setMonth(n.months.longhand.indexOf(t));
  },
  G: function(e, t) {
    e.setHours((e.getHours() >= 12 ? 12 : 0) + parseFloat(t));
  },
  H: function(e, t) {
    e.setHours(parseFloat(t));
  },
  J: function(e, t) {
    e.setDate(parseFloat(t));
  },
  K: function(e, t, n) {
    e.setHours(e.getHours() % 12 + 12 * Wa(new RegExp(n.amPM[1], "i").test(t)));
  },
  M: function(e, t, n) {
    e.setMonth(n.months.shorthand.indexOf(t));
  },
  S: function(e, t) {
    e.setSeconds(parseFloat(t));
  },
  U: function(e, t) {
    return new Date(parseFloat(t) * 1e3);
  },
  W: function(e, t, n) {
    var r = parseInt(t), i = new Date(e.getFullYear(), 0, 2 + (r - 1) * 7, 0, 0, 0, 0);
    return i.setDate(i.getDate() - i.getDay() + n.firstDayOfWeek), i;
  },
  Y: function(e, t) {
    e.setFullYear(parseFloat(t));
  },
  Z: function(e, t) {
    return new Date(t);
  },
  d: function(e, t) {
    e.setDate(parseFloat(t));
  },
  h: function(e, t) {
    e.setHours((e.getHours() >= 12 ? 12 : 0) + parseFloat(t));
  },
  i: function(e, t) {
    e.setMinutes(parseFloat(t));
  },
  j: function(e, t) {
    e.setDate(parseFloat(t));
  },
  l: wT,
  m: function(e, t) {
    e.setMonth(parseFloat(t) - 1);
  },
  n: function(e, t) {
    e.setMonth(parseFloat(t) - 1);
  },
  s: function(e, t) {
    e.setSeconds(parseFloat(t));
  },
  u: function(e, t) {
    return new Date(parseFloat(t));
  },
  w: wT,
  y: function(e, t) {
    e.setFullYear(2e3 + parseFloat(t));
  }
}, wu = {
  D: "",
  F: "",
  G: "(\\d\\d|\\d)",
  H: "(\\d\\d|\\d)",
  J: "(\\d\\d|\\d)\\w+",
  K: "",
  M: "",
  S: "(\\d\\d|\\d)",
  U: "(.+)",
  W: "(\\d\\d|\\d)",
  Y: "(\\d{4})",
  Z: "(.+)",
  d: "(\\d\\d|\\d)",
  h: "(\\d\\d|\\d)",
  i: "(\\d\\d|\\d)",
  j: "(\\d\\d|\\d)",
  l: "",
  m: "(\\d\\d|\\d)",
  n: "(\\d\\d|\\d)",
  s: "(\\d\\d|\\d)",
  u: "(.+)",
  w: "(\\d\\d|\\d)",
  y: "(\\d{2})"
}, ip = {
  Z: function(e) {
    return e.toISOString();
  },
  D: function(e, t, n) {
    return t.weekdays.shorthand[ip.w(e, t, n)];
  },
  F: function(e, t, n) {
    return g_(ip.n(e, t, n) - 1, !1, t);
  },
  G: function(e, t, n) {
    return ia(ip.h(e, t, n));
  },
  H: function(e) {
    return ia(e.getHours());
  },
  J: function(e, t) {
    return t.ordinal !== void 0 ? e.getDate() + t.ordinal(e.getDate()) : e.getDate();
  },
  K: function(e, t) {
    return t.amPM[Wa(e.getHours() > 11)];
  },
  M: function(e, t) {
    return g_(e.getMonth(), !0, t);
  },
  S: function(e) {
    return ia(e.getSeconds());
  },
  U: function(e) {
    return e.getTime() / 1e3;
  },
  W: function(e, t, n) {
    return n.getWeek(e);
  },
  Y: function(e) {
    return ia(e.getFullYear(), 4);
  },
  d: function(e) {
    return ia(e.getDate());
  },
  h: function(e) {
    return e.getHours() % 12 ? e.getHours() % 12 : 12;
  },
  i: function(e) {
    return ia(e.getMinutes());
  },
  j: function(e) {
    return e.getDate();
  },
  l: function(e, t) {
    return t.weekdays.longhand[e.getDay()];
  },
  m: function(e) {
    return ia(e.getMonth() + 1);
  },
  n: function(e) {
    return e.getMonth() + 1;
  },
  s: function(e) {
    return e.getSeconds();
  },
  u: function(e) {
    return e.getTime();
  },
  w: function(e) {
    return e.getDay();
  },
  y: function(e) {
    return String(e.getFullYear()).substring(2);
  }
}, F8 = function(e) {
  var t = e.config, n = t === void 0 ? id : t, r = e.l10n, i = r === void 0 ? Yp : r, a = e.isMobile, o = a === void 0 ? !1 : a;
  return function(s, l, u) {
    var c = u || i;
    return n.formatDate !== void 0 && !o ? n.formatDate(s, l, c) : l.split("").map(function(d, f, h) {
      return ip[d] && h[f - 1] !== "\\" ? ip[d](s, c, n) : d !== "\\" ? d : "";
    }).join("");
  };
}, zC = function(e) {
  var t = e.config, n = t === void 0 ? id : t, r = e.l10n, i = r === void 0 ? Yp : r;
  return function(a, o, s, l) {
    if (!(a !== 0 && !a)) {
      var u = l || i, c, d = a;
      if (a instanceof Date)
        c = new Date(a.getTime());
      else if (typeof a != "string" && a.toFixed !== void 0)
        c = new Date(a);
      else if (typeof a == "string") {
        var f = o || (n || id).dateFormat, h = String(a).trim();
        if (h === "today")
          c = /* @__PURE__ */ new Date(), s = !0;
        else if (n && n.parseDate)
          c = n.parseDate(a, f);
        else if (/Z$/.test(h) || /GMT$/.test(h))
          c = new Date(a);
        else {
          for (var m = void 0, v = [], b = 0, y = 0, g = ""; b < f.length; b++) {
            var E = f[b], S = E === "\\", C = f[b - 1] === "\\" || S;
            if (wu[E] && !C) {
              g += wu[E];
              var T = new RegExp(g).exec(a);
              T && (m = !0) && v[E !== "Y" ? "push" : "unshift"]({
                fn: xFe[E],
                val: T[++y]
              });
            } else S || (g += ".");
          }
          c = !n || !n.noCalendar ? new Date((/* @__PURE__ */ new Date()).getFullYear(), 0, 1, 0, 0, 0, 0) : new Date((/* @__PURE__ */ new Date()).setHours(0, 0, 0, 0)), v.forEach(function(O) {
            var R = O.fn, D = O.val;
            return c = R(c, D, u) || c;
          }), c = m ? c : void 0;
        }
      }
      if (!(c instanceof Date && !isNaN(c.getTime()))) {
        n.errorHandler(new Error("Invalid date provided: " + d));
        return;
      }
      return s === !0 && c.setHours(0, 0, 0, 0), c;
    }
  };
};
function Ta(e, t, n) {
  return n === void 0 && (n = !0), n !== !1 ? new Date(e.getTime()).setHours(0, 0, 0, 0) - new Date(t.getTime()).setHours(0, 0, 0, 0) : e.getTime() - t.getTime();
}
var NFe = function(e, t, n) {
  return e > Math.min(t, n) && e < Math.max(t, n);
}, xT = function(e, t, n) {
  return e * 3600 + t * 60 + n;
}, DFe = function(e) {
  var t = Math.floor(e / 3600), n = (e - t * 3600) / 60;
  return [t, n, e - t * 3600 - n * 60];
}, IFe = {
  DAY: 864e5
};
function NT(e) {
  var t = e.defaultHour, n = e.defaultMinute, r = e.defaultSeconds;
  if (e.minDate !== void 0) {
    var i = e.minDate.getHours(), a = e.minDate.getMinutes(), o = e.minDate.getSeconds();
    t < i && (t = i), t === i && n < a && (n = a), t === i && n === a && r < o && (r = e.minDate.getSeconds());
  }
  if (e.maxDate !== void 0) {
    var s = e.maxDate.getHours(), l = e.maxDate.getMinutes();
    t = Math.min(t, s), t === s && (n = Math.min(l, n)), t === s && n === l && (r = e.maxDate.getSeconds());
  }
  return { hours: t, minutes: n, seconds: r };
}
typeof Object.assign != "function" && (Object.assign = function(e) {
  for (var t = [], n = 1; n < arguments.length; n++)
    t[n - 1] = arguments[n];
  if (!e)
    throw TypeError("Cannot convert undefined or null to object");
  for (var r = function(s) {
    s && Object.keys(s).forEach(function(l) {
      return e[l] = s[l];
    });
  }, i = 0, a = t; i < a.length; i++) {
    var o = a[i];
    r(o);
  }
  return e;
});
var Ni = function() {
  return Ni = Object.assign || function(e) {
    for (var t, n = 1, r = arguments.length; n < r; n++) {
      t = arguments[n];
      for (var i in t) Object.prototype.hasOwnProperty.call(t, i) && (e[i] = t[i]);
    }
    return e;
  }, Ni.apply(this, arguments);
}, jM = function() {
  for (var e = 0, t = 0, n = arguments.length; t < n; t++) e += arguments[t].length;
  for (var r = Array(e), i = 0, t = 0; t < n; t++)
    for (var a = arguments[t], o = 0, s = a.length; o < s; o++, i++)
      r[i] = a[o];
  return r;
}, LFe = 300;
function kFe(e, t) {
  var n = {
    config: Ni(Ni({}, id), Kr.defaultConfig),
    l10n: Yp
  };
  n.parseDate = zC({ config: n.config, l10n: n.l10n }), n._handlers = [], n.pluginElements = [], n.loadedPlugins = [], n._bind = v, n._setHoursFromDate = f, n._positionCalendar = Ke, n.changeMonth = V, n.changeYear = pe, n.clear = K, n.close = ne, n.onMouseOver = ut, n._createElement = Bn, n.createDay = T, n.destroy = Ee, n.isEnabled = Se, n.jumpToDate = g, n.updateValue = X, n.open = Ot, n.redraw = pt, n.set = St, n.setDate = je, n.toggle = tt;
  function r() {
    n.utils = {
      getDaysInMonth: function(M, G) {
        return M === void 0 && (M = n.currentMonth), G === void 0 && (G = n.currentYear), M === 1 && (G % 4 === 0 && G % 100 !== 0 || G % 400 === 0) ? 29 : n.l10n.daysInMonth[M];
      }
    };
  }
  function i() {
    n.element = n.input = e, n.isOpen = !1, We(), Pt(), sn(), Rt(), r(), n.isMobile || C(), y(), (n.selectedDates.length || n.config.noCalendar) && (n.config.enableTime && f(n.config.noCalendar ? n.latestSelectedDateObj : void 0), X(!1)), s();
    var M = /^((?!chrome|android).)*safari/i.test(navigator.userAgent);
    !n.isMobile && M && Ke(), ot("onReady");
  }
  function a() {
    var M;
    return ((M = n.calendarContainer) === null || M === void 0 ? void 0 : M.getRootNode()).activeElement || document.activeElement;
  }
  function o(M) {
    return M.bind(n);
  }
  function s() {
    var M = n.config;
    M.weekNumbers === !1 && M.showMonths === 1 || M.noCalendar !== !0 && window.requestAnimationFrame(function() {
      if (n.calendarContainer !== void 0 && (n.calendarContainer.style.visibility = "hidden", n.calendarContainer.style.display = "block"), n.daysContainer !== void 0) {
        var G = (n.days.offsetWidth + 1) * M.showMonths;
        n.daysContainer.style.width = G + "px", n.calendarContainer.style.width = G + (n.weekWrapper !== void 0 ? n.weekWrapper.offsetWidth : 0) + "px", n.calendarContainer.style.removeProperty("visibility"), n.calendarContainer.style.removeProperty("display");
      }
    });
  }
  function l(M) {
    if (n.selectedDates.length === 0) {
      var G = n.config.minDate === void 0 || Ta(/* @__PURE__ */ new Date(), n.config.minDate) >= 0 ? /* @__PURE__ */ new Date() : new Date(n.config.minDate.getTime()), j = NT(n.config);
      G.setHours(j.hours, j.minutes, j.seconds, G.getMilliseconds()), n.selectedDates = [G], n.latestSelectedDateObj = G;
    }
    M !== void 0 && M.type !== "blur" && _e(M);
    var ce = n._input.value;
    d(), X(), n._input.value !== ce && n._debouncedChange();
  }
  function u(M, G) {
    return M % 12 + 12 * Wa(G === n.l10n.amPM[1]);
  }
  function c(M) {
    switch (M % 24) {
      case 0:
      case 12:
        return 12;
      default:
        return M % 12;
    }
  }
  function d() {
    if (!(n.hourElement === void 0 || n.minuteElement === void 0)) {
      var M = (parseInt(n.hourElement.value.slice(-2), 10) || 0) % 24, G = (parseInt(n.minuteElement.value, 10) || 0) % 60, j = n.secondElement !== void 0 ? (parseInt(n.secondElement.value, 10) || 0) % 60 : 0;
      n.amPM !== void 0 && (M = u(M, n.amPM.textContent));
      var ce = n.config.minTime !== void 0 || n.config.minDate && n.minDateHasTime && n.latestSelectedDateObj && Ta(n.latestSelectedDateObj, n.config.minDate, !0) === 0, be = n.config.maxTime !== void 0 || n.config.maxDate && n.maxDateHasTime && n.latestSelectedDateObj && Ta(n.latestSelectedDateObj, n.config.maxDate, !0) === 0;
      if (n.config.maxTime !== void 0 && n.config.minTime !== void 0 && n.config.minTime > n.config.maxTime) {
        var Ie = xT(n.config.minTime.getHours(), n.config.minTime.getMinutes(), n.config.minTime.getSeconds()), Ue = xT(n.config.maxTime.getHours(), n.config.maxTime.getMinutes(), n.config.maxTime.getSeconds()), Ve = xT(M, G, j);
        if (Ve > Ue && Ve < Ie) {
          var dt = DFe(Ie);
          M = dt[0], G = dt[1], j = dt[2];
        }
      } else {
        if (be) {
          var Pe = n.config.maxTime !== void 0 ? n.config.maxTime : n.config.maxDate;
          M = Math.min(M, Pe.getHours()), M === Pe.getHours() && (G = Math.min(G, Pe.getMinutes())), G === Pe.getMinutes() && (j = Math.min(j, Pe.getSeconds()));
        }
        if (ce) {
          var xe = n.config.minTime !== void 0 ? n.config.minTime : n.config.minDate;
          M = Math.max(M, xe.getHours()), M === xe.getHours() && G < xe.getMinutes() && (G = xe.getMinutes()), G === xe.getMinutes() && (j = Math.max(j, xe.getSeconds()));
        }
      }
      h(M, G, j);
    }
  }
  function f(M) {
    var G = M || n.latestSelectedDateObj;
    G && G instanceof Date && h(G.getHours(), G.getMinutes(), G.getSeconds());
  }
  function h(M, G, j) {
    n.latestSelectedDateObj !== void 0 && n.latestSelectedDateObj.setHours(M % 24, G, j || 0, 0), !(!n.hourElement || !n.minuteElement || n.isMobile) && (n.hourElement.value = ia(n.config.time_24hr ? M : (12 + M) % 12 + 12 * Wa(M % 12 === 0)), n.minuteElement.value = ia(G), n.amPM !== void 0 && (n.amPM.textContent = n.l10n.amPM[Wa(M >= 12)]), n.secondElement !== void 0 && (n.secondElement.value = ia(j)));
  }
  function m(M) {
    var G = ya(M), j = parseInt(G.value) + (M.delta || 0);
    (j / 1e3 > 1 || M.key === "Enter" && !/[^\d]/.test(j.toString())) && pe(j);
  }
  function v(M, G, j, ce) {
    if (G instanceof Array)
      return G.forEach(function(be) {
        return v(M, be, j, ce);
      });
    if (M instanceof Array)
      return M.forEach(function(be) {
        return v(be, G, j, ce);
      });
    M.addEventListener(G, j, ce), n._handlers.push({
      remove: function() {
        return M.removeEventListener(G, j, ce);
      }
    });
  }
  function b() {
    ot("onChange");
  }
  function y() {
    if (n.config.wrap && ["open", "close", "toggle", "clear"].forEach(function(j) {
      Array.prototype.forEach.call(n.element.querySelectorAll("[data-" + j + "]"), function(ce) {
        return v(ce, "click", n[j]);
      });
    }), n.isMobile) {
      He();
      return;
    }
    var M = KM(Tt, 50);
    if (n._debouncedChange = KM(b, LFe), n.daysContainer && !/iPhone|iPad|iPod/i.test(navigator.userAgent) && v(n.daysContainer, "mouseover", function(j) {
      n.config.mode === "range" && ut(ya(j));
    }), v(n._input, "keydown", nt), n.calendarContainer !== void 0 && v(n.calendarContainer, "keydown", nt), !n.config.inline && !n.config.static && v(window, "resize", M), window.ontouchstart !== void 0 ? v(window.document, "touchstart", ae) : v(window.document, "mousedown", ae), v(window.document, "focus", ae, { capture: !0 }), n.config.clickOpens === !0 && (v(n._input, "focus", n.open), v(n._input, "click", n.open)), n.daysContainer !== void 0 && (v(n.monthNav, "click", te), v(n.monthNav, ["keyup", "increment"], m), v(n.daysContainer, "click", Ze)), n.timeContainer !== void 0 && n.minuteElement !== void 0 && n.hourElement !== void 0) {
      var G = function(j) {
        return ya(j).select();
      };
      v(n.timeContainer, ["increment"], l), v(n.timeContainer, "blur", l, { capture: !0 }), v(n.timeContainer, "click", E), v([n.hourElement, n.minuteElement], ["focus", "click"], G), n.secondElement !== void 0 && v(n.secondElement, "focus", function() {
        return n.secondElement && n.secondElement.select();
      }), n.amPM !== void 0 && v(n.amPM, "click", function(j) {
        l(j);
      });
    }
    n.config.allowInput && v(n._input, "blur", Ye);
  }
  function g(M, G) {
    var j = M !== void 0 ? n.parseDate(M) : n.latestSelectedDateObj || (n.config.minDate && n.config.minDate > n.now ? n.config.minDate : n.config.maxDate && n.config.maxDate < n.now ? n.config.maxDate : n.now), ce = n.currentYear, be = n.currentMonth;
    try {
      j !== void 0 && (n.currentYear = j.getFullYear(), n.currentMonth = j.getMonth());
    } catch (Ie) {
      Ie.message = "Invalid date supplied: " + j, n.config.errorHandler(Ie);
    }
    G && n.currentYear !== ce && (ot("onYearChange"), Y()), G && (n.currentYear !== ce || n.currentMonth !== be) && ot("onMonthChange"), n.redraw();
  }
  function E(M) {
    var G = ya(M);
    ~G.className.indexOf("arrow") && S(M, G.classList.contains("arrowUp") ? 1 : -1);
  }
  function S(M, G, j) {
    var ce = M && ya(M), be = j || ce && ce.parentNode && ce.parentNode.firstChild, Ie = xn("increment");
    Ie.delta = G, be && be.dispatchEvent(Ie);
  }
  function C() {
    var M = window.document.createDocumentFragment();
    if (n.calendarContainer = Bn("div", "flatpickr-calendar"), n.calendarContainer.tabIndex = -1, !n.config.noCalendar) {
      if (M.appendChild(I()), n.innerContainer = Bn("div", "flatpickr-innerContainer"), n.config.weekNumbers) {
        var G = Z(), j = G.weekWrapper, ce = G.weekNumbers;
        n.innerContainer.appendChild(j), n.weekNumbers = ce, n.weekWrapper = j;
      }
      n.rContainer = Bn("div", "flatpickr-rContainer"), n.rContainer.appendChild(B()), n.daysContainer || (n.daysContainer = Bn("div", "flatpickr-days"), n.daysContainer.tabIndex = -1), P(), n.rContainer.appendChild(n.daysContainer), n.innerContainer.appendChild(n.rContainer), M.appendChild(n.innerContainer);
    }
    n.config.enableTime && M.appendChild(k()), qi(n.calendarContainer, "rangeMode", n.config.mode === "range"), qi(n.calendarContainer, "animate", n.config.animate === !0), qi(n.calendarContainer, "multiMonth", n.config.showMonths > 1), n.calendarContainer.appendChild(M);
    var be = n.config.appendTo !== void 0 && n.config.appendTo.nodeType !== void 0;
    if ((n.config.inline || n.config.static) && (n.calendarContainer.classList.add(n.config.inline ? "inline" : "static"), n.config.inline && (!be && n.element.parentNode ? n.element.parentNode.insertBefore(n.calendarContainer, n._input.nextSibling) : n.config.appendTo !== void 0 && n.config.appendTo.appendChild(n.calendarContainer)), n.config.static)) {
      var Ie = Bn("div", "flatpickr-wrapper");
      n.element.parentNode && n.element.parentNode.insertBefore(Ie, n.element), Ie.appendChild(n.element), n.altInput && Ie.appendChild(n.altInput), Ie.appendChild(n.calendarContainer);
    }
    !n.config.static && !n.config.inline && (n.config.appendTo !== void 0 ? n.config.appendTo : window.document.body).appendChild(n.calendarContainer);
  }
  function T(M, G, j, ce) {
    var be = Se(G, !0), Ie = Bn("span", M, G.getDate().toString());
    return Ie.dateObj = G, Ie.$i = ce, Ie.setAttribute("aria-label", n.formatDate(G, n.config.ariaDateFormat)), M.indexOf("hidden") === -1 && Ta(G, n.now) === 0 && (n.todayDateElem = Ie, Ie.classList.add("today"), Ie.setAttribute("aria-current", "date")), be ? (Ie.tabIndex = -1, kt(G) && (Ie.classList.add("selected"), n.selectedDateElem = Ie, n.config.mode === "range" && (qi(Ie, "startRange", n.selectedDates[0] && Ta(G, n.selectedDates[0], !0) === 0), qi(Ie, "endRange", n.selectedDates[1] && Ta(G, n.selectedDates[1], !0) === 0), M === "nextMonthDay" && Ie.classList.add("inRange")))) : Ie.classList.add("flatpickr-disabled"), n.config.mode === "range" && Dn(G) && !kt(G) && Ie.classList.add("inRange"), n.weekNumbers && n.config.showMonths === 1 && M !== "prevMonthDay" && ce % 7 === 6 && n.weekNumbers.insertAdjacentHTML("beforeend", "<span class='flatpickr-day'>" + n.config.getWeek(G) + "</span>"), ot("onDayCreate", Ie), Ie;
  }
  function O(M) {
    M.focus(), n.config.mode === "range" && ut(M);
  }
  function R(M) {
    for (var G = M > 0 ? 0 : n.config.showMonths - 1, j = M > 0 ? n.config.showMonths : -1, ce = G; ce != j; ce += M)
      for (var be = n.daysContainer.children[ce], Ie = M > 0 ? 0 : be.children.length - 1, Ue = M > 0 ? be.children.length : -1, Ve = Ie; Ve != Ue; Ve += M) {
        var dt = be.children[Ve];
        if (dt.className.indexOf("hidden") === -1 && Se(dt.dateObj))
          return dt;
      }
  }
  function D(M, G) {
    for (var j = M.className.indexOf("Month") === -1 ? M.dateObj.getMonth() : n.currentMonth, ce = G > 0 ? n.config.showMonths : -1, be = G > 0 ? 1 : -1, Ie = j - n.currentMonth; Ie != ce; Ie += be)
      for (var Ue = n.daysContainer.children[Ie], Ve = j - n.currentMonth === Ie ? M.$i + G : G < 0 ? Ue.children.length - 1 : 0, dt = Ue.children.length, Pe = Ve; Pe >= 0 && Pe < dt && Pe != (G > 0 ? dt : -1); Pe += be) {
        var xe = Ue.children[Pe];
        if (xe.className.indexOf("hidden") === -1 && Se(xe.dateObj) && Math.abs(M.$i - Pe) >= Math.abs(G))
          return O(xe);
      }
    n.changeMonth(be), q(R(be), 0);
  }
  function q(M, G) {
    var j = a(), ce = Re(j || document.body), be = M !== void 0 ? M : ce ? j : n.selectedDateElem !== void 0 && Re(n.selectedDateElem) ? n.selectedDateElem : n.todayDateElem !== void 0 && Re(n.todayDateElem) ? n.todayDateElem : R(G > 0 ? 1 : -1);
    be === void 0 ? n._input.focus() : ce ? D(be, G) : O(be);
  }
  function $(M, G) {
    for (var j = (new Date(M, G, 1).getDay() - n.l10n.firstDayOfWeek + 7) % 7, ce = n.utils.getDaysInMonth((G - 1 + 12) % 12, M), be = n.utils.getDaysInMonth(G, M), Ie = window.document.createDocumentFragment(), Ue = n.config.showMonths > 1, Ve = Ue ? "prevMonthDay hidden" : "prevMonthDay", dt = Ue ? "nextMonthDay hidden" : "nextMonthDay", Pe = ce + 1 - j, xe = 0; Pe <= ce; Pe++, xe++)
      Ie.appendChild(T("flatpickr-day " + Ve, new Date(M, G - 1, Pe), Pe, xe));
    for (Pe = 1; Pe <= be; Pe++, xe++)
      Ie.appendChild(T("flatpickr-day", new Date(M, G, Pe), Pe, xe));
    for (var Mt = be + 1; Mt <= 42 - j && (n.config.showMonths === 1 || xe % 7 !== 0); Mt++, xe++)
      Ie.appendChild(T("flatpickr-day " + dt, new Date(M, G + 1, Mt % be), Mt, xe));
    var Zt = Bn("div", "dayContainer");
    return Zt.appendChild(Ie), Zt;
  }
  function P() {
    if (n.daysContainer !== void 0) {
      Qh(n.daysContainer), n.weekNumbers && Qh(n.weekNumbers);
      for (var M = document.createDocumentFragment(), G = 0; G < n.config.showMonths; G++) {
        var j = new Date(n.currentYear, n.currentMonth, 1);
        j.setMonth(n.currentMonth + G), M.appendChild($(j.getFullYear(), j.getMonth()));
      }
      n.daysContainer.appendChild(M), n.days = n.daysContainer.firstChild, n.config.mode === "range" && n.selectedDates.length === 1 && ut();
    }
  }
  function Y() {
    if (!(n.config.showMonths > 1 || n.config.monthSelectorType !== "dropdown")) {
      var M = function(ce) {
        return n.config.minDate !== void 0 && n.currentYear === n.config.minDate.getFullYear() && ce < n.config.minDate.getMonth() ? !1 : !(n.config.maxDate !== void 0 && n.currentYear === n.config.maxDate.getFullYear() && ce > n.config.maxDate.getMonth());
      };
      n.monthsDropdownContainer.tabIndex = -1, n.monthsDropdownContainer.innerHTML = "";
      for (var G = 0; G < 12; G++)
        if (M(G)) {
          var j = Bn("option", "flatpickr-monthDropdown-month");
          j.value = new Date(n.currentYear, G).getMonth().toString(), j.textContent = g_(G, n.config.shorthandCurrentMonth, n.l10n), j.tabIndex = -1, n.currentMonth === G && (j.selected = !0), n.monthsDropdownContainer.appendChild(j);
        }
    }
  }
  function L() {
    var M = Bn("div", "flatpickr-month"), G = window.document.createDocumentFragment(), j;
    n.config.showMonths > 1 || n.config.monthSelectorType === "static" ? j = Bn("span", "cur-month") : (n.monthsDropdownContainer = Bn("select", "flatpickr-monthDropdown-months"), n.monthsDropdownContainer.setAttribute("aria-label", n.l10n.monthAriaLabel), v(n.monthsDropdownContainer, "change", function(Ue) {
      var Ve = ya(Ue), dt = parseInt(Ve.value, 10);
      n.changeMonth(dt - n.currentMonth), ot("onMonthChange");
    }), Y(), j = n.monthsDropdownContainer);
    var ce = Xh("cur-year", { tabindex: "-1" }), be = ce.getElementsByTagName("input")[0];
    be.setAttribute("aria-label", n.l10n.yearAriaLabel), n.config.minDate && be.setAttribute("min", n.config.minDate.getFullYear().toString()), n.config.maxDate && (be.setAttribute("max", n.config.maxDate.getFullYear().toString()), be.disabled = !!n.config.minDate && n.config.minDate.getFullYear() === n.config.maxDate.getFullYear());
    var Ie = Bn("div", "flatpickr-current-month");
    return Ie.appendChild(j), Ie.appendChild(ce), G.appendChild(Ie), M.appendChild(G), {
      container: M,
      yearElement: be,
      monthElement: j
    };
  }
  function x() {
    Qh(n.monthNav), n.monthNav.appendChild(n.prevMonthNav), n.config.showMonths && (n.yearElements = [], n.monthElements = []);
    for (var M = n.config.showMonths; M--; ) {
      var G = L();
      n.yearElements.push(G.yearElement), n.monthElements.push(G.monthElement), n.monthNav.appendChild(G.container);
    }
    n.monthNav.appendChild(n.nextMonthNav);
  }
  function I() {
    return n.monthNav = Bn("div", "flatpickr-months"), n.yearElements = [], n.monthElements = [], n.prevMonthNav = Bn("span", "flatpickr-prev-month"), n.prevMonthNav.innerHTML = n.config.prevArrow, n.nextMonthNav = Bn("span", "flatpickr-next-month"), n.nextMonthNav.innerHTML = n.config.nextArrow, x(), Object.defineProperty(n, "_hidePrevMonthArrow", {
      get: function() {
        return n.__hidePrevMonthArrow;
      },
      set: function(M) {
        n.__hidePrevMonthArrow !== M && (qi(n.prevMonthNav, "flatpickr-disabled", M), n.__hidePrevMonthArrow = M);
      }
    }), Object.defineProperty(n, "_hideNextMonthArrow", {
      get: function() {
        return n.__hideNextMonthArrow;
      },
      set: function(M) {
        n.__hideNextMonthArrow !== M && (qi(n.nextMonthNav, "flatpickr-disabled", M), n.__hideNextMonthArrow = M);
      }
    }), n.currentYearElement = n.yearElements[0], gn(), n.monthNav;
  }
  function k() {
    n.calendarContainer.classList.add("hasTime"), n.config.noCalendar && n.calendarContainer.classList.add("noCalendar");
    var M = NT(n.config);
    n.timeContainer = Bn("div", "flatpickr-time"), n.timeContainer.tabIndex = -1;
    var G = Bn("span", "flatpickr-time-separator", ":"), j = Xh("flatpickr-hour", {
      "aria-label": n.l10n.hourAriaLabel
    });
    n.hourElement = j.getElementsByTagName("input")[0];
    var ce = Xh("flatpickr-minute", {
      "aria-label": n.l10n.minuteAriaLabel
    });
    if (n.minuteElement = ce.getElementsByTagName("input")[0], n.hourElement.tabIndex = n.minuteElement.tabIndex = -1, n.hourElement.value = ia(n.latestSelectedDateObj ? n.latestSelectedDateObj.getHours() : n.config.time_24hr ? M.hours : c(M.hours)), n.minuteElement.value = ia(n.latestSelectedDateObj ? n.latestSelectedDateObj.getMinutes() : M.minutes), n.hourElement.setAttribute("step", n.config.hourIncrement.toString()), n.minuteElement.setAttribute("step", n.config.minuteIncrement.toString()), n.hourElement.setAttribute("min", n.config.time_24hr ? "0" : "1"), n.hourElement.setAttribute("max", n.config.time_24hr ? "23" : "12"), n.hourElement.setAttribute("maxlength", "2"), n.minuteElement.setAttribute("min", "0"), n.minuteElement.setAttribute("max", "59"), n.minuteElement.setAttribute("maxlength", "2"), n.timeContainer.appendChild(j), n.timeContainer.appendChild(G), n.timeContainer.appendChild(ce), n.config.time_24hr && n.timeContainer.classList.add("time24hr"), n.config.enableSeconds) {
      n.timeContainer.classList.add("hasSeconds");
      var be = Xh("flatpickr-second");
      n.secondElement = be.getElementsByTagName("input")[0], n.secondElement.value = ia(n.latestSelectedDateObj ? n.latestSelectedDateObj.getSeconds() : M.seconds), n.secondElement.setAttribute("step", n.minuteElement.getAttribute("step")), n.secondElement.setAttribute("min", "0"), n.secondElement.setAttribute("max", "59"), n.secondElement.setAttribute("maxlength", "2"), n.timeContainer.appendChild(Bn("span", "flatpickr-time-separator", ":")), n.timeContainer.appendChild(be);
    }
    return n.config.time_24hr || (n.amPM = Bn("span", "flatpickr-am-pm", n.l10n.amPM[Wa((n.latestSelectedDateObj ? n.hourElement.value : n.config.defaultHour) > 11)]), n.amPM.title = n.l10n.toggleTitle, n.amPM.tabIndex = -1, n.timeContainer.appendChild(n.amPM)), n.timeContainer;
  }
  function B() {
    n.weekdayContainer ? Qh(n.weekdayContainer) : n.weekdayContainer = Bn("div", "flatpickr-weekdays");
    for (var M = n.config.showMonths; M--; ) {
      var G = Bn("div", "flatpickr-weekdaycontainer");
      n.weekdayContainer.appendChild(G);
    }
    return W(), n.weekdayContainer;
  }
  function W() {
    if (n.weekdayContainer) {
      var M = n.l10n.firstDayOfWeek, G = jM(n.l10n.weekdays.shorthand);
      M > 0 && M < G.length && (G = jM(G.splice(M, G.length), G.splice(0, M)));
      for (var j = n.config.showMonths; j--; )
        n.weekdayContainer.children[j].innerHTML = `
      <span class='flatpickr-weekday'>
        ` + G.join("</span><span class='flatpickr-weekday'>") + `
      </span>
      `;
    }
  }
  function Z() {
    n.calendarContainer.classList.add("hasWeeks");
    var M = Bn("div", "flatpickr-weekwrapper");
    M.appendChild(Bn("span", "flatpickr-weekday", n.l10n.weekAbbreviation));
    var G = Bn("div", "flatpickr-weeks");
    return M.appendChild(G), {
      weekWrapper: M,
      weekNumbers: G
    };
  }
  function V(M, G) {
    G === void 0 && (G = !0);
    var j = G ? M : M - n.currentMonth;
    j < 0 && n._hidePrevMonthArrow === !0 || j > 0 && n._hideNextMonthArrow === !0 || (n.currentMonth += j, (n.currentMonth < 0 || n.currentMonth > 11) && (n.currentYear += n.currentMonth > 11 ? 1 : -1, n.currentMonth = (n.currentMonth + 12) % 12, ot("onYearChange"), Y()), P(), ot("onMonthChange"), gn());
  }
  function K(M, G) {
    if (M === void 0 && (M = !0), G === void 0 && (G = !0), n.input.value = "", n.altInput !== void 0 && (n.altInput.value = ""), n.mobileInput !== void 0 && (n.mobileInput.value = ""), n.selectedDates = [], n.latestSelectedDateObj = void 0, G === !0 && (n.currentYear = n._initialDate.getFullYear(), n.currentMonth = n._initialDate.getMonth()), n.config.enableTime === !0) {
      var j = NT(n.config), ce = j.hours, be = j.minutes, Ie = j.seconds;
      h(ce, be, Ie);
    }
    n.redraw(), M && ot("onChange");
  }
  function ne() {
    n.isOpen = !1, n.isMobile || (n.calendarContainer !== void 0 && n.calendarContainer.classList.remove("open"), n._input !== void 0 && n._input.classList.remove("active")), ot("onClose");
  }
  function Ee() {
    n.config !== void 0 && ot("onDestroy");
    for (var M = n._handlers.length; M--; )
      n._handlers[M].remove();
    if (n._handlers = [], n.mobileInput)
      n.mobileInput.parentNode && n.mobileInput.parentNode.removeChild(n.mobileInput), n.mobileInput = void 0;
    else if (n.calendarContainer && n.calendarContainer.parentNode)
      if (n.config.static && n.calendarContainer.parentNode) {
        var G = n.calendarContainer.parentNode;
        if (G.lastChild && G.removeChild(G.lastChild), G.parentNode) {
          for (; G.firstChild; )
            G.parentNode.insertBefore(G.firstChild, G);
          G.parentNode.removeChild(G);
        }
      } else
        n.calendarContainer.parentNode.removeChild(n.calendarContainer);
    n.altInput && (n.input.type = "text", n.altInput.parentNode && n.altInput.parentNode.removeChild(n.altInput), delete n.altInput), n.input && (n.input.type = n.input._type, n.input.classList.remove("flatpickr-input"), n.input.removeAttribute("readonly")), [
      "_showTimeInput",
      "latestSelectedDateObj",
      "_hideNextMonthArrow",
      "_hidePrevMonthArrow",
      "__hideNextMonthArrow",
      "__hidePrevMonthArrow",
      "isMobile",
      "isOpen",
      "selectedDateElem",
      "minDateHasTime",
      "maxDateHasTime",
      "days",
      "daysContainer",
      "_input",
      "_positionElement",
      "innerContainer",
      "rContainer",
      "monthNav",
      "todayDateElem",
      "calendarContainer",
      "weekdayContainer",
      "prevMonthNav",
      "nextMonthNav",
      "monthsDropdownContainer",
      "currentMonthElement",
      "currentYearElement",
      "navigationCurrentMonth",
      "selectedDateElem",
      "config"
    ].forEach(function(j) {
      try {
        delete n[j];
      } catch {
      }
    });
  }
  function oe(M) {
    return n.calendarContainer.contains(M);
  }
  function ae(M) {
    if (n.isOpen && !n.config.inline) {
      var G = ya(M), j = oe(G), ce = G === n.input || G === n.altInput || n.element.contains(G) || M.path && M.path.indexOf && (~M.path.indexOf(n.input) || ~M.path.indexOf(n.altInput)), be = !ce && !j && !oe(M.relatedTarget), Ie = !n.config.ignoredFocusElements.some(function(Ue) {
        return Ue.contains(G);
      });
      be && Ie && (n.config.allowInput && n.setDate(n._input.value, !1, n.config.altInput ? n.config.altFormat : n.config.dateFormat), n.timeContainer !== void 0 && n.minuteElement !== void 0 && n.hourElement !== void 0 && n.input.value !== "" && n.input.value !== void 0 && l(), n.close(), n.config && n.config.mode === "range" && n.selectedDates.length === 1 && n.clear(!1));
    }
  }
  function pe(M) {
    if (!(!M || n.config.minDate && M < n.config.minDate.getFullYear() || n.config.maxDate && M > n.config.maxDate.getFullYear())) {
      var G = M, j = n.currentYear !== G;
      n.currentYear = G || n.currentYear, n.config.maxDate && n.currentYear === n.config.maxDate.getFullYear() ? n.currentMonth = Math.min(n.config.maxDate.getMonth(), n.currentMonth) : n.config.minDate && n.currentYear === n.config.minDate.getFullYear() && (n.currentMonth = Math.max(n.config.minDate.getMonth(), n.currentMonth)), j && (n.redraw(), ot("onYearChange"), Y());
    }
  }
  function Se(M, G) {
    var j;
    G === void 0 && (G = !0);
    var ce = n.parseDate(M, void 0, G);
    if (n.config.minDate && ce && Ta(ce, n.config.minDate, G !== void 0 ? G : !n.minDateHasTime) < 0 || n.config.maxDate && ce && Ta(ce, n.config.maxDate, G !== void 0 ? G : !n.maxDateHasTime) > 0)
      return !1;
    if (!n.config.enable && n.config.disable.length === 0)
      return !0;
    if (ce === void 0)
      return !1;
    for (var be = !!n.config.enable, Ie = (j = n.config.enable) !== null && j !== void 0 ? j : n.config.disable, Ue = 0, Ve = void 0; Ue < Ie.length; Ue++) {
      if (Ve = Ie[Ue], typeof Ve == "function" && Ve(ce))
        return be;
      if (Ve instanceof Date && ce !== void 0 && Ve.getTime() === ce.getTime())
        return be;
      if (typeof Ve == "string") {
        var dt = n.parseDate(Ve, void 0, !0);
        return dt && dt.getTime() === ce.getTime() ? be : !be;
      } else if (typeof Ve == "object" && ce !== void 0 && Ve.from && Ve.to && ce.getTime() >= Ve.from.getTime() && ce.getTime() <= Ve.to.getTime())
        return be;
    }
    return !be;
  }
  function Re(M) {
    return n.daysContainer !== void 0 ? M.className.indexOf("hidden") === -1 && M.className.indexOf("flatpickr-disabled") === -1 && n.daysContainer.contains(M) : !1;
  }
  function Ye(M) {
    var G = M.target === n._input, j = n._input.value.trimEnd() !== Vn();
    G && j && !(M.relatedTarget && oe(M.relatedTarget)) && n.setDate(n._input.value, !0, M.target === n.altInput ? n.config.altFormat : n.config.dateFormat);
  }
  function nt(M) {
    var G = ya(M), j = n.config.wrap ? e.contains(G) : G === n._input, ce = n.config.allowInput, be = n.isOpen && (!ce || !j), Ie = n.config.inline && j && !ce;
    if (M.keyCode === 13 && j) {
      if (ce)
        return n.setDate(n._input.value, !0, G === n.altInput ? n.config.altFormat : n.config.dateFormat), n.close(), G.blur();
      n.open();
    } else if (oe(G) || be || Ie) {
      var Ue = !!n.timeContainer && n.timeContainer.contains(G);
      switch (M.keyCode) {
        case 13:
          Ue ? (M.preventDefault(), l(), ft()) : Ze(M);
          break;
        case 27:
          M.preventDefault(), ft();
          break;
        case 8:
        case 46:
          j && !n.config.allowInput && (M.preventDefault(), n.clear());
          break;
        case 37:
        case 39:
          if (!Ue && !j) {
            M.preventDefault();
            var Ve = a();
            if (n.daysContainer !== void 0 && (ce === !1 || Ve && Re(Ve))) {
              var dt = M.keyCode === 39 ? 1 : -1;
              M.ctrlKey ? (M.stopPropagation(), V(dt), q(R(1), 0)) : q(void 0, dt);
            }
          } else n.hourElement && n.hourElement.focus();
          break;
        case 38:
        case 40:
          M.preventDefault();
          var Pe = M.keyCode === 40 ? 1 : -1;
          n.daysContainer && G.$i !== void 0 || G === n.input || G === n.altInput ? M.ctrlKey ? (M.stopPropagation(), pe(n.currentYear - Pe), q(R(1), 0)) : Ue || q(void 0, Pe * 7) : G === n.currentYearElement ? pe(n.currentYear - Pe) : n.config.enableTime && (!Ue && n.hourElement && n.hourElement.focus(), l(M), n._debouncedChange());
          break;
        case 9:
          if (Ue) {
            var xe = [
              n.hourElement,
              n.minuteElement,
              n.secondElement,
              n.amPM
            ].concat(n.pluginElements).filter(function(Jt) {
              return Jt;
            }), Mt = xe.indexOf(G);
            if (Mt !== -1) {
              var Zt = xe[Mt + (M.shiftKey ? -1 : 1)];
              M.preventDefault(), (Zt || n._input).focus();
            }
          } else !n.config.noCalendar && n.daysContainer && n.daysContainer.contains(G) && M.shiftKey && (M.preventDefault(), n._input.focus());
          break;
      }
    }
    if (n.amPM !== void 0 && G === n.amPM)
      switch (M.key) {
        case n.l10n.amPM[0].charAt(0):
        case n.l10n.amPM[0].charAt(0).toLowerCase():
          n.amPM.textContent = n.l10n.amPM[0], d(), X();
          break;
        case n.l10n.amPM[1].charAt(0):
        case n.l10n.amPM[1].charAt(0).toLowerCase():
          n.amPM.textContent = n.l10n.amPM[1], d(), X();
          break;
      }
    (j || oe(G)) && ot("onKeyDown", M);
  }
  function ut(M, G) {
    if (G === void 0 && (G = "flatpickr-day"), !(n.selectedDates.length !== 1 || M && (!M.classList.contains(G) || M.classList.contains("flatpickr-disabled")))) {
      for (var j = M ? M.dateObj.getTime() : n.days.firstElementChild.dateObj.getTime(), ce = n.parseDate(n.selectedDates[0], void 0, !0).getTime(), be = Math.min(j, n.selectedDates[0].getTime()), Ie = Math.max(j, n.selectedDates[0].getTime()), Ue = !1, Ve = 0, dt = 0, Pe = be; Pe < Ie; Pe += IFe.DAY)
        Se(new Date(Pe), !0) || (Ue = Ue || Pe > be && Pe < Ie, Pe < ce && (!Ve || Pe > Ve) ? Ve = Pe : Pe > ce && (!dt || Pe < dt) && (dt = Pe));
      var xe = Array.from(n.rContainer.querySelectorAll("*:nth-child(-n+" + n.config.showMonths + ") > ." + G));
      xe.forEach(function(Mt) {
        var Zt = Mt.dateObj, Jt = Zt.getTime(), xr = Ve > 0 && Jt < Ve || dt > 0 && Jt > dt;
        if (xr) {
          Mt.classList.add("notAllowed"), ["inRange", "startRange", "endRange"].forEach(function(Un) {
            Mt.classList.remove(Un);
          });
          return;
        } else if (Ue && !xr)
          return;
        ["startRange", "inRange", "endRange", "notAllowed"].forEach(function(Un) {
          Mt.classList.remove(Un);
        }), M !== void 0 && (M.classList.add(j <= n.selectedDates[0].getTime() ? "startRange" : "endRange"), ce < j && Jt === ce ? Mt.classList.add("startRange") : ce > j && Jt === ce && Mt.classList.add("endRange"), Jt >= Ve && (dt === 0 || Jt <= dt) && NFe(Jt, ce, j) && Mt.classList.add("inRange"));
      });
    }
  }
  function Tt() {
    n.isOpen && !n.config.static && !n.config.inline && Ke();
  }
  function Ot(M, G) {
    if (G === void 0 && (G = n._positionElement), n.isMobile === !0) {
      if (M) {
        M.preventDefault();
        var j = ya(M);
        j && j.blur();
      }
      n.mobileInput !== void 0 && (n.mobileInput.focus(), n.mobileInput.click()), ot("onOpen");
      return;
    } else if (n._input.disabled || n.config.inline)
      return;
    var ce = n.isOpen;
    n.isOpen = !0, ce || (n.calendarContainer.classList.add("open"), n._input.classList.add("active"), ot("onOpen"), Ke(G)), n.config.enableTime === !0 && n.config.noCalendar === !0 && n.config.allowInput === !1 && (M === void 0 || !n.timeContainer.contains(M.relatedTarget)) && setTimeout(function() {
      return n.hourElement.select();
    }, 50);
  }
  function Xt(M) {
    return function(G) {
      var j = n.config["_" + M + "Date"] = n.parseDate(G, n.config.dateFormat), ce = n.config["_" + (M === "min" ? "max" : "min") + "Date"];
      j !== void 0 && (n[M === "min" ? "minDateHasTime" : "maxDateHasTime"] = j.getHours() > 0 || j.getMinutes() > 0 || j.getSeconds() > 0), n.selectedDates && (n.selectedDates = n.selectedDates.filter(function(be) {
        return Se(be);
      }), !n.selectedDates.length && M === "min" && f(j), X()), n.daysContainer && (pt(), j !== void 0 ? n.currentYearElement[M] = j.getFullYear().toString() : n.currentYearElement.removeAttribute(M), n.currentYearElement.disabled = !!ce && j !== void 0 && ce.getFullYear() === j.getFullYear());
    };
  }
  function We() {
    var M = [
      "wrap",
      "weekNumbers",
      "allowInput",
      "allowInvalidPreload",
      "clickOpens",
      "time_24hr",
      "enableTime",
      "noCalendar",
      "altInput",
      "shorthandCurrentMonth",
      "inline",
      "static",
      "enableSeconds",
      "disableMobile"
    ], G = Ni(Ni({}, JSON.parse(JSON.stringify(e.dataset || {}))), t), j = {};
    n.config.parseDate = G.parseDate, n.config.formatDate = G.formatDate, Object.defineProperty(n.config, "enable", {
      get: function() {
        return n.config._enable;
      },
      set: function(xe) {
        n.config._enable = yt(xe);
      }
    }), Object.defineProperty(n.config, "disable", {
      get: function() {
        return n.config._disable;
      },
      set: function(xe) {
        n.config._disable = yt(xe);
      }
    });
    var ce = G.mode === "time";
    if (!G.dateFormat && (G.enableTime || ce)) {
      var be = Kr.defaultConfig.dateFormat || id.dateFormat;
      j.dateFormat = G.noCalendar || ce ? "H:i" + (G.enableSeconds ? ":S" : "") : be + " H:i" + (G.enableSeconds ? ":S" : "");
    }
    if (G.altInput && (G.enableTime || ce) && !G.altFormat) {
      var Ie = Kr.defaultConfig.altFormat || id.altFormat;
      j.altFormat = G.noCalendar || ce ? "h:i" + (G.enableSeconds ? ":S K" : " K") : Ie + (" h:i" + (G.enableSeconds ? ":S" : "") + " K");
    }
    Object.defineProperty(n.config, "minDate", {
      get: function() {
        return n.config._minDate;
      },
      set: Xt("min")
    }), Object.defineProperty(n.config, "maxDate", {
      get: function() {
        return n.config._maxDate;
      },
      set: Xt("max")
    });
    var Ue = function(xe) {
      return function(Mt) {
        n.config[xe === "min" ? "_minTime" : "_maxTime"] = n.parseDate(Mt, "H:i:S");
      };
    };
    Object.defineProperty(n.config, "minTime", {
      get: function() {
        return n.config._minTime;
      },
      set: Ue("min")
    }), Object.defineProperty(n.config, "maxTime", {
      get: function() {
        return n.config._maxTime;
      },
      set: Ue("max")
    }), G.mode === "time" && (n.config.noCalendar = !0, n.config.enableTime = !0), Object.assign(n.config, j, G);
    for (var Ve = 0; Ve < M.length; Ve++)
      n.config[M[Ve]] = n.config[M[Ve]] === !0 || n.config[M[Ve]] === "true";
    OT.filter(function(xe) {
      return n.config[xe] !== void 0;
    }).forEach(function(xe) {
      n.config[xe] = RT(n.config[xe] || []).map(o);
    }), n.isMobile = !n.config.disableMobile && !n.config.inline && n.config.mode === "single" && !n.config.disable.length && !n.config.enable && !n.config.weekNumbers && /Android|webOS|iPhone|iPad|iPod|BlackBerry|IEMobile|Opera Mini/i.test(navigator.userAgent);
    for (var Ve = 0; Ve < n.config.plugins.length; Ve++) {
      var dt = n.config.plugins[Ve](n) || {};
      for (var Pe in dt)
        OT.indexOf(Pe) > -1 ? n.config[Pe] = RT(dt[Pe]).map(o).concat(n.config[Pe]) : typeof G[Pe] > "u" && (n.config[Pe] = dt[Pe]);
    }
    G.altInputClass || (n.config.altInputClass = st().className + " " + n.config.altInputClass), ot("onParseConfig");
  }
  function st() {
    return n.config.wrap ? e.querySelector("[data-input]") : e;
  }
  function Pt() {
    typeof n.config.locale != "object" && typeof Kr.l10ns[n.config.locale] > "u" && n.config.errorHandler(new Error("flatpickr: invalid locale " + n.config.locale)), n.l10n = Ni(Ni({}, Kr.l10ns.default), typeof n.config.locale == "object" ? n.config.locale : n.config.locale !== "default" ? Kr.l10ns[n.config.locale] : void 0), wu.D = "(" + n.l10n.weekdays.shorthand.join("|") + ")", wu.l = "(" + n.l10n.weekdays.longhand.join("|") + ")", wu.M = "(" + n.l10n.months.shorthand.join("|") + ")", wu.F = "(" + n.l10n.months.longhand.join("|") + ")", wu.K = "(" + n.l10n.amPM[0] + "|" + n.l10n.amPM[1] + "|" + n.l10n.amPM[0].toLowerCase() + "|" + n.l10n.amPM[1].toLowerCase() + ")";
    var M = Ni(Ni({}, t), JSON.parse(JSON.stringify(e.dataset || {})));
    M.time_24hr === void 0 && Kr.defaultConfig.time_24hr === void 0 && (n.config.time_24hr = n.l10n.time_24hr), n.formatDate = F8(n), n.parseDate = zC({ config: n.config, l10n: n.l10n });
  }
  function Ke(M) {
    if (typeof n.config.position == "function")
      return void n.config.position(n, M);
    if (n.calendarContainer !== void 0) {
      ot("onPreCalendarPosition");
      var G = M || n._positionElement, j = Array.prototype.reduce.call(n.calendarContainer.children, function(ye, ct) {
        return ye + ct.offsetHeight;
      }, 0), ce = n.calendarContainer.offsetWidth, be = n.config.position.split(" "), Ie = be[0], Ue = be.length > 1 ? be[1] : null, Ve = G.getBoundingClientRect(), dt = window.innerHeight - Ve.bottom, Pe = Ie === "above" || Ie !== "below" && dt < j && Ve.top > j, xe = window.pageYOffset + Ve.top + (Pe ? -j - 2 : G.offsetHeight + 2);
      if (qi(n.calendarContainer, "arrowTop", !Pe), qi(n.calendarContainer, "arrowBottom", Pe), !n.config.inline) {
        var Mt = window.pageXOffset + Ve.left, Zt = !1, Jt = !1;
        Ue === "center" ? (Mt -= (ce - Ve.width) / 2, Zt = !0) : Ue === "right" && (Mt -= ce - Ve.width, Jt = !0), qi(n.calendarContainer, "arrowLeft", !Zt && !Jt), qi(n.calendarContainer, "arrowCenter", Zt), qi(n.calendarContainer, "arrowRight", Jt);
        var xr = window.document.body.offsetWidth - (window.pageXOffset + Ve.right), Un = Mt + ce > window.document.body.offsetWidth, pi = xr + ce > window.document.body.offsetWidth;
        if (qi(n.calendarContainer, "rightMost", Un), !n.config.static)
          if (n.calendarContainer.style.top = xe + "px", !Un)
            n.calendarContainer.style.left = Mt + "px", n.calendarContainer.style.right = "auto";
          else if (!pi)
            n.calendarContainer.style.left = "auto", n.calendarContainer.style.right = xr + "px";
          else {
            var Cr = Je();
            if (Cr === void 0)
              return;
            var ti = window.document.body.offsetWidth, Si = Math.max(0, ti / 2 - ce / 2), yi = ".flatpickr-calendar.centerMost:before", vt = ".flatpickr-calendar.centerMost:after", ue = Cr.cssRules.length, Q = "{left:" + Ve.left + "px;right:auto;}";
            qi(n.calendarContainer, "rightMost", !1), qi(n.calendarContainer, "centerMost", !0), Cr.insertRule(yi + "," + vt + Q, ue), n.calendarContainer.style.left = Si + "px", n.calendarContainer.style.right = "auto";
          }
      }
    }
  }
  function Je() {
    for (var M = null, G = 0; G < document.styleSheets.length; G++) {
      var j = document.styleSheets[G];
      if (j.cssRules) {
        try {
          j.cssRules;
        } catch {
          continue;
        }
        M = j;
        break;
      }
    }
    return M ?? Be();
  }
  function Be() {
    var M = document.createElement("style");
    return document.head.appendChild(M), M.sheet;
  }
  function pt() {
    n.config.noCalendar || n.isMobile || (Y(), gn(), P());
  }
  function ft() {
    n._input.focus(), window.navigator.userAgent.indexOf("MSIE") !== -1 || navigator.msMaxTouchPoints !== void 0 ? setTimeout(n.close, 0) : n.close();
  }
  function Ze(M) {
    M.preventDefault(), M.stopPropagation();
    var G = function(xe) {
      return xe.classList && xe.classList.contains("flatpickr-day") && !xe.classList.contains("flatpickr-disabled") && !xe.classList.contains("notAllowed");
    }, j = P8(ya(M), G);
    if (j !== void 0) {
      var ce = j, be = n.latestSelectedDateObj = new Date(ce.dateObj.getTime()), Ie = (be.getMonth() < n.currentMonth || be.getMonth() > n.currentMonth + n.config.showMonths - 1) && n.config.mode !== "range";
      if (n.selectedDateElem = ce, n.config.mode === "single")
        n.selectedDates = [be];
      else if (n.config.mode === "multiple") {
        var Ue = kt(be);
        Ue ? n.selectedDates.splice(parseInt(Ue), 1) : n.selectedDates.push(be);
      } else n.config.mode === "range" && (n.selectedDates.length === 2 && n.clear(!1, !1), n.latestSelectedDateObj = be, n.selectedDates.push(be), Ta(be, n.selectedDates[0], !0) !== 0 && n.selectedDates.sort(function(xe, Mt) {
        return xe.getTime() - Mt.getTime();
      }));
      if (d(), Ie) {
        var Ve = n.currentYear !== be.getFullYear();
        n.currentYear = be.getFullYear(), n.currentMonth = be.getMonth(), Ve && (ot("onYearChange"), Y()), ot("onMonthChange");
      }
      if (gn(), P(), X(), !Ie && n.config.mode !== "range" && n.config.showMonths === 1 ? O(ce) : n.selectedDateElem !== void 0 && n.hourElement === void 0 && n.selectedDateElem && n.selectedDateElem.focus(), n.hourElement !== void 0 && n.hourElement !== void 0 && n.hourElement.focus(), n.config.closeOnSelect) {
        var dt = n.config.mode === "single" && !n.config.enableTime, Pe = n.config.mode === "range" && n.selectedDates.length === 2 && !n.config.enableTime;
        (dt || Pe) && ft();
      }
      b();
    }
  }
  var _t = {
    locale: [Pt, W],
    showMonths: [x, s, B],
    minDate: [g],
    maxDate: [g],
    positionElement: [me],
    clickOpens: [
      function() {
        n.config.clickOpens === !0 ? (v(n._input, "focus", n.open), v(n._input, "click", n.open)) : (n._input.removeEventListener("focus", n.open), n._input.removeEventListener("click", n.open));
      }
    ]
  };
  function St(M, G) {
    if (M !== null && typeof M == "object") {
      Object.assign(n.config, M);
      for (var j in M)
        _t[j] !== void 0 && _t[j].forEach(function(ce) {
          return ce();
        });
    } else
      n.config[M] = G, _t[M] !== void 0 ? _t[M].forEach(function(ce) {
        return ce();
      }) : OT.indexOf(M) > -1 && (n.config[M] = RT(G));
    n.redraw(), X(!0);
  }
  function we(M, G) {
    var j = [];
    if (M instanceof Array)
      j = M.map(function(ce) {
        return n.parseDate(ce, G);
      });
    else if (M instanceof Date || typeof M == "number")
      j = [n.parseDate(M, G)];
    else if (typeof M == "string")
      switch (n.config.mode) {
        case "single":
        case "time":
          j = [n.parseDate(M, G)];
          break;
        case "multiple":
          j = M.split(n.config.conjunction).map(function(ce) {
            return n.parseDate(ce, G);
          });
          break;
        case "range":
          j = M.split(n.l10n.rangeSeparator).map(function(ce) {
            return n.parseDate(ce, G);
          });
          break;
      }
    else
      n.config.errorHandler(new Error("Invalid date supplied: " + JSON.stringify(M)));
    n.selectedDates = n.config.allowInvalidPreload ? j : j.filter(function(ce) {
      return ce instanceof Date && Se(ce, !1);
    }), n.config.mode === "range" && n.selectedDates.sort(function(ce, be) {
      return ce.getTime() - be.getTime();
    });
  }
  function je(M, G, j) {
    if (G === void 0 && (G = !1), j === void 0 && (j = n.config.dateFormat), M !== 0 && !M || M instanceof Array && M.length === 0)
      return n.clear(G);
    we(M, j), n.latestSelectedDateObj = n.selectedDates[n.selectedDates.length - 1], n.redraw(), g(void 0, G), f(), n.selectedDates.length === 0 && n.clear(!1), X(G), G && ot("onChange");
  }
  function yt(M) {
    return M.slice().map(function(G) {
      return typeof G == "string" || typeof G == "number" || G instanceof Date ? n.parseDate(G, void 0, !0) : G && typeof G == "object" && G.from && G.to ? {
        from: n.parseDate(G.from, void 0),
        to: n.parseDate(G.to, void 0)
      } : G;
    }).filter(function(G) {
      return G;
    });
  }
  function Rt() {
    n.selectedDates = [], n.now = n.parseDate(n.config.now) || /* @__PURE__ */ new Date();
    var M = n.config.defaultDate || ((n.input.nodeName === "INPUT" || n.input.nodeName === "TEXTAREA") && n.input.placeholder && n.input.value === n.input.placeholder ? null : n.input.value);
    M && we(M, n.config.dateFormat), n._initialDate = n.selectedDates.length > 0 ? n.selectedDates[0] : n.config.minDate && n.config.minDate.getTime() > n.now.getTime() ? n.config.minDate : n.config.maxDate && n.config.maxDate.getTime() < n.now.getTime() ? n.config.maxDate : n.now, n.currentYear = n._initialDate.getFullYear(), n.currentMonth = n._initialDate.getMonth(), n.selectedDates.length > 0 && (n.latestSelectedDateObj = n.selectedDates[0]), n.config.minTime !== void 0 && (n.config.minTime = n.parseDate(n.config.minTime, "H:i")), n.config.maxTime !== void 0 && (n.config.maxTime = n.parseDate(n.config.maxTime, "H:i")), n.minDateHasTime = !!n.config.minDate && (n.config.minDate.getHours() > 0 || n.config.minDate.getMinutes() > 0 || n.config.minDate.getSeconds() > 0), n.maxDateHasTime = !!n.config.maxDate && (n.config.maxDate.getHours() > 0 || n.config.maxDate.getMinutes() > 0 || n.config.maxDate.getSeconds() > 0);
  }
  function sn() {
    if (n.input = st(), !n.input) {
      n.config.errorHandler(new Error("Invalid input element specified"));
      return;
    }
    n.input._type = n.input.type, n.input.type = "text", n.input.classList.add("flatpickr-input"), n._input = n.input, n.config.altInput && (n.altInput = Bn(n.input.nodeName, n.config.altInputClass), n._input = n.altInput, n.altInput.placeholder = n.input.placeholder, n.altInput.disabled = n.input.disabled, n.altInput.required = n.input.required, n.altInput.tabIndex = n.input.tabIndex, n.altInput.type = "text", n.input.setAttribute("type", "hidden"), !n.config.static && n.input.parentNode && n.input.parentNode.insertBefore(n.altInput, n.input.nextSibling)), n.config.allowInput || n._input.setAttribute("readonly", "readonly"), me();
  }
  function me() {
    n._positionElement = n.config.positionElement || n._input;
  }
  function He() {
    var M = n.config.enableTime ? n.config.noCalendar ? "time" : "datetime-local" : "date";
    n.mobileInput = Bn("input", n.input.className + " flatpickr-mobile"), n.mobileInput.tabIndex = 1, n.mobileInput.type = M, n.mobileInput.disabled = n.input.disabled, n.mobileInput.required = n.input.required, n.mobileInput.placeholder = n.input.placeholder, n.mobileFormatStr = M === "datetime-local" ? "Y-m-d\\TH:i:S" : M === "date" ? "Y-m-d" : "H:i:S", n.selectedDates.length > 0 && (n.mobileInput.defaultValue = n.mobileInput.value = n.formatDate(n.selectedDates[0], n.mobileFormatStr)), n.config.minDate && (n.mobileInput.min = n.formatDate(n.config.minDate, "Y-m-d")), n.config.maxDate && (n.mobileInput.max = n.formatDate(n.config.maxDate, "Y-m-d")), n.input.getAttribute("step") && (n.mobileInput.step = String(n.input.getAttribute("step"))), n.input.type = "hidden", n.altInput !== void 0 && (n.altInput.type = "hidden");
    try {
      n.input.parentNode && n.input.parentNode.insertBefore(n.mobileInput, n.input.nextSibling);
    } catch {
    }
    v(n.mobileInput, "change", function(G) {
      n.setDate(ya(G).value, !1, n.mobileFormatStr), ot("onChange"), ot("onClose");
    });
  }
  function tt(M) {
    if (n.isOpen === !0)
      return n.close();
    n.open(M);
  }
  function ot(M, G) {
    if (n.config !== void 0) {
      var j = n.config[M];
      if (j !== void 0 && j.length > 0)
        for (var ce = 0; j[ce] && ce < j.length; ce++)
          j[ce](n.selectedDates, n.input.value, n, G);
      M === "onChange" && (n.input.dispatchEvent(xn("change")), n.input.dispatchEvent(xn("input")));
    }
  }
  function xn(M) {
    var G = document.createEvent("Event");
    return G.initEvent(M, !0, !0), G;
  }
  function kt(M) {
    for (var G = 0; G < n.selectedDates.length; G++) {
      var j = n.selectedDates[G];
      if (j instanceof Date && Ta(j, M) === 0)
        return "" + G;
    }
    return !1;
  }
  function Dn(M) {
    return n.config.mode !== "range" || n.selectedDates.length < 2 ? !1 : Ta(M, n.selectedDates[0]) >= 0 && Ta(M, n.selectedDates[1]) <= 0;
  }
  function gn() {
    n.config.noCalendar || n.isMobile || !n.monthNav || (n.yearElements.forEach(function(M, G) {
      var j = new Date(n.currentYear, n.currentMonth, 1);
      j.setMonth(n.currentMonth + G), n.config.showMonths > 1 || n.config.monthSelectorType === "static" ? n.monthElements[G].textContent = g_(j.getMonth(), n.config.shorthandCurrentMonth, n.l10n) + " " : n.monthsDropdownContainer.value = j.getMonth().toString(), M.value = j.getFullYear().toString();
    }), n._hidePrevMonthArrow = n.config.minDate !== void 0 && (n.currentYear === n.config.minDate.getFullYear() ? n.currentMonth <= n.config.minDate.getMonth() : n.currentYear < n.config.minDate.getFullYear()), n._hideNextMonthArrow = n.config.maxDate !== void 0 && (n.currentYear === n.config.maxDate.getFullYear() ? n.currentMonth + 1 > n.config.maxDate.getMonth() : n.currentYear > n.config.maxDate.getFullYear()));
  }
  function Vn(M) {
    var G = M || (n.config.altInput ? n.config.altFormat : n.config.dateFormat);
    return n.selectedDates.map(function(j) {
      return n.formatDate(j, G);
    }).filter(function(j, ce, be) {
      return n.config.mode !== "range" || n.config.enableTime || be.indexOf(j) === ce;
    }).join(n.config.mode !== "range" ? n.config.conjunction : n.l10n.rangeSeparator);
  }
  function X(M) {
    M === void 0 && (M = !0), n.mobileInput !== void 0 && n.mobileFormatStr && (n.mobileInput.value = n.latestSelectedDateObj !== void 0 ? n.formatDate(n.latestSelectedDateObj, n.mobileFormatStr) : ""), n.input.value = Vn(n.config.dateFormat), n.altInput !== void 0 && (n.altInput.value = Vn(n.config.altFormat)), M !== !1 && ot("onValueUpdate");
  }
  function te(M) {
    var G = ya(M), j = n.prevMonthNav.contains(G), ce = n.nextMonthNav.contains(G);
    j || ce ? V(j ? -1 : 1) : n.yearElements.indexOf(G) >= 0 ? G.select() : G.classList.contains("arrowUp") ? n.changeYear(n.currentYear + 1) : G.classList.contains("arrowDown") && n.changeYear(n.currentYear - 1);
  }
  function _e(M) {
    M.preventDefault();
    var G = M.type === "keydown", j = ya(M), ce = j;
    n.amPM !== void 0 && j === n.amPM && (n.amPM.textContent = n.l10n.amPM[Wa(n.amPM.textContent === n.l10n.amPM[0])]);
    var be = parseFloat(ce.getAttribute("min")), Ie = parseFloat(ce.getAttribute("max")), Ue = parseFloat(ce.getAttribute("step")), Ve = parseInt(ce.value, 10), dt = M.delta || (G ? M.which === 38 ? 1 : -1 : 0), Pe = Ve + Ue * dt;
    if (typeof ce.value < "u" && ce.value.length === 2) {
      var xe = ce === n.hourElement, Mt = ce === n.minuteElement;
      Pe < be ? (Pe = Ie + Pe + Wa(!xe) + (Wa(xe) && Wa(!n.amPM)), Mt && S(void 0, -1, n.hourElement)) : Pe > Ie && (Pe = ce === n.hourElement ? Pe - Ie - Wa(!n.amPM) : be, Mt && S(void 0, 1, n.hourElement)), n.amPM && xe && (Ue === 1 ? Pe + Ve === 23 : Math.abs(Pe - Ve) > Ue) && (n.amPM.textContent = n.l10n.amPM[Wa(n.amPM.textContent === n.l10n.amPM[0])]), ce.value = ia(Pe);
    }
  }
  return i(), n;
}
function ad(e, t) {
  for (var n = Array.prototype.slice.call(e).filter(function(o) {
    return o instanceof HTMLElement;
  }), r = [], i = 0; i < n.length; i++) {
    var a = n[i];
    try {
      if (a.getAttribute("data-fp-omit") !== null)
        continue;
      a._flatpickr !== void 0 && (a._flatpickr.destroy(), a._flatpickr = void 0), a._flatpickr = kFe(a, t || {}), r.push(a._flatpickr);
    } catch (o) {
      console.error(o);
    }
  }
  return r.length === 1 ? r[0] : r;
}
typeof HTMLElement < "u" && typeof HTMLCollection < "u" && typeof NodeList < "u" && (HTMLCollection.prototype.flatpickr = NodeList.prototype.flatpickr = function(e) {
  return ad(this, e);
}, HTMLElement.prototype.flatpickr = function(e) {
  return ad([this], e);
});
var Kr = function(e, t) {
  return typeof e == "string" ? ad(window.document.querySelectorAll(e), t) : e instanceof Node ? ad([e], t) : ad(e, t);
};
Kr.defaultConfig = {};
Kr.l10ns = {
  en: Ni({}, Yp),
  default: Ni({}, Yp)
};
Kr.localize = function(e) {
  Kr.l10ns.default = Ni(Ni({}, Kr.l10ns.default), e);
};
Kr.setDefaults = function(e) {
  Kr.defaultConfig = Ni(Ni({}, Kr.defaultConfig), e);
};
Kr.parseDate = zC({});
Kr.formatDate = F8({});
Kr.compareDates = Ta;
typeof jQuery < "u" && typeof jQuery.fn < "u" && (jQuery.fn.flatpickr = function(e) {
  return ad(this, e);
});
Date.prototype.fp_incr = function(e) {
  return new Date(this.getFullYear(), this.getMonth(), this.getDate() + (typeof e == "string" ? parseInt(e, 10) : e));
};
typeof window < "u" && (window.flatpickr = Kr);
var B8 = {
  name: "DatepickerWrapper",
  emits: ["change"],
  props: {
    value: {
      required: !0
    },
    options: {
      type: [Object],
      required: !0
    },
    id: {
      type: [Number, String],
      required: !0
    },
    placeholder: {
      type: [Number, String],
      required: !1
    },
    attrs: {
      required: !1,
      type: [Object],
      default: () => ({})
    }
  },
  setup(e, t) {
    var {
      id: n,
      options: r,
      value: i
    } = De(e), {
      el$: a,
      form$: o,
      Size: s,
      View: l,
      classesInstance: u,
      classes: c,
      Templates: d,
      template: f,
      theme: h
    } = bi(e, t), m = fi().proxy, v = he(null), b = he(null), y = N(() => a.value.available), g = N(() => {
      var R, D;
      return ((R = m.$vueform.i18n.locales[m.$vueform.i18n.locale]) === null || R === void 0 || (R = R.vueform) === null || R === void 0 ? void 0 : R.datepicker) || ((D = m.$vueform.i18n.locales[m.$vueform.i18n.fallbackLocale]) === null || D === void 0 || (D = D.vueform) === null || D === void 0 ? void 0 : D.datepicker) || {};
    }), E = N(() => r.value.mode || "single"), S = N(() => {
      var R = {};
      return Te(r.value, (D, q) => {
        D != null && (R[q] = D);
      }), R.static = !0, R;
    }), C = (R) => {
      t.emit("change", E.value == "single" ? R[0] || null : R);
    }, T = () => {
      v.value.input.parentElement.id = "datepicker-" + n.value;
    }, O = /* @__PURE__ */ function() {
      var R = ht(function* () {
        b.value || (yield Ut()), v.value = Kr(b.value, Object.assign({}, S.value, {
          onChange: (D) => {
            C(D);
          },
          onClose: (D) => {
            D = E.value == "range" && D.length < 2 ? [] : D, C(D);
          },
          // creating a date object from a string date provided in displayFormat (to value)
          parseDate: (D, q) => Ge(D, q, !0).toDate(),
          // creating a date string according to displayFormat (to display)
          formatDate: (D, q) => Ge(D).format(q),
          ariaDateFormat: "MMMM D, YYYY",
          disableMobile: !0,
          locale: g.value
        })), v.value.calendarContainer && c.value.calendarContainer.forEach((D) => {
          v.value.calendarContainer.classList.add(D);
        }), T(), i.value !== null && v.value.setDate(i.value, !1);
      });
      return function() {
        return R.apply(this, arguments);
      };
    }();
    return et(i, (R, D) => {
      var q;
      (q = v.value) === null || q === void 0 || q.setDate(R, !1);
    }), et(n, (R, D) => {
      T();
    }, {
      immediate: !1
    }), et(r, (R, D) => {
      zd(R, D) || O();
    }, {
      deep: !0
    }), et([g, y], (R, D) => {
      O();
    }, {
      deep: !0
    }), On(() => {
      O();
    }), {
      el$: a,
      form$: o,
      Size: s,
      View: l,
      classesInstance: u,
      theme: h,
      classes: c,
      Templates: d,
      template: f,
      datepicker$: v,
      input: b,
      config: S,
      mode: E,
      locale: g,
      update: C,
      init: O
    };
  }
}, $8 = {
  name: "EditorWrapper",
  emits: ["input", "alert", "error", "blur"],
  props: {
    value: {
      required: !1,
      default: null
    },
    placeholder: {
      required: !1,
      type: [String, Number],
      default: null
    },
    name: {
      required: !1,
      type: [String, Number],
      default: null
    },
    id: {
      required: !1,
      type: [String, Number],
      default: null
    },
    accept: {
      required: !1,
      type: Array,
      default: () => []
    },
    acceptMimes: {
      required: !1,
      type: Array,
      default: () => []
    },
    endpoint: {
      required: !1,
      type: [String, Function],
      default: null
    },
    method: {
      required: !1,
      type: String,
      default: "post"
    },
    disabled: {
      required: !1,
      type: Boolean,
      default: !1
    },
    hideTools: {
      required: !1,
      type: [Array],
      default: () => []
    },
    attrs: {
      required: !1,
      type: [Object],
      default: () => ({})
    }
  },
  setup(e, t) {
    var {
      value: n,
      disabled: r,
      acceptMimes: i,
      accept: a,
      endpoint: o,
      method: s,
      attrs: l,
      placeholder: u,
      id: c
    } = De(e), {
      el$: d,
      form$: f,
      Size: h,
      View: m,
      classesInstance: v,
      classes: b,
      Templates: y,
      template: g,
      theme: E
    } = bi(e, t), S = he(null), C = N(() => o.value ? typeof o.value == "function" ? o.value : f.value.$vueform.config.endpoints[o.value] || o.value : typeof f.value.$vueform.config.endpoints.attachment == "function" ? f.value.$vueform.config.endpoints.attachment : f.value.$vueform.config.endpoints.attachment.url), T = N(() => typeof C.value == "function" ? null : o.value && f.value.$vueform.config.endpoints[o.value] ? f.value.$vueform.config.endpoints[o.value] : s.value || f.value.$vueform.config.endpoints.attachment.method), O = N(() => oF("trix-editor", mt(mt({}, l.value), {}, {
      placeholder: u.value,
      disabled: r.value,
      id: c.value,
      input: "editor-input-".concat(c.value),
      ref: "editor$"
    }))), R = (L) => {
      typeof L == "number" && (L = String(L)), S.value.editor.loadHTML(L);
    }, D = (L, x) => {
      S.value[L] = x;
    }, q = () => {
      S.value.value == n.value || !S.value.value && !n.value || t.emit("input", {
        target: {
          value: S.value.value
        }
      });
    }, $ = (L) => {
      if (r.value) {
        L.preventDefault();
        return;
      }
      if (!L.file) {
        L.preventDefault();
        return;
      }
      i.value && i.value.length && i.value.indexOf(L.file.type) === -1 && (L.preventDefault(), t.emit("alert", f.value.__(f.value.translations.vueform.editor.acceptedMimesError, {
        mimes: i.value.join(", ")
      })));
      var x = L.file.name.split(".").pop();
      a.value && a.value.length && a.value.indexOf(x) === -1 && (L.preventDefault(), t.emit("alert", f.value.__(f.value.translations.vueform.editor.acceptedExtensionsError, {
        extensions: a.value.join(", ")
      })));
    }, P = /* @__PURE__ */ function() {
      var L = ht(function* (x) {
        if (x.attachment.file) {
          var I = new FormData();
          I.append("Content-Type", x.attachment.file.type), I.append("file", x.attachment.file);
          var k;
          try {
            typeof C.value == "function" ? k = yield C.value(x.attachment, d.value) : (k = yield d.value.$vueform.services.axios.request({
              url: C.value,
              method: T.value,
              [T.value.toLowerCase() === "get" ? "params" : "data"]: I,
              onUploadProgress: (B) => {
                x.attachment.setUploadProgress(Math.round(B.loaded * 100 / B.total));
              }
            }), k = k.data), x.attachment.setAttributes({
              url: k.url,
              href: k.href
            });
          } catch (B) {
            t.emit("error", B);
          }
        }
      });
      return function(I) {
        return L.apply(this, arguments);
      };
    }(), Y = () => {
      t.emit("blur");
    };
    return et(r, (L) => {
      S.value.contentEditable = !L;
    }), On(() => {
      r.value && (S.value.contentEditable = !1), S.value.addEventListener("trix-change", q), S.value.addEventListener("trix-blur", Y), S.value.addEventListener("trix-file-accept", $), S.value.addEventListener("trix-attachment-add", P);
    }), pa(() => {
      var L, x, I, k;
      (L = S.value) === null || L === void 0 || L.removeEventListener("trix-change", q), (x = S.value) === null || x === void 0 || x.removeEventListener("trix-blur", Y), (I = S.value) === null || I === void 0 || I.removeEventListener("trix-file-accept", $), (k = S.value) === null || k === void 0 || k.removeEventListener("trix-attachment-add", P);
    }), {
      el$: d,
      form$: f,
      Size: h,
      View: m,
      classesInstance: v,
      resolvedEndpoint: C,
      editorComponent: O,
      theme: E,
      classes: b,
      Templates: y,
      template: g,
      editor$: S,
      update: R,
      setOption: D,
      handleChange: q,
      handleFileAccept: $,
      handleAttachmentAdd: P,
      handleBlur: Y
    };
  }
}, ir = function(t, n, r) {
  var {
    label: i
  } = De(t), a = r.form$, o = r.el$, s = En("config$"), l = N(() => {
    var f, h;
    return !!(a.value.options.forceLabels || i.value || o.value.slots.label || (f = o.value.$slots) !== null && f !== void 0 && f.label || /* istanbul ignore next: vue2 */
    a.value.$vueform.vueVersion === 2 && (h = o.value.$scopedSlots) !== null && h !== void 0 && h.label);
  }), u = N(() => typeof i.value == "function" && (!i.value.prototype || !i.value.prototype.constructor || i.value.prototype.constructor && i.value.prototype.constructor.name !== "VueComponent")), c = N(() => Gp(i.value)), d = N(() => {
    var f = u.value ? i.value(o.value) : i.value || null;
    return c.value || (f = oi(f, s.value, a.value)), f;
  });
  return {
    hasLabel: l,
    Label: d
  };
}, ar = function(t, n, r) {
  var {
    columns: i,
    presets: a
  } = De(t), o = r.form$, s = r.theme, l = r.hasLabel, u = he(pn(i.value)), c = N(() => {
    var m = o.value.$vueform.config;
    return new o.value.$vueform.services.columns({
      configPresetColumns: m.usePresets,
      configColumns: m.columns,
      formPresetColumns: o.value.options.presets,
      formColumns: o.value.options.columns,
      elementPresetColumns: a.value,
      elementColumns: u.value
    }, l.value, s.value.columns, m.presets);
  }), d = N(() => c.value.classes), f = N(() => c.value.cols), h = (m) => {
    u.value = pn(m);
  };
  return et(i, (m) => {
    u.value = pn(m);
  }, {
    immediate: !1,
    deep: !0
  }), {
    cols: f,
    columnsClassesService: c,
    columnsClasses: d,
    updateColumns: h
  };
}, or = function(t, n, r) {
  var {
    size: i,
    view: a,
    views: o,
    presets: s
  } = De(t), l = n.name, u = r.available, c = r.active, d = r.form$, f = r.parent, h = he(!1), m = N(() => u.value && !h.value && c.value), v = N(() => {
    var S;
    return i.value ? S = i.value : Te(s.value, (C) => {
      var T = d.value.$vueform.config.presets[C];
      !T || !T.size || (S = T.size);
    }), S || (f.value ? S = f.value.Size : S = d.value.Size), S;
  }), b = N(() => a.value ? a.value : y.value[l.value]), y = N(() => {
    var S = d.value.Views;
    return Te(s.value, (C) => {
      var T = d.value.$vueform.config.presets[C];
      !T || !T.views || (S = Object.assign({}, S, T.views));
    }), S = Object.assign({}, S, o.value), S;
  }), g = () => {
    h.value = !0;
  }, E = () => {
    h.value = !1;
  };
  return aa("Size", v), aa("View", b), aa("Views", y), {
    hidden: h,
    visible: m,
    Size: v,
    View: b,
    Views: y,
    hide: g,
    show: E
  };
}, Xn = function(t, n, r) {
  var {
    templates: i,
    presets: a
  } = De(t), o = n.name, s = r.theme, l = r.View, u = r.form$, c = N(() => {
    var f = {};
    return Te(a ? a.value : [], (h) => {
      var m = u.value.$vueform.config.presets[h];
      !m || !m.templates || (f = Object.assign({}, f, m.templates));
    }), mt(mt(mt({}, s.value.templates), f), i ? i.value : {});
  }), d = N(() => l && l.value && c.value["".concat(o.value, "_").concat(l.value)] ? c.value["".concat(o.value, "_").concat(l.value)] : c.value[o.value]);
  return {
    Templates: c,
    template: d
  };
}, sr = function(t, n, r) {
  var i = arguments.length > 3 && arguments[3] !== void 0 ? arguments[3] : {};
  De(t);
  var a = r.el$, o = ["label", "info", "description", "before", "between", "after"], s = ["checkbox", "radio", "option", "single-label", "multiple-label", "tag", "no-results", "no-options", "after-list", "before-list", "placeholder", "group-label", "caret", "clear", "spinner", "option", "default", "addon-before", "addon-after"], l = N(() => {
    var c = {};
    return o.filter((d) => i.slots.indexOf(d) !== -1).forEach((d) => {
      var f = a.value.slots[d] || a.value.slots[p_(d)];
      typeof f == "object" && (f.props && (Array.isArray(f.props) && f.props.indexOf("el$") === -1 || !Array.isArray(f.props) && Object.keys(f.props).indexOf("el$") === -1) ? Array.isArray(f.props) ? f.props.push("el$") : f.props.el$ = {
        type: Object,
        required: !0
      } : f.props || (f.props = ["el$"])), c[d] = f;
    }), c;
  }), u = N(() => {
    var c = {};
    return s.filter((d) => i.slots.indexOf(d) !== -1).forEach((d) => {
      var f = a.value.slots[d] || a.value.slots[p_(d)];
      typeof f == "object" && (f.props && (Array.isArray(f.props) && f.props.indexOf("el$") === -1 || !Array.isArray(f.props) && Object.keys(f.props).indexOf("el$") === -1) ? Array.isArray(f.props) ? f.props.push("el$") : f.props.el$ = {
        type: Object,
        required: !0
      } : f.props || (f.props = ["el$"])), c[d] = f;
    }), c;
  });
  return {
    elementSlots: l,
    fieldSlots: u
  };
}, MFe = function(t, n, r) {
  var {
    buttonLabel: i,
    buttonType: a,
    href: o,
    target: s,
    loading: l,
    onClick: u,
    resets: c,
    submits: d
  } = De(t), f = r.form$, h = r.isDisabled, m = r.fieldId, v = r.fire, b = r.el$, y = N(() => typeof l.value == "function" ? l.value(f.value, b.value) : d.value && (f.value.submitting || f.value.preparing || f.value.isLoading) ? !0 : l.value), g = N(() => i.value !== null && typeof i.value == "object"), E = N(() => {
    var C = {
      id: m.value
    };
    switch (a.value) {
      case "anchor":
        C.href = o.value, C.target = s.value;
        break;
      case "button":
        C.disabled = h.value;
        break;
    }
    return y.value && (C.tabindex = void 0), C;
  }), S = (C) => {
    if (a.value === "anchor" && !o.value && C.preventDefault(), h.value || y.value) {
      C.preventDefault();
      return;
    }
    c.value && f.value.reset(), d.value && f.value.submit(), typeof u.value == "function" && v("click", f.value, b.value, C);
  };
  return {
    isButtonLabelComponent: g,
    button: E,
    isLoading: y,
    handleClick: S
  };
}, lr = function(t, n, r) {
  var {
    layout: i,
    inline: a
  } = De(t), o = N(() => a.value || !i.value ? "ElementLayoutInline" : i.value);
  return {
    elementLayout: o
  };
}, Zn = function(t, n, r) {
  var {
    id: i,
    name: a
  } = De(t), o = r.parent, s = N(() => {
    var l, u;
    return i.value || ((l = o.value) !== null && l !== void 0 && l.fieldId ? "".concat((u = o.value) === null || u === void 0 ? void 0 : u.fieldId, ".").concat(a.value) : a.value);
  });
  return {
    fieldId: s
  };
}, ur = function(t, n, r) {
  var {
    container: i
  } = r, a = () => {
    var o, s, l = ((o = i.value) === null || o === void 0 ? void 0 : o.$el) || i.value;
    l == null || (s = l.querySelector("a[href],area[href],input:not([disabled]),select:not([disabled]),textarea:not([disabled]),button:not([disabled]),iframe,[tabindex],[contentEditable=true],trix-editor")) === null || s === void 0 || s.focus();
  };
  return {
    focus: a
  };
}, PFe = function(t, n, r) {
  var {
    input: i
  } = r, a = () => {
    i.value.editor$.focus();
  };
  return {
    focus: a
  };
}, FFe = jA, BFe = 4;
function $Fe(e) {
  return FFe(e, BFe);
}
var bo = $Fe, qr = function(t, n, r) {
  var {
    disabled: i
  } = De(t), a = he(null), o = N(() => i.value && a.value !== !1 || a.value === !0), s = () => {
    a.value = !0;
  }, l = () => {
    a.value = !1;
  };
  return {
    localDisabled: a,
    isDisabled: o,
    disable: s,
    enable: l
  };
}, U8 = function(t, n, r) {
  var {
    disables: i
  } = De(t), {
    localDisabled: a,
    isDisabled: o
  } = qr(t), s = he([]), l = (f) => {
    At(f) || (f = [f]);
    var h = bo(s.value);
    Te(f, (m) => {
      m = String(m), h.indexOf(m) === -1 && h.push(m);
    }), s.value = h;
  }, u = (f) => {
    At(f) || (f = [f]);
    var h = bo(s.value);
    Te(f, (m) => {
      m = String(m);
      var v = h.indexOf(m);
      v !== -1 && h.splice(v, 1);
    }), s.value = h;
  }, c = () => {
    a.value = !0;
  }, d = () => {
    a.value = !1, s.value = [];
  };
  return s.value = Ku(i.value || /* istanbul ignore next: can't fall into this, because it is hardwired to be `[]` if undefined */
  [], (f) => String(f)), {
    disabledItems: s,
    isDisabled: o,
    disableAll: c,
    enableAll: d,
    disable: l,
    enable: u
  };
}, UFe = function(t, n, r) {
  var {
    disabled: i,
    submits: a
  } = De(t), o = r.form$, s = r.el$, l = N(() => typeof i.value == "function" ? i.value(s.value, o.value) : a.value && (o.value.invalid && o.value.shouldValidateOnChange || o.value.busy || o.value.isDisabled) ? !0 : i.value);
  return {
    isDisabled: l
  };
}, qFe = U8, Lr = function(t, n, r) {
  var i = r.fieldId, a = r.invalid, o = r.isDisabled, s = r.busy, l = N(() => "".concat(i.value, "__label")), u = N(() => "".concat(i.value, "__description")), c = N(() => "".concat(i.value, "__info")), d = N(() => "".concat(i.value, "__error")), f = N(() => ({
    "aria-labelledby": l.value,
    "aria-describedby": "".concat(u.value, " ").concat(c.value),
    "aria-invalid": a.value,
    "aria-errormessage": d.value,
    "aria-disabled": o == null ? void 0 : o.value,
    "aria-busy": s.value
  }));
  return {
    descriptionId: u,
    labelId: l,
    infoId: c,
    errorId: d,
    aria: f
  };
}, eO = function(t, n, r) {
  var {
    text: i
  } = De(t), {
    descriptionId: a,
    labelId: o,
    infoId: s,
    errorId: l
  } = Lr(t, n, r), u = r.invalid, c = r.isDisabled, d = r.busy, f = N(() => {
    var h = {
      "aria-label": i.value,
      "aria-describedby": "".concat(o.value, " ").concat(a.value, " ").concat(s.value),
      "aria-invalid": u.value,
      "aria-errormessage": l.value,
      "aria-disabled": c.value,
      "aria-busy": d.value
    };
    return h["aria-label"] || (h["aria-labelledby"] = o.value), h;
  });
  return {
    descriptionId: a,
    labelId: o,
    infoId: s,
    errorId: l,
    aria: f
  };
}, tO = function(t, n, r) {
  var {
    descriptionId: i,
    labelId: a,
    infoId: o,
    errorId: s
  } = Lr(t, n, r), l = r.invalid, u = r.isDisabled, c = r.busy, d = N(() => ({
    "aria-describedby": "".concat(i.value, " ").concat(o.value),
    "aria-invalid": l.value,
    "aria-errormessage": s.value,
    "aria-disabled": u.value,
    "aria-busy": c.value
  }));
  return {
    descriptionId: i,
    labelId: a,
    infoId: o,
    errorId: s,
    aria: d
  };
}, GFe = function(t, n, r) {
  var {
    descriptionId: i,
    labelId: a,
    infoId: o,
    errorId: s
  } = Lr(t, n, r), l = r.isDisabled, u = N(() => ({
    "aria-labelledby": a.value,
    "aria-describedby": "".concat(i.value, " ").concat(o.value),
    "aria-disabled": l.value
  }));
  return {
    descriptionId: i,
    labelId: a,
    infoId: o,
    errorId: s,
    aria: u
  };
}, YFe = function(t, n, r) {
  var {
    descriptionId: i,
    labelId: a,
    infoId: o,
    errorId: s
  } = Lr(t, n, r), l = N(() => ({
    "aria-labelledby": a.value,
    "aria-describedby": "".concat(i.value, " ").concat(o.value)
  }));
  return {
    descriptionId: i,
    labelId: a,
    infoId: o,
    errorId: s,
    aria: l
  };
}, HFe = tO, zFe = eO, VFe = eO, WFe = tO, KFe = A$, jFe = KFe("toLowerCase"), QM = jFe, QFe = function(t, n, r) {
  var {
    name: i
  } = De(t), a = fi(), o = r.form$, s = (u, c) => {
    u.children$Array ? u.children$Array.push(a.proxy) : u.elements$ ? o.value.$set(u.elements$, i.value, a.proxy) : c(u.$parent, c);
  }, l = (u, c) => {
    u.children$Array ? u.children$Array.splice(u.children$Array.map((d) => Ur(d.name)).indexOf(Ur(i.value)), 1) : u.elements$ ? o.value.$delete(u.elements$, i.value) : c(u.$parent, c);
  };
  return {
    assignToParent: s,
    removeFromParent: l
  };
}, Gr = function(t, n, r) {
  var i = ["onBeforeCreate", "onCreated"], a = {
    onBeforeMount: Gu,
    onMounted: On,
    onBeforeUpdate: iF,
    onUpdated: aF,
    onBeforeUnmount: pa,
    onUnmounted: l1
  }, o = fi(), s = r.form$, l = r.fire, {
    assignToParent: u,
    removeFromParent: c
  } = QFe(t, n, {
    form$: s
  }), d = he(null), f = he(!1), h = he(!0), m = N(() => !1), v = N(() => !1), b = N(() => !1), y = N(() => !1), g = N(() => h.value), E = N(() => o.proxy), S = () => {
    h.value = !0;
  }, C = () => {
    h.value = !1;
  };
  return aa("el$", E), Gu(() => {
    u(o.proxy.$parent, u);
  }), On(() => {
    f.value = !0;
  }), pa(() => {
    c(o.proxy.$parent, c);
  }), Object.values(i).forEach((T) => {
    l(QM(T.replace("on", "")), E.value);
  }), Object.keys(a).forEach((T) => {
    a[T](() => {
      l(QM(T.replace("on", "")), E.value);
    });
  }), {
    el$: E,
    isStatic: m,
    isFileType: v,
    isArrayType: y,
    isImageType: b,
    isActive: g,
    active: h,
    mounted: f,
    container: d,
    activate: S,
    deactivate: C
  };
}, Vd = function(t, n, r) {
  var {
    el$: i,
    isStatic: a,
    isFileType: o,
    isImageType: s,
    isActive: l,
    active: u,
    mounted: c,
    container: d,
    activate: f,
    deactivate: h
  } = Gr(t, n, r), m = N(() => !0);
  return {
    el$: i,
    isStatic: a,
    isFileType: o,
    isArrayType: m,
    isImageType: s,
    isActive: l,
    active: u,
    mounted: c,
    container: d,
    activate: f,
    deactivate: h
  };
}, XFe = function(t, n, r) {
  var {
    view: i
  } = De(t), {
    el$: a,
    isStatic: o,
    isArrayType: s,
    isActive: l,
    active: u,
    mounted: c,
    container: d,
    activate: f,
    deactivate: h
  } = Gr(t, n, r), m = N(() => !0), v = N(() => ["gallery", "image"].indexOf(i.value) !== -1);
  return {
    el$: a,
    isStatic: o,
    isFileType: m,
    isArrayType: s,
    isImageType: v,
    isActive: l,
    active: u,
    mounted: c,
    container: d,
    activate: f,
    deactivate: h
  };
}, q8 = function(t, n, r) {
  var {
    el$: i,
    isArrayType: a,
    isFileType: o,
    isImageType: s,
    isActive: l,
    active: u,
    mounted: c,
    container: d,
    activate: f,
    deactivate: h
  } = Gr(t, n, r), m = N(() => !0);
  return {
    el$: i,
    isStatic: m,
    isFileType: o,
    isArrayType: a,
    isImageType: s,
    isActive: l,
    active: u,
    mounted: c,
    container: d,
    activate: f,
    deactivate: h
  };
}, ZFe = Vd, JFe = Vd, e3e = Vd, t3e = Vd, cr = function(t, n, r) {
  var {
    name: i
  } = De(t), a = fi(), {
    form$: o
  } = r, s = N(() => {
    var d = (f, h) => f && (o.value.$vueform.vueVersion === 3 && f.$options.name && f.$options.name.match(/^[a-zA-Z\-]*Element$/) || o.value.$vueform.vueVersion === 2 && f.hasOwnProperty("el$") && typeof f.el$ != "function") ? f.el$ : f.$parent ? h(f.$parent, h) : null;
    return d(o.value.$vueform.vueVersion === 3 ? a.parent.proxy : a.proxy.$parent, d);
  }), l = N(() => s.value && s.value.path ? s.value.path + "." + i.value : i.value), u = N(() => s.value && s.value.dataPath ? s.value.dataPath + "." + i.value : i.value), c = N(() => !1);
  return {
    parent: s,
    path: l,
    dataPath: u,
    flat: c
  };
}, n3e = function(t, n, r) {
  var {
    path: i,
    parent: a
  } = cr(t, n, r), o = N(() => a.value && a.value.dataPath ? a.value.dataPath : null), s = N(() => !0);
  return {
    path: i,
    dataPath: o,
    flat: s,
    parent: a
  };
}, G8 = function(t, n, r) {
  var {
    path: i,
    parent: a,
    flat: o
  } = cr(t, n, r);
  return {
    path: i,
    flat: o,
    parent: a
  };
};
function Uv(e, t, n) {
  var r = n.deps || {};
  return n = mt(mt({}, n), {}, {
    events: t.emits,
    slots: t.slots
  }), t.features.forEach((i) => {
    Te(i(e, t, r, n), (a, o) => {
      r[o] = a;
    });
  }), r;
}
var Yr = function(t, n) {
  var r = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : {}, i = Uv(t, n, r);
  return On(() => {
    i.initWatcher && i.initWatcher(), i.initMessageBag && i.initMessageBag(), i.initValidation && i.initValidation();
  }), mt({}, i);
}, Y8 = function(t, n) {
  var r = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : {}, i = Uv(t, n, r);
  return mt({}, i);
}, nO = function(t, n) {
  var r = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : {}, i = Uv(t, n, r);
  return On(() => {
    i.initWatcher(), i.initState(), i.initMessageBag(), i.initValidation();
  }), mt({}, i);
}, r3e = function(t, n) {
  var r = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : {}, {
    displayKey: i
  } = De(t), a = Uv(t, n, r);
  return On(() => {
    a.value.value[i.value] && (a.input.value.value = a.value.value[i.value]);
  }), On(() => {
    a.initWatcher(), a.initMessageBag(), a.initValidation();
  }), mt({}, a);
}, Jn = {
  props: {
    name: {
      required: !0,
      type: [String, Number]
    },
    conditions: {
      required: !1,
      type: [Array],
      default: () => []
    },
    onBeforeCreate: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    },
    onCreated: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    },
    onBeforeMount: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    },
    onMounted: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    },
    onBeforeUpdate: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    },
    onUpdated: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    },
    onBeforeUnmount: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    },
    onUnmounted: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    }
  }
}, dr = {
  props: {
    inline: {
      required: !1,
      type: [Boolean],
      default: !1
    },
    layout: {
      required: !1,
      type: [String, Object, Boolean],
      default: "ElementLayout",
      private: !0
    },
    addClass: {
      required: !1,
      type: [Array, Object, String],
      default: null
    },
    removeClass: {
      required: !1,
      type: [Array, Object],
      default: null
    },
    replaceClass: {
      required: !1,
      type: [Object],
      default: null
    },
    overrideClass: {
      required: !1,
      type: [Array, Object, String],
      default: null
    },
    addClasses: {
      required: !1,
      type: [Object],
      default: () => ({})
    },
    replaceClasses: {
      required: !1,
      type: [Object],
      default: () => ({})
    },
    removeClasses: {
      required: !1,
      type: [Object],
      default: () => ({})
    },
    overrideClasses: {
      required: !1,
      type: [Object],
      default: () => ({})
    },
    presets: {
      required: !1,
      type: [Array],
      default: () => []
    },
    view: {
      required: !1,
      type: [String],
      default: void 0
    },
    views: {
      required: !1,
      type: [Object],
      default: () => ({})
    },
    size: {
      required: !1,
      type: [String],
      default: void 0
    },
    columns: {
      required: !1,
      type: [Object, String, Number],
      default: null
    },
    templates: {
      required: !1,
      type: [Object],
      default: () => ({})
    },
    description: {
      required: !1,
      type: [String, Object],
      localized: !0,
      default: null
    },
    info: {
      required: !1,
      type: [String, Object],
      localized: !0,
      default: null
    },
    infoPosition: {
      required: !1,
      type: [String],
      default: "right"
    },
    label: {
      required: !1,
      type: [String, Object, Function],
      localized: !0,
      default: null
    },
    before: {
      required: !1,
      type: [Object, String, Number],
      localized: !0,
      default: null
    },
    between: {
      required: !1,
      type: [Object, String, Number],
      localized: !0,
      default: null
    },
    after: {
      required: !1,
      type: [Object, String, Number],
      localized: !0,
      default: null
    },
    slots: {
      required: !1,
      type: [Object],
      default: () => ({})
    }
  }
}, H8 = {
  name: "ButtonElement",
  mixins: [Jn, dr],
  emits: ["click", "beforeCreate", "created", "beforeMount", "mounted", "beforeUpdate", "updated", "beforeUnmount", "unmounted"],
  props: {
    type: {
      required: !1,
      type: [String],
      default: "button",
      private: !0
    },
    buttonLabel: {
      required: !1,
      type: [String, Object, Function],
      default: null
    },
    buttonType: {
      required: !1,
      type: [String],
      default: "button"
      // button|anchor
    },
    buttonClass: {
      required: !1,
      type: [String, Array, Object],
      default: null
    },
    id: {
      required: !1,
      type: [String],
      default: null
    },
    disabled: {
      required: !1,
      type: [Function, Boolean],
      default: !1
    },
    loading: {
      required: !1,
      type: [Function, Boolean],
      default: !1
    },
    href: {
      required: !1,
      type: [String],
      default: ""
    },
    target: {
      required: !1,
      type: [String],
      default: null
    },
    onClick: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    },
    resets: {
      required: !1,
      type: [Boolean],
      default: !1
    },
    submits: {
      required: !1,
      type: [Boolean],
      default: !1
    },
    secondary: {
      required: !1,
      type: [Boolean],
      default: !1
    },
    danger: {
      required: !1,
      type: [Boolean],
      default: !1
    },
    full: {
      required: !1,
      type: [Boolean],
      default: !1
    },
    align: {
      required: !1,
      type: [String],
      default: void 0
    }
  },
  setup(e, t) {
    return t.features = [Hn, zn, lr, G8, Mn, q8, UFe, Qn, ir, or, Xn, Zn, MFe, rr, ar, sr, GFe, ur], t.slots = ["label", "info", "description", "before", "between", "after", "default"], mt({}, Y8(e, t));
  }
}, ei = function(t, n, r) {
  var i = he(null);
  return {
    input: i
  };
};
function i3e(e, t) {
  var n = e.length;
  for (e.sort(t); n--; )
    e[n] = e[n].value;
  return e;
}
var a3e = i3e, XM = wm;
function o3e(e, t) {
  if (e !== t) {
    var n = e !== void 0, r = e === null, i = e === e, a = XM(e), o = t !== void 0, s = t === null, l = t === t, u = XM(t);
    if (!s && !u && !a && e > t || a && o && l && !s && !u || r && o && l || !n && l || !i)
      return 1;
    if (!r && !a && !u && e < t || u && n && i && !r && !a || s && n && i || !o && i || !l)
      return -1;
  }
  return 0;
}
var s3e = o3e, l3e = s3e;
function u3e(e, t, n) {
  for (var r = -1, i = e.criteria, a = t.criteria, o = i.length, s = n.length; ++r < o; ) {
    var l = l3e(i[r], a[r]);
    if (l) {
      if (r >= s)
        return l;
      var u = n[r];
      return l * (u == "desc" ? -1 : 1);
    }
  }
  return e.index - t.index;
}
var c3e = u3e, DT = qd, d3e = xm, f3e = Qs, p3e = X$, m3e = a3e, h3e = Sm, g3e = c3e, _3e = Tm, v3e = At;
function b3e(e, t, n) {
  t.length ? t = DT(t, function(a) {
    return v3e(a) ? function(o) {
      return d3e(o, a.length === 1 ? a[0] : a);
    } : a;
  }) : t = [_3e];
  var r = -1;
  t = DT(t, h3e(f3e));
  var i = p3e(e, function(a, o, s) {
    var l = DT(t, function(u) {
      return u(a);
    });
    return { criteria: l, index: ++r, value: a };
  });
  return m3e(i, function(a, o) {
    return g3e(a, o, n);
  });
}
var E3e = b3e, S3e = rc, y3e = E3e, T3e = Om, ZM = UA, C3e = T3e(function(e, t) {
  if (e == null)
    return [];
  var n = t.length;
  return n > 1 && ZM(e, t[0], t[1]) ? t = [] : n > 2 && ZM(t[0], t[1], t[2]) && (t = [t[0]]), y3e(e, S3e(t, 1), []);
}), JM = C3e;
function $u(e, t) {
  !(t instanceof Date) && Ge(t, e).format(e) !== t && console.warn('Wrong formatted date. Expected format: "'.concat(e, '", received: "').concat(t, '"'));
}
var li = function(t, n, r) {
  var i = arguments.length > 3 && arguments[3] !== void 0 ? arguments[3] : {}, {
    submit: a,
    formatData: o,
    formatLoad: s,
    name: l
  } = De(t), u = r.form$, c = r.available, d = r.value, f = r.resetValidators, h = r.defaultValue, m = r.nullValue, v = r.resetting, b = (R) => {
    if (i.setValue)
      return i.setValue(R);
    d.value = R;
  }, y = N(() => ({
    [l.value]: d.value
  })), g = N(() => !c.value || !a.value ? {} : o.value ? o.value(l.value, d.value, u.value) : {
    [l.value]: d.value
  }), E = function(D) {
    var q = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : !1;
    b(q && s.value ? s.value(D, u.value) : D);
  }, S = (R) => {
    b(R);
  }, C = () => {
    b(pn(m.value));
  }, T = () => {
    v.value = !0, b(pn(h.value)), f();
  }, O = /* @__PURE__ */ function() {
    var R = ht(function* () {
    });
    return function() {
      return R.apply(this, arguments);
    };
  }();
  return {
    data: y,
    requestData: g,
    load: E,
    update: S,
    clear: C,
    reset: T,
    prepare: O
  };
}, rO = function(t, n, r) {
  var i = arguments.length > 3 && arguments[3] !== void 0 ? arguments[3] : {}, {
    resolveOnLoad: a,
    items: o
  } = De(t), {
    data: s,
    requestData: l,
    load: u,
    update: c,
    clear: d,
    prepare: f
  } = li(t, n, r), h = r.value, m = r.resetValidators, v = r.defaultValue, b = r.updateItems, y = r.resetting, g = (S) => {
    if (i.setValue)
      return i.setValue(S);
    h.value = S;
  }, E = () => {
    y.value = !0, g(pn(v.value)), m(), typeof o.value == "string" && a.value !== !1 && b();
  };
  return {
    data: s,
    requestData: l,
    load: u,
    update: c,
    clear: d,
    reset: E,
    prepare: f
  };
}, z8 = function(t, n, r) {
  var {
    name: i,
    formatLoad: a,
    formatData: o,
    submit: s
  } = De(t), {
    data: l
  } = li(t, n, r), u = r.form$, c = r.available, d = r.children$, f = r.children$Array, h = r.resetting, m = N(() => {
    if (!c.value || !s.value)
      return {};
    var S = {};
    return Te(d.value, (C) => {
      C.isStatic || (S = Object.assign({}, S, C.requestData));
    }), o.value ? o.value(i.value, S, u.value) : {
      [i.value]: S
    };
  }), v = function(C) {
    var T = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : !1, O = T && a.value ? a.value(C, u.value) : C;
    Te(d.value, (R) => {
      if (!R.isStatic) {
        if (!R.flat && O[R.name] === void 0) {
          R.clear();
          return;
        }
        R.load(R.flat ? O : O[R.name], T);
      }
    });
  }, b = (S) => {
    Te(d.value, (C) => {
      C.isStatic || S[C.name] === void 0 && !C.flat || C.update(C.flat ? S : S[C.name]);
    });
  }, y = () => {
    Te(d.value, (S) => {
      S.isStatic || S.clear();
    });
  }, g = () => {
    h.value = !0, Te(d.value, (S) => {
      S.isStatic || S.reset();
    });
  }, E = /* @__PURE__ */ function() {
    var S = ht(function* () {
      yield ki(f.value, /* @__PURE__ */ function() {
        var C = ht(function* (T) {
          T.prepare && (yield T.prepare());
        });
        return function(T) {
          return C.apply(this, arguments);
        };
      }());
    });
    return function() {
      return S.apply(this, arguments);
    };
  }();
  return {
    data: l,
    requestData: m,
    load: v,
    update: b,
    clear: y,
    reset: g,
    prepare: E
  };
}, A3e = function(t, n, r) {
  var {
    name: i,
    formatData: a,
    submit: o
  } = De(t), {
    load: s,
    update: l,
    clear: u,
    reset: c,
    prepare: d
  } = z8(t, n, r), f = r.form$, h = r.children$, m = r.available, v = r.value, b = N(() => v.value), y = N(() => {
    if (!m.value || !o.value)
      return {};
    var g = {};
    return Te(h.value, (E) => {
      E.isStatic || (g = Object.assign({}, g, E.requestData));
    }), a.value ? a.value(i.value, g, f.value) : g;
  });
  return {
    data: b,
    requestData: y,
    load: s,
    update: l,
    clear: u,
    reset: c,
    prepare: d
  };
}, V8 = function(t, n, r, i) {
  var {
    name: a,
    storeOrder: o,
    formatLoad: s,
    formatData: l,
    order: u,
    submit: c,
    initial: d,
    default: f
  } = De(t), {
    update: h,
    clear: m,
    data: v
  } = li(t, n, r), b = r.form$, y = r.children$, g = r.children$Array, E = r.available, S = r.isDisabled, C = r.value, T = r.orderByName, O = r.refreshOrderStore, R = r.dataPath, D = r.parent, q = r.nullValue, $ = r.defaultValue, P = r.fire, Y = r.resetValidators, L = r.resetting, x = he($r(b.value.model, R.value)), I = N(() => D && D.value ? D.value.defaultValue[a.value] : b.value.options.default[a.value]), k = N(() => {
    if (!E.value || !c.value)
      return {};
    var Se = [];
    return Te(y.value, (Re) => {
      var Ye = Re.requestData[Re.name];
      Ye !== void 0 && Se.push(Ye);
    }), l.value ? l.value(a.value, Se, b.value) : {
      [a.value]: Se
    };
  }), B = N(() => Object.keys(C.value || /* istanbul ignore next: failsafe only */
  {}).length), W = function() {
    var Re = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : void 0, Ye = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : !1, nt = o.value ? Object.assign({}, Re || {}, {
      [o.value]: Re ? Re[o.value] : void 0
    }) : Re;
    C.value = O(C.value.concat([nt]));
    var ut = C.value.length - 1;
    return P("add", ut, nt, C.value), Ye && Ut(() => {
      g.value[g.value.length - 1].focus();
    }), ut;
  }, Z = (Se) => {
    C.value = C.value.filter((Re, Ye) => Ye !== Se), O(C.value), P("remove", Se, C.value);
  }, V = /* @__PURE__ */ function() {
    var Se = ht(function* (Re) {
      var Ye = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : !1, nt = Ee(Ye && s.value ? s.value(Re, b.value) : Re);
      m(), yield Ut();
      for (var ut = 0; ut < nt.length; ut++)
        W();
      yield Ut(), Te(y.value, (Tt, Ot) => {
        Tt.load(nt[Ot], Ye);
      });
    });
    return function(Ye) {
      return Se.apply(this, arguments);
    };
  }(), K = () => {
    if (L.value = !0, C.value = pn($.value), Y(), !C.value.length && d.value > 0) {
      for (var Se = 0; Se < d.value; Se++)
        W();
      g.value.forEach((Re) => {
        Re.reset();
      });
    }
    Ut(() => {
      O(C.value);
    });
  }, ne = /* @__PURE__ */ function() {
    var Se = ht(function* () {
      yield ki(g.value, /* @__PURE__ */ function() {
        var Re = ht(function* (Ye) {
          Ye.prepare && (yield Ye.prepare());
        });
        return function(Ye) {
          return Re.apply(this, arguments);
        };
      }());
    });
    return function() {
      return Se.apply(this, arguments);
    };
  }(), Ee = (Se) => {
    if (!u.value && !T.value || !Se)
      return Se;
    var Re = u.value && typeof u.value == "string" && u.value.toUpperCase() == "DESC";
    return T.value ? Se = Re ? JM(Se, T.value).reverse() : JM(Se, T.value) : u.value && (Se = Re ? Se.sort().reverse() : Se.sort()), Se;
  }, oe = () => {
    S.value || W(void 0, !0);
  }, ae = (Se) => {
    S.value || Z(Se);
  };
  if (x.value === void 0 && I.value === void 0 && f.value === void 0)
    if (d.value > 0)
      for (var pe = 0; pe < d.value; pe++)
        W();
    else
      C.value = q.value;
  else x.value === void 0 && (C.value = $.value);
  return {
    requestData: k,
    data: v,
    length: B,
    add: W,
    remove: Z,
    load: V,
    update: h,
    clear: m,
    reset: K,
    handleAdd: oe,
    handleRemove: ae,
    prepare: ne
  };
}, O3e = function(t, n, r) {
  var {
    formatLoad: i
  } = De(t), {
    data: a,
    requestData: o,
    update: s,
    clear: l,
    reset: u,
    prepare: c
  } = li(t, n, r), d = r.form$, f = r.value, h = r.loadDateFormat, m = function(b) {
    var y = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : !1, g = y && i.value ? i.value(b, d.value) : b;
    $u(h.value, g), f.value = g instanceof Date || !g ? g : Ge(g, h.value).toDate();
  };
  return {
    data: a,
    requestData: o,
    load: m,
    update: s,
    clear: l,
    reset: u,
    prepare: c
  };
}, R3e = function(t, n, r) {
  var {
    formatLoad: i
  } = De(t), {
    data: a,
    requestData: o,
    update: s,
    clear: l,
    reset: u,
    prepare: c
  } = li(t, n, r), d = r.form$, f = r.value, h = r.loadDateFormat, m = function(b) {
    var y = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : !1, g = y && i.value ? i.value(b, d.value) : b;
    f.value = Ku(g, (E) => ($u(h.value, E), E instanceof Date ? E : Ge(E, h.value).toDate()));
  };
  return {
    data: a,
    requestData: o,
    load: m,
    update: s,
    clear: l,
    reset: u,
    prepare: c
  };
}, iO = function(t, n, r) {
  var i = arguments.length > 3 && arguments[3] !== void 0 ? arguments[3] : {}, {
    formatLoad: a
  } = De(t), {
    data: o,
    requestData: s,
    clear: l,
    reset: u,
    prepare: c
  } = li(t, n, r, i), d = r.form$, f = r.value, h = r.language, m = r.nullValue, v = (g) => {
    if (i.setValue)
      return i.setValue(g);
    f.value = g;
  }, b = function(E) {
    var S = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : !1, C = S && a.value ? a.value(E, d.value) : E;
    if (!jn(C))
      throw new Error("Multilingual element requires an object to load");
    v(Object.assign({}, bo(m.value), C));
  }, y = (g) => {
    var E = g;
    jn(E) || (E = {
      [h.value]: g
    }), v(Object.assign({}, f.value, E));
  };
  return {
    data: o,
    requestData: s,
    load: b,
    update: y,
    clear: l,
    reset: u,
    prepare: c
  };
}, w3e = function(t, n, r) {
  var {
    data: i,
    requestData: a,
    load: o,
    update: s,
    clear: l,
    reset: u,
    prepare: c
  } = li(t, n, r, {
    setValue: (h) => {
      f.value = h, Ut(() => {
        d.value.update(h);
      });
    }
  }), d = r.input, f = r.value;
  return {
    data: i,
    requestData: a,
    load: o,
    update: s,
    clear: l,
    reset: u,
    prepare: c
  };
}, x3e = function(t, n, r) {
  var {
    data: i,
    requestData: a,
    load: o,
    update: s,
    clear: l,
    reset: u,
    prepare: c
  } = iO(t, n, r, {
    setValue: (v) => {
      h.value = v, Ut(() => {
        d.value.update(v[m.value]);
      });
    }
  }), d = r.input, f = r.model, h = r.value, m = r.language;
  return et(m, () => {
    d.value.update(f.value);
  }), {
    data: i,
    requestData: a,
    load: o,
    update: s,
    clear: l,
    reset: u,
    prepare: c
  };
}, yg = function(t, n, r) {
  var {
    load: i,
    update: a,
    clear: o,
    reset: s,
    prepare: l
  } = li(t, n, r), {
    submit: u,
    formatData: c,
    name: d
  } = De(t), f = r.form$, h = r.available, m = r.value, v = N(() => {
    var y, g = m.value;
    return typeof g == "object" && (y = g) !== null && y !== void 0 && y.__file__ && (g = g instanceof File ? g : mt({}, g), delete g.__file__), {
      [d.value]: g
    };
  }), b = N(() => {
    var y;
    if (!h.value || !u.value)
      return {};
    var g = m.value;
    return typeof g == "object" && (y = g) !== null && y !== void 0 && y.__file__ && (g = g instanceof File ? g : mt({}, g), delete g.__file__), c.value ? c.value(d.value, g, f.value) : {
      [d.value]: g
    };
  });
  return {
    data: v,
    requestData: b,
    load: i,
    update: a,
    clear: o,
    reset: s,
    prepare: l
  };
}, N3e = function(t, n, r) {
  var {
    length: i,
    add: a,
    remove: o,
    load: s,
    update: l,
    clear: u,
    reset: c,
    handleAdd: d,
    handleRemove: f,
    prepare: h
  } = V8(t, n, r), {
    submit: m,
    formatData: v,
    name: b
  } = De(t), y = r.form$, g = r.available, E = r.value, S = r.children$, C = N(() => {
    var O = E.value;
    return O = O.map((R) => {
      if (typeof R == "object" && R !== null && R !== void 0 && R.__file__) {
        var D = R instanceof File ? R : mt({}, R);
        return delete D.__file__, D;
      }
      return R;
    }), {
      [b.value]: O
    };
  }), T = N(() => {
    if (!g.value || !m.value)
      return {};
    var O = [];
    return Te(S.value, (R) => {
      var D = R.requestData[R.name];
      if (D !== void 0) {
        var q;
        if (typeof D == "object" && (q = D) !== null && q !== void 0 && q.__file__) {
          var $ = yg instanceof File ? yg : mt({}, yg);
          delete $.__file__, D = $;
        }
        O.push(D);
      }
    }), v.value ? v.value(b.value, O, y.value) : {
      [b.value]: O
    };
  });
  return {
    requestData: T,
    data: C,
    length: i,
    add: a,
    remove: o,
    load: s,
    update: l,
    clear: u,
    reset: c,
    handleAdd: d,
    handleRemove: f,
    prepare: h
  };
}, D3e = rO, I3e = rO, Mi = function(t, n, r) {
  var {
    default: i,
    name: a
  } = De(t), o = r.nullValue, s = r.form$, l = r.parent, u = N(() => {
    var c;
    return l && l.value && !l.value.mounted ? c = l.value.defaultValue[a.value] : !s.value.mounted && s.value.options.default[a.value] !== void 0 && (c = s.value.options.default[a.value]), c !== void 0 ? c instanceof File ? new File([c], c.name, c) : pn(c) : i.value !== void 0 ? i.value instanceof File ? new File([i.value], i.value.name, i.value) : pn(i.value) : pn(o.value);
  });
  return {
    defaultValue: u
  };
}, qv = function(t, n, r) {
  var {
    default: i,
    name: a
  } = De(t), o = r.nullValue, s = r.form$, l = r.parent, u = En("config$"), c = N(() => {
    var d;
    return l && l.value && !l.value.mounted ? d = l.value.defaultValue[a.value] : !s.value.mounted && typeof s.value.options.default[a.value] !== void 0 && (d = s.value.options.default[a.value]), d !== void 0 ? d instanceof File ? new File([d], d.name, d) : jn(d) ? oi(pn(d), u.value, s.value) : pn(d) : i.value !== void 0 ? i.value instanceof File ? new File([i.value], i.value.name, i.value) : jn(i.value) ? oi(pn(i.value), u.value, s.value) : pn(i.value) : pn(o.value);
  });
  return {
    defaultValue: c
  };
}, L3e = function(t, n, r) {
  var {
    default: i,
    name: a
  } = De(t), o = r.nullValue, s = r.form$, l = r.parent, u = N(() => {
    var c;
    return l && l.value && !l.value.mounted ? c = l.value.defaultValue[a.value] : !s.value.mounted && s.value.options.default[a.value] && (c = s.value.options.default[a.value]), c !== void 0 ? pn(Ls({}, i.value || /* istanbul ignore next: `default_.value` will never be undefined, because it is a hardwired `{}` */
    o.value, c)) : Object.keys(i.value).length > 0 ? pn(i.value) : pn(o.value);
  });
  return {
    defaultValue: u
  };
}, k3e = function(t, n, r) {
  var {
    default: i
  } = De(t), a = r.form$, o = r.parent, s = N(() => {
    var l = {};
    return o && o.value && !o.value.mounted ? l = o.value.defaultValue : !a.value.mounted && a.value.options.default && (l = a.value.options.default), pn(Ls({}, i.value, l));
  });
  return {
    defaultValue: s
  };
}, aO = function(t, n, r) {
  var {
    default: i,
    name: a
  } = De(t), o = r.nullValue, s = r.form$, l = r.parent, u = N(() => {
    var c;
    if (l && l.value && !l.value.mounted ? c = l.value.defaultValue[a.value] : !s.value.mounted && s.value.options.default[a.value] && (c = s.value.options.default[a.value]), c !== void 0)
      return pn(Object.assign({}, bo(o.value), c));
    if (i.value === void 0)
      return bo(o.value);
    var d = bo(i.value);
    if (!jn(d)) {
      var f = {};
      Te(o.value, (h, m) => {
        f[m] = d;
      }), d = f;
    }
    return Object.assign({}, bo(o.value), d);
  });
  return {
    defaultValue: u
  };
}, ji = function(t, n, r) {
  var {
    rules: i
  } = De(t), a = r.form$, o = r.path, s = he({
    dirty: !1,
    validated: !0
  }), l = he([]), u = he({}), c = u1({}), d = he(!1), f = N(() => i.value), h = N(() => s.value.dirty), m = N(() => s.value.validated), v = N(() => hn(l.value, {
    invalid: !0
  })), b = N(() => hn(l.value, {
    pending: !0
  })), y = N(() => b.value), g = N(() => {
    var x = [];
    return Te(l.value, (I) => {
      I.failing && x.push(I.message);
    }), x;
  }), E = N(() => u.value.errors), S = N(() => u.value.error || null), C = N(() => S.value !== null), T = N(() => f.value && f.value.length > 0 && s.value.validated && !v.value || (!f.value || !f.value.length) && h.value), O = /* @__PURE__ */ function() {
    var x = ht(function* () {
      if (f.value && a.value.validation !== !1) {
        if (d.value) {
          d.value = !1;
          return;
        }
        yield ki(l.value, /* @__PURE__ */ function() {
          var I = ht(function* (k) {
            yield k.validate();
          });
          return function(k) {
            return I.apply(this, arguments);
          };
        }()), s.value.validated = !0;
      }
    });
    return function() {
      return x.apply(this, arguments);
    };
  }(), R = () => {
    Te(l.value, (x) => {
      x.reset();
    }), s.value.validated = !f.value;
  }, D = () => {
    s.value.dirty = !0;
  }, q = () => {
    s.value.dirty = !1;
  }, $ = () => {
    u.value && u.value.clear();
  }, P = () => {
    u.value = new a.value.$vueform.services.messageBag(g);
  }, Y = () => {
    f.value && (s.value.validated = !1, c.value = new a.value.$vueform.services.validation.factory(o.value, a.value), l.value = [], Te(c.value.makeAll(f.value), (x) => {
      l.value.push(x);
    }));
  }, L = () => {
    Y();
  };
  return {
    state: s,
    Validators: l,
    messageBag: u,
    resetting: d,
    dirty: h,
    validated: m,
    invalid: v,
    pending: b,
    busy: y,
    errors: E,
    error: S,
    validationRules: f,
    isDanger: C,
    isSuccess: T,
    validate: O,
    dirt: D,
    clean: q,
    clearMessages: $,
    resetValidators: R,
    initMessageBag: P,
    initValidation: Y,
    reinitValidation: L
  };
}, Wd = function(t, n, r) {
  var {
    state: i,
    Validators: a,
    messageBag: o,
    resetting: s,
    dirty: l,
    validated: u,
    invalid: c,
    pending: d,
    errors: f,
    error: h,
    validationRules: m,
    isDanger: v,
    isSuccess: b,
    validate: y,
    dirt: g,
    clean: E,
    clearMessages: S,
    resetValidators: C,
    initMessageBag: T,
    initValidation: O,
    reinitValidation: R
  } = ji(t, n, r), D = N(() => hn(a.value, {
    debouncing: !0
  })), q = N(() => d.value || D.value);
  return {
    state: i,
    Validators: a,
    messageBag: o,
    resetting: s,
    dirty: l,
    validated: u,
    invalid: c,
    pending: d,
    debouncing: D,
    busy: q,
    errors: f,
    error: h,
    validationRules: m,
    isDanger: v,
    isSuccess: b,
    validate: y,
    dirt: g,
    clean: E,
    clearMessages: S,
    resetValidators: C,
    initMessageBag: T,
    initValidation: O,
    reinitValidation: R
  };
}, Gv = function(t, n, r) {
  var {
    state: i,
    Validators: a,
    messageBag: o,
    validationRules: s,
    dirt: l,
    initValidation: u,
    resetting: c
  } = ji(t, n, r), d = r.form$, f = r.children$, h = N(() => hn(f.value, {
    available: !0,
    dirty: !0
  }) || i.value.dirty), m = N(() => !hn(f.value, {
    available: !0,
    validated: !1
  }) && i.value.validated), v = N(() => hn(f.value, {
    available: !0,
    invalid: !0
  }) || hn(a.value, {
    invalid: !0
  })), b = N(() => hn(f.value, {
    available: !0,
    pending: !0
  }) || hn(a.value, {
    pending: !0
  })), y = N(() => hn(f.value, {
    available: !0,
    debouncing: !0
  }) || hn(a.value, {
    debouncing: !0
  })), g = N(() => hn(f.value, {
    available: !0,
    busy: !0
  }) || b.value || y.value), E = N(() => {
    var I = [];
    return Te(a.value, (k) => {
      k.failing && I.push(k.message);
    }), I;
  }), S = N(() => {
    var I = [];
    return Te(f.value, (k) => {
      !k.available || k.isStatic || Te(k.errors, (B) => {
        I.push(B);
      });
    }), I;
  }), C = N(() => E.value.concat(S.value)), T = N(() => o.value.errors), O = N(() => h_(E.value)), R = /* @__PURE__ */ function() {
    var I = ht(function* () {
      if (c.value) {
        c.value = !1;
        return;
      }
      yield D(), yield q();
    });
    return function() {
      return I.apply(this, arguments);
    };
  }(), D = /* @__PURE__ */ function() {
    var I = ht(function* () {
      d.value.validation !== !1 && (yield ki(a.value, /* @__PURE__ */ function() {
        var k = ht(function* (B) {
          yield B.validate();
        });
        return function(B) {
          return k.apply(this, arguments);
        };
      }()), i.value.validated = !0);
    });
    return function() {
      return I.apply(this, arguments);
    };
  }(), q = /* @__PURE__ */ function() {
    var I = ht(function* () {
      d.value.validation !== !1 && (yield ki(f.value, /* @__PURE__ */ function() {
        var k = ht(function* (B) {
          B.isStatic || (yield B.validate());
        });
        return function(B) {
          return k.apply(this, arguments);
        };
      }()));
    });
    return function() {
      return I.apply(this, arguments);
    };
  }(), $ = () => {
    Te(f.value, (I) => {
      I.isStatic || I.clean();
    }), i.value.dirty = !1;
  }, P = () => {
    o.value && o.value.clear(), Te(f.value, (I) => {
      I.isStatic || I.clearMessages();
    });
  }, Y = () => {
    Te(f.value, (I) => {
      I.isStatic || I.resetValidators();
    }), Te(a.value, (I) => {
      I.reset();
    }), i.value.validated = !s.value;
  }, L = () => {
    o.value = new d.value.$vueform.services.messageBag(C);
  }, x = () => {
    u(), Te(f.value, (I) => {
      I.isStatic || I.reinitValidation();
    });
  };
  return {
    state: i,
    Validators: a,
    messageBag: o,
    resetting: c,
    dirty: h,
    validated: m,
    invalid: v,
    pending: b,
    debouncing: y,
    busy: g,
    validatorErrors: E,
    childrenErrors: S,
    errors: T,
    error: O,
    validationRules: s,
    validate: R,
    validateValidators: D,
    validateChildren: q,
    dirt: l,
    clean: $,
    clearMessages: P,
    resetValidators: Y,
    initMessageBag: L,
    initValidation: u,
    reinitValidation: x
  };
}, oO = function(t, n, r) {
  var {
    rules: i
  } = De(t), a = r.form$, o = r.path, s = r.languages, l = r.language, u = r.value, {
    messageBag: c,
    clearMessages: d,
    resetting: f
  } = Wd(t, n, r), h = he({
    dirty: {},
    validated: {}
  }), m = he({}), v = N(() => {
    var Z = {};
    return i.value && Te(s.value, (V) => {
      Z[V] = jn(i.value) ? i.value[V] || null : i.value;
    }), Z;
  }), b = N(() => hn(h.value.dirty, (Z) => Z === !0)), y = N(() => !hn(h.value.validated, (Z) => Z === !1)), g = N(() => {
    var Z = !1;
    return Te(m.value, (V) => {
      hn(V, {
        invalid: !0
      }) && (Z = !0);
    }), Z;
  }), E = N(() => {
    var Z = !1;
    return Te(m.value, (V) => {
      hn(V, {
        pending: !0
      }) && (Z = !0);
    }), Z;
  }), S = N(() => {
    var Z = !1;
    return Te(m.value, (V) => {
      hn(V, {
        debouncing: !0
      }) && (Z = !0);
    }), Z;
  }), C = N(() => E.value || S.value), T = N(() => {
    var Z = [];
    return Te(m.value, (V, K) => {
      Te(V, (ne) => {
        ne.failing && Z.push(ne.message + " (" + K + ")");
      });
    }), Z;
  }), O = N(() => c.value.errors), R = N(() => {
    var Z = null;
    Te(m.value[l.value], (K) => {
      if (Z !== null)
        return !1;
      K.failing && (Z = K.message);
    });
    var V = c.value.prepends ? c.value.prepends.errors : [];
    return Z !== null && (V = m_(V, [Z])), V = m_(V, c.value.appends ? c.value.appends.errors : []), h_(V);
  }), D = N(() => R.value !== null && R.value !== void 0), q = N(() => v.value[l.value] && v.value[l.value].length > 0 && h.value.validated[l.value] && !hn(m.value[l.value], {
    invalid: !0
  }) || (!v.value[l.value] || !v.value[l.value].length) && h.value.dirty[l.value]), $ = /* @__PURE__ */ function() {
    var Z = ht(function* () {
      if (f.value) {
        f.value = !1;
        return;
      }
      yield ki(s.value, /* @__PURE__ */ function() {
        var V = ht(function* (K) {
          yield P(K);
        });
        return function(K) {
          return V.apply(this, arguments);
        };
      }());
    });
    return function() {
      return Z.apply(this, arguments);
    };
  }(), P = /* @__PURE__ */ function() {
    var Z = ht(function* () {
      var V = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : l.value;
      a.value.validation !== !1 && m.value[V] && (yield ki(m.value[V], /* @__PURE__ */ function() {
        var K = ht(function* (ne) {
          yield ne.validate(u.value[V]);
        });
        return function(ne) {
          return K.apply(this, arguments);
        };
      }()), h.value.validated[V] = !0);
    });
    return function() {
      return Z.apply(this, arguments);
    };
  }(), Y = () => {
    Te(s.value, (Z) => {
      Te(m.value[Z], (V) => {
        V.reset();
      }), Te(v.value, (V, K) => {
        h.value.validated[K] = !(V.length > 0);
      });
    });
  }, L = () => {
    h.value.dirty[l.value] = !0;
  }, x = () => {
    h.value.dirty[l.value] = !1;
  }, I = () => {
    var Z = {}, V = {};
    Te(s.value, (K) => {
      Z[K] = !1;
    }), Te(s.value, (K) => {
      V[K] = !0;
    }), h.value = {
      dirty: Z,
      validated: V
    };
  }, k = () => {
    c.value = new a.value.$vueform.services.messageBag(T);
  }, B = () => {
    if (v.value) {
      Te(v.value, (V, K) => {
        h.value.validated[K] = !(V !== null && V.length > 0);
      });
      var Z = new a.value.$vueform.services.validation.factory(o.value, a.value);
      m.value = {}, Te(v.value, (V, K) => {
        V !== null && (m.value[K] || (m.value = Object.assign({}, m.value, {
          [K]: []
        })), Te(Z.makeAll(V), (ne) => {
          m.value[K].push(ne);
        }));
      });
    }
  }, W = () => {
    B();
  };
  return {
    state: h,
    Validators: m,
    messageBag: c,
    resetting: f,
    dirty: b,
    validated: y,
    invalid: g,
    pending: E,
    debouncing: S,
    busy: C,
    errors: O,
    error: R,
    validationRules: v,
    isDanger: D,
    isSuccess: q,
    validate: $,
    validateLanguage: P,
    dirt: L,
    clean: x,
    clearMessages: d,
    resetValidators: Y,
    initState: I,
    initMessageBag: k,
    initValidation: B,
    reinitValidation: W
  };
}, M3e = function(t, n, r) {
  var i = r.value, {
    state: a,
    Validators: o,
    messageBag: s,
    resetting: l,
    dirty: u,
    validated: c,
    invalid: d,
    pending: f,
    busy: h,
    errors: m,
    error: v,
    validationRules: b,
    dirt: y,
    clean: g,
    clearMessages: E,
    resetValidators: S,
    initMessageBag: C,
    initValidation: T,
    reinitValidation: O
  } = ji(t, n, r), R = /* @__PURE__ */ function() {
    var D = ht(function* () {
      if (b.value) {
        if (l.value) {
          l.value = !1;
          return;
        }
        At(i.value) ? yield ki(i.value, /* @__PURE__ */ function() {
          var q = ht(function* ($) {
            if (yield ki(o.value, /* @__PURE__ */ function() {
              var P = ht(function* (Y) {
                yield Y.validate($);
              });
              return function(Y) {
                return P.apply(this, arguments);
              };
            }()), d.value)
              return !1;
          });
          return function($) {
            return q.apply(this, arguments);
          };
        }()) : yield ki(o.value, /* @__PURE__ */ function() {
          var q = ht(function* ($) {
            yield $.validate(i.value);
          });
          return function($) {
            return q.apply(this, arguments);
          };
        }()), a.value.validated = !0;
      }
    });
    return function() {
      return D.apply(this, arguments);
    };
  }();
  return {
    state: a,
    Validators: o,
    messageBag: s,
    resetting: l,
    dirty: u,
    validated: c,
    invalid: d,
    pending: f,
    busy: h,
    errors: m,
    error: v,
    validationRules: b,
    validate: R,
    dirt: y,
    clean: g,
    clearMessages: E,
    resetValidators: S,
    initMessageBag: C,
    initValidation: T,
    reinitValidation: O
  };
}, P3e = function(t, n, r) {
  var i = r.form$, a = r.value, o = r.uploading, s = r.removing, {
    state: l,
    Validators: u,
    messageBag: c,
    resetting: d,
    dirty: f,
    validated: h,
    invalid: m,
    pending: v,
    errors: b,
    error: y,
    validationRules: g,
    dirt: E,
    clean: S,
    clearMessages: C,
    resetValidators: T,
    initMessageBag: O,
    initValidation: R,
    reinitValidation: D
  } = ji(t, n, r), q = N(() => v.value || o.value || s.value), $ = /* @__PURE__ */ function() {
    var P = ht(function* () {
      if (g.value && i.value.validation !== !1) {
        if (d.value) {
          d.value = !1;
          return;
        }
        var Y = ["min", "max", "between", "size", "mimetypes", "mimes", "dimensions", "file", "image", "gt", "gte", "lt", "lte"];
        yield ki(u.value, /* @__PURE__ */ function() {
          var L = ht(function* (x) {
            !(a.value instanceof File) && a.value && Y.indexOf(x.name) !== -1 || (yield x.validate());
          });
          return function(x) {
            return L.apply(this, arguments);
          };
        }()), l.value.validated = !0;
      }
    });
    return function() {
      return P.apply(this, arguments);
    };
  }();
  return {
    state: l,
    Validators: u,
    messageBag: c,
    resetting: d,
    dirty: f,
    validated: h,
    invalid: m,
    pending: v,
    busy: q,
    errors: b,
    error: y,
    validationRules: g,
    validate: $,
    dirt: E,
    clean: S,
    clearMessages: C,
    resetValidators: T,
    initMessageBag: O,
    initValidation: R,
    reinitValidation: D
  };
}, F3e = function(t, n, r) {
  var {
    displayKey: i
  } = De(t), a = r.form$, o = r.value, {
    state: s,
    Validators: l,
    messageBag: u,
    resetting: c,
    dirty: d,
    validated: f,
    invalid: h,
    pending: m,
    debouncing: v,
    busy: b,
    errors: y,
    error: g,
    validationRules: E,
    isSuccess: S,
    isDanger: C,
    dirt: T,
    clean: O,
    clearMessages: R,
    resetValidators: D,
    initMessageBag: q,
    initValidation: $,
    reinitValidation: P
  } = Wd(t, n, r), Y = /* @__PURE__ */ function() {
    var L = ht(function* () {
      if (E.value && a.value.validation !== !1) {
        if (c.value) {
          c.value = !1;
          return;
        }
        yield ki(l.value, /* @__PURE__ */ function() {
          var x = ht(function* (I) {
            yield I.validate(o.value[i.value]);
          });
          return function(I) {
            return x.apply(this, arguments);
          };
        }()), s.value.validated = !0;
      }
    });
    return function() {
      return L.apply(this, arguments);
    };
  }();
  return {
    state: s,
    Validators: l,
    messageBag: u,
    resetting: c,
    dirty: d,
    validated: f,
    invalid: h,
    pending: m,
    debouncing: v,
    busy: b,
    errors: y,
    error: g,
    validationRules: E,
    isSuccess: S,
    isDanger: C,
    validate: Y,
    dirt: T,
    clean: O,
    clearMessages: R,
    resetValidators: D,
    initMessageBag: q,
    initValidation: $,
    reinitValidation: P
  };
}, B3e = Gv, $3e = Gv, kr = function(t, n, r) {
  var {
    name: i,
    floating: a,
    placeholder: o,
    label: s,
    fieldName: l
  } = De(t), u = r.form$, c = r.Label, d = En("config$"), f = N(() => l && l.value ? oi(l.value, d.value, u.value) : s && s.value ? c.value : a && a.value ? oi(a.value, d.value, u.value) : o && o.value && u.value.options.floatPlaceholders ? oi(o.value, d.value, u.value) : Hd(i.value).replace(/_|-/g, " "));
  return {
    genericName: f
  };
}, U3e = function(t, n, r) {
  var {
    name: i,
    embed: a,
    label: o,
    fieldName: s
  } = De(t), l = r.form$, u = r.Label, c = r.filename || /* istanbul ignore next: failsafe only */
  he(null), d = En("config$"), f = N(() => a.value && c.value ? c.value : s && s.value ? oi(s.value, d.value, l.value) : o.value ? u.value : /^\d+$/.test(i.value) ? l.value.translations.vueform.elements.file.defaultName : Hd(i.value).replace(/_|-/g, " "));
  return {
    genericName: f
  };
}, Mr = function(t, n, r) {
  var i, a, o = arguments.length > 3 && arguments[3] !== void 0 ? arguments[3] : {}, {
    name: s,
    type: l
  } = De(t), u = r.parent, c = r.defaultValue, d = r.dataPath, f = r.form$, h = he(void 0);
  f.value.isSync ? h.value = $r(f.value.model, d.value) : u.value && ["group", "object", "list", "multifile"].indexOf(u.value.type) !== -1 && (h.value = u.value.value[s.value]);
  var m = he(c.value instanceof File ? c.value : pn(c.value)), v = N({
    get: ((i = o.value) === null || i === void 0 ? void 0 : i.get) || function() {
      var y;
      return f.value.isSync ? y = $r(f.value.model, d.value) : u.value && ["group", "object", "list", "multifile"].indexOf(u.value.type) !== -1 ? y = u.value.value[s.value] : y = m.value, y !== void 0 ? y : (
        /* istanbul ignore next: value is never undefined if default is set */
        c.value instanceof File ? c.value : pn(c.value)
      );
    },
    set: ((a = o.value) === null || a === void 0 ? void 0 : a.set) || function(y) {
      if (f.value.isSync)
        f.value.updateModel(d.value, y);
      else if (u.value && ["list", "multifile"].indexOf(u.value.type) !== -1) {
        var g = u.value.value.map((E, S) => S == s.value ? y : E);
        u.value.update(g);
      } else u.value && ["group", "object"].indexOf(u.value.type) !== -1 ? u.value.value = Object.assign({}, u.value.value, {
        [s.value]: y
      }) : m.value = y;
    }
  }), b = N({
    get() {
      return v.value;
    },
    set(y) {
      v.value = y;
    }
  });
  return (o.init === void 0 || o.init !== !1) && h.value === void 0 && (v.value = c.value instanceof File ? c.value : pn(c.value)), et(l, () => {
    v.value = c.value instanceof File ? c.value : pn(c.value);
  }), {
    initialValue: h,
    internalValue: m,
    value: v,
    model: b
  };
}, q3e = function(t, n, r) {
  var {
    initialValue: i,
    internalValue: a,
    value: o,
    model: s
  } = Mr(t, n, r, {
    init: !1
  });
  return {
    initialValue: i,
    internalValue: a,
    value: o,
    model: s
  };
}, G3e = function(t, n, r) {
  var i = arguments.length > 3 && arguments[3] !== void 0 ? arguments[3] : {}, {
    initialValue: a,
    internalValue: o,
    value: s
  } = Mr(t, n, r, {
    init: !1
  }), l = r.defaultValue;
  return (i.init === void 0 || /* istanbul ignore next: init will always be false */
  i.init !== !1) && (a.value === void 0 ? s.value = l.value : s.value = Object.assign({}, l.value, s.value)), {
    internalValue: o,
    value: s
  };
}, Y3e = function(t, n, r) {
  var i = arguments.length > 3 && arguments[3] !== void 0 ? arguments[3] : {}, a = r.parent, o = r.dataPath, s = r.defaultValue, l = r.children$Array, u = r.form$, c = he(pn(s.value)), d = N(i.value || {
    get() {
      var f;
      u.value.isSync ? f = o.value ? $r(u.value.model, o.value) || {} : u.value.model : a.value && ["group", "object"].indexOf(a.value.type) !== -1 ? f = a.value.value : f = c.value;
      var h = l.value.reduce((v, b) => {
        if (b.isStatic || !b)
          return v;
        var y = [];
        if (!b.flat)
          y.push(b.name);
        else {
          var g = (E) => {
            E.forEach((S) => {
              !S.isStatic && S.flat ? g(S.children$Array) : S.isStatic || y.push(S.name);
            });
          };
          g(b.children$Array);
        }
        return v.concat(y);
      }, []), m = {};
      return h.forEach((v) => {
        f[v] !== void 0 && (m[v] = f[v]);
      }), f = m, f !== void 0 ? f : (
        /* istanbul ignore next: will never reach, internalValue is assigned at the beginning */
        pn(s.value)
      );
    },
    set(f) {
      u.value.isSync ? u.value.updateModel(o.value, f) : a.value && ["group", "object"].indexOf(a.value.type) !== -1 ? a.value.value = Object.assign({}, a.value.value, f) : c.value = f;
    }
  });
  return {
    value: d
  };
}, sO = function(t, n, r) {
  var {
    value: i
  } = Mr(t, n, r), a = r.language, o = N({
    get() {
      return i.value[a.value];
    },
    set(s) {
      i.value = Object.assign({}, i.value, {
        [a.value]: s
      });
    }
  });
  return {
    value: i,
    model: o
  };
}, H3e = function(t, n, r) {
  var {
    name: i
  } = De(t), a = r.parent, o = r.valueDateFormat, s = r.defaultValue, l = r.dataPath, u = r.form$, c = he(s.value instanceof File ? (
    /* istanbul ignore next: @todo:adam date type will never have file instance default value */
    s.value
  ) : pn(s.value)), {
    value: d,
    initialValue: f
  } = Mr(t, n, r, {
    value: {
      get() {
        var m;
        return u.value.isSync ? m = $r(u.value.model, l.value) : a.value && ["object", "list", "multifile"].indexOf(a.value.type) !== -1 ? m = a.value.value[i.value] : m = c.value, m !== void 0 ? m : (
          /* istanbul ignore next: can not be undefined @todo:adam can not be file */
          s.value instanceof File ? s.value : pn(s.value)
        );
      },
      set(m) {
        if (!np(m) && !(m instanceof Date) && o.value !== !1 && $u(o.value, m), m = m && m instanceof Date && o.value !== !1 ? Ge(m).format(o.value) : m, u.value.isSync)
          u.value.updateModel(l.value, m);
        else if (a.value && ["list", "multifile"].indexOf(a.value.type) !== -1) {
          var v = a.value.value.map((b, y) => y == i.value ? m : b);
          a.value.update(v);
        } else a.value && ["group", "object"].indexOf(a.value.type) !== -1 ? a.value.value = Object.assign({}, a.value.value, {
          [i.value]: m
        }) : c.value = m;
      }
    }
  }), h = N(() => d.value instanceof Date || !d.value ? d.value : Ge(d.value, o.value).toDate());
  return {
    value: d,
    model: h,
    initialValue: f,
    internalValue: c
  };
}, z3e = function(t, n, r) {
  var {
    name: i
  } = De(t), a = r.parent, o = r.valueDateFormat, s = r.defaultValue, l = r.dataPath, u = r.form$, c = he(s.value instanceof File ? (
    /* istanbul ignore next: @todo:adam date type will never have file instance default value */
    s.value
  ) : pn(s.value)), {
    value: d,
    initialValue: f
  } = Mr(t, n, r, {
    value: {
      get() {
        var m;
        return u.value.isSync ? m = $r(u.value.model, l.value) : a.value && ["object", "list", "multifile"].indexOf(a.value.type) !== -1 ? m = a.value.value[i.value] : m = c.value, m !== void 0 ? m : (
          /* istanbul ignore next: can not be undefined @todo:adam can not be file */
          s.value instanceof File ? s.value : pn(s.value)
        );
      },
      set(m) {
        if (Array.isArray(m) || (m = [m]), m = m.map((b) => (!np(b) && !(b instanceof Date) && o.value !== !1 && $u(o.value, b), b && b instanceof Date && o.value !== !1 ? Ge(b).format(o.value) : b)), u.value.isSync)
          u.value.updateModel(l.value, m);
        else if (a.value && ["list", "multifile"].indexOf(a.value.type) !== -1) {
          var v = a.value.value.map((b, y) => y == i.value ? m : b);
          a.value.update(v);
        } else a.value && ["group", "object"].indexOf(a.value.type) !== -1 ? a.value.value = Object.assign({}, a.value.value, {
          [i.value]: m
        }) : c.value = m;
      }
    }
  }), h = N(() => d.value.map((m) => m instanceof Date || !m ? m : Ge(m, o.value).toDate()));
  return {
    value: d,
    model: h,
    initialValue: f,
    internalValue: c
  };
}, Ei = function(t, n, r) {
  var i = r.form$, a = r.el$, o = r.fire, s = r.dirt, l = r.validate, u = r.value, c = () => {
    et(u, (d, f) => {
      Vl(d, f) || (o("change", d, f, a.value), s && s(), l && i.value.shouldValidateOnChange && l());
    }, {
      immediate: !1,
      deep: !0
    });
  };
  return {
    initWatcher: c
  };
}, lO = function(t, n, r) {
  var i = r.form$, a = r.el$, o = r.fire, s = r.dirt, l = r.value, u = r.language, c = r.validateLanguage, d = () => {
    et(l, (f, h) => {
      Vl(f, h) || (o("change", f, h, a.value), s && s(), i.value.shouldValidateOnChange && c(u.value));
    }, {
      immediate: !1,
      deep: !0
    });
  };
  return {
    initWatcher: d
  };
}, W8 = function(t, n, r) {
  var i = r.form$, a = r.el$, o = r.fire, s = r.dirt, l = r.validateValidators, u = r.value, c = () => {
    et(u, (d, f) => {
      Vl(d, f) || (o("change", d, f, a.value), s && s(), l && i.value.shouldValidateOnChange && l());
    }, {
      immediate: !1,
      deep: !0
    });
  };
  return {
    initWatcher: c
  };
}, K8 = function(t, n, r) {
  var i = r.form$, a = r.fire, o = r.value, s = r.el$, l = r.dirt, u = r.validateValidators, c = () => {
    et(o, (d, f) => {
      Vl(d, f) || (a("change", d, f, s.value), l && l(), u && i.value.shouldValidateOnChange && u());
    }, {
      immediate: !1,
      deep: !0
    });
  };
  return {
    initWatcher: c
  };
}, V3e = function(t, n, r) {
  var {
    displayKey: i
  } = De(t), a = r.form$, o = r.el$, s = r.fire, l = r.dirt, u = r.validate, c = r.value, d = r.input, f = () => {
    et(c, (h, m) => {
      Vl(h, m) || (s("change", h, m, o.value), l(), d.value.value = d.value && c.value && c.value[i.value] !== void 0 ? c.value[i.value] : "", u && a.value.shouldValidateOnChange && u());
    }, {
      immediate: !1,
      deep: !0
    });
  };
  return {
    initWatcher: f
  };
}, W3e = W8, K3e = K8, uO = function(t, n, r) {
  var {
    text: i
  } = De(t), a = En("config$"), o = En("form$"), s = N(() => oi(i.value, a.value, o.value) || "");
  return {
    Text: s
  };
}, ls = function(t, n, r) {
  var i = N(() => null);
  return {
    nullValue: i
  };
}, Kd = function(t, n, r) {
  var i = N(() => []);
  return {
    nullValue: i
  };
}, j8 = function(t, n, r) {
  var {
    falseValue: i
  } = De(t), a = N(() => i.value);
  return {
    nullValue: a
  };
}, j3e = function(t, n, r) {
  var {
    min: i,
    default: a
  } = De(t), o = N(() => a.value !== void 0 && At(a.value) ? a.value.map((s) => i.value) : i.value);
  return {
    nullValue: o
  };
}, Q8 = function(t, n, r) {
  var i = N(() => ({}));
  return {
    nullValue: i
  };
}, Q3e = function(t, n, r) {
  var i = N(() => ({
    country: null,
    country_code: null,
    state: null,
    state_code: null,
    city: null,
    zip: null,
    address: null,
    formatted_address: null,
    lat: null,
    lng: null
  }));
  return {
    nullValue: i
  };
}, cO = function(t, n, r) {
  var i = r.languages, a = N(() => {
    var o = {};
    return Te(i.value, (s) => {
      o[s] = null;
    }), o;
  });
  return {
    nullValue: a
  };
}, X3e = function(t, n, r) {
  var {
    trueValue: i,
    falseValue: a
  } = De(t), o = r.update, s = () => {
    o(i.value);
  }, l = () => {
    o(a.value);
  };
  return {
    check: s,
    uncheck: l
  };
}, Z3e = function(t, n, r) {
  var {
    trueValue: i,
    falseValue: a
  } = De(t), o = r.update, s = () => {
    o(i.value);
  }, l = () => {
    o(a.value);
  };
  return {
    check: s,
    uncheck: l
  };
}, _r = {
  props: {
    onChange: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    }
  }
}, vr = {
  props: {
    formatData: {
      required: !1,
      type: [Function],
      default: null
    },
    formatLoad: {
      required: !1,
      type: [Function],
      default: null
    },
    submit: {
      required: !1,
      type: [Boolean],
      default: !0
    }
  }
}, br = {
  props: {
    rules: {
      required: !1,
      type: [Array, String, Object],
      default: null
    },
    messages: {
      required: !1,
      type: [Object],
      default: () => ({})
    },
    fieldName: {
      required: !1,
      type: [String],
      "@default": "name|label"
    }
  }
}, X8 = {
  name: "CheckboxElement",
  mixins: [Jn, dr, _r, vr, br],
  emits: ["change", "beforeCreate", "created", "beforeMount", "mounted", "beforeUpdate", "updated", "beforeUnmount", "unmounted"],
  props: {
    type: {
      required: !1,
      type: [String],
      default: "checkbox",
      private: !0
    },
    default: {
      required: !1,
      type: [String, Boolean, Number],
      default: void 0
      // falseValue
    },
    id: {
      required: !1,
      type: [String],
      default: null
    },
    text: {
      required: !1,
      type: [String, Object],
      localized: !0,
      default: null
    },
    disabled: {
      required: !1,
      type: [Boolean],
      default: !1
    },
    trueValue: {
      required: !1,
      type: [Boolean, String, Number],
      default: !0
    },
    falseValue: {
      required: !1,
      type: [Boolean, String, Number],
      default: !1
    },
    align: {
      required: !1,
      type: [String],
      default: void 0
    }
  },
  setup(e, t) {
    return t.features = [Hn, zn, lr, ei, cr, qr, j8, Zn, Mn, Gr, Mi, Qn, ji, Mr, li, ir, kr, or, Xn, rr, ar, sr, Z3e, eO, Ei, ur, uO], t.slots = ["default", "label", "info", "description", "before", "between", "after"], mt({}, Yr(e, t));
  }
}, J3e = function(t, n, r) {
  var i = r.value, a = r.resolvedOptions, o = (d) => {
    i.value.indexOf(String(d)) === -1 && i.value.indexOf(Number(d)) === -1 ? s(d) : l(d);
  }, s = (d) => {
    At(d) || (d = [d]);
    var f = bo(i.value);
    Te(d, (h) => {
      f.indexOf(String(h)) === -1 && f.indexOf(Number(h)) === -1 && f.push(h);
    }), i.value = f;
  }, l = (d) => {
    At(d) || (d = [d]);
    var f = bo(i.value);
    Te(d, (h) => {
      var m = f.indexOf(String(h));
      m === -1 && (m = f.indexOf(Number(h))), m !== -1 && f.splice(m, 1);
    }), i.value = f;
  }, u = () => {
    s(a.value.map((d) => d.value));
  }, c = () => {
    l(a.value.map((d) => d.value));
  };
  return {
    toggle: o,
    check: s,
    uncheck: l,
    checkAll: u,
    uncheckAll: c
  };
}, Z8 = function(t, n, r) {
  var {
    items: i,
    valueProp: a,
    labelProp: o,
    dataKey: s,
    searchParam: l,
    clearOnRefetch: u
  } = De(t), c = r.isNative, d = r.disable, f = r.enable, h = r.input, m = r.value, v = r.nullValue, b = r.path, y = r.el$, g = r.form$, E = En("config$"), S = he(null), C = he([]), T = N(() => {
    if (!c.value)
      return S.value;
    var L = [];
    return Te(S.value, (x, I) => {
      [null, void 0].indexOf(x) === -1 && (Array.isArray(S.value) && typeof x == "object" ? (x[a.value] === void 0 && console.warn("You must define `value` property for each option when using an array of objects options for select element"), L.push({
        value: x[a.value],
        label: x[o.value]
      })) : Array.isArray(S.value) ? L.push({
        value: x,
        label: x
      }) : L.push({
        value: I,
        label: x
      }));
    }), L.map((x) => mt(mt({}, x), {}, {
      label: oi(x.label, E.value, g.value)
    }));
  }), O = /* @__PURE__ */ function() {
    var L = ht(function* () {
      var x = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : !0;
      if (!c.value) {
        var I;
        typeof i.value == "string" && (S.value = D()), yield (I = h.value) === null || I === void 0 ? void 0 : I.resolveOptions();
        return;
      }
      x && d(), typeof i.value == "string" ? yield R() : typeof i.value == "function" ? yield q() : S.value = i.value, x && f();
    });
    return function() {
      return L.apply(this, arguments);
    };
  }(), R = /* @__PURE__ */ function() {
    var L = ht(function* () {
      try {
        var x, I = yield Y(i.value, O), k = ((x = yield g.value.$vueform.services.axios.get(I)) === null || x === void 0 ? void 0 : x.data) || [];
        s && s.value && Object.keys(k).length && (k = $r(k, s.value) || []), S.value = k;
      } catch (W) {
        S.value = [], console.warn("Couldn't resolve items from ".concat(i.value), W);
      } finally {
        var B;
        P(((B = T.value) === null || B === void 0 ? void 0 : B.map((W) => W.value)) || []);
      }
    });
    return function() {
      return L.apply(this, arguments);
    };
  }(), D = () => /* @__PURE__ */ function() {
    var L = ht(function* (x) {
      var I = yield Y(i.value, O), k;
      try {
        var B;
        k = ((B = yield g.value.$vueform.services.axios.get("".concat(I).concat(I.match(/\?/) ? "&" : "?").concat(l.value, "=").concat(x || ""))) === null || B === void 0 ? void 0 : B.data) || [], s && s.value && Object.keys(k).length && (k = $r(k, s.value) || []);
      } catch (W) {
        console.error(W);
      } finally {
        setTimeout(() => {
          var W;
          P(((W = h.value) === null || W === void 0 || (W = W.eo) === null || W === void 0 ? void 0 : W.map((Z) => Z[a.value])) || []);
        }, 0);
      }
      return k;
    });
    return function(x) {
      return L.apply(this, arguments);
    };
  }(), q = /* @__PURE__ */ function() {
    var L = ht(function* () {
      try {
        S.value = (yield i.value(y.value)) || [];
      } catch (x) {
        S.value = [], console.warn("Couldn't resolve items from async function", x);
      }
    });
    return function() {
      return L.apply(this, arguments);
    };
  }(), $ = /* @__PURE__ */ function() {
    var L = ht(function* (x, I) {
      typeof i.value == "function" && c.value ? yield q() : (!zd(x, I) || x === void 0 && I === void 0) && (typeof i.value == "string" && c.value ? yield R() : typeof i.value == "string" && !c.value ? S.value = D() : S.value = i.value);
    });
    return function(I, k) {
      return L.apply(this, arguments);
    };
  }(), P = (L) => {
    if (u.value) {
      m.value = pn(v.value);
      return;
    }
    !Array.isArray(v.value) && m.value && L.indexOf(m.value) === -1 ? m.value = pn(v.value) : Array.isArray(v.value) && m.value.length && (m.value = m.value.filter((x) => L.indexOf(x) !== -1));
  }, Y = /* @__PURE__ */ function() {
    var L = ht(function* (x, I) {
      var k = /{([^}]+)}/g, B = x;
      if (x.match(k)) {
        yield Ut(), C.value.forEach((V) => V());
        for (var W, Z = function* () {
          var K, ne = ((K = W[1].match(/\|'([^']+)/)) === null || K === void 0 ? void 0 : K[1]) || "", Ee = Ho(W[1].match(/^([^|]+)/)[1], b.value), oe = g.value.el$(Ee), ae = typeof (oe == null ? void 0 : oe.value) < "u" && oe.value !== null && typeof oe.value == "object" ? JSON.stringify(oe.value) : typeof (oe == null ? void 0 : oe.value) < "u" && oe.value !== null ? oe.value : ne;
          B = B.replace(W[0], encodeURIComponent(ae)), C.value.push(et(N(() => oe == null ? void 0 : oe.value), () => {
            I();
          }));
        }; (W = k.exec(x)) !== null; )
          yield* Z();
      }
      return B;
    });
    return function(I, k) {
      return L.apply(this, arguments);
    };
  }();
  return {
    resolveOptions: $,
    resolvedOptions: T,
    updateItems: O,
    watchers: C,
    cleanupValue: P,
    resolveUrlAndSetWatchers: Y
  };
}, dO = function(t, n, r) {
  var {
    items: i
  } = De(t), {
    resolveOptions: a,
    resolvedOptions: o,
    updateItems: s,
    watchers: l,
    cleanupValue: u,
    resolveUrlAndSetWatchers: c
  } = Z8(t, n, r);
  return a(), et(i, a), {
    resolveOptions: a,
    resolvedOptions: o,
    updateItems: s,
    watchers: l,
    cleanupValue: u,
    resolveUrlAndSetWatchers: c
  };
}, J8 = function(t, n, r) {
  var {
    items: i
  } = De(t), {
    watchers: a,
    cleanupValue: o,
    resolveUrlAndSetWatchers: s
  } = Z8(t, n, r), l = r.disableAll, u = r.enableAll, c = r.el$, d = r.form$, f = En("config$"), h = he(null), m = N(() => {
    var E = [];
    return Te(h.value, (S, C) => {
      [null, void 0].indexOf(S) === -1 && (Array.isArray(h.value) && typeof S == "object" ? (S.value === void 0 && console.warn("You must define `value` property for each item when using an array of objects options"), E.push(S)) : Array.isArray(h.value) ? E.push({
        value: S,
        label: S
      }) : typeof S == "object" ? E.push(mt(mt({}, S), {}, {
        value: C
      })) : E.push({
        label: S,
        value: C
      }));
    }), E.map((S) => mt(mt({}, S), {}, {
      label: oi(S.label, f.value, d.value)
    }));
  }), v = /* @__PURE__ */ function() {
    var E = ht(function* () {
      var S = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : !0;
      S && l(), typeof i.value == "string" ? yield b() : yield y(), S && u();
    });
    return function() {
      return E.apply(this, arguments);
    };
  }(), b = /* @__PURE__ */ function() {
    var E = ht(function* () {
      try {
        var S, C, T = yield s(i.value, v);
        h.value = ((S = yield d.value.$vueform.services.axios.get(T)) === null || S === void 0 ? void 0 : S.data) || [], o(((C = m.value) === null || C === void 0 ? void 0 : C.map((O) => O.value)) || []);
      } catch (O) {
        h.value = [], console.warn("Couldn't resolve items from ".concat(i.value), O);
      }
    });
    return function() {
      return E.apply(this, arguments);
    };
  }(), y = /* @__PURE__ */ function() {
    var E = ht(function* () {
      try {
        h.value = (yield i.value(c.value)) || [];
      } catch (S) {
        h.value = [], console.warn("Couldn't resolve items from async function", S);
      }
    });
    return function() {
      return E.apply(this, arguments);
    };
  }(), g = /* @__PURE__ */ function() {
    var E = ht(function* () {
      typeof i.value == "function" ? yield y() : typeof i.value == "string" ? yield b() : h.value = i.value;
    });
    return function() {
      return E.apply(this, arguments);
    };
  }();
  return g(), et(i, g), {
    resolveOptions: g,
    resolvedOptions: m,
    updateItems: v,
    watchers: a,
    cleanupValue: o,
    resolveUrlAndSetWatchers: s
  };
}, eBe = J8, tBe = dO, nBe = dO, e5 = {
  name: "CheckboxgroupElement",
  mixins: [Jn, dr, _r, vr, br],
  emits: ["change", "beforeCreate", "created", "beforeMount", "mounted", "beforeUpdate", "updated", "beforeUnmount", "unmounted"],
  props: {
    type: {
      required: !1,
      type: [String],
      default: "checkboxgroup",
      private: !0
    },
    default: {
      required: !1,
      type: [Array],
      default: () => []
    },
    id: {
      required: !1,
      type: [String],
      default: null
    },
    items: {
      required: !1,
      type: [Object, Array, Function, String],
      localized: !0,
      default: () => ({})
    },
    disabled: {
      required: !1,
      type: [Boolean],
      default: !1
    },
    disables: {
      required: !1,
      type: [Array],
      default: () => []
    },
    clearOnRefetch: {
      type: [Boolean],
      required: !1,
      default: !0
    }
  },
  setup(e, t) {
    return t.features = [Hn, zn, lr, cr, Kd, Zn, Mn, ZFe, U8, Mi, Mr, J8, Qn, ji, J3e, li, ir, kr, ar, or, Xn, rr, sr, tO, Ei, ur], t.slots = ["checkbox", "label", "info", "description", "before", "between", "after"], mt({}, Yr(e, t));
  }
}, ic = function(t, n, r) {
  var {
    addons: i,
    slots: a
  } = De(t), o = r.el$, s = r.form$, l = N(() => {
    var c, d;
    return !!(i.value.before || (c = o.value.$slots) !== null && c !== void 0 && c["addon-before"] || /* istanbul ignore next */
    s.value.$vueform.vueVersion === 2 && (d = o.value.$scopedSlots) !== null && d !== void 0 && d["addon-before"] || a.value["addon-before"]);
  }), u = N(() => {
    var c, d;
    return !!(i.value.after || (c = o.value.$slots) !== null && c !== void 0 && c["addon-after"] || /* istanbul ignore next */
    s.value.$vueform.vueVersion === 2 && (d = o.value.$scopedSlots) !== null && d !== void 0 && d["addon-after"] || a.value["addon-after"]);
  });
  return {
    hasAddonBefore: l,
    hasAddonAfter: u
  };
}, us = function(t, n, r) {
  var i = r.value, a = r.nullValue, o = N(() => zd(i.value, a.value) || [void 0, null, ""].indexOf(i.value) !== -1);
  return {
    empty: o
  };
}, fO = function(t, n, r) {
  var i = r.value, a = r.nullValue, o = r.language, s = N(() => i.value[o.value] == a.value[o.value] || i.value[o.value] === "");
  return {
    empty: s
  };
}, Yv = function(t, n, r) {
  var i = r.value, a = r.nullValue, o = N(() => zd(i.value, a.value) || [void 0, null, ""].indexOf(i.value) !== -1 || i.value.length == 0);
  return {
    empty: o
  };
}, rBe = function(t, n, r) {
  var {
    displayFormat: i,
    valueFormat: a,
    loadFormat: o,
    date: s,
    time: l,
    seconds: u,
    hour24: c
  } = De(t), d = r.form$, f = N(() => {
    var g;
    return s.value && l.value && u.value && c.value ? g = "datetimeSeconds24" : s.value && l.value && u.value && !c.value ? g = "datetimeSeconds12" : s.value && l.value && !u.value && c.value ? g = "datetime24" : s.value && l.value && !u.value && !c.value ? g = "datetime12" : !s.value && l.value && u.value && c.value ? g = "timeSeconds24" : !s.value && l.value && u.value && !c.value ? g = "timeSeconds12" : !s.value && l.value && !u.value && c.value ? g = "time24" : !s.value && l.value && !u.value && !c.value ? g = "time12" : g = "date", g;
  }), h = N(() => d.value.translations.vueform.dateFormats[f.value]), m = N(() => {
    var g = {
      datetimeSeconds24: "YYYY-MM-DD HH:mm:ss",
      datetimeSeconds12: "YYYY-MM-DD hh:mm:ss a",
      datetime24: "YYYY-MM-DD HH:mm",
      datetime12: "YYYY-MM-DD hh:mm a",
      timeSeconds24: "HH:mm:ss",
      timeSeconds12: "hh:mm:ss a",
      time24: "HH:mm",
      time12: "hh:mm a",
      date: "YYYY-MM-DD"
    };
    return g[f.value];
  }), v = N(() => i.value !== null ? i.value : h.value), b = N(() => a.value !== null || a.value === !1 ? a.value : m.value), y = N(() => o.value !== null ? o.value : m.value);
  return {
    displayDateFormat: v,
    valueDateFormat: b,
    loadDateFormat: y
  };
}, iBe = function(t, n, r) {
  var {
    displayFormat: i,
    valueFormat: a,
    loadFormat: o
  } = De(t), s = r.form$, l = N(() => s.value.translations.vueform.dateFormats.date), u = N(() => i.value !== null ? i.value : l.value), c = N(() => a.value !== null || a.value === !1 ? a.value : l.value), d = N(() => o.value !== null ? o.value : l.value);
  return {
    displayDateFormat: u,
    valueDateFormat: c,
    loadDateFormat: d
  };
}, Hv = function(t, n, r) {
  var i = r.value, a = (o) => {
    i.value = o;
  };
  return {
    handleChange: a
  };
}, cs = function(t, n, r) {
  var {
    floating: i,
    placeholder: a
  } = De(t), o = r.form$, s = N(() => !!(i.value || a.value && o.value.options.floatPlaceholders) && i.value !== !1);
  return {
    hasFloating: s
  };
}, ro = function(t, n, r) {
  var {
    placeholder: i
  } = De(t), a = En("config$"), o = En("form$"), s = N(() => oi(i.value, a.value, o.value));
  return {
    Placeholder: s
  };
}, t5 = function(t, n, r) {
  var {
    disables: i,
    min: a,
    max: o,
    extendOptions: s,
    readonly: l,
    hour24: u,
    seconds: c,
    date: d,
    time: f
  } = De(t), h = r.isDisabled, m = r.displayDateFormat, v = r.valueDateFormat, b = N(() => i.value === void 0 ? [] : Ku(i.value, (O) => ($u(v.value, O), O instanceof Date ? O : Ge(O, v.value, !0).toDate()))), y = N(() => a.value ? ($u(v.value, a.value), a.value instanceof Date ? a.value : Ge(a.value, v.value, !0).toDate()) : null), g = N(() => o.value ? ($u(v.value, o.value), o.value instanceof Date ? o.value : Ge(o.value, v.value, !0).toDate()) : null), E = N(() => ({
    dateFormat: m.value,
    minDate: y.value,
    maxDate: g.value,
    disable: b.value,
    clickOpens: !h.value && !l.value,
    time_24hr: u.value,
    enableTime: f.value,
    enableSeconds: c.value,
    noCalendar: !d.value
  })), S = N(() => Object.assign({}, E.value, s.value || /* istanbul ignore next */
  {})), C = N(() => !0), T = N(() => !1);
  return {
    minDate: y,
    maxDate: g,
    disabledDates: b,
    fieldOptions: S,
    hasDate: C,
    hasTime: T
  };
}, aBe = function(t, n, r) {
  var {
    mode: i,
    extendOptions: a,
    readonly: o
  } = De(t), {
    minDate: s,
    maxDate: l,
    disabledDates: u
  } = t5(t, n, r), c = r.isDisabled, d = r.displayDateFormat, f = N(() => ({
    mode: i.value,
    dateFormat: d.value,
    minDate: s.value,
    maxDate: l.value,
    disable: u.value,
    clickOpens: !c.value && !o.value
  })), h = N(() => Object.assign({}, f.value, a.value || /* istanbul ignore next */
  {})), m = N(() => !0), v = N(() => !1);
  return {
    minDate: s,
    maxDate: l,
    disabledDates: u,
    fieldOptions: h,
    hasDate: m,
    hasTime: v
  };
}, oBe = function(t, n, r) {
  var {
    native: i,
    extendOptions: a,
    labelProp: o,
    trackBy: s,
    valueProp: l,
    search: u,
    limit: c,
    noOptionsText: d,
    noResultsText: f,
    caret: h,
    object: m,
    delay: v,
    minChars: b,
    resolveOnLoad: y,
    filterResults: g,
    clearOnSearch: E,
    canDeselect: S,
    canClear: C,
    openDirection: T,
    strict: O,
    closeOnSelect: R,
    closeOnDeselect: D,
    autocomplete: q,
    groups: $,
    groupLabel: P,
    groupOptions: Y,
    groupHideEmpty: L,
    inputType: x,
    create: I,
    appendNewOption: k,
    addOptionOn: B,
    appendTo: W,
    appendToBody: Z
  } = De(t), V = r.form$, K = r.isLoading, ne = En("config$"), Ee = N(() => i.value && !u.value), oe = N(() => ({
    mode: "single",
    searchable: u.value || I.value,
    noOptionsText: d.value || V.value.translations.vueform.multiselect.noOptions,
    noResultsText: f.value || V.value.translations.vueform.multiselect.noResults,
    locale: Object.keys(ne.value.i18n.locales).length > 1 ? ne.value.i18n.locale : null,
    //@todo:adam can not be localized on form level
    fallbackLocale: ne.value.i18n.fallbackLocale,
    label: o.value,
    trackBy: s.value,
    valueProp: l.value,
    limit: c.value,
    caret: h.value,
    loading: K.value,
    object: m.value,
    delay: v.value,
    minChars: b.value,
    resolveOnLoad: y.value,
    filterResults: g.value,
    clearOnSearch: E.value,
    canDeselect: S.value,
    canClear: C.value,
    openDirection: T.value,
    strict: O.value,
    closeOnSelect: R.value,
    closeOnDeselect: D.value,
    autocomplete: q.value,
    groups: $.value,
    groupLabel: P.value,
    groupOptions: Y.value,
    groupHideEmpty: L.value,
    inputType: x.value,
    createOption: I.value,
    appendNewOption: k.value,
    addOptionOn: B.value,
    appendTo: W.value,
    appendToBody: Z.value
  })), ae = N(() => Object.assign({}, oe.value, a.value || /* istanbul ignore next */
  {}));
  return {
    fieldOptions: ae,
    isNative: Ee
  };
}, sBe = function(t, n, r) {
  var {
    native: i,
    extendOptions: a,
    labelProp: o,
    trackBy: s,
    valueProp: l,
    search: u,
    limit: c,
    noOptionsText: d,
    noResultsText: f,
    caret: h,
    object: m,
    delay: v,
    minChars: b,
    resolveOnLoad: y,
    filterResults: g,
    clearOnSearch: E,
    clearOnSelect: S,
    canClear: C,
    max: T,
    openDirection: O,
    strict: R,
    closeOnSelect: D,
    closeOnDeselect: q,
    autocomplete: $,
    groups: P,
    groupLabel: Y,
    groupOptions: L,
    groupHideEmpty: x,
    groupSelect: I,
    inputType: k,
    hideSelected: B,
    multipleLabel: W,
    multipleLabelMultiple: Z,
    multipleLabelSingle: V,
    create: K,
    appendNewOption: ne,
    addOptionOn: Ee,
    appendTo: oe,
    appendToBody: ae
  } = De(t), pe = r.form$, Se = r.isLoading, Re = En("config$"), Ye = N(() => i.value && !u.value), nt = N(() => ({
    mode: "multiple",
    searchable: u.value || K.value,
    noOptionsText: d.value || pe.value.translations.vueform.multiselect.noOptions,
    noResultsText: f.value || pe.value.translations.vueform.multiselect.noResults,
    multipleLabel: W.value || ((Tt, Ot) => Tt && Tt.length > 1 ? Z.value ? Z.value.replace(":x:", Tt.length) : pe.value.__(pe.value.translations.vueform.multiselect.multipleLabelMore, {
      options: Tt.length
    }) : V.value || pe.value.translations.vueform.multiselect.multipleLabelOne),
    locale: Object.keys(Re.value.i18n.locales).length > 1 ? Re.value.i18n.locale : null,
    //@todo:adam can not be localized on form level
    fallbackLocale: Re.value.i18n.fallbackLocale,
    label: o.value,
    trackBy: s.value,
    valueProp: l.value,
    limit: c.value,
    caret: h.value,
    loading: Se.value,
    object: m.value,
    delay: v.value,
    minChars: b.value,
    resolveOnLoad: y.value,
    filterResults: g.value,
    clearOnSearch: E.value,
    clearOnSelect: S.value,
    canClear: C.value,
    max: T.value,
    openDirection: O.value,
    strict: R.value,
    closeOnSelect: D.value,
    closeOnDeselect: q.value,
    autocomplete: $.value,
    groups: P.value,
    groupLabel: Y.value,
    groupOptions: L.value,
    groupHideEmpty: x.value,
    groupSelect: I.value,
    inputType: k.value,
    hideSelected: B.value,
    createOption: K.value,
    appendNewOption: ne.value,
    addOptionOn: Ee.value,
    appendTo: oe.value,
    appendToBody: ae.value
  })), ut = N(() => Object.assign({}, nt.value, a.value || /* istanbul ignore next */
  {}));
  return {
    fieldOptions: ut,
    isNative: Ye
  };
}, lBe = function(t, n, r) {
  var {
    extendOptions: i,
    labelProp: a,
    trackBy: o,
    valueProp: s,
    search: l,
    limit: u,
    noOptionsText: c,
    noResultsText: d,
    caret: f,
    object: h,
    delay: m,
    minChars: v,
    resolveOnLoad: b,
    filterResults: y,
    clearOnSearch: g,
    clearOnSelect: E,
    canClear: S,
    max: C,
    showOptions: T,
    openDirection: O,
    strict: R,
    closeOnSelect: D,
    closeOnDeselect: q,
    autocomplete: $,
    groups: P,
    groupLabel: Y,
    groupOptions: L,
    groupHideEmpty: x,
    groupSelect: I,
    inputType: k,
    hideSelected: B,
    create: W,
    appendNewOption: Z,
    addOptionOn: V,
    breakTags: K,
    appendTo: ne,
    appendToBody: Ee
  } = De(t), oe = r.form$, ae = r.isLoading, pe = En("config$"), Se = he(!1), Re = N(() => !1), Ye = N(() => ({
    mode: "tags",
    searchable: l.value || W.value,
    noOptionsText: c.value || oe.value.translations.vueform.multiselect.noOptions,
    noResultsText: d.value || oe.value.translations.vueform.multiselect.noResults,
    locale: Object.keys(pe.value.i18n.locales).length > 1 ? pe.value.i18n.locale : null,
    //@todo:adam can not be localized on form level
    fallbackLocale: pe.value.i18n.fallbackLocale,
    label: a.value,
    trackBy: o.value,
    valueProp: s.value,
    limit: u.value,
    caret: f.value,
    loading: ae.value,
    object: h.value,
    delay: m.value,
    minChars: v.value,
    resolveOnLoad: b.value,
    filterResults: y.value,
    clearOnSearch: g.value,
    clearOnSelect: E.value,
    canClear: S.value,
    max: C.value,
    showOptions: T.value,
    openDirection: O.value,
    strict: R.value,
    closeOnSelect: D.value,
    closeOnDeselect: q.value,
    autocomplete: $.value,
    groups: P.value,
    groupLabel: Y.value,
    groupOptions: L.value,
    groupHideEmpty: x.value,
    groupSelect: I.value,
    inputType: k.value,
    hideSelected: B.value,
    createOption: W.value,
    appendNewOption: Z.value,
    addOptionOn: V.value,
    breakTags: K.value,
    appendTo: ne.value,
    appendToBody: Ee.value
  })), nt = N(() => Object.assign({}, Ye.value, i.value || /* istanbul ignore next */
  {}));
  return {
    native: Se,
    fieldOptions: nt,
    isNative: Re
  };
}, uBe = function(t, n, r) {
  var {
    min: i,
    max: a,
    step: o,
    tooltips: s,
    merge: l,
    format: u,
    orientation: c,
    direction: d,
    extendOptions: f,
    showTooltip: h,
    tooltipPosition: m,
    lazy: v
  } = De(t), b = r.isDisabled;
  r.labelId;
  var y = N(() => ({
    min: i.value,
    max: a.value,
    step: o.value,
    tooltips: s.value,
    merge: l.value,
    format: u.value,
    orientation: c.value,
    direction: d.value,
    disabled: b.value,
    showTooltip: h.value,
    tooltipPosition: m.value,
    lazy: v.value
  })), g = N(() => Object.assign({}, y.value, f.value || /* istanbul ignore next */
  {}));
  return {
    fieldOptions: g
  };
}, cBe = function(t, n, r) {
  var {
    labels: i,
    extendOptions: a,
    trueValue: o,
    falseValue: s
  } = De(t), l = r.isDisabled, u = r.form$, c = En("config$"), d = N(() => ({
    disabled: l.value,
    offLabel: i.value && oi(i.value.off, c.value, u.value) || "",
    onLabel: i.value && oi(i.value.on, c.value, u.value) || "",
    trueValue: o.value,
    falseValue: s.value
  })), f = N(() => Object.assign({}, d.value, a.value || /* istanbul ignore next */
  {}));
  return {
    fieldOptions: f
  };
}, jd = function(t, n, r) {
  var i = r.input, a = he(!1);
  return On(() => {
    i && i.value && i.value.addEventListener && (i.value.addEventListener("focus", () => {
      a.value = !0;
    }), i.value.addEventListener("blur", () => {
      a.value = !1;
    }));
  }), {
    focused: a
  };
}, n5 = function(t, n, r) {
  var i = r.input, a = he(!1);
  return On(() => {
    i.value.input.addEventListener("focus", () => {
      a.value = !0;
    }), i.value.input.addEventListener("blur", () => {
      a.value = !1;
    });
  }), {
    focused: a
  };
}, pO = function(t, n, r) {
  var i = r.input, a = r.isNative, o = he(!1);
  return On(() => {
    a.value ? (i.value.addEventListener("focus", () => {
      o.value = !0;
    }), i.value.addEventListener("blur", () => {
      o.value = !1;
    })) : et(N(() => {
      var s;
      return (s = i.value) === null || s === void 0 ? void 0 : s.isActive;
    }), (s) => {
      o.value = s;
    });
  }), {
    focused: o
  };
}, dBe = n5, fBe = pO, pBe = pO, r5 = {
  name: "DateElement",
  mixins: [Jn, dr, _r, vr, br],
  emits: ["change", "beforeCreate", "created", "beforeMount", "mounted", "beforeUpdate", "updated", "beforeUnmount", "unmounted"],
  props: {
    type: {
      required: !1,
      type: [String],
      default: "date",
      private: !0
    },
    default: {
      required: !1,
      type: [String, Date],
      default: null
    },
    addons: {
      required: !1,
      type: [Object],
      localized: !0,
      default: () => ({})
    },
    disabled: {
      required: !1,
      type: [Boolean],
      default: !1
    },
    floating: {
      required: !1,
      type: [String, Boolean, Object],
      localized: !0,
      default: null
    },
    id: {
      required: !1,
      type: [String],
      default: null
    },
    displayFormat: {
      required: !1,
      type: [String],
      default: null,
      "@default": "locale.vueform.dateFormats.*"
    },
    valueFormat: {
      required: !1,
      type: [String, Boolean],
      default: null,
      "@default": "locale.vueform.dateFormats.*"
    },
    loadFormat: {
      required: !1,
      type: [String],
      default: null,
      "@default": "locale.vueform.dateFormats.*"
    },
    date: {
      required: !1,
      type: [Boolean],
      default: !0
    },
    time: {
      required: !1,
      type: [Boolean],
      default: !1
    },
    seconds: {
      required: !1,
      type: [Boolean],
      default: !1
    },
    hour24: {
      required: !1,
      type: [Boolean],
      default: !0
    },
    min: {
      required: !1,
      type: [String, Date],
      default: null
    },
    max: {
      required: !1,
      type: [String, Date],
      default: null
    },
    disables: {
      required: !1,
      type: [Array],
      default: () => []
    },
    extendOptions: {
      required: !1,
      type: [Object],
      default: () => ({})
    },
    placeholder: {
      required: !1,
      type: [String, Object],
      localized: !0,
      default: null
    },
    readonly: {
      required: !1,
      type: [Boolean],
      default: !1
    }
  },
  setup(e, t) {
    return t.features = [Hn, zn, lr, ei, cr, qr, ls, Zn, cs, Mn, Gr, ic, rBe, t5, Mi, Qn, ji, H3e, O3e, us, ir, kr, or, Xn, rr, ar, sr, Hv, n5, Lr, Ei, ur, ro], t.slots = ["label", "info", "description", "before", "between", "after", "addon-before", "addon-after"], mt({}, Yr(e, t));
  }
}, i5 = {
  name: "DatesElement",
  mixins: [Jn, dr, _r, vr, br],
  emits: ["change", "beforeCreate", "created", "beforeMount", "mounted", "beforeUpdate", "updated", "beforeUnmount", "unmounted"],
  props: {
    type: {
      required: !1,
      type: [String],
      default: "dates",
      private: !0
    },
    default: {
      required: !1,
      type: [Array],
      default: () => []
    },
    addons: {
      required: !1,
      type: [Object],
      localized: !0,
      default: () => ({})
    },
    disabled: {
      required: !1,
      type: [Boolean],
      default: !1
    },
    floating: {
      required: !1,
      type: [String, Boolean, Object],
      localized: !0,
      default: null
    },
    id: {
      required: !1,
      type: [String],
      default: null
    },
    displayFormat: {
      required: !1,
      type: [String],
      default: null
    },
    valueFormat: {
      required: !1,
      type: [String, Boolean],
      default: null
    },
    loadFormat: {
      required: !1,
      type: [String, Boolean],
      default: null
    },
    mode: {
      required: !1,
      type: [String],
      default: "multiple"
    },
    min: {
      required: !1,
      type: [String, Date],
      default: null
    },
    max: {
      required: !1,
      type: [String, Date],
      default: null
    },
    disables: {
      required: !1,
      type: [Array],
      default: () => []
    },
    extendOptions: {
      required: !1,
      type: [Object],
      default: () => ({})
    },
    placeholder: {
      required: !1,
      type: [String, Object],
      localized: !0,
      default: null
    },
    readonly: {
      required: !1,
      type: [Boolean],
      default: !1
    }
  },
  setup(e, t) {
    return t.features = [Hn, zn, lr, ei, cr, qr, Kd, Zn, cs, Mn, JFe, ic, iBe, aBe, Mi, z3e, Qn, ji, R3e, us, ir, kr, or, Xn, rr, ar, sr, Hv, dBe, Lr, Ei, ur, ro], t.slots = ["label", "info", "description", "before", "between", "after", "addon-before", "addon-after"], mt({}, Yr(e, t));
  }
}, mBe = function(t, n, r) {
  var {
    type: i,
    embed: a,
    auto: o,
    methods: s,
    urls: l,
    uploadTempEndpoint: u,
    removeTempEndpoint: c,
    removeEndpoint: d,
    url: f,
    previewUrl: h,
    params: m,
    softRemove: v,
    view: b
  } = De(t), y = r.form$, g = r.value, E = r.isDisabled, S = r.validate, C = r.invalid, T = r.path, O = r.axios, R = r.request, D = r.uploading, q = r.input, $ = r.update, P = r.fire, Y = r.isImageType, L = r.removing, x = r.handleError, I = r.el$, k = he(!1), B = he(null), W = he(0), Z = he(!1), V = he({}), K = N(() => {
    var ft = y.value.$vueform.config.endpoints, Ze = {
      uploadTempFile: u.value,
      removeTempFile: c.value,
      removeFile: d.value
    }, _t = {};
    return Object.keys(Ze).forEach((St) => {
      var we = ft[St];
      l.value[St] && (we = {
        url: l.value[St],
        method: "POST"
      }), s.value[St] && typeof we == "object" && (we.method = s.value[St]), typeof Ze[St] == "string" && (ft[Ze[St]] !== void 0 ? we = ft[Ze[St]] : we.url = Ze[St]), typeof Ze[St] == "function" && (we = Ze[St]), typeof Ze[St] == "object" && (we = {
        url: Ze[St].url || Ze[St].endpoint || ft[St].url,
        method: Ze[St].method || ft[St].method
      }), _t[St] = we;
    }), _t;
  }), ne = N(() => {
    if (f.value === void 0)
      return "/";
    if (f.value === !1)
      return "";
    var ft = f.value;
    return ft.match(/\/$/) || (ft += "/"), !ft.match(/^http/) && !ft.match(/^\//) && (ft = "/" + ft), ft;
  }), Ee = N(() => {
    if (h.value === void 0)
      return ne.value;
    var ft = h.value;
    return ft.match(/\/$/) || (ft += "/"), !ft.match(/^http/) && !ft.match(/^\//) && (ft = "/" + ft), ft;
  }), oe = N(() => g.value === null ? 0 : g.value instanceof File ? 1 : Ma(g.value) && g.value.tmp !== void 0 ? 2 : Bv(g.value) ? 3 : -1), ae = N(() => {
    switch (oe.value) {
      case 1:
        return g.value.name;
      case 2:
        return g.value.originalName;
      case 3:
        return g.value;
      default:
        return null;
    }
  }), pe = N(() => {
    if (Ye.value)
      return ne.value + ae.value;
  }), Se = N(() => {
    if (Ye.value)
      return Ee.value + ae.value;
  }), Re = N(() => b.value === "file" ? null : Ye.value ? Se.value : B.value), Ye = N(() => oe.value === 3), nt = N(() => oe.value > 0 && !D.value && !E.value && !Z.value && !L.value), ut = N(() => oe.value === 1 && !o.value && !D.value && !E.value), Tt = N(() => !a.value && oe.value == 0), Ot = /* @__PURE__ */ function() {
    var ft = ht(function* () {
      if (oe.value !== 1)
        throw new Error("No file is selected");
      if (yield S(), !C.value) {
        R.value = O.value.CancelToken.source();
        try {
          var Ze = M$(Object.assign({}, m.value, {
            file: g.value,
            formKey: y.value.options.formKey,
            path: T.value
          }));
          k.value = !1;
          var _t;
          if (typeof K.value.uploadTempFile == "function")
            _t = yield K.value.uploadTempFile(g.value, I.value);
          else {
            var St = K.value.uploadTempFile.method.toLowerCase();
            _t = yield O.value.request({
              url: K.value.uploadTempFile.url,
              method: St,
              [St === "get" ? "params" : "data"]: Ze,
              onUploadProgress: (we) => {
                W.value = Math.round(we.loaded * 100 / we.total);
              },
              cancelToken: R.value.token
            }), _t = _t.data;
          }
          _t && typeof _t == "object" && (_t.__file__ = g.value), $(_t);
        } catch (we) {
          throw W.value = 0, O.value.isCancel(we) || (k.value = !0, x(we)), new Error(we);
        } finally {
          R.value = null;
        }
      }
    });
    return function() {
      return ft.apply(this, arguments);
    };
  }(), Xt = /* @__PURE__ */ function() {
    var ft = ht(function* () {
      L.value = !0, k.value = !1;
      try {
        if (oe.value === 3 && !v.value) {
          if (!confirm(y.value.translations.vueform.elements.file.removeConfirm))
            return !1;
          if (typeof K.value.removeFile == "function")
            yield K.value.removeFile(g.value, I.value);
          else {
            var Ze = K.value.removeFile.method.toLowerCase();
            yield O.value.request({
              method: Ze,
              url: K.value.removeFile.url,
              [Ze === "get" ? "params" : "data"]: Object.assign({}, m.value, {
                file: g.value,
                formKey: y.value.options.formKey,
                path: T.value
              })
            });
          }
        } else if (oe.value === 2 && !v.value)
          if (typeof K.value.removeTempFile == "function")
            yield K.value.removeTempFile(g.value, I.value);
          else {
            var _t = K.value.removeTempFile.method.toLowerCase();
            yield O.value.request({
              method: _t,
              url: K.value.removeTempFile.url,
              [_t === "get" ? "params" : "data"]: Object.assign({}, m.value, {
                file: g.value.tmp,
                formKey: y.value.options.formKey,
                path: T.value
              })
            });
          }
      } catch (St) {
        x(St);
        return;
      } finally {
        L.value = !1;
      }
      $(null), W.value = 0, P("remove");
    });
    return function() {
      return ft.apply(this, arguments);
    };
  }(), We = /* @__PURE__ */ function() {
    var ft = ht(function* () {
      if (oe.value === 1) {
        Z.value = !0;
        try {
          yield Ot();
        } finally {
          Z.value = !1;
        }
      }
    });
    return function() {
      return ft.apply(this, arguments);
    };
  }(), st = function() {
    var Ze = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : g.value, _t = new FileReader();
    _t.onload = (St) => {
      B.value = St.target.result;
    }, _t.readAsDataURL(Ze);
  }, Pt = /* @__PURE__ */ function() {
    var ft = ht(function* (Ze) {
      var _t = Ze.target.files[0];
      q.value.value = "", $(_t || null), o.value && (yield Ot()), y.value.shouldValidateOnChange && S();
    });
    return function(_t) {
      return ft.apply(this, arguments);
    };
  }(), Ke = () => {
    E.value || q.value.click();
  }, Je = () => {
    Ot();
  }, Be = () => {
    Xt();
  }, pt = () => {
    R.value !== null && R.value.cancel();
  };
  return V.value.value = et(g, (ft) => {
    var Ze, _t;
    if (!ft) {
      B.value = null;
      return;
    }
    !Y.value || b.value === "file" || !(g.value instanceof File) && !((Ze = g.value) !== null && Ze !== void 0 && Ze.__file__) || st(g.value instanceof File ? g.value : (_t = g.value) === null || _t === void 0 ? void 0 : _t.__file__);
  }, {
    immediate: !0
  }), V.value.view = et(b, (ft) => {
    ["image", "gallery"].indexOf(ft) !== -1 && !B.value && g.value instanceof File && st();
  }), g.value instanceof File && o.value && Ut(() => {
    Ot();
  }), {
    hasUploadError: k,
    base64: B,
    progress: W,
    preparing: Z,
    endpoints: K,
    fileUrl: ne,
    stage: oe,
    filename: ae,
    link: pe,
    preview: Re,
    uploaded: Ye,
    canRemove: nt,
    canUploadTemp: ut,
    canSelect: Tt,
    watchers: V,
    uploadTemp: Ot,
    remove: Xt,
    prepare: We,
    handleChange: Pt,
    handleClick: Ke,
    handleUploadTemp: Je,
    handleRemove: Be,
    handleAbort: pt
  };
}, hBe = function(t, n, r) {
  var i = r.form$, a = he(null), o = he(null), s = N(() => a.value !== null);
  return On(() => {
    o.value = i.value.$vueform.services.axios;
  }), {
    request: a,
    axios: o,
    uploading: s
  };
};
function a5(e, t) {
  return t ? (At(t) || (t = t.split(","), Te(t, (n, r) => {
    t[r] = n.trim();
  })), hn(t, (n) => {
    var r = n.match(/^([^\/]+)\/\*$/);
    return r ? !!new RegExp("^".concat(r[1], "/")).exec(e.type) : n == e.type ? !0 : n == ".".concat(e.name.split(".").pop());
  })) : !0;
}
var o5 = function(t, n, r) {
  var {
    accept: i,
    auto: a
  } = De(t), o = r.update, s = r.isDisabled, l = r.uploadTemp, u = N(() => {
    var d = document.createElement("div");
    return ("draggable" in d || /* istanbul ignore next: failsafe only, can not influence div from outside */
    "ondragstart" in d && "ondrop" in d) && "FormData" in window && "FileReader" in window;
  }), c = (d) => {
    if (!s.value) {
      var f = d.dataTransfer.files[0];
      a5(f, i.value) && (o(f || /* istanbul ignore next: failsafe only */
      null), a.value && l(), f.value = null);
    }
  };
  return {
    canDrop: u,
    handleDrop: c
  };
}, gBe = function(t, n, r) {
  var {
    accept: i
  } = De(t), {
    canDrop: a
  } = o5(t, n, r), o = r.add, s = r.isDisabled, l = r.isObject, u = r.storeFileName, c = (d) => {
    !d.dataTransfer || !d.dataTransfer.files || d.dataTransfer.files.length == 0 || s.value || Te(d.dataTransfer.files, (f) => {
      a5(f, i.value) && o(l.value ? {
        [u.value]: f
      } : f);
    });
  };
  return {
    canDrop: a,
    handleDrop: c
  };
}, _Be = function(t, n, r) {
  var i = he(!1);
  return {
    removing: i
  };
}, mO = function(t, n, r) {
  var i = r.fire;
  r.listeners;
  var a = (o) => {
    i("error", o);
  };
  return {
    handleError: a
  };
}, s5 = {
  name: "FileElement",
  mixins: [Jn, dr, _r, vr, br],
  emits: ["change", "remove", "error", "beforeCreate", "created", "beforeMount", "mounted", "beforeUpdate", "updated", "beforeUnmount", "unmounted"],
  props: {
    type: {
      required: !1,
      type: [String],
      default: "file",
      private: !0
    },
    default: {
      required: !1,
      type: [String, Object],
      default: null
    },
    disabled: {
      required: !1,
      type: [Boolean],
      default: !1
    },
    id: {
      required: !1,
      type: [String],
      default: null
    },
    onRemove: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    },
    onError: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    },
    view: {
      type: [String],
      required: !1,
      default: "file"
    },
    drop: {
      required: !1,
      type: [Boolean],
      default: !1
    },
    accept: {
      required: !1,
      type: [String, Array],
      default: null
    },
    clickable: {
      required: !1,
      type: [Boolean],
      default: !0
    },
    url: {
      required: !1,
      type: [String, Boolean],
      default: "/"
    },
    previewUrl: {
      required: !1,
      type: [String],
      default: void 0
    },
    auto: {
      required: !1,
      type: [Boolean],
      default: !0
    },
    urls: {
      required: !1,
      type: [Object],
      default: () => ({})
    },
    methods: {
      required: !1,
      type: [Object],
      default: () => ({})
    },
    uploadTempEndpoint: {
      required: !1,
      type: [Object, String, Function],
      default: void 0,
      "@default": "config.endpoints.uploadTempFile"
    },
    removeTempEndpoint: {
      required: !1,
      type: [Object, String, Function],
      default: void 0,
      "@default": "config.endpoints.removeTempFile"
    },
    removeEndpoint: {
      required: !1,
      type: [Object, String, Function],
      default: void 0,
      "@default": "config.endpoints.removeFile"
    },
    params: {
      required: !1,
      type: [Object],
      default: () => ({})
    },
    softRemove: {
      required: !1,
      type: [Boolean],
      default: !1
    },
    embed: {
      type: [Boolean],
      required: !1,
      default: !1,
      private: !0
    }
  },
  setup(e, t) {
    return t.features = [Hn, zn, lr, ei, cr, qr, ls, _Be, Zn, Mn, XFe, hBe, Mi, Qn, Mr, P3e, yg, mO, mBe, o5, us, ir, U3e, or, Xn, rr, ar, sr, WFe, Ei, ur], t.slots = ["label", "info", "description", "before", "between", "after"], mt({}, Yr(e, t));
  }
}, ac = function(t, n, r) {
  var i = r.model, a = (o) => {
    i.value = o.target.value;
  };
  return {
    handleInput: a
  };
}, l5 = {
  register: !1,
  name: "GenericElement",
  mixins: [Jn, dr, _r, vr, br],
  emits: ["change", "beforeCreate", "created", "beforeMount", "mounted", "beforeUpdate", "updated", "beforeUnmount", "unmounted"],
  props: {
    type: {
      required: !1,
      type: [String],
      default: "",
      private: !0
    },
    id: {
      required: !1,
      type: [String],
      default: null
    },
    disabled: {
      required: !1,
      type: [Boolean],
      default: !1
    },
    default: {
      required: !1,
      type: [String, Number, Object],
      default: void 0
    }
  },
  setup(e, t) {
    return t.features = [Hn, zn, lr, ei, cr, qr, ls, Zn, Mn, Gr, qv, Qn, Wd, Mr, li, us, ir, kr, or, Xn, rr, ar, sr, ac, jd, Lr, Ei, ur], t.slots = ["label", "info", "description", "before", "between", "after"], mt({}, Yr(e, t));
  }
}, hO = function(t, n, r) {
  var i = he([]), a = N(() => {
    var o = {};
    return i.value.forEach((s) => {
      o[s.name] = s;
    }), o;
  });
  return {
    children$Array: i,
    children$: a
  };
}, u5 = function(t, n, r) {
  var i = arguments.length > 3 && arguments[3] !== void 0 ? arguments[3] : {}, a = i.schemaName || "schema", {
    [a]: o
  } = De(t), {
    children$Array: s,
    children$: l
  } = hO(), u = N(() => o.value);
  return o && et(o, (c) => {
    var d = [];
    Te(c, (f, h) => {
      d.push(s.value[s.value.map((m) => Ur(m.name)).indexOf(Ur(h))]);
    }), s.value = d;
  }, {
    flush: "post",
    deep: !0
  }), {
    children: u,
    children$Array: s,
    children$: l
  };
}, vBe = u5, c5 = {
  name: "GroupElement",
  mixins: [Jn, dr, _r, vr, br],
  emits: ["change", "beforeCreate", "created", "beforeMount", "mounted", "beforeUpdate", "updated", "beforeUnmount", "unmounted"],
  props: {
    type: {
      required: !1,
      type: [String],
      default: "group",
      private: !0
    },
    default: {
      required: !1,
      type: [Object],
      default: () => ({})
    },
    id: {
      required: !1,
      type: [String],
      default: null
    },
    schema: {
      required: !1,
      type: [Object],
      default: () => ({})
    }
  },
  setup(e, t) {
    return t.features = [Hn, zn, lr, n3e, Zn, Q8, Mn, Gr, vBe, k3e, ir, B3e, Y3e, Lm, yFe, or, Xn, rr, ar, sr, A3e, Lr, K3e, ur], t.slots = ["label", "info", "description", "before", "between", "after"], mt({}, Yr(e, t));
  }
}, d5 = {
  name: "HiddenElement",
  mixins: [Jn, _r, vr, br],
  emits: ["change", "beforeCreate", "created", "beforeMount", "mounted", "beforeUpdate", "updated", "beforeUnmount", "unmounted"],
  props: {
    type: {
      required: !1,
      type: [String],
      default: "hidden",
      private: !0
    },
    default: {
      required: !1,
      type: [String, Number, Object],
      default: null
    },
    id: {
      required: !1,
      type: [String],
      default: null
    },
    meta: {
      required: !1,
      type: [Boolean],
      default: !1
    }
  },
  setup(e, t) {
    return t.features = [Hn, zn, ei, cr, ls, kr, Zn, Xn, Mn, Gr, Mi, Qn, ji, Mr, li, us, Ei, ur], mt({}, Yr(e, t));
  }
};
/**!
 * Sortable 1.15.2
 * @author	RubaXa   <trash@rubaxa.org>
 * @author	owenm    <owen23355@gmail.com>
 * @license MIT
 */
function eP(e, t) {
  var n = Object.keys(e);
  if (Object.getOwnPropertySymbols) {
    var r = Object.getOwnPropertySymbols(e);
    t && (r = r.filter(function(i) {
      return Object.getOwnPropertyDescriptor(e, i).enumerable;
    })), n.push.apply(n, r);
  }
  return n;
}
function Xo(e) {
  for (var t = 1; t < arguments.length; t++) {
    var n = arguments[t] != null ? arguments[t] : {};
    t % 2 ? eP(Object(n), !0).forEach(function(r) {
      bBe(e, r, n[r]);
    }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(n)) : eP(Object(n)).forEach(function(r) {
      Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(n, r));
    });
  }
  return e;
}
function Tg(e) {
  "@babel/helpers - typeof";
  return typeof Symbol == "function" && typeof Symbol.iterator == "symbol" ? Tg = function(t) {
    return typeof t;
  } : Tg = function(t) {
    return t && typeof Symbol == "function" && t.constructor === Symbol && t !== Symbol.prototype ? "symbol" : typeof t;
  }, Tg(e);
}
function bBe(e, t, n) {
  return t in e ? Object.defineProperty(e, t, {
    value: n,
    enumerable: !0,
    configurable: !0,
    writable: !0
  }) : e[t] = n, e;
}
function Gs() {
  return Gs = Object.assign || function(e) {
    for (var t = 1; t < arguments.length; t++) {
      var n = arguments[t];
      for (var r in n)
        Object.prototype.hasOwnProperty.call(n, r) && (e[r] = n[r]);
    }
    return e;
  }, Gs.apply(this, arguments);
}
function EBe(e, t) {
  if (e == null) return {};
  var n = {}, r = Object.keys(e), i, a;
  for (a = 0; a < r.length; a++)
    i = r[a], !(t.indexOf(i) >= 0) && (n[i] = e[i]);
  return n;
}
function SBe(e, t) {
  if (e == null) return {};
  var n = EBe(e, t), r, i;
  if (Object.getOwnPropertySymbols) {
    var a = Object.getOwnPropertySymbols(e);
    for (i = 0; i < a.length; i++)
      r = a[i], !(t.indexOf(r) >= 0) && Object.prototype.propertyIsEnumerable.call(e, r) && (n[r] = e[r]);
  }
  return n;
}
var yBe = "1.15.2";
function Bs(e) {
  if (typeof window < "u" && window.navigator)
    return !!/* @__PURE__ */ navigator.userAgent.match(e);
}
var Xs = Bs(/(?:Trident.*rv[ :]?11\.|msie|iemobile|Windows Phone)/i), km = Bs(/Edge/i), tP = Bs(/firefox/i), ap = Bs(/safari/i) && !Bs(/chrome/i) && !Bs(/android/i), f5 = Bs(/iP(ad|od|hone)/i), p5 = Bs(/chrome/i) && Bs(/android/i), m5 = {
  capture: !1,
  passive: !1
};
function $n(e, t, n) {
  e.addEventListener(t, n, !Xs && m5);
}
function Nn(e, t, n) {
  e.removeEventListener(t, n, !Xs && m5);
}
function __(e, t) {
  if (t) {
    if (t[0] === ">" && (t = t.substring(1)), e)
      try {
        if (e.matches)
          return e.matches(t);
        if (e.msMatchesSelector)
          return e.msMatchesSelector(t);
        if (e.webkitMatchesSelector)
          return e.webkitMatchesSelector(t);
      } catch {
        return !1;
      }
    return !1;
  }
}
function TBe(e) {
  return e.host && e !== document && e.host.nodeType ? e.host : e.parentNode;
}
function ho(e, t, n, r) {
  if (e) {
    n = n || document;
    do {
      if (t != null && (t[0] === ">" ? e.parentNode === n && __(e, t) : __(e, t)) || r && e === n)
        return e;
      if (e === n) break;
    } while (e = TBe(e));
  }
  return null;
}
var nP = /\s+/g;
function Ca(e, t, n) {
  if (e && t)
    if (e.classList)
      e.classList[n ? "add" : "remove"](t);
    else {
      var r = (" " + e.className + " ").replace(nP, " ").replace(" " + t + " ", " ");
      e.className = (r + (n ? " " + t : "")).replace(nP, " ");
    }
}
function Vt(e, t, n) {
  var r = e && e.style;
  if (r) {
    if (n === void 0)
      return document.defaultView && document.defaultView.getComputedStyle ? n = document.defaultView.getComputedStyle(e, "") : e.currentStyle && (n = e.currentStyle), t === void 0 ? n : n[t];
    !(t in r) && t.indexOf("webkit") === -1 && (t = "-webkit-" + t), r[t] = n + (typeof n == "string" ? "" : "px");
  }
}
function od(e, t) {
  var n = "";
  if (typeof e == "string")
    n = e;
  else
    do {
      var r = Vt(e, "transform");
      r && r !== "none" && (n = r + " " + n);
    } while (!t && (e = e.parentNode));
  var i = window.DOMMatrix || window.WebKitCSSMatrix || window.CSSMatrix || window.MSCSSMatrix;
  return i && new i(n);
}
function h5(e, t, n) {
  if (e) {
    var r = e.getElementsByTagName(t), i = 0, a = r.length;
    if (n)
      for (; i < a; i++)
        n(r[i], i);
    return r;
  }
  return [];
}
function zo() {
  var e = document.scrollingElement;
  return e || document.documentElement;
}
function zr(e, t, n, r, i) {
  if (!(!e.getBoundingClientRect && e !== window)) {
    var a, o, s, l, u, c, d;
    if (e !== window && e.parentNode && e !== zo() ? (a = e.getBoundingClientRect(), o = a.top, s = a.left, l = a.bottom, u = a.right, c = a.height, d = a.width) : (o = 0, s = 0, l = window.innerHeight, u = window.innerWidth, c = window.innerHeight, d = window.innerWidth), (t || n) && e !== window && (i = i || e.parentNode, !Xs))
      do
        if (i && i.getBoundingClientRect && (Vt(i, "transform") !== "none" || n && Vt(i, "position") !== "static")) {
          var f = i.getBoundingClientRect();
          o -= f.top + parseInt(Vt(i, "border-top-width")), s -= f.left + parseInt(Vt(i, "border-left-width")), l = o + a.height, u = s + a.width;
          break;
        }
      while (i = i.parentNode);
    if (r && e !== window) {
      var h = od(i || e), m = h && h.a, v = h && h.d;
      h && (o /= v, s /= m, d /= m, c /= v, l = o + c, u = s + d);
    }
    return {
      top: o,
      left: s,
      bottom: l,
      right: u,
      width: d,
      height: c
    };
  }
}
function rP(e, t, n) {
  for (var r = Dl(e, !0), i = zr(e)[t]; r; ) {
    var a = zr(r)[n], o = void 0;
    if (o = i >= a, !o) return r;
    if (r === zo()) break;
    r = Dl(r, !1);
  }
  return !1;
}
function _d(e, t, n, r) {
  for (var i = 0, a = 0, o = e.children; a < o.length; ) {
    if (o[a].style.display !== "none" && o[a] !== Wt.ghost && (r || o[a] !== Wt.dragged) && ho(o[a], n.draggable, e, !1)) {
      if (i === t)
        return o[a];
      i++;
    }
    a++;
  }
  return null;
}
function gO(e, t) {
  for (var n = e.lastElementChild; n && (n === Wt.ghost || Vt(n, "display") === "none" || t && !__(n, t)); )
    n = n.previousElementSibling;
  return n || null;
}
function Ka(e, t) {
  var n = 0;
  if (!e || !e.parentNode)
    return -1;
  for (; e = e.previousElementSibling; )
    e.nodeName.toUpperCase() !== "TEMPLATE" && e !== Wt.clone && (!t || __(e, t)) && n++;
  return n;
}
function iP(e) {
  var t = 0, n = 0, r = zo();
  if (e)
    do {
      var i = od(e), a = i.a, o = i.d;
      t += e.scrollLeft * a, n += e.scrollTop * o;
    } while (e !== r && (e = e.parentNode));
  return [t, n];
}
function CBe(e, t) {
  for (var n in e)
    if (e.hasOwnProperty(n)) {
      for (var r in t)
        if (t.hasOwnProperty(r) && t[r] === e[n][r]) return Number(n);
    }
  return -1;
}
function Dl(e, t) {
  if (!e || !e.getBoundingClientRect) return zo();
  var n = e, r = !1;
  do
    if (n.clientWidth < n.scrollWidth || n.clientHeight < n.scrollHeight) {
      var i = Vt(n);
      if (n.clientWidth < n.scrollWidth && (i.overflowX == "auto" || i.overflowX == "scroll") || n.clientHeight < n.scrollHeight && (i.overflowY == "auto" || i.overflowY == "scroll")) {
        if (!n.getBoundingClientRect || n === document.body) return zo();
        if (r || t) return n;
        r = !0;
      }
    }
  while (n = n.parentNode);
  return zo();
}
function ABe(e, t) {
  if (e && t)
    for (var n in t)
      t.hasOwnProperty(n) && (e[n] = t[n]);
  return e;
}
function IT(e, t) {
  return Math.round(e.top) === Math.round(t.top) && Math.round(e.left) === Math.round(t.left) && Math.round(e.height) === Math.round(t.height) && Math.round(e.width) === Math.round(t.width);
}
var op;
function g5(e, t) {
  return function() {
    if (!op) {
      var n = arguments, r = this;
      n.length === 1 ? e.call(r, n[0]) : e.apply(r, n), op = setTimeout(function() {
        op = void 0;
      }, t);
    }
  };
}
function OBe() {
  clearTimeout(op), op = void 0;
}
function _5(e, t, n) {
  e.scrollLeft += t, e.scrollTop += n;
}
function v5(e) {
  var t = window.Polymer, n = window.jQuery || window.Zepto;
  return t && t.dom ? t.dom(e).cloneNode(!0) : n ? n(e).clone(!0)[0] : e.cloneNode(!0);
}
function b5(e, t, n) {
  var r = {};
  return Array.from(e.children).forEach(function(i) {
    var a, o, s, l;
    if (!(!ho(i, t.draggable, e, !1) || i.animated || i === n)) {
      var u = zr(i);
      r.left = Math.min((a = r.left) !== null && a !== void 0 ? a : 1 / 0, u.left), r.top = Math.min((o = r.top) !== null && o !== void 0 ? o : 1 / 0, u.top), r.right = Math.max((s = r.right) !== null && s !== void 0 ? s : -1 / 0, u.right), r.bottom = Math.max((l = r.bottom) !== null && l !== void 0 ? l : -1 / 0, u.bottom);
    }
  }), r.width = r.right - r.left, r.height = r.bottom - r.top, r.x = r.left, r.y = r.top, r;
}
var Ra = "Sortable" + (/* @__PURE__ */ new Date()).getTime();
function RBe() {
  var e = [], t;
  return {
    captureAnimationState: function() {
      if (e = [], !!this.options.animation) {
        var r = [].slice.call(this.el.children);
        r.forEach(function(i) {
          if (!(Vt(i, "display") === "none" || i === Wt.ghost)) {
            e.push({
              target: i,
              rect: zr(i)
            });
            var a = Xo({}, e[e.length - 1].rect);
            if (i.thisAnimationDuration) {
              var o = od(i, !0);
              o && (a.top -= o.f, a.left -= o.e);
            }
            i.fromRect = a;
          }
        });
      }
    },
    addAnimationState: function(r) {
      e.push(r);
    },
    removeAnimationState: function(r) {
      e.splice(CBe(e, {
        target: r
      }), 1);
    },
    animateAll: function(r) {
      var i = this;
      if (!this.options.animation) {
        clearTimeout(t), typeof r == "function" && r();
        return;
      }
      var a = !1, o = 0;
      e.forEach(function(s) {
        var l = 0, u = s.target, c = u.fromRect, d = zr(u), f = u.prevFromRect, h = u.prevToRect, m = s.rect, v = od(u, !0);
        v && (d.top -= v.f, d.left -= v.e), u.toRect = d, u.thisAnimationDuration && IT(f, d) && !IT(c, d) && // Make sure animatingRect is on line between toRect & fromRect
        (m.top - d.top) / (m.left - d.left) === (c.top - d.top) / (c.left - d.left) && (l = xBe(m, f, h, i.options)), IT(d, c) || (u.prevFromRect = c, u.prevToRect = d, l || (l = i.options.animation), i.animate(u, m, d, l)), l && (a = !0, o = Math.max(o, l), clearTimeout(u.animationResetTimer), u.animationResetTimer = setTimeout(function() {
          u.animationTime = 0, u.prevFromRect = null, u.fromRect = null, u.prevToRect = null, u.thisAnimationDuration = null;
        }, l), u.thisAnimationDuration = l);
      }), clearTimeout(t), a ? t = setTimeout(function() {
        typeof r == "function" && r();
      }, o) : typeof r == "function" && r(), e = [];
    },
    animate: function(r, i, a, o) {
      if (o) {
        Vt(r, "transition", ""), Vt(r, "transform", "");
        var s = od(this.el), l = s && s.a, u = s && s.d, c = (i.left - a.left) / (l || 1), d = (i.top - a.top) / (u || 1);
        r.animatingX = !!c, r.animatingY = !!d, Vt(r, "transform", "translate3d(" + c + "px," + d + "px,0)"), this.forRepaintDummy = wBe(r), Vt(r, "transition", "transform " + o + "ms" + (this.options.easing ? " " + this.options.easing : "")), Vt(r, "transform", "translate3d(0,0,0)"), typeof r.animated == "number" && clearTimeout(r.animated), r.animated = setTimeout(function() {
          Vt(r, "transition", ""), Vt(r, "transform", ""), r.animated = !1, r.animatingX = !1, r.animatingY = !1;
        }, o);
      }
    }
  };
}
function wBe(e) {
  return e.offsetWidth;
}
function xBe(e, t, n, r) {
  return Math.sqrt(Math.pow(t.top - e.top, 2) + Math.pow(t.left - e.left, 2)) / Math.sqrt(Math.pow(t.top - n.top, 2) + Math.pow(t.left - n.left, 2)) * r.animation;
}
var Dc = [], LT = {
  initializeByDefault: !0
}, Mm = {
  mount: function(t) {
    for (var n in LT)
      LT.hasOwnProperty(n) && !(n in t) && (t[n] = LT[n]);
    Dc.forEach(function(r) {
      if (r.pluginName === t.pluginName)
        throw "Sortable: Cannot mount plugin ".concat(t.pluginName, " more than once");
    }), Dc.push(t);
  },
  pluginEvent: function(t, n, r) {
    var i = this;
    this.eventCanceled = !1, r.cancel = function() {
      i.eventCanceled = !0;
    };
    var a = t + "Global";
    Dc.forEach(function(o) {
      n[o.pluginName] && (n[o.pluginName][a] && n[o.pluginName][a](Xo({
        sortable: n
      }, r)), n.options[o.pluginName] && n[o.pluginName][t] && n[o.pluginName][t](Xo({
        sortable: n
      }, r)));
    });
  },
  initializePlugins: function(t, n, r, i) {
    Dc.forEach(function(s) {
      var l = s.pluginName;
      if (!(!t.options[l] && !s.initializeByDefault)) {
        var u = new s(t, n, t.options);
        u.sortable = t, u.options = t.options, t[l] = u, Gs(r, u.defaults);
      }
    });
    for (var a in t.options)
      if (t.options.hasOwnProperty(a)) {
        var o = this.modifyOption(t, a, t.options[a]);
        typeof o < "u" && (t.options[a] = o);
      }
  },
  getEventProperties: function(t, n) {
    var r = {};
    return Dc.forEach(function(i) {
      typeof i.eventProperties == "function" && Gs(r, i.eventProperties.call(n[i.pluginName], t));
    }), r;
  },
  modifyOption: function(t, n, r) {
    var i;
    return Dc.forEach(function(a) {
      t[a.pluginName] && a.optionListeners && typeof a.optionListeners[n] == "function" && (i = a.optionListeners[n].call(t[a.pluginName], r));
    }), i;
  }
};
function NBe(e) {
  var t = e.sortable, n = e.rootEl, r = e.name, i = e.targetEl, a = e.cloneEl, o = e.toEl, s = e.fromEl, l = e.oldIndex, u = e.newIndex, c = e.oldDraggableIndex, d = e.newDraggableIndex, f = e.originalEvent, h = e.putSortable, m = e.extraEventProperties;
  if (t = t || n && n[Ra], !!t) {
    var v, b = t.options, y = "on" + r.charAt(0).toUpperCase() + r.substr(1);
    window.CustomEvent && !Xs && !km ? v = new CustomEvent(r, {
      bubbles: !0,
      cancelable: !0
    }) : (v = document.createEvent("Event"), v.initEvent(r, !0, !0)), v.to = o || n, v.from = s || n, v.item = i || n, v.clone = a, v.oldIndex = l, v.newIndex = u, v.oldDraggableIndex = c, v.newDraggableIndex = d, v.originalEvent = f, v.pullMode = h ? h.lastPutMode : void 0;
    var g = Xo(Xo({}, m), Mm.getEventProperties(r, t));
    for (var E in g)
      v[E] = g[E];
    n && n.dispatchEvent(v), b[y] && b[y].call(t, v);
  }
}
var DBe = ["evt"], na = function(t, n) {
  var r = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : {}, i = r.evt, a = SBe(r, DBe);
  Mm.pluginEvent.bind(Wt)(t, n, Xo({
    dragEl: rt,
    parentEl: Ir,
    ghostEl: nn,
    rootEl: yr,
    nextEl: Ou,
    lastDownEl: Cg,
    cloneEl: Rr,
    cloneHidden: Ol,
    dragStarted: Yf,
    putSortable: _i,
    activeSortable: Wt.active,
    originalEvent: i,
    oldIndex: Wc,
    oldDraggableIndex: sp,
    newIndex: Aa,
    newDraggableIndex: Tl,
    hideGhostForTarget: T5,
    unhideGhostForTarget: C5,
    cloneNowHidden: function() {
      Ol = !0;
    },
    cloneNowShown: function() {
      Ol = !1;
    },
    dispatchSortableEvent: function(s) {
      Gi({
        sortable: n,
        name: s,
        originalEvent: i
      });
    }
  }, a));
};
function Gi(e) {
  NBe(Xo({
    putSortable: _i,
    cloneEl: Rr,
    targetEl: rt,
    rootEl: yr,
    oldIndex: Wc,
    oldDraggableIndex: sp,
    newIndex: Aa,
    newDraggableIndex: Tl
  }, e));
}
var rt, Ir, nn, yr, Ou, Cg, Rr, Ol, Wc, Aa, sp, Tl, Zh, _i, Uc = !1, v_ = !1, b_ = [], Su, co, kT, MT, aP, oP, Yf, Ic, lp, up = !1, Jh = !1, Ag, Oi, PT = [], VC = !1, E_ = [], zv = typeof document < "u", eg = f5, sP = km || Xs ? "cssFloat" : "float", IBe = zv && !p5 && !f5 && "draggable" in document.createElement("div"), E5 = function() {
  if (zv) {
    if (Xs)
      return !1;
    var e = document.createElement("x");
    return e.style.cssText = "pointer-events:auto", e.style.pointerEvents === "auto";
  }
}(), S5 = function(t, n) {
  var r = Vt(t), i = parseInt(r.width) - parseInt(r.paddingLeft) - parseInt(r.paddingRight) - parseInt(r.borderLeftWidth) - parseInt(r.borderRightWidth), a = _d(t, 0, n), o = _d(t, 1, n), s = a && Vt(a), l = o && Vt(o), u = s && parseInt(s.marginLeft) + parseInt(s.marginRight) + zr(a).width, c = l && parseInt(l.marginLeft) + parseInt(l.marginRight) + zr(o).width;
  if (r.display === "flex")
    return r.flexDirection === "column" || r.flexDirection === "column-reverse" ? "vertical" : "horizontal";
  if (r.display === "grid")
    return r.gridTemplateColumns.split(" ").length <= 1 ? "vertical" : "horizontal";
  if (a && s.float && s.float !== "none") {
    var d = s.float === "left" ? "left" : "right";
    return o && (l.clear === "both" || l.clear === d) ? "vertical" : "horizontal";
  }
  return a && (s.display === "block" || s.display === "flex" || s.display === "table" || s.display === "grid" || u >= i && r[sP] === "none" || o && r[sP] === "none" && u + c > i) ? "vertical" : "horizontal";
}, LBe = function(t, n, r) {
  var i = r ? t.left : t.top, a = r ? t.right : t.bottom, o = r ? t.width : t.height, s = r ? n.left : n.top, l = r ? n.right : n.bottom, u = r ? n.width : n.height;
  return i === s || a === l || i + o / 2 === s + u / 2;
}, kBe = function(t, n) {
  var r;
  return b_.some(function(i) {
    var a = i[Ra].options.emptyInsertThreshold;
    if (!(!a || gO(i))) {
      var o = zr(i), s = t >= o.left - a && t <= o.right + a, l = n >= o.top - a && n <= o.bottom + a;
      if (s && l)
        return r = i;
    }
  }), r;
}, y5 = function(t) {
  function n(a, o) {
    return function(s, l, u, c) {
      var d = s.options.group.name && l.options.group.name && s.options.group.name === l.options.group.name;
      if (a == null && (o || d))
        return !0;
      if (a == null || a === !1)
        return !1;
      if (o && a === "clone")
        return a;
      if (typeof a == "function")
        return n(a(s, l, u, c), o)(s, l, u, c);
      var f = (o ? s : l).options.group.name;
      return a === !0 || typeof a == "string" && a === f || a.join && a.indexOf(f) > -1;
    };
  }
  var r = {}, i = t.group;
  (!i || Tg(i) != "object") && (i = {
    name: i
  }), r.name = i.name, r.checkPull = n(i.pull, !0), r.checkPut = n(i.put), r.revertClone = i.revertClone, t.group = r;
}, T5 = function() {
  !E5 && nn && Vt(nn, "display", "none");
}, C5 = function() {
  !E5 && nn && Vt(nn, "display", "");
};
zv && !p5 && document.addEventListener("click", function(e) {
  if (v_)
    return e.preventDefault(), e.stopPropagation && e.stopPropagation(), e.stopImmediatePropagation && e.stopImmediatePropagation(), v_ = !1, !1;
}, !0);
var yu = function(t) {
  if (rt) {
    t = t.touches ? t.touches[0] : t;
    var n = kBe(t.clientX, t.clientY);
    if (n) {
      var r = {};
      for (var i in t)
        t.hasOwnProperty(i) && (r[i] = t[i]);
      r.target = r.rootEl = n, r.preventDefault = void 0, r.stopPropagation = void 0, n[Ra]._onDragOver(r);
    }
  }
}, MBe = function(t) {
  rt && rt.parentNode[Ra]._isOutsideThisEl(t.target);
};
function Wt(e, t) {
  if (!(e && e.nodeType && e.nodeType === 1))
    throw "Sortable: `el` must be an HTMLElement, not ".concat({}.toString.call(e));
  this.el = e, this.options = t = Gs({}, t), e[Ra] = this;
  var n = {
    group: null,
    sort: !0,
    disabled: !1,
    store: null,
    handle: null,
    draggable: /^[uo]l$/i.test(e.nodeName) ? ">li" : ">*",
    swapThreshold: 1,
    // percentage; 0 <= x <= 1
    invertSwap: !1,
    // invert always
    invertedSwapThreshold: null,
    // will be set to same as swapThreshold if default
    removeCloneOnHide: !0,
    direction: function() {
      return S5(e, this.options);
    },
    ghostClass: "sortable-ghost",
    chosenClass: "sortable-chosen",
    dragClass: "sortable-drag",
    ignore: "a, img",
    filter: null,
    preventOnFilter: !0,
    animation: 0,
    easing: null,
    setData: function(o, s) {
      o.setData("Text", s.textContent);
    },
    dropBubble: !1,
    dragoverBubble: !1,
    dataIdAttr: "data-id",
    delay: 0,
    delayOnTouchOnly: !1,
    touchStartThreshold: (Number.parseInt ? Number : window).parseInt(window.devicePixelRatio, 10) || 1,
    forceFallback: !1,
    fallbackClass: "sortable-fallback",
    fallbackOnBody: !1,
    fallbackTolerance: 0,
    fallbackOffset: {
      x: 0,
      y: 0
    },
    supportPointer: Wt.supportPointer !== !1 && "PointerEvent" in window && !ap,
    emptyInsertThreshold: 5
  };
  Mm.initializePlugins(this, e, n);
  for (var r in n)
    !(r in t) && (t[r] = n[r]);
  y5(t);
  for (var i in this)
    i.charAt(0) === "_" && typeof this[i] == "function" && (this[i] = this[i].bind(this));
  this.nativeDraggable = t.forceFallback ? !1 : IBe, this.nativeDraggable && (this.options.touchStartThreshold = 1), t.supportPointer ? $n(e, "pointerdown", this._onTapStart) : ($n(e, "mousedown", this._onTapStart), $n(e, "touchstart", this._onTapStart)), this.nativeDraggable && ($n(e, "dragover", this), $n(e, "dragenter", this)), b_.push(this.el), t.store && t.store.get && this.sort(t.store.get(this) || []), Gs(this, RBe());
}
Wt.prototype = /** @lends Sortable.prototype */
{
  constructor: Wt,
  _isOutsideThisEl: function(t) {
    !this.el.contains(t) && t !== this.el && (Ic = null);
  },
  _getDirection: function(t, n) {
    return typeof this.options.direction == "function" ? this.options.direction.call(this, t, n, rt) : this.options.direction;
  },
  _onTapStart: function(t) {
    if (t.cancelable) {
      var n = this, r = this.el, i = this.options, a = i.preventOnFilter, o = t.type, s = t.touches && t.touches[0] || t.pointerType && t.pointerType === "touch" && t, l = (s || t).target, u = t.target.shadowRoot && (t.path && t.path[0] || t.composedPath && t.composedPath()[0]) || l, c = i.filter;
      if (YBe(r), !rt && !(/mousedown|pointerdown/.test(o) && t.button !== 0 || i.disabled) && !u.isContentEditable && !(!this.nativeDraggable && ap && l && l.tagName.toUpperCase() === "SELECT") && (l = ho(l, i.draggable, r, !1), !(l && l.animated) && Cg !== l)) {
        if (Wc = Ka(l), sp = Ka(l, i.draggable), typeof c == "function") {
          if (c.call(this, t, l, this)) {
            Gi({
              sortable: n,
              rootEl: u,
              name: "filter",
              targetEl: l,
              toEl: r,
              fromEl: r
            }), na("filter", n, {
              evt: t
            }), a && t.cancelable && t.preventDefault();
            return;
          }
        } else if (c && (c = c.split(",").some(function(d) {
          if (d = ho(u, d.trim(), r, !1), d)
            return Gi({
              sortable: n,
              rootEl: d,
              name: "filter",
              targetEl: l,
              fromEl: r,
              toEl: r
            }), na("filter", n, {
              evt: t
            }), !0;
        }), c)) {
          a && t.cancelable && t.preventDefault();
          return;
        }
        i.handle && !ho(u, i.handle, r, !1) || this._prepareDragStart(t, s, l);
      }
    }
  },
  _prepareDragStart: function(t, n, r) {
    var i = this, a = i.el, o = i.options, s = a.ownerDocument, l;
    if (r && !rt && r.parentNode === a) {
      var u = zr(r);
      if (yr = a, rt = r, Ir = rt.parentNode, Ou = rt.nextSibling, Cg = r, Zh = o.group, Wt.dragged = rt, Su = {
        target: rt,
        clientX: (n || t).clientX,
        clientY: (n || t).clientY
      }, aP = Su.clientX - u.left, oP = Su.clientY - u.top, this._lastX = (n || t).clientX, this._lastY = (n || t).clientY, rt.style["will-change"] = "all", l = function() {
        if (na("delayEnded", i, {
          evt: t
        }), Wt.eventCanceled) {
          i._onDrop();
          return;
        }
        i._disableDelayedDragEvents(), !tP && i.nativeDraggable && (rt.draggable = !0), i._triggerDragStart(t, n), Gi({
          sortable: i,
          name: "choose",
          originalEvent: t
        }), Ca(rt, o.chosenClass, !0);
      }, o.ignore.split(",").forEach(function(c) {
        h5(rt, c.trim(), FT);
      }), $n(s, "dragover", yu), $n(s, "mousemove", yu), $n(s, "touchmove", yu), $n(s, "mouseup", i._onDrop), $n(s, "touchend", i._onDrop), $n(s, "touchcancel", i._onDrop), tP && this.nativeDraggable && (this.options.touchStartThreshold = 4, rt.draggable = !0), na("delayStart", this, {
        evt: t
      }), o.delay && (!o.delayOnTouchOnly || n) && (!this.nativeDraggable || !(km || Xs))) {
        if (Wt.eventCanceled) {
          this._onDrop();
          return;
        }
        $n(s, "mouseup", i._disableDelayedDrag), $n(s, "touchend", i._disableDelayedDrag), $n(s, "touchcancel", i._disableDelayedDrag), $n(s, "mousemove", i._delayedDragTouchMoveHandler), $n(s, "touchmove", i._delayedDragTouchMoveHandler), o.supportPointer && $n(s, "pointermove", i._delayedDragTouchMoveHandler), i._dragStartTimer = setTimeout(l, o.delay);
      } else
        l();
    }
  },
  _delayedDragTouchMoveHandler: function(t) {
    var n = t.touches ? t.touches[0] : t;
    Math.max(Math.abs(n.clientX - this._lastX), Math.abs(n.clientY - this._lastY)) >= Math.floor(this.options.touchStartThreshold / (this.nativeDraggable && window.devicePixelRatio || 1)) && this._disableDelayedDrag();
  },
  _disableDelayedDrag: function() {
    rt && FT(rt), clearTimeout(this._dragStartTimer), this._disableDelayedDragEvents();
  },
  _disableDelayedDragEvents: function() {
    var t = this.el.ownerDocument;
    Nn(t, "mouseup", this._disableDelayedDrag), Nn(t, "touchend", this._disableDelayedDrag), Nn(t, "touchcancel", this._disableDelayedDrag), Nn(t, "mousemove", this._delayedDragTouchMoveHandler), Nn(t, "touchmove", this._delayedDragTouchMoveHandler), Nn(t, "pointermove", this._delayedDragTouchMoveHandler);
  },
  _triggerDragStart: function(t, n) {
    n = n || t.pointerType == "touch" && t, !this.nativeDraggable || n ? this.options.supportPointer ? $n(document, "pointermove", this._onTouchMove) : n ? $n(document, "touchmove", this._onTouchMove) : $n(document, "mousemove", this._onTouchMove) : ($n(rt, "dragend", this), $n(yr, "dragstart", this._onDragStart));
    try {
      document.selection ? Og(function() {
        document.selection.empty();
      }) : window.getSelection().removeAllRanges();
    } catch {
    }
  },
  _dragStarted: function(t, n) {
    if (Uc = !1, yr && rt) {
      na("dragStarted", this, {
        evt: n
      }), this.nativeDraggable && $n(document, "dragover", MBe);
      var r = this.options;
      !t && Ca(rt, r.dragClass, !1), Ca(rt, r.ghostClass, !0), Wt.active = this, t && this._appendGhost(), Gi({
        sortable: this,
        name: "start",
        originalEvent: n
      });
    } else
      this._nulling();
  },
  _emulateDragOver: function() {
    if (co) {
      this._lastX = co.clientX, this._lastY = co.clientY, T5();
      for (var t = document.elementFromPoint(co.clientX, co.clientY), n = t; t && t.shadowRoot && (t = t.shadowRoot.elementFromPoint(co.clientX, co.clientY), t !== n); )
        n = t;
      if (rt.parentNode[Ra]._isOutsideThisEl(t), n)
        do {
          if (n[Ra]) {
            var r = void 0;
            if (r = n[Ra]._onDragOver({
              clientX: co.clientX,
              clientY: co.clientY,
              target: t,
              rootEl: n
            }), r && !this.options.dragoverBubble)
              break;
          }
          t = n;
        } while (n = n.parentNode);
      C5();
    }
  },
  _onTouchMove: function(t) {
    if (Su) {
      var n = this.options, r = n.fallbackTolerance, i = n.fallbackOffset, a = t.touches ? t.touches[0] : t, o = nn && od(nn, !0), s = nn && o && o.a, l = nn && o && o.d, u = eg && Oi && iP(Oi), c = (a.clientX - Su.clientX + i.x) / (s || 1) + (u ? u[0] - PT[0] : 0) / (s || 1), d = (a.clientY - Su.clientY + i.y) / (l || 1) + (u ? u[1] - PT[1] : 0) / (l || 1);
      if (!Wt.active && !Uc) {
        if (r && Math.max(Math.abs(a.clientX - this._lastX), Math.abs(a.clientY - this._lastY)) < r)
          return;
        this._onDragStart(t, !0);
      }
      if (nn) {
        o ? (o.e += c - (kT || 0), o.f += d - (MT || 0)) : o = {
          a: 1,
          b: 0,
          c: 0,
          d: 1,
          e: c,
          f: d
        };
        var f = "matrix(".concat(o.a, ",").concat(o.b, ",").concat(o.c, ",").concat(o.d, ",").concat(o.e, ",").concat(o.f, ")");
        Vt(nn, "webkitTransform", f), Vt(nn, "mozTransform", f), Vt(nn, "msTransform", f), Vt(nn, "transform", f), kT = c, MT = d, co = a;
      }
      t.cancelable && t.preventDefault();
    }
  },
  _appendGhost: function() {
    if (!nn) {
      var t = this.options.fallbackOnBody ? document.body : yr, n = zr(rt, !0, eg, !0, t), r = this.options;
      if (eg) {
        for (Oi = t; Vt(Oi, "position") === "static" && Vt(Oi, "transform") === "none" && Oi !== document; )
          Oi = Oi.parentNode;
        Oi !== document.body && Oi !== document.documentElement ? (Oi === document && (Oi = zo()), n.top += Oi.scrollTop, n.left += Oi.scrollLeft) : Oi = zo(), PT = iP(Oi);
      }
      nn = rt.cloneNode(!0), Ca(nn, r.ghostClass, !1), Ca(nn, r.fallbackClass, !0), Ca(nn, r.dragClass, !0), Vt(nn, "transition", ""), Vt(nn, "transform", ""), Vt(nn, "box-sizing", "border-box"), Vt(nn, "margin", 0), Vt(nn, "top", n.top), Vt(nn, "left", n.left), Vt(nn, "width", n.width), Vt(nn, "height", n.height), Vt(nn, "opacity", "0.8"), Vt(nn, "position", eg ? "absolute" : "fixed"), Vt(nn, "zIndex", "100000"), Vt(nn, "pointerEvents", "none"), Wt.ghost = nn, t.appendChild(nn), Vt(nn, "transform-origin", aP / parseInt(nn.style.width) * 100 + "% " + oP / parseInt(nn.style.height) * 100 + "%");
    }
  },
  _onDragStart: function(t, n) {
    var r = this, i = t.dataTransfer, a = r.options;
    if (na("dragStart", this, {
      evt: t
    }), Wt.eventCanceled) {
      this._onDrop();
      return;
    }
    na("setupClone", this), Wt.eventCanceled || (Rr = v5(rt), Rr.removeAttribute("id"), Rr.draggable = !1, Rr.style["will-change"] = "", this._hideClone(), Ca(Rr, this.options.chosenClass, !1), Wt.clone = Rr), r.cloneId = Og(function() {
      na("clone", r), !Wt.eventCanceled && (r.options.removeCloneOnHide || yr.insertBefore(Rr, rt), r._hideClone(), Gi({
        sortable: r,
        name: "clone"
      }));
    }), !n && Ca(rt, a.dragClass, !0), n ? (v_ = !0, r._loopId = setInterval(r._emulateDragOver, 50)) : (Nn(document, "mouseup", r._onDrop), Nn(document, "touchend", r._onDrop), Nn(document, "touchcancel", r._onDrop), i && (i.effectAllowed = "move", a.setData && a.setData.call(r, i, rt)), $n(document, "drop", r), Vt(rt, "transform", "translateZ(0)")), Uc = !0, r._dragStartId = Og(r._dragStarted.bind(r, n, t)), $n(document, "selectstart", r), Yf = !0, ap && Vt(document.body, "user-select", "none");
  },
  // Returns true - if no further action is needed (either inserted or another condition)
  _onDragOver: function(t) {
    var n = this.el, r = t.target, i, a, o, s = this.options, l = s.group, u = Wt.active, c = Zh === l, d = s.sort, f = _i || u, h, m = this, v = !1;
    if (VC) return;
    function b(B, W) {
      na(B, m, Xo({
        evt: t,
        isOwner: c,
        axis: h ? "vertical" : "horizontal",
        revert: o,
        dragRect: i,
        targetRect: a,
        canSort: d,
        fromSortable: f,
        target: r,
        completed: g,
        onMove: function(V, K) {
          return tg(yr, n, rt, i, V, zr(V), t, K);
        },
        changed: E
      }, W));
    }
    function y() {
      b("dragOverAnimationCapture"), m.captureAnimationState(), m !== f && f.captureAnimationState();
    }
    function g(B) {
      return b("dragOverCompleted", {
        insertion: B
      }), B && (c ? u._hideClone() : u._showClone(m), m !== f && (Ca(rt, _i ? _i.options.ghostClass : u.options.ghostClass, !1), Ca(rt, s.ghostClass, !0)), _i !== m && m !== Wt.active ? _i = m : m === Wt.active && _i && (_i = null), f === m && (m._ignoreWhileAnimating = r), m.animateAll(function() {
        b("dragOverAnimationComplete"), m._ignoreWhileAnimating = null;
      }), m !== f && (f.animateAll(), f._ignoreWhileAnimating = null)), (r === rt && !rt.animated || r === n && !r.animated) && (Ic = null), !s.dragoverBubble && !t.rootEl && r !== document && (rt.parentNode[Ra]._isOutsideThisEl(t.target), !B && yu(t)), !s.dragoverBubble && t.stopPropagation && t.stopPropagation(), v = !0;
    }
    function E() {
      Aa = Ka(rt), Tl = Ka(rt, s.draggable), Gi({
        sortable: m,
        name: "change",
        toEl: n,
        newIndex: Aa,
        newDraggableIndex: Tl,
        originalEvent: t
      });
    }
    if (t.preventDefault !== void 0 && t.cancelable && t.preventDefault(), r = ho(r, s.draggable, n, !0), b("dragOver"), Wt.eventCanceled) return v;
    if (rt.contains(t.target) || r.animated && r.animatingX && r.animatingY || m._ignoreWhileAnimating === r)
      return g(!1);
    if (v_ = !1, u && !s.disabled && (c ? d || (o = Ir !== yr) : _i === this || (this.lastPutMode = Zh.checkPull(this, u, rt, t)) && l.checkPut(this, u, rt, t))) {
      if (h = this._getDirection(t, r) === "vertical", i = zr(rt), b("dragOverValid"), Wt.eventCanceled) return v;
      if (o)
        return Ir = yr, y(), this._hideClone(), b("revert"), Wt.eventCanceled || (Ou ? yr.insertBefore(rt, Ou) : yr.appendChild(rt)), g(!0);
      var S = gO(n, s.draggable);
      if (!S || $Be(t, h, this) && !S.animated) {
        if (S === rt)
          return g(!1);
        if (S && n === t.target && (r = S), r && (a = zr(r)), tg(yr, n, rt, i, r, a, t, !!r) !== !1)
          return y(), S && S.nextSibling ? n.insertBefore(rt, S.nextSibling) : n.appendChild(rt), Ir = n, E(), g(!0);
      } else if (S && BBe(t, h, this)) {
        var C = _d(n, 0, s, !0);
        if (C === rt)
          return g(!1);
        if (r = C, a = zr(r), tg(yr, n, rt, i, r, a, t, !1) !== !1)
          return y(), n.insertBefore(rt, C), Ir = n, E(), g(!0);
      } else if (r.parentNode === n) {
        a = zr(r);
        var T = 0, O, R = rt.parentNode !== n, D = !LBe(rt.animated && rt.toRect || i, r.animated && r.toRect || a, h), q = h ? "top" : "left", $ = rP(r, "top", "top") || rP(rt, "top", "top"), P = $ ? $.scrollTop : void 0;
        Ic !== r && (O = a[q], up = !1, Jh = !D && s.invertSwap || R), T = UBe(t, r, a, h, D ? 1 : s.swapThreshold, s.invertedSwapThreshold == null ? s.swapThreshold : s.invertedSwapThreshold, Jh, Ic === r);
        var Y;
        if (T !== 0) {
          var L = Ka(rt);
          do
            L -= T, Y = Ir.children[L];
          while (Y && (Vt(Y, "display") === "none" || Y === nn));
        }
        if (T === 0 || Y === r)
          return g(!1);
        Ic = r, lp = T;
        var x = r.nextElementSibling, I = !1;
        I = T === 1;
        var k = tg(yr, n, rt, i, r, a, t, I);
        if (k !== !1)
          return (k === 1 || k === -1) && (I = k === 1), VC = !0, setTimeout(FBe, 30), y(), I && !x ? n.appendChild(rt) : r.parentNode.insertBefore(rt, I ? x : r), $ && _5($, 0, P - $.scrollTop), Ir = rt.parentNode, O !== void 0 && !Jh && (Ag = Math.abs(O - zr(r)[q])), E(), g(!0);
      }
      if (n.contains(rt))
        return g(!1);
    }
    return !1;
  },
  _ignoreWhileAnimating: null,
  _offMoveEvents: function() {
    Nn(document, "mousemove", this._onTouchMove), Nn(document, "touchmove", this._onTouchMove), Nn(document, "pointermove", this._onTouchMove), Nn(document, "dragover", yu), Nn(document, "mousemove", yu), Nn(document, "touchmove", yu);
  },
  _offUpEvents: function() {
    var t = this.el.ownerDocument;
    Nn(t, "mouseup", this._onDrop), Nn(t, "touchend", this._onDrop), Nn(t, "pointerup", this._onDrop), Nn(t, "touchcancel", this._onDrop), Nn(document, "selectstart", this);
  },
  _onDrop: function(t) {
    var n = this.el, r = this.options;
    if (Aa = Ka(rt), Tl = Ka(rt, r.draggable), na("drop", this, {
      evt: t
    }), Ir = rt && rt.parentNode, Aa = Ka(rt), Tl = Ka(rt, r.draggable), Wt.eventCanceled) {
      this._nulling();
      return;
    }
    Uc = !1, Jh = !1, up = !1, clearInterval(this._loopId), clearTimeout(this._dragStartTimer), WC(this.cloneId), WC(this._dragStartId), this.nativeDraggable && (Nn(document, "drop", this), Nn(n, "dragstart", this._onDragStart)), this._offMoveEvents(), this._offUpEvents(), ap && Vt(document.body, "user-select", ""), Vt(rt, "transform", ""), t && (Yf && (t.cancelable && t.preventDefault(), !r.dropBubble && t.stopPropagation()), nn && nn.parentNode && nn.parentNode.removeChild(nn), (yr === Ir || _i && _i.lastPutMode !== "clone") && Rr && Rr.parentNode && Rr.parentNode.removeChild(Rr), rt && (this.nativeDraggable && Nn(rt, "dragend", this), FT(rt), rt.style["will-change"] = "", Yf && !Uc && Ca(rt, _i ? _i.options.ghostClass : this.options.ghostClass, !1), Ca(rt, this.options.chosenClass, !1), Gi({
      sortable: this,
      name: "unchoose",
      toEl: Ir,
      newIndex: null,
      newDraggableIndex: null,
      originalEvent: t
    }), yr !== Ir ? (Aa >= 0 && (Gi({
      rootEl: Ir,
      name: "add",
      toEl: Ir,
      fromEl: yr,
      originalEvent: t
    }), Gi({
      sortable: this,
      name: "remove",
      toEl: Ir,
      originalEvent: t
    }), Gi({
      rootEl: Ir,
      name: "sort",
      toEl: Ir,
      fromEl: yr,
      originalEvent: t
    }), Gi({
      sortable: this,
      name: "sort",
      toEl: Ir,
      originalEvent: t
    })), _i && _i.save()) : Aa !== Wc && Aa >= 0 && (Gi({
      sortable: this,
      name: "update",
      toEl: Ir,
      originalEvent: t
    }), Gi({
      sortable: this,
      name: "sort",
      toEl: Ir,
      originalEvent: t
    })), Wt.active && ((Aa == null || Aa === -1) && (Aa = Wc, Tl = sp), Gi({
      sortable: this,
      name: "end",
      toEl: Ir,
      originalEvent: t
    }), this.save()))), this._nulling();
  },
  _nulling: function() {
    na("nulling", this), yr = rt = Ir = nn = Ou = Rr = Cg = Ol = Su = co = Yf = Aa = Tl = Wc = sp = Ic = lp = _i = Zh = Wt.dragged = Wt.ghost = Wt.clone = Wt.active = null, E_.forEach(function(t) {
      t.checked = !0;
    }), E_.length = kT = MT = 0;
  },
  handleEvent: function(t) {
    switch (t.type) {
      case "drop":
      case "dragend":
        this._onDrop(t);
        break;
      case "dragenter":
      case "dragover":
        rt && (this._onDragOver(t), PBe(t));
        break;
      case "selectstart":
        t.preventDefault();
        break;
    }
  },
  /**
   * Serializes the item into an array of string.
   * @returns {String[]}
   */
  toArray: function() {
    for (var t = [], n, r = this.el.children, i = 0, a = r.length, o = this.options; i < a; i++)
      n = r[i], ho(n, o.draggable, this.el, !1) && t.push(n.getAttribute(o.dataIdAttr) || GBe(n));
    return t;
  },
  /**
   * Sorts the elements according to the array.
   * @param  {String[]}  order  order of the items
   */
  sort: function(t, n) {
    var r = {}, i = this.el;
    this.toArray().forEach(function(a, o) {
      var s = i.children[o];
      ho(s, this.options.draggable, i, !1) && (r[a] = s);
    }, this), n && this.captureAnimationState(), t.forEach(function(a) {
      r[a] && (i.removeChild(r[a]), i.appendChild(r[a]));
    }), n && this.animateAll();
  },
  /**
   * Save the current sorting
   */
  save: function() {
    var t = this.options.store;
    t && t.set && t.set(this);
  },
  /**
   * For each element in the set, get the first element that matches the selector by testing the element itself and traversing up through its ancestors in the DOM tree.
   * @param   {HTMLElement}  el
   * @param   {String}       [selector]  default: `options.draggable`
   * @returns {HTMLElement|null}
   */
  closest: function(t, n) {
    return ho(t, n || this.options.draggable, this.el, !1);
  },
  /**
   * Set/get option
   * @param   {string} name
   * @param   {*}      [value]
   * @returns {*}
   */
  option: function(t, n) {
    var r = this.options;
    if (n === void 0)
      return r[t];
    var i = Mm.modifyOption(this, t, n);
    typeof i < "u" ? r[t] = i : r[t] = n, t === "group" && y5(r);
  },
  /**
   * Destroy
   */
  destroy: function() {
    na("destroy", this);
    var t = this.el;
    t[Ra] = null, Nn(t, "mousedown", this._onTapStart), Nn(t, "touchstart", this._onTapStart), Nn(t, "pointerdown", this._onTapStart), this.nativeDraggable && (Nn(t, "dragover", this), Nn(t, "dragenter", this)), Array.prototype.forEach.call(t.querySelectorAll("[draggable]"), function(n) {
      n.removeAttribute("draggable");
    }), this._onDrop(), this._disableDelayedDragEvents(), b_.splice(b_.indexOf(this.el), 1), this.el = t = null;
  },
  _hideClone: function() {
    if (!Ol) {
      if (na("hideClone", this), Wt.eventCanceled) return;
      Vt(Rr, "display", "none"), this.options.removeCloneOnHide && Rr.parentNode && Rr.parentNode.removeChild(Rr), Ol = !0;
    }
  },
  _showClone: function(t) {
    if (t.lastPutMode !== "clone") {
      this._hideClone();
      return;
    }
    if (Ol) {
      if (na("showClone", this), Wt.eventCanceled) return;
      rt.parentNode == yr && !this.options.group.revertClone ? yr.insertBefore(Rr, rt) : Ou ? yr.insertBefore(Rr, Ou) : yr.appendChild(Rr), this.options.group.revertClone && this.animate(rt, Rr), Vt(Rr, "display", ""), Ol = !1;
    }
  }
};
function PBe(e) {
  e.dataTransfer && (e.dataTransfer.dropEffect = "move"), e.cancelable && e.preventDefault();
}
function tg(e, t, n, r, i, a, o, s) {
  var l, u = e[Ra], c = u.options.onMove, d;
  return window.CustomEvent && !Xs && !km ? l = new CustomEvent("move", {
    bubbles: !0,
    cancelable: !0
  }) : (l = document.createEvent("Event"), l.initEvent("move", !0, !0)), l.to = t, l.from = e, l.dragged = n, l.draggedRect = r, l.related = i || t, l.relatedRect = a || zr(t), l.willInsertAfter = s, l.originalEvent = o, e.dispatchEvent(l), c && (d = c.call(u, l, o)), d;
}
function FT(e) {
  e.draggable = !1;
}
function FBe() {
  VC = !1;
}
function BBe(e, t, n) {
  var r = zr(_d(n.el, 0, n.options, !0)), i = b5(n.el, n.options, nn), a = 10;
  return t ? e.clientX < i.left - a || e.clientY < r.top && e.clientX < r.right : e.clientY < i.top - a || e.clientY < r.bottom && e.clientX < r.left;
}
function $Be(e, t, n) {
  var r = zr(gO(n.el, n.options.draggable)), i = b5(n.el, n.options, nn), a = 10;
  return t ? e.clientX > i.right + a || e.clientY > r.bottom && e.clientX > r.left : e.clientY > i.bottom + a || e.clientX > r.right && e.clientY > r.top;
}
function UBe(e, t, n, r, i, a, o, s) {
  var l = r ? e.clientY : e.clientX, u = r ? n.height : n.width, c = r ? n.top : n.left, d = r ? n.bottom : n.right, f = !1;
  if (!o) {
    if (s && Ag < u * i) {
      if (!up && (lp === 1 ? l > c + u * a / 2 : l < d - u * a / 2) && (up = !0), up)
        f = !0;
      else if (lp === 1 ? l < c + Ag : l > d - Ag)
        return -lp;
    } else if (l > c + u * (1 - i) / 2 && l < d - u * (1 - i) / 2)
      return qBe(t);
  }
  return f = f || o, f && (l < c + u * a / 2 || l > d - u * a / 2) ? l > c + u / 2 ? 1 : -1 : 0;
}
function qBe(e) {
  return Ka(rt) < Ka(e) ? 1 : -1;
}
function GBe(e) {
  for (var t = e.tagName + e.className + e.src + e.href + e.textContent, n = t.length, r = 0; n--; )
    r += t.charCodeAt(n);
  return r.toString(36);
}
function YBe(e) {
  E_.length = 0;
  for (var t = e.getElementsByTagName("input"), n = t.length; n--; ) {
    var r = t[n];
    r.checked && E_.push(r);
  }
}
function Og(e) {
  return setTimeout(e, 0);
}
function WC(e) {
  return clearTimeout(e);
}
zv && $n(document, "touchmove", function(e) {
  (Wt.active || Uc) && e.cancelable && e.preventDefault();
});
Wt.utils = {
  on: $n,
  off: Nn,
  css: Vt,
  find: h5,
  is: function(t, n) {
    return !!ho(t, n, t, !1);
  },
  extend: ABe,
  throttle: g5,
  closest: ho,
  toggleClass: Ca,
  clone: v5,
  index: Ka,
  nextTick: Og,
  cancelNextTick: WC,
  detectDirection: S5,
  getChild: _d
};
Wt.get = function(e) {
  return e[Ra];
};
Wt.mount = function() {
  for (var e = arguments.length, t = new Array(e), n = 0; n < e; n++)
    t[n] = arguments[n];
  t[0].constructor === Array && (t = t[0]), t.forEach(function(r) {
    if (!r.prototype || !r.prototype.constructor)
      throw "Sortable: Mounted plugin must be a constructor function, not ".concat({}.toString.call(r));
    r.utils && (Wt.utils = Xo(Xo({}, Wt.utils), r.utils)), Mm.mount(r);
  });
};
Wt.create = function(e, t) {
  return new Wt(e, t);
};
Wt.version = yBe;
var Hr = [], Hf, KC, jC = !1, BT, $T, S_, zf;
function HBe() {
  function e() {
    this.defaults = {
      scroll: !0,
      forceAutoScrollFallback: !1,
      scrollSensitivity: 30,
      scrollSpeed: 10,
      bubbleScroll: !0
    };
    for (var t in this)
      t.charAt(0) === "_" && typeof this[t] == "function" && (this[t] = this[t].bind(this));
  }
  return e.prototype = {
    dragStarted: function(n) {
      var r = n.originalEvent;
      this.sortable.nativeDraggable ? $n(document, "dragover", this._handleAutoScroll) : this.options.supportPointer ? $n(document, "pointermove", this._handleFallbackAutoScroll) : r.touches ? $n(document, "touchmove", this._handleFallbackAutoScroll) : $n(document, "mousemove", this._handleFallbackAutoScroll);
    },
    dragOverCompleted: function(n) {
      var r = n.originalEvent;
      !this.options.dragOverBubble && !r.rootEl && this._handleAutoScroll(r);
    },
    drop: function() {
      this.sortable.nativeDraggable ? Nn(document, "dragover", this._handleAutoScroll) : (Nn(document, "pointermove", this._handleFallbackAutoScroll), Nn(document, "touchmove", this._handleFallbackAutoScroll), Nn(document, "mousemove", this._handleFallbackAutoScroll)), lP(), Rg(), OBe();
    },
    nulling: function() {
      S_ = KC = Hf = jC = zf = BT = $T = null, Hr.length = 0;
    },
    _handleFallbackAutoScroll: function(n) {
      this._handleAutoScroll(n, !0);
    },
    _handleAutoScroll: function(n, r) {
      var i = this, a = (n.touches ? n.touches[0] : n).clientX, o = (n.touches ? n.touches[0] : n).clientY, s = document.elementFromPoint(a, o);
      if (S_ = n, r || this.options.forceAutoScrollFallback || km || Xs || ap) {
        UT(n, this.options, s, r);
        var l = Dl(s, !0);
        jC && (!zf || a !== BT || o !== $T) && (zf && lP(), zf = setInterval(function() {
          var u = Dl(document.elementFromPoint(a, o), !0);
          u !== l && (l = u, Rg()), UT(n, i.options, u, r);
        }, 10), BT = a, $T = o);
      } else {
        if (!this.options.bubbleScroll || Dl(s, !0) === zo()) {
          Rg();
          return;
        }
        UT(n, this.options, Dl(s, !1), !1);
      }
    }
  }, Gs(e, {
    pluginName: "scroll",
    initializeByDefault: !0
  });
}
function Rg() {
  Hr.forEach(function(e) {
    clearInterval(e.pid);
  }), Hr = [];
}
function lP() {
  clearInterval(zf);
}
var UT = g5(function(e, t, n, r) {
  if (t.scroll) {
    var i = (e.touches ? e.touches[0] : e).clientX, a = (e.touches ? e.touches[0] : e).clientY, o = t.scrollSensitivity, s = t.scrollSpeed, l = zo(), u = !1, c;
    KC !== n && (KC = n, Rg(), Hf = t.scroll, c = t.scrollFn, Hf === !0 && (Hf = Dl(n, !0)));
    var d = 0, f = Hf;
    do {
      var h = f, m = zr(h), v = m.top, b = m.bottom, y = m.left, g = m.right, E = m.width, S = m.height, C = void 0, T = void 0, O = h.scrollWidth, R = h.scrollHeight, D = Vt(h), q = h.scrollLeft, $ = h.scrollTop;
      h === l ? (C = E < O && (D.overflowX === "auto" || D.overflowX === "scroll" || D.overflowX === "visible"), T = S < R && (D.overflowY === "auto" || D.overflowY === "scroll" || D.overflowY === "visible")) : (C = E < O && (D.overflowX === "auto" || D.overflowX === "scroll"), T = S < R && (D.overflowY === "auto" || D.overflowY === "scroll"));
      var P = C && (Math.abs(g - i) <= o && q + E < O) - (Math.abs(y - i) <= o && !!q), Y = T && (Math.abs(b - a) <= o && $ + S < R) - (Math.abs(v - a) <= o && !!$);
      if (!Hr[d])
        for (var L = 0; L <= d; L++)
          Hr[L] || (Hr[L] = {});
      (Hr[d].vx != P || Hr[d].vy != Y || Hr[d].el !== h) && (Hr[d].el = h, Hr[d].vx = P, Hr[d].vy = Y, clearInterval(Hr[d].pid), (P != 0 || Y != 0) && (u = !0, Hr[d].pid = setInterval((function() {
        r && this.layer === 0 && Wt.active._onTouchMove(S_);
        var x = Hr[this.layer].vy ? Hr[this.layer].vy * s : 0, I = Hr[this.layer].vx ? Hr[this.layer].vx * s : 0;
        typeof c == "function" && c.call(Wt.dragged.parentNode[Ra], I, x, e, S_, Hr[this.layer].el) !== "continue" || _5(Hr[this.layer].el, I, x);
      }).bind({
        layer: d
      }), 24))), d++;
    } while (t.bubbleScroll && f !== l && (f = Dl(f, !1)));
    jC = u;
  }
}, 30), A5 = function(t) {
  var n = t.originalEvent, r = t.putSortable, i = t.dragEl, a = t.activeSortable, o = t.dispatchSortableEvent, s = t.hideGhostForTarget, l = t.unhideGhostForTarget;
  if (n) {
    var u = r || a;
    s();
    var c = n.changedTouches && n.changedTouches.length ? n.changedTouches[0] : n, d = document.elementFromPoint(c.clientX, c.clientY);
    l(), u && !u.el.contains(d) && (o("spill"), this.onSpill({
      dragEl: i,
      putSortable: r
    }));
  }
};
function _O() {
}
_O.prototype = {
  startIndex: null,
  dragStart: function(t) {
    var n = t.oldDraggableIndex;
    this.startIndex = n;
  },
  onSpill: function(t) {
    var n = t.dragEl, r = t.putSortable;
    this.sortable.captureAnimationState(), r && r.captureAnimationState();
    var i = _d(this.sortable.el, this.startIndex, this.options);
    i ? this.sortable.el.insertBefore(n, i) : this.sortable.el.appendChild(n), this.sortable.animateAll(), r && r.animateAll();
  },
  drop: A5
};
Gs(_O, {
  pluginName: "revertOnSpill"
});
function vO() {
}
vO.prototype = {
  onSpill: function(t) {
    var n = t.dragEl, r = t.putSortable, i = r || this.sortable;
    i.captureAnimationState(), n.parentNode && n.parentNode.removeChild(n), i.animateAll();
  },
  drop: A5
};
Gs(vO, {
  pluginName: "removeOnSpill"
});
Wt.mount(new HBe());
Wt.mount(vO, _O);
var O5 = function(t, n, r, i) {
  var {
    sort: a
  } = De(t), o = r.isDisabled, s = r.fire, l = r.refreshOrderStore, u = r.value, c = r.sorting, d = r.length, f = r.path, h = r.children$Array, m = he(null), v = he(null), b = N(() => a.value && !o.value), y = () => {
    v.value = new Wt(m.value, {
      handle: "[data-handle]",
      onStart: (
        /* istanbul ignore next: can not imitate dragging */
        () => {
          c.value = !0;
        }
      ),
      onEnd: E
    });
  }, g = () => {
    var S;
    (S = v.value) === null || S === void 0 || S.destroy(), v.value = null;
  }, E = (S) => {
    var {
      oldIndex: C,
      newIndex: T,
      item: O
    } = S;
    if (c.value = !1, !(C === T || o.value)) {
      m.value.children[T].remove(), m.value.insertBefore(O, m.value.children[C]);
      var R = pn(u.value);
      R.splice(T, 0, R.splice(C, 1)[0]), u.value = R, l(u.value), s("sort", u.value, C, T, h.value[T]);
    }
  };
  return et(b, (S, C) => {
    S === !0 && C === !1 ? y() : S === !1 && C === !0 && g();
  }, {
    immediate: !1
  }), On(() => {
    b.value && y();
  }), et(d, (S) => {
    var C;
    b.value && (g(), y(), (C = v.value) === null || C === void 0 || C.sort(Array.from(Array(S).keys()).reduce((T, O, R) => (T.push("".concat(f.value, "-").concat(R)), T), [])));
  }, {
    flush: "post"
  }), {
    list: m,
    sortable: v,
    isSortable: b,
    handleSort: E,
    initSortable: y,
    destroySortable: g
  };
}, R5 = function(t, n, r) {
  var i = he(!1);
  return {
    sorting: i
  };
}, w5 = function(t, n, r, i) {
  var {
    storeOrder: a,
    orderBy: o,
    order: s
  } = De(t), l = r.form$, u = r.value, c = he(l.value.$vueform.config.orderFrom), d = (h) => (a.value && Te(h, (m, v) => {
    m[a.value] = s.value && s.value.toUpperCase() === "DESC" ? h.length - v - (c.value == 0 ? 1 : 0) : parseInt(v) + c.value;
  }), h), f = N(() => o.value || a.value);
  return et(a, (h, m) => {
    h ? d(u.value) : Te(u.value, (v, b) => {
      v[m] = null;
    });
  }, {
    immediate: !1
  }), {
    refreshOrderStore: d,
    orderByName: f
  };
}, zBe = function(t, n, r, i) {
  var {
    storeOrder: a,
    orderBy: o
  } = De(t), {
    refreshOrderStore: s
  } = w5(t, n, r), l = N(() => o.value || a.value);
  return {
    refreshOrderStore: s,
    orderByName: l
  };
}, VBe = function(t, n, r) {
  var {
    object: i,
    element: a
  } = De(t), o = N(() => s.value ? Object.assign({}, i.value, {
    type: "object"
  }) : a.value || {}), s = N(() => !!i.value);
  return {
    prototype: o,
    isObject: s
  };
}, WBe = function(t, n, r) {
  var i = arguments.length > 3 && arguments[3] !== void 0 ? arguments[3] : {}, {
    auto: a,
    object: o,
    file: s,
    fields: l,
    storeFile: u,
    storeOrder: c,
    view: d,
    clickable: f,
    url: h,
    previewUrl: m,
    uploadTempEndpoint: v,
    removeTempEndpoint: b,
    removeEndpoint: y,
    params: g,
    softRemove: E
  } = De(t), S = r.isDisabled, C = N(() => i.type || "file"), T = N(() => u.value ? u.value : o.value || si(l.value).length || c.value ? "file" : null), O = N(() => !!o.value || !!c.value || !!si(l.value).length), R = N(() => {
    var D = {
      type: C.value,
      auto: a.value,
      view: d.value,
      layout: d.value === "gallery" ? "ElementLayoutInline" : "ElementLayout",
      disabled: S.value,
      clickable: f.value,
      url: h.value,
      previewUrl: m.value,
      uploadTempEndpoint: v.value,
      removeTempEndpoint: b.value,
      removeEndpoint: y.value,
      params: g.value,
      softRemove: E.value
    };
    return O.value ? {
      type: "object",
      schema: Object.assign(
        {},
        // File
        {
          [T.value]: Object.assign({}, D, {
            embed: !0
          }, s.value)
        },
        // Order
        c.value ? {
          [c.value]: {
            type: "hidden",
            meta: !0
          }
        } : {},
        // Other fields
        l.value
      )
    } : Object.assign({}, D, s.value);
  });
  return {
    storeFileName: T,
    isObject: O,
    prototype: R
  };
}, KBe = function(t, n, r) {
  var {
    controls: i,
    sort: a,
    min: o,
    max: s,
    addText: l
  } = De(t), u = r.isDisabled, c = r.value, d = r.form$, f = N(() => !u.value && (i.value.add || i.value.add === void 0) && (s.value === -1 || s.value > c.value.length)), h = N(() => !u.value && (i.value.remove || i.value.remove === void 0) && (o.value === -1 || o.value < c.value.length)), m = N(() => !u.value && (i.value.sort || i.value.sort === void 0) && a.value), v = N(() => l.value || d.value.translations.vueform.elements.list.add);
  return {
    hasAdd: f,
    hasRemove: h,
    hasSort: m,
    addLabel: v
  };
}, jBe = function(t, n, r) {
  var {
    controls: i,
    sort: a
  } = De(t), o = r.isDisabled, s = r.hasUploading, l = N(() => i.value.add || i.value.add === void 0), u = N(() => !o.value && (i.value.remove || i.value.remove === void 0) && !s.value), c = N(() => !o.value && (i.value.sort || i.value.sort === void 0) && a.value && !s.value);
  return {
    hasAdd: l,
    hasRemove: u,
    hasSort: c
  };
}, x5 = {
  name: "ListElement",
  mixins: [Jn, dr, _r, vr, br],
  emits: ["change", "add", "remove", "sort", "beforeCreate", "created", "beforeMount", "mounted", "beforeUpdate", "updated", "beforeUnmount", "unmounted"],
  props: {
    type: {
      required: !1,
      type: [String],
      default: "list",
      private: !0
    },
    default: {
      required: !1,
      type: [Array],
      default: void 0
    },
    id: {
      required: !1,
      type: [String],
      default: null
    },
    disabled: {
      required: !1,
      type: [Boolean],
      default: !1
    },
    onAdd: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    },
    onRemove: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    },
    onSort: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    },
    element: {
      required: !1,
      type: [Object],
      default: null
    },
    object: {
      required: !1,
      type: [Object],
      default: null
    },
    initial: {
      required: !1,
      type: [Number],
      default: 1
    },
    min: {
      required: !1,
      type: [Number],
      default: -1
    },
    max: {
      required: !1,
      type: [Number],
      default: -1
    },
    addText: {
      required: !1,
      type: [String],
      default: null,
      "@default": "locale.elements.list.add"
    },
    sort: {
      required: !1,
      type: [Boolean],
      default: !1
    },
    controls: {
      required: !1,
      type: [Object],
      default: () => ({
        add: !0,
        remove: !0,
        sort: !0
      })
    },
    storeOrder: {
      required: !1,
      type: [String],
      default: null
    },
    order: {
      required: !1,
      type: [String],
      default: null
    },
    orderBy: {
      required: !1,
      type: [String],
      default: null
    }
  },
  setup(e, t) {
    return t.features = [Hn, zn, lr, cr, Zn, qr, Kd, VBe, hO, R5, w5, Mn, Vd, Mi, ir, kr, Lm, ZA, Gv, q3e, KBe, Yv, ar, or, Xn, rr, sr, V8, O5, Lr, W8, ur], t.slots = ["label", "info", "description", "before", "between", "after"], mt({}, Yr(e, t));
  }
}, QBe = function(t, n, r) {
  var i = arguments.length > 3 && arguments[3] !== void 0 ? arguments[3] : {}, {
    provider: a,
    extendOptions: o
  } = De(t), s = r.form$, l = r.value, u = r.clear, c = r.input, d = () => i.input ? i.input.value : c.value, f = he(null), h = he({}), m = N(() => a.value || s.value.$vueform.config.locationProvider), v = N(() => {
    var S = {
      google: {
        fields: ["geometry", "formatted_address", "address_components"]
      },
      algolia: {
        type: "address",
        appId: s.value.$vueform.config.services.algolia.app_id,
        apiKey: s.value.$vueform.config.services.algolia.api_key,
        templates: i.templates || {}
      }
    };
    return S[m.value];
  }), b = N(() => Object.assign({}, v.value, o.value || /* istanbul ignore next: failsafe only */
  {})), y = (S, C) => {
    if (i.handleAddressChange) {
      i.handleAddressChange(S, C);
      return;
    }
    h.value = C, l.value = S;
  }, g = () => {
    d().value.length ? d().value = l.value.formatted_address : u();
  }, E = () => {
    f.value && f.value.destroy(), f.value = new s.value.$vueform.services.location[m.value](), f.value.init(d(), y, b.value);
  };
  return et([m, b], () => {
    E();
  }, {
    deep: !0,
    immediate: !1
  }), On(() => {
    E();
  }), {
    locationService: f,
    location: h,
    defaultOptions: v,
    providerOptions: b,
    handleAddressChange: y,
    handleLocationBlur: g,
    initLocationService: E
  };
}, N5 = {
  name: "LocationElement",
  mixins: [Jn, dr, _r, vr, br],
  emits: ["change", "beforeCreate", "created", "beforeMount", "mounted", "beforeUpdate", "updated", "beforeUnmount", "unmounted"],
  props: {
    type: {
      required: !1,
      type: [String],
      default: "location",
      private: !0
    },
    default: {
      required: !1,
      type: [Object],
      default: () => ({
        country: null,
        country_code: null,
        state: null,
        state_code: null,
        city: null,
        zip: null,
        address: null,
        formatted_address: null,
        lat: null,
        lng: null
      })
    },
    debounce: {
      required: !1,
      type: [Number],
      default: null
    },
    disabled: {
      required: !1,
      type: [Boolean],
      default: !1
    },
    floating: {
      required: !1,
      type: [String, Boolean, Object],
      localized: !0,
      default: null
    },
    id: {
      required: !1,
      type: [String],
      default: null
    },
    placeholder: {
      required: !1,
      type: [String, Object],
      localized: !0,
      default: null
    },
    readonly: {
      required: !1,
      type: [Boolean],
      default: !1
    },
    attrs: {
      required: !1,
      type: [Object],
      default: () => ({})
    },
    addons: {
      required: !1,
      type: [Object],
      localized: !0,
      default: () => ({})
    },
    provider: {
      required: !1,
      type: [String],
      default: "google"
    },
    displayKey: {
      required: !1,
      type: [String],
      default: "formatted_address"
    },
    extendOptions: {
      required: !1,
      type: [Object],
      default: () => ({})
    }
  },
  setup(e, t) {
    return t.features = [Hn, zn, lr, ei, cr, qr, Q3e, Zn, cs, Mn, Gr, ic, Mi, Mr, F3e, Qn, li, QBe, us, ir, kr, or, Xn, rr, ar, sr, jd, Lr, V3e, ur, ro], t.slots = ["label", "info", "description", "before", "between", "after", "addon-before", "addon-after"], mt({}, r3e(e, t));
  }
}, XBe = function(t, n, r) {
  var i = r.isDisabled, a = r.add, o = r.input, s = r.isObject, l = r.storeFileName, u = r.children$, c = N(() => hn(u.value, {
    available: !0,
    preparing: !0
  })), d = N(() => hn(u.value, {
    uploading: !0
  })), f = (m) => {
    !m.target || !m.target.files || m.target.files.length == 0 || i.value || (Te(m.target.files, (v) => {
      a(s.value ? {
        [l.value]: v
      } : v);
    }), o.value.value = "");
  }, h = () => {
    i.value || o.value.click();
  };
  return {
    preparing: c,
    hasUploading: d,
    handleChange: f,
    handleClick: h
  };
}, D5 = {
  name: "MultifileElement",
  mixins: [Jn, dr, _r, vr, br],
  emits: ["change", "add", "remove", "sort", "beforeCreate", "created", "beforeMount", "mounted", "beforeUpdate", "updated", "beforeUnmount", "unmounted"],
  props: {
    type: {
      required: !1,
      type: [String],
      default: "multifile",
      private: !0
    },
    default: {
      required: !1,
      type: [Array],
      default: () => []
    },
    initial: {
      required: !1,
      type: [Number],
      default: 0,
      private: !0
    },
    disabled: {
      required: !1,
      type: [Boolean],
      default: !1
    },
    id: {
      required: !1,
      type: [String],
      default: null
    },
    onAdd: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    },
    onRemove: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    },
    onSort: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    },
    view: {
      type: [String],
      required: !1,
      default: "file"
    },
    drop: {
      required: !1,
      type: [Boolean],
      default: !1
    },
    sort: {
      required: !1,
      type: [Boolean],
      default: !1
    },
    controls: {
      required: !1,
      type: [Object],
      default: () => ({
        add: !0,
        remove: !0,
        sort: !0
      })
    },
    object: {
      required: !1,
      type: [Boolean],
      default: null
    },
    storeFile: {
      required: !1,
      type: [String],
      default: "file"
    },
    fields: {
      required: !1,
      type: [Object],
      default: () => ({})
    },
    storeOrder: {
      required: !1,
      type: [String],
      default: null
    },
    order: {
      required: !1,
      type: [String],
      default: null
    },
    orderBy: {
      required: !1,
      type: [String],
      default: null
    },
    file: {
      required: !1,
      type: [Object],
      default: () => ({})
    },
    accept: {
      required: !1,
      type: [String, Array],
      default: null
    },
    clickable: {
      required: !1,
      type: [Boolean],
      default: !0
    },
    url: {
      required: !1,
      type: [String, Boolean],
      default: "/"
    },
    previewUrl: {
      required: !1,
      type: [String],
      default: void 0
    },
    auto: {
      required: !1,
      type: [Boolean],
      default: !0
    },
    uploadTempEndpoint: {
      required: !1,
      type: [Object, String, Function],
      default: void 0,
      "@default": "config.endpoints.uploadTempFile"
    },
    removeTempEndpoint: {
      required: !1,
      type: [Object, String, Function],
      default: void 0,
      "@default": "config.endpoints.removeTempFile"
    },
    removeEndpoint: {
      required: !1,
      type: [Object, String, Function],
      default: void 0,
      "@default": "config.endpoints.removeFile"
    },
    params: {
      required: !1,
      type: [Object],
      default: () => ({})
    },
    softRemove: {
      required: !1,
      type: [Boolean],
      default: !1
    }
  },
  setup(e, t) {
    return t.features = [Hn, zn, lr, cr, qr, Kd, hO, ei, R5, WBe, Zn, Mn, Vd, Mi, ir, kr, Gv, Mr, Yv, Lm, Qn, ar, or, Xn, sr, zBe, N3e, XBe, jBe, gBe, rr, O5, Lr, W3e, ur], t.slots = ["label", "info", "description", "before", "between", "after"], mt({}, Yr(e, t));
  }
}, bO = function(t, n, r) {
  var i = r.fire, a = r.el$, o = (m) => {
    i("select", m, a.value);
  }, s = (m) => {
    i("deselect", m, a.value);
  }, l = (m) => {
    i("search-change", m, a.value);
  }, u = () => {
    i("open", a.value);
  }, c = () => {
    i("close", a.value);
  }, d = () => {
    i("clear", a.value);
  }, f = (m) => {
    i("paste", m, a.value);
  }, h = (m) => {
  };
  return {
    handleSelect: o,
    handleDeselect: s,
    handleSearchChange: l,
    handleOpen: u,
    handleClose: c,
    handleClear: d,
    handlePaste: f,
    handleTag: h
  };
};
function ZBe(e, t) {
  t.sort();
  for (var n = t.length - 1; n >= 0; n--)
    e.splice(t[n], 1);
  return e;
}
var I5 = function(t, n, r) {
  var i = r.value, a = (l) => i.value.indexOf(l) !== -1, o = (l) => {
    At(l) || (l = [l]);
    var u = bo(i.value);
    Te(l, (c) => {
      a(Ur(c)) || u.push(c);
    }), i.value = u;
  }, s = (l) => {
    At(l) || (l = [l]);
    var u = bo(i.value), c = [];
    Te(l, (d) => {
      var f = i.value.indexOf(d);
      f === -1 || c.indexOf(f) !== -1 || c.push(f);
    }), i.value = ZBe(u, c);
  };
  return {
    select: o,
    deselect: s
  };
}, Pm = function(t, n, r) {
  var {
    loading: i
  } = De(t), a = r.pending, o = N(() => a.value || i.value);
  return {
    isLoading: o
  };
}, L5 = {
  name: "MultiselectElement",
  mixins: [Jn, dr, _r, vr, br],
  emits: ["change", "select", "deselect", "search-change", "open", "close", "clear", "paste", "beforeCreate", "created", "beforeMount", "mounted", "beforeUpdate", "updated", "beforeUnmount", "unmounted"],
  props: {
    type: {
      required: !1,
      type: [String],
      default: "multiselect",
      private: !0
    },
    default: {
      required: !1,
      type: [Array],
      default: () => []
    },
    disabled: {
      required: !1,
      type: [Boolean],
      default: !1
    },
    floating: {
      required: !1,
      type: [String, Boolean, Object],
      localized: !0,
      default: null
    },
    id: {
      required: !1,
      type: [String],
      default: null
    },
    placeholder: {
      required: !1,
      type: [String, Object],
      localized: !0,
      default: null,
      native: !1
    },
    attrs: {
      required: !1,
      type: [Object],
      default: () => ({})
    },
    onSelect: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    },
    onDeselect: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    },
    onSearchChange: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    },
    onOpen: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    },
    onClose: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    },
    onClear: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    },
    onPaste: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    },
    native: {
      required: !1,
      type: [Boolean],
      default: !0
    },
    items: {
      required: !1,
      type: [Object, Array, Function, String],
      localized: !0,
      default: () => ({})
    },
    labelProp: {
      type: [String],
      required: !1,
      default: "label",
      native: !1
    },
    valueProp: {
      type: [String],
      required: !1,
      default: "value",
      native: !1
    },
    dataKey: {
      type: [String],
      required: !1,
      default: void 0
    },
    searchParam: {
      type: [String],
      required: !1,
      default: "query"
    },
    search: {
      required: !1,
      type: [Boolean],
      default: !1,
      native: !1
    },
    trackBy: {
      type: [String, Array],
      required: !1,
      default: "label",
      native: !1
    },
    strict: {
      type: [Boolean],
      required: !1,
      default: !0,
      native: !1
    },
    multipleLabel: {
      type: [Function],
      required: !1,
      native: !1
    },
    multipleLabelSingle: {
      type: [String],
      required: !1,
      native: !1,
      "@default": "locale.vueform.multiselect.multipleLabelOne"
    },
    multipleLabelMultiple: {
      type: [String],
      required: !1,
      native: !1,
      "@default": "locale.vueform.multiselect.multipleLabelMore"
    },
    create: {
      required: !1,
      type: [Boolean],
      default: !1,
      native: !1
    },
    appendNewOption: {
      type: [Boolean],
      required: !1,
      default: !0,
      native: !1
    },
    addOptionOn: {
      type: [Array],
      required: !1,
      default: () => ["enter"],
      native: !1
    },
    object: {
      type: [Boolean],
      required: !1,
      default: !1,
      native: !1
    },
    limit: {
      type: [Number],
      required: !1,
      default: -1,
      native: !1
    },
    max: {
      type: [Number],
      required: !1,
      default: -1,
      native: !1
    },
    groups: {
      type: [Boolean],
      required: !1,
      default: !1,
      native: !1
    },
    groupLabel: {
      type: [String],
      required: !1,
      default: "label",
      native: !1
    },
    groupOptions: {
      type: [String],
      required: !1,
      default: "items",
      native: !1
    },
    groupHideEmpty: {
      type: [Boolean],
      required: !1,
      default: !1,
      native: !1
    },
    groupSelect: {
      type: [Boolean],
      required: !1,
      default: !0,
      native: !1
    },
    openDirection: {
      type: [String],
      required: !1,
      default: "bottom",
      native: !1
    },
    appendToBody: {
      type: [Boolean],
      required: !1,
      default: !1,
      native: !1
    },
    appendTo: {
      type: [String],
      required: !1,
      default: void 0,
      native: !1
    },
    canClear: {
      type: [Boolean],
      required: !1,
      default: !0,
      native: !1
    },
    clearOnSelect: {
      type: [Boolean],
      required: !1,
      default: !1,
      native: !1
    },
    closeOnSelect: {
      type: [Boolean],
      required: !1,
      default: !0,
      native: !1
    },
    closeOnDeselect: {
      type: [Boolean],
      required: !1,
      default: !1,
      native: !1
    },
    clearOnRefetch: {
      type: [Boolean],
      required: !1,
      default: !0
    },
    delay: {
      type: [Number],
      required: !1,
      default: -1,
      native: !1
    },
    minChars: {
      type: [Number],
      required: !1,
      default: 0,
      native: !1
    },
    resolveOnLoad: {
      type: [Boolean],
      required: !1,
      default: !0,
      native: !1
    },
    filterResults: {
      type: [Boolean],
      required: !1,
      default: !0,
      native: !1
    },
    clearOnSearch: {
      type: [Boolean],
      required: !1,
      default: !1,
      native: !1
    },
    hideSelected: {
      type: [Boolean],
      required: !1,
      default: !0,
      native: !1
    },
    caret: {
      type: [Boolean],
      required: !1,
      default: !0,
      native: !1
    },
    loading: {
      type: [Boolean],
      required: !1,
      default: !1,
      native: !1
    },
    noOptionsText: {
      type: [String, Object],
      required: !1,
      default: void 0,
      "@default": "locale.multiselect.noOptions",
      localized: !0,
      native: !1
    },
    noResultsText: {
      type: [String, Object],
      required: !1,
      default: void 0,
      "@default": "locale.multiselect.noResults",
      localized: !0,
      native: !1
    },
    autocomplete: {
      type: [String],
      required: !1,
      native: !1
    },
    inputType: {
      type: [String],
      required: !1,
      default: "text",
      native: !1
    },
    extendOptions: {
      required: !1,
      type: [Object],
      default: () => ({})
    }
  },
  setup(e, t) {
    return t.features = [Hn, zn, lr, ei, cr, qr, Kd, Zn, cs, Mn, e3e, Mi, ji, Pm, sBe, Mr, tBe, Qn, D3e, Yv, ir, kr, or, Xn, rr, ar, sr, bO, I5, fBe, Lr, Ei, ur, ro], t.slots = ["option", "multiple-label", "placeholder", "group-label", "before-list", "after-list", "no-results", "no-options", "caret", "spinner", "clear", "label", "info", "description", "before", "between", "after"], mt({}, Yr(e, t));
  }
}, k5 = {
  name: "ObjectElement",
  mixins: [Jn, dr, _r, vr, br],
  emits: ["change", "remove", "beforeCreate", "created", "beforeMount", "mounted", "beforeUpdate", "updated", "beforeUnmount", "unmounted"],
  props: {
    type: {
      required: !1,
      type: [String],
      default: "object",
      private: !0
    },
    default: {
      required: !1,
      type: [Object],
      default: () => ({})
    },
    id: {
      required: !1,
      type: [String],
      default: null
    },
    schema: {
      required: !1,
      type: [Object],
      default: () => ({})
    },
    embed: {
      required: !1,
      type: [Boolean],
      default: !1
    },
    onRemove: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    }
  },
  setup(e, t) {
    return t.features = [Hn, zn, lr, cr, Zn, Q8, Mn, Gr, L3e, G3e, ir, u5, Lm, SFe, $3e, or, Xn, rr, ar, sr, z8, Lr, K8, ur], t.slots = ["label", "info", "description", "before", "between", "after"], mt({}, Yr(e, t));
  }
}, JBe = function(t, n, r) {
  var {
    radioName: i,
    radioValue: a
  } = De(t), o = r.update, s = r.nullValue, l = r.fieldId, u = r.path, c = r.form$, d = he([]), f = N(() => i.value || u.value), h = () => {
    o(a.value);
  }, m = () => {
    o(s.value);
  }, v = (b, y) => {
    y && c.value.$el.querySelectorAll('input[name="'.concat(y, '"')).forEach((g, E) => {
      d.value[E] && g.removeEventListener("change", d.value[E]);
    }), c.value.$el.querySelectorAll('input[name="'.concat(b, '"')).forEach((g) => {
      var E = () => {
        g.id != l.value && o(s.value);
      };
      d.value.push(E), g.addEventListener("change", E);
    });
  };
  return On(() => {
    v(f.value);
  }), et(f, v), {
    inputName: f,
    check: h,
    uncheck: m
  };
}, M5 = {
  name: "RadioElement",
  mixins: [Jn, dr, _r, vr, br],
  emits: ["change", "beforeCreate", "created", "beforeMount", "mounted", "beforeUpdate", "updated", "beforeUnmount", "unmounted"],
  props: {
    type: {
      required: !1,
      type: [String],
      default: "radio",
      private: !0
    },
    default: {
      required: !1,
      type: [String, Number],
      default: null
    },
    disabled: {
      required: !1,
      type: [Boolean],
      default: !1
    },
    id: {
      required: !1,
      type: [String],
      default: null
    },
    radioName: {
      required: !1,
      type: [String],
      default: null
    },
    radioValue: {
      required: !1,
      type: [Boolean, String, Number],
      default: 1
    },
    text: {
      required: !1,
      type: [String, Object],
      localized: !0,
      default: null
    },
    align: {
      required: !1,
      type: [String],
      default: void 0
    }
  },
  setup(e, t) {
    return t.features = [Hn, zn, lr, ei, cr, qr, Zn, Mn, Gr, ls, Mi, Qn, ji, Mr, li, ir, kr, or, Xn, rr, ar, sr, JBe, zFe, Ei, ur, uO], t.slots = ["default", "label", "info", "description", "before", "between", "after"], mt({}, Yr(e, t));
  }
}, P5 = {
  name: "RadiogroupElement",
  mixins: [Jn, dr, _r, vr, br],
  emits: ["change", "beforeCreate", "created", "beforeMount", "mounted", "beforeUpdate", "updated", "beforeUnmount", "unmounted"],
  props: {
    type: {
      required: !1,
      type: [String],
      default: "radiogroup",
      private: !0
    },
    default: {
      required: !1,
      type: [String, Number],
      default: null
    },
    disabled: {
      required: !1,
      type: [Boolean],
      default: !1
    },
    id: {
      required: !1,
      type: [String],
      default: null
    },
    items: {
      required: !1,
      type: [Object, Array, Function, String],
      localized: !0,
      default: () => ({})
    },
    disables: {
      required: !1,
      type: [Array],
      default: () => []
    },
    clearOnRefetch: {
      type: [Boolean],
      required: !1,
      default: !0
    }
  },
  setup(e, t) {
    return t.features = [Hn, zn, lr, cr, ls, Zn, Mn, Gr, qFe, Mi, Mr, eBe, Qn, ji, li, ir, kr, or, Xn, rr, ar, sr, HFe, Ei, ur], t.slots = ["radio", "label", "info", "description", "before", "between", "after"], mt({}, Yr(e, t));
  }
}, F5 = {
  name: "SelectElement",
  mixins: [Jn, dr, _r, vr, br],
  emits: ["change", "select", "deselect", "search-change", "open", "close", "clear", "paste", "beforeCreate", "created", "beforeMount", "mounted", "beforeUpdate", "updated", "beforeUnmount", "unmounted"],
  props: {
    type: {
      required: !1,
      type: [String],
      default: "select",
      private: !0
    },
    default: {
      required: !1,
      type: [String, Number, Object],
      default: null
    },
    disabled: {
      required: !1,
      type: [Boolean],
      default: !1
    },
    floating: {
      required: !1,
      type: [String, Boolean, Object],
      localized: !0,
      default: null
    },
    id: {
      required: !1,
      type: [String],
      default: null
    },
    placeholder: {
      required: !1,
      type: [String, Object],
      localized: !0,
      default: null
    },
    attrs: {
      required: !1,
      type: [Object],
      default: () => ({})
    },
    onSelect: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    },
    onDeselect: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    },
    onSearchChange: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    },
    onOpen: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    },
    onClose: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    },
    onClear: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    },
    onPaste: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    },
    native: {
      required: !1,
      type: [Boolean],
      default: !0
    },
    items: {
      required: !1,
      type: [Object, Array, Function, String],
      localized: !0,
      default: () => ({})
    },
    labelProp: {
      type: [String],
      required: !1,
      default: "label"
    },
    valueProp: {
      type: [String],
      required: !1,
      default: "value"
    },
    dataKey: {
      type: [String],
      required: !1,
      default: void 0
    },
    searchParam: {
      type: [String],
      required: !1,
      default: "query"
    },
    search: {
      required: !1,
      type: [Boolean],
      default: !1,
      native: !1
    },
    trackBy: {
      type: [String, Array],
      required: !1,
      default: void 0,
      native: !1
    },
    strict: {
      type: [Boolean],
      required: !1,
      default: !0,
      native: !1
    },
    create: {
      required: !1,
      type: [Boolean],
      default: !1,
      native: !1
    },
    appendNewOption: {
      type: [Boolean],
      required: !1,
      default: !0,
      native: !1
    },
    addOptionOn: {
      type: [Array],
      required: !1,
      default: () => ["enter"],
      native: !1
    },
    object: {
      type: [Boolean],
      required: !1,
      default: !1,
      native: !1
    },
    limit: {
      type: [Number],
      required: !1,
      default: -1,
      native: !1
    },
    groups: {
      type: [Boolean],
      required: !1,
      default: !1,
      native: !1
    },
    groupLabel: {
      type: [String],
      required: !1,
      default: "label",
      native: !1
    },
    groupOptions: {
      type: [String],
      required: !1,
      default: "items",
      native: !1
    },
    groupHideEmpty: {
      type: [Boolean],
      required: !1,
      default: !1,
      native: !1
    },
    openDirection: {
      type: [String],
      required: !1,
      default: "bottom",
      native: !1
    },
    appendToBody: {
      type: [Boolean],
      required: !1,
      default: !1,
      native: !1
    },
    appendTo: {
      type: [String],
      required: !1,
      default: void 0,
      native: !1
    },
    canDeselect: {
      type: [Boolean],
      required: !1,
      default: !0,
      native: !1
    },
    canClear: {
      type: [Boolean],
      required: !1,
      default: !0,
      native: !1
    },
    closeOnSelect: {
      type: [Boolean],
      required: !1,
      default: !0,
      native: !1
    },
    closeOnDeselect: {
      type: [Boolean],
      required: !1,
      default: !1,
      native: !1
    },
    clearOnRefetch: {
      type: [Boolean],
      required: !1,
      default: !1
    },
    delay: {
      type: [Number],
      required: !1,
      default: -1,
      native: !1
    },
    minChars: {
      type: [Number],
      required: !1,
      default: 0,
      native: !1
    },
    resolveOnLoad: {
      type: [Boolean],
      required: !1,
      default: !0,
      native: !1
    },
    filterResults: {
      type: [Boolean],
      required: !1,
      default: !0,
      native: !1
    },
    clearOnSearch: {
      type: [Boolean],
      required: !1,
      default: !1,
      native: !1
    },
    caret: {
      type: [Boolean],
      required: !1,
      default: !0,
      native: !1
    },
    truncate: {
      type: [Boolean],
      required: !1,
      default: !0,
      native: !1
    },
    loading: {
      type: [Boolean],
      required: !1,
      default: !1,
      native: !1
    },
    noOptionsText: {
      type: [String, Object],
      required: !1,
      default: void 0,
      "@default": "locale.multiselect.noOptions",
      localized: !0,
      native: !1
    },
    noResultsText: {
      type: [String, Object],
      required: !1,
      default: void 0,
      "@default": "locale.multiselect.noResults",
      localized: !0,
      native: !1
    },
    autocomplete: {
      type: [String],
      required: !1,
      native: !1
    },
    inputType: {
      type: [String],
      required: !1,
      default: "text",
      native: !1
    },
    extendOptions: {
      required: !1,
      type: [Object],
      default: () => ({})
    }
  },
  setup(e, t) {
    return t.features = [Hn, zn, lr, ei, cr, qr, ls, Zn, cs, Mn, Gr, Mi, ji, Pm, oBe, Mr, dO, Qn, rO, us, ir, kr, or, Xn, rr, ar, sr, bO, pO, Lr, Ei, ur, ro], t.slots = ["option", "single-label", "placeholder", "group-label", "before-list", "after-list", "no-results", "no-options", "caret", "spinner", "clear", "label", "info", "description", "before", "between", "after"], mt({}, Yr(e, t));
  }
}, e6e = function(t, n, r) {
  var {
    lazy: i
  } = De(t), a = r.value, o = (s) => {
    i.value || (a.value = s);
  };
  return {
    handleUpdate: o
  };
}, B5 = {
  name: "SliderElement",
  mixins: [Jn, dr, _r, vr, br],
  emits: ["change", "beforeCreate", "created", "beforeMount", "mounted", "beforeUpdate", "updated", "beforeUnmount", "unmounted"],
  props: {
    type: {
      required: !1,
      type: [String],
      default: "slider",
      private: !0
    },
    default: {
      required: !1,
      type: [Number, Array],
      default: 0
    },
    disabled: {
      required: !1,
      type: [Boolean],
      default: !1
    },
    id: {
      required: !1,
      type: [String],
      default: null
    },
    min: {
      required: !1,
      type: [Number],
      default: 0
    },
    max: {
      required: !1,
      type: [Number],
      default: 100
    },
    step: {
      required: !1,
      type: [Number],
      default: 1
    },
    tooltips: {
      required: !1,
      type: [Boolean],
      default: !0
    },
    showTooltip: {
      required: !1,
      type: [String],
      default: "always"
    },
    tooltipPosition: {
      required: !1,
      type: [String],
      default: null
    },
    merge: {
      required: !1,
      type: [Number],
      default: -1
    },
    format: {
      required: !1,
      type: [Object, Function],
      default: null
    },
    orientation: {
      required: !1,
      type: [String],
      default: "horizontal"
    },
    direction: {
      required: !1,
      type: [String],
      default: "ltr"
    },
    lazy: {
      required: !1,
      type: [Boolean],
      default: !0,
      private: !0
    },
    extendOptions: {
      required: !1,
      type: [Object],
      default: () => ({})
    }
  },
  setup(e, t) {
    return t.features = [Hn, zn, lr, ei, cr, qr, j3e, Zn, Mn, Gr, Mi, uBe, Mr, M3e, Qn, li, ir, kr, or, Xn, rr, ar, sr, Hv, e6e, Lr, Ei, ur], t.slots = ["label", "info", "description", "before", "between", "after"], mt({}, Yr(e, t));
  }
}, t6e = function(t, n, r) {
  var {
    content: i
  } = De(t), a = r.fieldSlots, o = N(() => typeof i.value == "string"), s = N(() => {
    var c, d;
    return !((c = i.value) !== null && c !== void 0 && c.render) && !((d = i.value) !== null && d !== void 0 && d.template) ? i.value : u(i.value);
  }), l = N(() => {
    var c, d;
    return !((c = a.value.default) !== null && c !== void 0 && c.render) && !((d = a.value.default) !== null && d !== void 0 && d.template) ? a.value.default : u(a.value.default);
  }), u = (c) => (c = mt({}, c), c.props ? Array.isArray(c.props) && c.props.indexOf("el$") === -1 ? c.props.push("el$") : !Array.isArray(c.props) && !c.props.el$ && (c.props.el$ = {
    type: Object,
    required: !1,
    default: () => ({})
  }) : c.props = ["el$"], c);
  return {
    isHtml: o,
    componentContent: s,
    slotContent: l
  };
}, $5 = {
  name: "StaticElement",
  mixins: [Jn, dr],
  emits: ["beforeCreate", "created", "beforeMount", "mounted", "beforeUpdate", "updated", "beforeUnmount", "unmounted"],
  props: {
    type: {
      required: !1,
      type: [String],
      default: "static",
      private: !0
    },
    id: {
      required: !1,
      type: [String],
      default: null
    },
    content: {
      required: !1,
      type: [String, Object],
      default: ""
    },
    wrap: {
      required: !1,
      type: [Boolean],
      default: !0
    },
    tag: {
      required: !1,
      type: [String],
      default: void 0
    },
    allowHtml: {
      required: !1,
      type: [Boolean],
      default: !0
    },
    href: {
      required: !1,
      type: [String],
      default: void 0
    },
    target: {
      required: !1,
      type: [String],
      default: void 0
    },
    src: {
      required: !1,
      type: [String],
      default: void 0
    },
    alt: {
      required: !1,
      type: [String],
      default: void 0
    },
    title: {
      required: !1,
      type: [String],
      default: void 0
    },
    width: {
      required: !1,
      type: [String],
      default: void 0
    },
    height: {
      required: !1,
      type: [String],
      default: void 0
    },
    attrs: {
      required: !1,
      type: [Object],
      default: () => ({})
    },
    align: {
      required: !1,
      type: [String],
      default: void 0
    },
    top: {
      required: !1,
      type: [String, Number],
      default: 0
    },
    bottom: {
      required: !1,
      type: [String, Number],
      default: 0
    }
  },
  setup(e, t) {
    return t.features = [Hn, zn, lr, G8, Mn, q8, Qn, ir, or, Xn, rr, ar, sr, Zn, YFe, ur, t6e], t.slots = ["default", "label", "info", "description", "before", "between", "after"], mt({}, Y8(e, t));
  }
}, n6e = function(t, n, r) {
  var i = r.fire, a = r.el$, o = (s) => {
    i("tag", s, a.value);
  };
  return {
    handleTag: o
  };
}, U5 = {
  name: "TagsElement",
  mixins: [Jn, dr, _r, vr, br],
  emits: ["change", "select", "deselect", "search-change", "open", "close", "tag", "clear", "paste", "beforeCreate", "created", "beforeMount", "mounted", "beforeUpdate", "updated", "beforeUnmount", "unmounted"],
  props: {
    type: {
      required: !1,
      type: [String],
      default: "tags",
      private: !0
    },
    default: {
      required: !1,
      type: [Array],
      default: () => []
    },
    disabled: {
      required: !1,
      type: [Boolean],
      default: !1
    },
    floating: {
      required: !1,
      type: [String, Boolean, Object],
      localized: !0,
      default: null
    },
    id: {
      required: !1,
      type: [String],
      default: null
    },
    placeholder: {
      required: !1,
      type: [String, Object],
      localized: !0,
      default: null
    },
    attrs: {
      required: !1,
      type: [Object],
      default: () => ({})
    },
    onSelect: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    },
    onDeselect: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    },
    onSearchChange: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    },
    onOpen: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    },
    onClose: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    },
    onTag: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    },
    onClear: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    },
    onPaste: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    },
    items: {
      required: !1,
      type: [Object, Array, Function, String],
      localized: !0,
      default: () => ({})
    },
    labelProp: {
      type: [String],
      required: !1,
      default: "label"
    },
    valueProp: {
      type: [String],
      required: !1,
      default: "value"
    },
    dataKey: {
      type: [String],
      required: !1,
      default: void 0
    },
    searchParam: {
      type: [String],
      required: !1,
      default: "query"
    },
    search: {
      required: !1,
      type: [Boolean],
      default: !1
    },
    trackBy: {
      type: [String, Array],
      required: !1,
      default: "label"
    },
    strict: {
      type: [Boolean],
      required: !1,
      default: !0
    },
    breakTags: {
      type: [Boolean],
      required: !1,
      default: !1
    },
    create: {
      required: !1,
      type: [Boolean],
      default: !1
    },
    appendNewOption: {
      type: [Boolean],
      required: !1,
      default: !0
    },
    addOptionOn: {
      type: [Array],
      required: !1,
      default: () => ["enter"]
    },
    object: {
      type: [Boolean],
      required: !1,
      default: !1
    },
    limit: {
      type: [Number],
      required: !1,
      default: -1
    },
    max: {
      type: [Number],
      required: !1,
      default: -1
    },
    groups: {
      type: [Boolean],
      required: !1,
      default: !1
    },
    groupLabel: {
      type: [String],
      required: !1,
      default: "label"
    },
    groupOptions: {
      type: [String],
      required: !1,
      default: "items"
    },
    groupHideEmpty: {
      type: [Boolean],
      required: !1,
      default: !1
    },
    groupSelect: {
      type: [Boolean],
      required: !1,
      default: !0
    },
    openDirection: {
      type: [String],
      required: !1,
      default: "bottom"
    },
    appendToBody: {
      type: [Boolean],
      required: !1,
      default: !1,
      native: !1
    },
    appendTo: {
      type: [String],
      required: !1,
      default: void 0,
      native: !1
    },
    canClear: {
      type: [Boolean],
      required: !1,
      default: !0
    },
    clearOnSelect: {
      type: [Boolean],
      required: !1,
      default: !0
    },
    closeOnSelect: {
      type: [Boolean],
      required: !1,
      default: !0
    },
    closeOnDeselect: {
      type: [Boolean],
      required: !1,
      default: !1
    },
    clearOnRefetch: {
      type: [Boolean],
      required: !1,
      default: !1
    },
    delay: {
      type: [Number],
      required: !1,
      default: -1
    },
    minChars: {
      type: [Number],
      required: !1,
      default: 0
    },
    resolveOnLoad: {
      type: [Boolean],
      required: !1,
      default: !0
    },
    filterResults: {
      type: [Boolean],
      required: !1,
      default: !0
    },
    clearOnSearch: {
      type: [Boolean],
      required: !1,
      default: !1
    },
    hideSelected: {
      type: [Boolean],
      required: !1,
      default: !0
    },
    showOptions: {
      type: [Boolean],
      required: !1,
      default: !0
    },
    caret: {
      type: [Boolean],
      required: !1,
      default: !0
    },
    loading: {
      type: [Boolean],
      required: !1,
      default: !1
    },
    noOptionsText: {
      type: [String, Object],
      required: !1,
      default: void 0,
      "@default": "locale.multiselect.noOptions",
      localized: !0
    },
    noResultsText: {
      type: [String, Object],
      required: !1,
      default: void 0,
      "@default": "locale.multiselect.noResults",
      localized: !0
    },
    autocomplete: {
      type: [String],
      required: !1
    },
    inputType: {
      type: [String],
      required: !1,
      default: "text"
    },
    extendOptions: {
      required: !1,
      type: [Object],
      default: () => ({})
    }
  },
  setup(e, t) {
    return t.features = [Hn, zn, lr, ei, cr, qr, Kd, Zn, cs, Mn, t3e, Mi, ji, Pm, lBe, Mr, nBe, Qn, I3e, Yv, ir, kr, or, Xn, rr, ar, sr, bO, n6e, I5, pBe, Lr, Ei, ur, ro], t.slots = ["tag", "option", "placeholder", "group-label", "before-list", "after-list", "no-results", "no-options", "caret", "spinner", "clear", "label", "info", "description", "before", "between", "after"], mt({}, Yr(e, t));
  }
}, q5 = function(t, n, r) {
  var {
    autogrow: i
  } = De(t), a = r.form$, o = r.input, s = r.value, l = () => {
    i.value && a.value.$vueform.services.autosize.update(o.value);
  };
  return et(i, (u) => {
    u ? a.value.$vueform.services.autosize(o.value) : a.value.$vueform.services.autosize.destroy(o.value);
  }), et(s, () => {
    l();
  }), On(() => {
    i.value && Ut(() => {
      a.value.$vueform.services.autosize(o.value);
    });
  }), {
    autosize: l
  };
}, r6e = function(t, n, r) {
  var {
    autosize: i
  } = q5(t, n, r), a = r.form$;
  return On(() => {
    a.value.on("language", () => {
      i();
    });
  }), {
    autosize: i
  };
}, Qd = function(t, n, r) {
  var i = r.fire, a = r.el$, o = () => {
    i("blur", a.value);
  };
  return {
    handleBlur: o
  };
}, Vv = function(t, n, r) {
  var {
    fire: i,
    el$: a
  } = r, o = (u) => {
    i("keydown", u, a.value);
  }, s = (u) => {
    i("keyup", u, a.value);
  }, l = (u) => {
    i("keypress", u, a.value);
  };
  return {
    handleKeydown: o,
    handleKeyup: s,
    handleKeypress: l
  };
}, G5 = {
  name: "TextareaElement",
  mixins: [Jn, dr, _r, vr, br],
  emits: ["change", "blur", "keydown", "keyup", "keypress", "beforeCreate", "created", "beforeMount", "mounted", "beforeUpdate", "updated", "beforeUnmount", "unmounted"],
  props: {
    type: {
      required: !1,
      type: [String],
      default: "textarea",
      private: !0
    },
    default: {
      required: !1,
      type: [String, Number, Object],
      localized: !0,
      default: null
    },
    addons: {
      required: !1,
      type: [Object],
      localized: !0,
      default: () => ({})
    },
    autogrow: {
      required: !1,
      type: [Boolean],
      default: !0
    },
    rows: {
      required: !1,
      type: [Number],
      default: 3
    },
    debounce: {
      required: !1,
      type: [Number],
      default: null
    },
    disabled: {
      required: !1,
      type: [Boolean],
      default: !1
    },
    floating: {
      required: !1,
      type: [String, Boolean, Object],
      localized: !0,
      default: null
    },
    id: {
      required: !1,
      type: [String],
      default: null
    },
    placeholder: {
      required: !1,
      type: [String, Object],
      localized: !0,
      default: null
    },
    readonly: {
      required: !1,
      type: [Boolean],
      default: !1
    },
    attrs: {
      required: !1,
      type: [Object],
      default: () => ({})
    },
    onBlur: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    },
    onKeydown: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    },
    onKeyup: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    },
    onKeypress: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    }
  },
  setup(e, t) {
    return t.features = [Hn, zn, lr, ei, cr, qr, ls, Zn, cs, Mn, Gr, ic, qv, Qn, Wd, Mr, li, us, ir, kr, or, Xn, rr, ar, sr, ac, q5, jd, Qd, Lr, Ei, ur, Vv, ro], t.slots = ["label", "info", "description", "before", "between", "after", "addon-before", "addon-after"], mt({}, Yr(e, t));
  }
}, Y5 = {
  name: "TextElement",
  mixins: [Jn, dr, _r, vr, br],
  emits: ["change", "blur", "keydown", "keyup", "keypress", "beforeCreate", "created", "beforeMount", "mounted", "beforeUpdate", "updated", "beforeUnmount", "unmounted"],
  props: {
    type: {
      required: !1,
      type: [String],
      default: "text",
      private: !0
    },
    default: {
      required: !1,
      type: [String, Number, Object],
      localized: !0,
      default: null
    },
    debounce: {
      required: !1,
      type: [Number],
      default: null
    },
    disabled: {
      required: !1,
      type: [Boolean],
      default: !1
    },
    floating: {
      required: !1,
      type: [String, Boolean, Object],
      localized: !0,
      default: null
    },
    id: {
      required: !1,
      type: [String],
      default: null
    },
    placeholder: {
      required: !1,
      type: [String, Object],
      localized: !0,
      default: null
    },
    readonly: {
      required: !1,
      type: [Boolean],
      default: !1
    },
    inputType: {
      required: !1,
      type: [String],
      default: "text"
    },
    attrs: {
      required: !1,
      type: [Object],
      default: () => ({})
    },
    addons: {
      required: !1,
      type: [Object],
      localized: !0,
      default: () => ({})
    },
    autocomplete: {
      required: !1,
      type: [String, Number],
      default: null
    },
    loading: {
      type: [Boolean],
      required: !1,
      default: !1
    },
    onBlur: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    },
    onKeydown: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    },
    onKeyup: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    },
    onKeypress: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    }
  },
  setup(e, t) {
    return t.features = [Hn, zn, lr, ei, cr, qr, ls, Zn, cs, Mn, Gr, ic, qv, Qn, Wd, Pm, Mr, li, us, ir, kr, or, Xn, rr, ar, sr, ac, jd, Qd, Lr, Ei, ur, Vv, ro], t.slots = ["label", "info", "description", "before", "between", "after", "addon-before", "addon-after"], mt({}, Yr(e, t));
  }
}, H5 = {
  name: "ToggleElement",
  mixins: [Jn, dr, _r, vr, br],
  emits: ["change", "beforeCreate", "created", "beforeMount", "mounted", "beforeUpdate", "updated", "beforeUnmount", "unmounted"],
  props: {
    type: {
      required: !1,
      type: [String],
      default: "toggle",
      private: !0
    },
    default: {
      required: !1,
      type: [String, Number, Boolean],
      default: void 0
      // falseValue
    },
    disabled: {
      required: !1,
      type: [Boolean],
      default: !1
    },
    id: {
      required: !1,
      type: [String],
      default: null
    },
    text: {
      required: !1,
      type: [String, Object],
      localized: !0,
      default: null
    },
    labels: {
      required: !1,
      type: [Object],
      localized: !0,
      default: () => ({})
    },
    trueValue: {
      required: !1,
      type: [Boolean, String, Number],
      default: !0
    },
    falseValue: {
      required: !1,
      type: [Boolean, String, Number],
      default: !1
    },
    extendOptions: {
      required: !1,
      type: [Object],
      default: () => ({})
    },
    align: {
      required: !1,
      type: [String],
      default: void 0
    }
  },
  setup(e, t) {
    return t.features = [Hn, zn, lr, ei, cr, qr, j8, Zn, Mn, Gr, cBe, Mi, Qn, ji, Mr, li, ir, kr, or, Xn, rr, ar, sr, Hv, X3e, VFe, Ei, ur, uO], t.slots = ["default", "label", "info", "description", "before", "between", "after"], mt({}, Yr(e, t));
  }
}, z5 = function(t, n, r) {
  var {
    endpoint: i,
    method: a
  } = De(t), o = r.form$, s = r.input, l = he(!1), u = N(() => i.value || o.value.$vueform.config.endpoints.attachment.url), c = N(() => a.value || o.value.$vueform.config.endpoints.attachment.method);
  return On(() => {
    s.value.editor$.addEventListener("focus", () => {
      l.value = !0;
    }), s.value.editor$.addEventListener("blur", () => {
      l.value = !1;
    });
  }), {
    editorEndpoint: u,
    editorMethod: c,
    focused: l
  };
}, V5 = function(t, n, r) {
  var i = r.fire, a = r.listeners, o = (s) => {
    i("alert", s), a.value.alert || alert(s);
  };
  return {
    handleAlert: o
  };
}, W5 = {
  name: "EditorElement",
  mixins: [Jn, dr, _r, vr, br],
  emits: ["change", "blur", "alert", "error", "beforeCreate", "created", "beforeMount", "mounted", "beforeUpdate", "updated", "beforeUnmount", "unmounted"],
  props: {
    type: {
      required: !1,
      type: [String],
      default: "editor",
      private: !0
    },
    default: {
      required: !1,
      type: [String, Number, Object],
      localized: !0,
      default: null
    },
    debounce: {
      required: !1,
      type: [Number],
      default: null
    },
    disabled: {
      required: !1,
      type: [Boolean],
      default: !1
    },
    id: {
      required: !1,
      type: [String],
      default: null
    },
    placeholder: {
      required: !1,
      type: [String, Object],
      localized: !0,
      default: null
    },
    onError: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    },
    onAlert: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    },
    accept: {
      required: !1,
      type: [Array],
      default: () => []
    },
    acceptMimes: {
      required: !1,
      type: [Array],
      default: () => []
    },
    endpoint: {
      required: !1,
      type: [String, Function],
      default: null,
      "@default": "config.endpoints.attachment.url"
    },
    method: {
      required: !1,
      type: [String],
      default: null,
      "@default": "config.endpoints.attachment.method"
    },
    hideTools: {
      required: !1,
      type: [Array],
      default: () => []
    },
    onBlur: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    }
  },
  setup(e, t) {
    return t.features = [Hn, zn, lr, ei, cr, qr, ls, Zn, Mn, Gr, qv, Qn, Wd, Mr, w3e, us, ir, kr, or, Xn, z5, rr, ar, sr, ac, V5, mO, Qd, Lr, Ei, PFe, ro], t.slots = ["label", "info", "description", "before", "between", "after"], mt({}, Yr(e, t));
  }
}, EO = function(t, n, r) {
  var i = r.form$, a = N(() => i.value.selectedLanguage), o = N(() => si(i.value.options.languages));
  return {
    language: a,
    languages: o
  };
}, K5 = {
  name: "TTextareaElement",
  mixins: [Jn, dr, _r, vr, br],
  emits: ["change", "blur", "keydown", "keyup", "keypress", "beforeCreate", "created", "beforeMount", "mounted", "beforeUpdate", "updated", "beforeUnmount", "unmounted"],
  props: {
    type: {
      required: !1,
      type: [String],
      default: "t-textarea",
      private: !0
    },
    default: {
      required: !1,
      type: [Object, String, Number],
      localized: !0,
      default: null
    },
    addons: {
      required: !1,
      type: [Object],
      localized: !0,
      default: () => ({})
    },
    autogrow: {
      required: !1,
      type: [Boolean],
      default: !0
    },
    rows: {
      required: !1,
      type: [Number],
      default: 3
    },
    debounce: {
      required: !1,
      type: [Number],
      default: null
    },
    disabled: {
      required: !1,
      type: [Boolean],
      default: !1
    },
    floating: {
      required: !1,
      type: [String, Boolean, Object],
      localized: !0,
      default: null
    },
    id: {
      required: !1,
      type: [String],
      default: null
    },
    placeholder: {
      required: !1,
      type: [String, Object],
      localized: !0,
      default: null
    },
    readonly: {
      required: !1,
      type: [Boolean],
      default: !1
    },
    attrs: {
      required: !1,
      type: [Object],
      default: () => ({})
    },
    onBlur: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    },
    onKeydown: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    },
    onKeyup: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    },
    onKeypress: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    }
  },
  setup(e, t) {
    return t.features = [Hn, zn, lr, ei, cr, qr, Zn, cs, Mn, Gr, ic, EO, cO, aO, sO, Qn, oO, iO, fO, ir, kr, or, Xn, rr, ar, sr, ac, r6e, jd, Qd, Lr, lO, ur, Vv, ro], t.slots = ["label", "info", "description", "before", "between", "after", "addon-before", "addon-after"], mt({}, nO(e, t));
  }
}, j5 = {
  name: "TTextElement",
  mixins: [Jn, dr, _r, vr, br],
  emits: ["change", "blur", "keydown", "keyup", "keypress", "beforeCreate", "created", "beforeMount", "mounted", "beforeUpdate", "updated", "beforeUnmount", "unmounted"],
  props: {
    type: {
      required: !1,
      type: [String],
      default: "t-text",
      private: !0
    },
    default: {
      required: !1,
      type: [Object, String, Number],
      localized: !0,
      default: void 0
    },
    addons: {
      required: !1,
      type: [Object],
      localized: !0,
      default: () => ({})
    },
    autocomplete: {
      required: !1,
      type: [String, Number],
      default: null
    },
    debounce: {
      required: !1,
      type: [Number],
      default: null
    },
    disabled: {
      required: !1,
      type: [Boolean],
      default: !1
    },
    floating: {
      required: !1,
      type: [String, Boolean, Object],
      localized: !0,
      default: null
    },
    id: {
      required: !1,
      type: [String],
      default: null
    },
    inputType: {
      required: !1,
      type: [String],
      default: "text"
    },
    attrs: {
      required: !1,
      type: [Object],
      default: () => ({})
    },
    placeholder: {
      required: !1,
      type: [String, Object],
      localized: !0,
      default: null
    },
    readonly: {
      required: !1,
      type: [Boolean],
      default: !1
    },
    loading: {
      type: [Boolean],
      required: !1,
      default: !1
    },
    onBlur: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    },
    onKeydown: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    },
    onKeyup: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    },
    onKeypress: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    }
  },
  setup(e, t) {
    return t.features = [Hn, zn, lr, ei, cr, qr, Zn, cs, Mn, Gr, ic, EO, cO, aO, sO, Qn, oO, Pm, iO, fO, ir, kr, or, Xn, rr, ar, sr, ac, jd, Qd, Lr, lO, ur, Vv, ro], t.slots = ["label", "info", "description", "before", "between", "after", "addon-before", "addon-after"], mt({}, nO(e, t));
  }
}, Q5 = {
  name: "TEditorElement",
  mixins: [Jn, dr, _r, vr, br],
  emits: ["change", "blur", "alert", "error", "beforeCreate", "created", "beforeMount", "mounted", "beforeUpdate", "updated", "beforeUnmount", "unmounted"],
  props: {
    type: {
      required: !1,
      type: [String],
      default: "t-editor",
      private: !0
    },
    default: {
      required: !1,
      type: [Object, String, Number],
      localized: !0,
      default: null
    },
    debounce: {
      required: !1,
      type: [Number],
      default: null
    },
    disabled: {
      required: !1,
      type: [Boolean],
      default: !1
    },
    id: {
      required: !1,
      type: [String],
      default: null
    },
    placeholder: {
      required: !1,
      type: [String, Object],
      localized: !0,
      default: null
    },
    onError: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    },
    onAlert: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    },
    accept: {
      required: !1,
      type: [Array],
      default: null
    },
    acceptMimes: {
      required: !1,
      type: [Array],
      default: null
    },
    endpoint: {
      required: !1,
      type: [String, Function],
      default: null,
      "@default": "config.endpoints.attachment.url"
    },
    method: {
      required: !1,
      type: [String],
      default: null,
      "@default": "config.endpoints.attachment.method"
    },
    hideTools: {
      required: !1,
      type: [Array],
      default: () => []
    },
    onBlur: {
      required: !1,
      type: [Function],
      default: null,
      private: !0
    }
  },
  setup(e, t) {
    return t.features = [Hn, zn, lr, ei, cr, qr, Zn, Mn, Gr, EO, cO, aO, sO, Qn, oO, x3e, fO, ir, kr, or, Xn, z5, rr, ar, sr, ac, V5, mO, Qd, Lr, lO, ur, ro], t.slots = ["label", "info", "description", "before", "between", "after"], mt({}, nO(e, t));
  }
}, X5 = {
  name: "CheckboxgroupCheckbox",
  props: {
    item: {
      type: [Object, String, Number],
      required: !0
    },
    value: {
      type: [String, Number],
      required: !0
    },
    items: {
      type: [Object, Array],
      required: !0
    },
    index: {
      type: [Number],
      required: !0
    },
    attrs: {
      required: !1,
      type: [Object],
      default: () => ({})
    }
  },
  setup(e, t) {
    var {
      value: n,
      item: r
    } = De(e), {
      el$: i,
      form$: a,
      Size: o,
      View: s,
      classesInstance: l,
      classes: u,
      Templates: c,
      template: d,
      theme: f
    } = bi(e, t), h = N(() => {
      var g;
      return i.value.disabledItems.map((E) => String(E)).indexOf(String(n.value)) !== -1 || i.value.isDisabled || !!((g = r.value) !== null && g !== void 0 && g.disabled);
    }), m = N(() => i.value.value.indexOf(String(n.value)) !== -1 || i.value.value.indexOf(Number(n.value)) !== -1), v = N(() => "".concat(i.value.fieldId, "-").concat(n.value)), b = N(() => "".concat(i.value.path, "-").concat(n.value)), y = (g) => {
      if (["ArrowRight", "ArrowDown"].indexOf(g.key) !== -1) {
        g.preventDefault();
        var E = g.target.nextElementSibling;
        (E == null ? void 0 : E.getAttribute("role")) === "checkbox" && E.focus();
      } else if (["ArrowLeft", "ArrowUp"].indexOf(g.key) !== -1) {
        g.preventDefault();
        var S = g.target.previousElementSibling;
        (S == null ? void 0 : S.getAttribute("role")) === "checkbox" && S.focus();
      }
    };
    return {
      el$: i,
      form$: a,
      Size: o,
      View: s,
      classesInstance: l,
      classes: u,
      Templates: c,
      template: d,
      theme: f,
      isDisabled: h,
      id: v,
      name: b,
      checked: m,
      handleKeydown: y
    };
  }
}, i6e = function(t, n, r) {
  var i = r.el$, a = r.form$, o = N(() => i.value.stage > 0), s = N(() => i.value.link && i.value.clickable), l = N(() => i.value.hasUploadError), u = N(() => i.value.link), c = N(() => {
    var T = i.value.filename && typeof i.value.filename == "string" ? i.value.filename.split("\\").pop().split("/").pop() : i.value.filename;
    return T && (T = T.split("?")[0]), T;
  }), d = N(() => i.value.clickable), f = N(() => i.value.stage > 1), h = N(() => i.value.uploading), m = N(() => i.value.progress), v = N(() => (i.value.canRemove || i.value.uploading) && !i.value.isDisabled), b = N(() => i.value.canUploadTemp), y = N(() => a.value.translations.vueform.elements.file.upload), g = N(() => i.value.embed ? void 0 : i.value.labelId), E = () => {
    i.value.uploadTemp();
  }, S = () => {
    h.value ? i.value.handleAbort() : i.value.handleRemove();
  }, C = /* @__PURE__ */ function() {
    var T = ht(function* (O) {
      switch (O.key) {
        case "Backspace":
        case "Delete":
          if (S(), !i.value.canSelect)
            return;
          yield Ut(), document.querySelector("#".concat(i.value.fieldId)).focus();
          break;
        case "Enter":
          if (i.value.auto)
            return;
          E();
          break;
      }
    });
    return function(R) {
      return T.apply(this, arguments);
    };
  }();
  return {
    visible: o,
    hasLink: s,
    hasError: l,
    link: u,
    filename: c,
    clickable: d,
    uploaded: f,
    uploading: h,
    progress: m,
    canRemove: v,
    canUploadTemp: b,
    uploadText: y,
    ariaLabelledby: g,
    upload: E,
    remove: S,
    handleKeyup: C
  };
}, Z5 = {
  name: "FilePreview",
  props: {
    attrs: {
      required: !1,
      type: [Object],
      default: () => ({})
    }
  },
  setup(e, t) {
    var {
      el$: n,
      form$: r,
      Size: i,
      View: a,
      classesInstance: o,
      classes: s,
      Templates: l,
      template: u,
      theme: c
    } = bi(e, t), {
      visible: d,
      hasLink: f,
      hasError: h,
      link: m,
      filename: v,
      clickable: b,
      uploaded: y,
      uploading: g,
      progress: E,
      canRemove: S,
      canUploadTemp: C,
      uploadText: T,
      ariaLabelledby: O,
      upload: R,
      remove: D,
      handleKeyup: q
    } = i6e(e, t, {
      el$: n,
      form$: r
    }), $ = N(() => ["image", "gallery"].indexOf(n.value.View) !== -1 ? n.value.preview : null), P = N(() => {
      var L = n.value.embed && n.value.View !== "gallery" ? void 0 : v.value;
      return h.value && (L ? L += ", error" : L = "error"), L;
    }), Y = N(() => n.value.embed && n.value.View !== "gallery" || y.value || n.value.auto ? void 0 : T.value);
    return {
      el$: n,
      form$: r,
      Size: i,
      View: a,
      classesInstance: o,
      classes: s,
      Templates: l,
      template: u,
      theme: c,
      visible: d,
      hasLink: f,
      hasError: h,
      link: m,
      filename: v,
      clickable: b,
      uploaded: y,
      uploading: g,
      progress: E,
      canRemove: S,
      canUploadTemp: C,
      uploadText: T,
      preview: $,
      ariaLabelledby: O,
      ariaPlaceholder: P,
      ariaRoledescription: Y,
      upload: R,
      remove: D,
      handleKeyup: q
    };
  }
}, J5 = {
  name: "RadiogroupRadio",
  props: {
    item: {
      type: [Object, String, Number],
      required: !0
    },
    value: {
      type: [String, Number],
      required: !0
    },
    items: {
      type: [Object, Array],
      required: !0
    },
    index: {
      type: [Number],
      required: !0
    },
    attrs: {
      required: !1,
      type: [Object],
      default: () => ({})
    }
  },
  setup(e, t) {
    var {
      value: n,
      item: r
    } = De(e), {
      el$: i,
      form$: a,
      Size: o,
      View: s,
      classesInstance: l,
      classes: u,
      Templates: c,
      template: d,
      theme: f
    } = bi(e, t), h = N(() => {
      var g;
      return i.value.disabledItems.map((E) => String(E)).indexOf(String(n.value)) !== -1 || i.value.isDisabled || !!((g = r.value) !== null && g !== void 0 && g.disabled);
    }), m = N(() => i.value.value === String(n.value) || i.value.value === Number(n.value)), v = N(() => "".concat(i.value.fieldId, "-").concat(n.value)), b = N(() => i.value.path), y = (g) => {
      if (["ArrowRight", "ArrowDown"].indexOf(g.key) !== -1) {
        g.preventDefault();
        var E = g.target.nextElementSibling;
        (E == null ? void 0 : E.getAttribute("role")) === "radio" && E.focus();
      } else if (["ArrowLeft", "ArrowUp"].indexOf(g.key) !== -1) {
        g.preventDefault();
        var S = g.target.previousElementSibling;
        (S == null ? void 0 : S.getAttribute("role")) === "radio" && S.focus();
      }
    };
    return {
      el$: i,
      form$: a,
      Size: o,
      View: s,
      classesInstance: l,
      classes: u,
      Templates: c,
      template: d,
      theme: f,
      isDisabled: h,
      id: v,
      name: b,
      checked: m,
      handleKeydown: y
    };
  }
}, a6e = {
  Vueform: Fv,
  FormErrors: p8,
  FormMessages: m8,
  FormLanguages: h8,
  FormLanguage: g8,
  FormTabs: v8,
  FormTab: b8,
  FormSteps: E8,
  FormStepsControls: S8,
  FormStepsControl: y8,
  FormStep: T8,
  FormElements: JA,
  ElementLayout: C8,
  ElementLayoutInline: A8,
  ElementLoader: O8,
  ElementLabelFloating: R8,
  ElementLabel: w8,
  ElementInfo: x8,
  ElementDescription: N8,
  ElementError: D8,
  ElementMessage: I8,
  ElementText: L8,
  DragAndDrop: k8,
  ElementAddon: M8,
  DatepickerWrapper: B8,
  EditorWrapper: $8,
  ButtonElement: H8,
  CheckboxElement: X8,
  CheckboxgroupElement: e5,
  DateElement: r5,
  DatesElement: i5,
  FileElement: s5,
  GenericElement: l5,
  GroupElement: c5,
  HiddenElement: d5,
  ListElement: x5,
  LocationElement: N5,
  MultifileElement: D5,
  MultiselectElement: L5,
  ObjectElement: k5,
  RadioElement: M5,
  RadiogroupElement: P5,
  SelectElement: F5,
  SliderElement: B5,
  StaticElement: $5,
  TagsElement: U5,
  TextareaElement: G5,
  TextElement: Y5,
  ToggleElement: H5,
  EditorElement: W5,
  TTextareaElement: K5,
  TTextElement: j5,
  TEditorElement: Q5,
  CheckboxgroupCheckbox: X5,
  FilePreview: Z5,
  RadiogroupRadio: J5
}, o6e = /* @__PURE__ */ Object.freeze({
  __proto__: null,
  default: a6e,
  Vueform: Fv,
  FormErrors: p8,
  FormMessages: m8,
  FormLanguages: h8,
  FormLanguage: g8,
  FormTabs: v8,
  FormTab: b8,
  FormSteps: E8,
  FormStepsControls: S8,
  FormStepsControl: y8,
  FormStep: T8,
  FormElements: JA,
  ElementLayout: C8,
  ElementLayoutInline: A8,
  ElementLoader: O8,
  ElementLabelFloating: R8,
  ElementLabel: w8,
  ElementInfo: x8,
  ElementDescription: N8,
  ElementError: D8,
  ElementMessage: I8,
  ElementText: L8,
  DragAndDrop: k8,
  ElementAddon: M8,
  DatepickerWrapper: B8,
  EditorWrapper: $8,
  ButtonElement: H8,
  CheckboxElement: X8,
  CheckboxgroupElement: e5,
  DateElement: r5,
  DatesElement: i5,
  FileElement: s5,
  GenericElement: l5,
  GroupElement: c5,
  HiddenElement: d5,
  ListElement: x5,
  LocationElement: N5,
  MultifileElement: D5,
  MultiselectElement: L5,
  ObjectElement: k5,
  RadioElement: M5,
  RadiogroupElement: P5,
  SelectElement: F5,
  SliderElement: B5,
  StaticElement: $5,
  TagsElement: U5,
  TextareaElement: G5,
  TextElement: Y5,
  ToggleElement: H5,
  EditorElement: W5,
  TTextareaElement: K5,
  TTextElement: j5,
  TEditorElement: Q5,
  CheckboxgroupCheckbox: X5,
  FilePreview: Z5,
  RadiogroupRadio: J5
});
c8(void 0, {
  Vueform: Fv,
  FormElements: JA
});
var y_ = c8(void 0, mt({}, o6e), mt({}, IPe));
/*! js-yaml 4.1.0 https://github.com/nodeca/js-yaml @license MIT */
function eq(e) {
  return typeof e > "u" || e === null;
}
function s6e(e) {
  return typeof e == "object" && e !== null;
}
function l6e(e) {
  return Array.isArray(e) ? e : eq(e) ? [] : [e];
}
function u6e(e, t) {
  var n, r, i, a;
  if (t)
    for (a = Object.keys(t), n = 0, r = a.length; n < r; n += 1)
      i = a[n], e[i] = t[i];
  return e;
}
function c6e(e, t) {
  var n = "", r;
  for (r = 0; r < t; r += 1)
    n += e;
  return n;
}
function d6e(e) {
  return e === 0 && Number.NEGATIVE_INFINITY === 1 / e;
}
var f6e = eq, p6e = s6e, m6e = l6e, h6e = c6e, g6e = d6e, _6e = u6e, ii = {
  isNothing: f6e,
  isObject: p6e,
  toArray: m6e,
  repeat: h6e,
  isNegativeZero: g6e,
  extend: _6e
};
function tq(e, t) {
  var n = "", r = e.reason || "(unknown reason)";
  return e.mark ? (e.mark.name && (n += 'in "' + e.mark.name + '" '), n += "(" + (e.mark.line + 1) + ":" + (e.mark.column + 1) + ")", !t && e.mark.snippet && (n += `

` + e.mark.snippet), r + " " + n) : r;
}
function Hp(e, t) {
  Error.call(this), this.name = "YAMLException", this.reason = e, this.mark = t, this.message = tq(this, !1), Error.captureStackTrace ? Error.captureStackTrace(this, this.constructor) : this.stack = new Error().stack || "";
}
Hp.prototype = Object.create(Error.prototype);
Hp.prototype.constructor = Hp;
Hp.prototype.toString = function(t) {
  return this.name + ": " + tq(this, t);
};
var zi = Hp;
function qT(e, t, n, r, i) {
  var a = "", o = "", s = Math.floor(i / 2) - 1;
  return r - t > s && (a = " ... ", t = r - s + a.length), n - r > s && (o = " ...", n = r + s - o.length), {
    str: a + e.slice(t, n).replace(/\t/g, "→") + o,
    pos: r - t + a.length
    // relative position
  };
}
function GT(e, t) {
  return ii.repeat(" ", t - e.length) + e;
}
function v6e(e, t) {
  if (t = Object.create(t || null), !e.buffer) return null;
  t.maxLength || (t.maxLength = 79), typeof t.indent != "number" && (t.indent = 1), typeof t.linesBefore != "number" && (t.linesBefore = 3), typeof t.linesAfter != "number" && (t.linesAfter = 2);
  for (var n = /\r?\n|\r|\0/g, r = [0], i = [], a, o = -1; a = n.exec(e.buffer); )
    i.push(a.index), r.push(a.index + a[0].length), e.position <= a.index && o < 0 && (o = r.length - 2);
  o < 0 && (o = r.length - 1);
  var s = "", l, u, c = Math.min(e.line + t.linesAfter, i.length).toString().length, d = t.maxLength - (t.indent + c + 3);
  for (l = 1; l <= t.linesBefore && !(o - l < 0); l++)
    u = qT(
      e.buffer,
      r[o - l],
      i[o - l],
      e.position - (r[o] - r[o - l]),
      d
    ), s = ii.repeat(" ", t.indent) + GT((e.line - l + 1).toString(), c) + " | " + u.str + `
` + s;
  for (u = qT(e.buffer, r[o], i[o], e.position, d), s += ii.repeat(" ", t.indent) + GT((e.line + 1).toString(), c) + " | " + u.str + `
`, s += ii.repeat("-", t.indent + c + 3 + u.pos) + `^
`, l = 1; l <= t.linesAfter && !(o + l >= i.length); l++)
    u = qT(
      e.buffer,
      r[o + l],
      i[o + l],
      e.position - (r[o] - r[o + l]),
      d
    ), s += ii.repeat(" ", t.indent) + GT((e.line + l + 1).toString(), c) + " | " + u.str + `
`;
  return s.replace(/\n$/, "");
}
var b6e = v6e, E6e = [
  "kind",
  "multi",
  "resolve",
  "construct",
  "instanceOf",
  "predicate",
  "represent",
  "representName",
  "defaultStyle",
  "styleAliases"
], S6e = [
  "scalar",
  "sequence",
  "mapping"
];
function y6e(e) {
  var t = {};
  return e !== null && Object.keys(e).forEach(function(n) {
    e[n].forEach(function(r) {
      t[String(r)] = n;
    });
  }), t;
}
function T6e(e, t) {
  if (t = t || {}, Object.keys(t).forEach(function(n) {
    if (E6e.indexOf(n) === -1)
      throw new zi('Unknown option "' + n + '" is met in definition of "' + e + '" YAML type.');
  }), this.options = t, this.tag = e, this.kind = t.kind || null, this.resolve = t.resolve || function() {
    return !0;
  }, this.construct = t.construct || function(n) {
    return n;
  }, this.instanceOf = t.instanceOf || null, this.predicate = t.predicate || null, this.represent = t.represent || null, this.representName = t.representName || null, this.defaultStyle = t.defaultStyle || null, this.multi = t.multi || !1, this.styleAliases = y6e(t.styleAliases || null), S6e.indexOf(this.kind) === -1)
    throw new zi('Unknown kind "' + this.kind + '" is specified for "' + e + '" YAML type.');
}
var vi = T6e;
function uP(e, t) {
  var n = [];
  return e[t].forEach(function(r) {
    var i = n.length;
    n.forEach(function(a, o) {
      a.tag === r.tag && a.kind === r.kind && a.multi === r.multi && (i = o);
    }), n[i] = r;
  }), n;
}
function C6e() {
  var e = {
    scalar: {},
    sequence: {},
    mapping: {},
    fallback: {},
    multi: {
      scalar: [],
      sequence: [],
      mapping: [],
      fallback: []
    }
  }, t, n;
  function r(i) {
    i.multi ? (e.multi[i.kind].push(i), e.multi.fallback.push(i)) : e[i.kind][i.tag] = e.fallback[i.tag] = i;
  }
  for (t = 0, n = arguments.length; t < n; t += 1)
    arguments[t].forEach(r);
  return e;
}
function QC(e) {
  return this.extend(e);
}
QC.prototype.extend = function(t) {
  var n = [], r = [];
  if (t instanceof vi)
    r.push(t);
  else if (Array.isArray(t))
    r = r.concat(t);
  else if (t && (Array.isArray(t.implicit) || Array.isArray(t.explicit)))
    t.implicit && (n = n.concat(t.implicit)), t.explicit && (r = r.concat(t.explicit));
  else
    throw new zi("Schema.extend argument should be a Type, [ Type ], or a schema definition ({ implicit: [...], explicit: [...] })");
  n.forEach(function(a) {
    if (!(a instanceof vi))
      throw new zi("Specified list of YAML types (or a single Type object) contains a non-Type object.");
    if (a.loadKind && a.loadKind !== "scalar")
      throw new zi("There is a non-scalar type in the implicit list of a schema. Implicit resolving of such types is not supported.");
    if (a.multi)
      throw new zi("There is a multi type in the implicit list of a schema. Multi tags can only be listed as explicit.");
  }), r.forEach(function(a) {
    if (!(a instanceof vi))
      throw new zi("Specified list of YAML types (or a single Type object) contains a non-Type object.");
  });
  var i = Object.create(QC.prototype);
  return i.implicit = (this.implicit || []).concat(n), i.explicit = (this.explicit || []).concat(r), i.compiledImplicit = uP(i, "implicit"), i.compiledExplicit = uP(i, "explicit"), i.compiledTypeMap = C6e(i.compiledImplicit, i.compiledExplicit), i;
};
var nq = QC, rq = new vi("tag:yaml.org,2002:str", {
  kind: "scalar",
  construct: function(e) {
    return e !== null ? e : "";
  }
}), iq = new vi("tag:yaml.org,2002:seq", {
  kind: "sequence",
  construct: function(e) {
    return e !== null ? e : [];
  }
}), aq = new vi("tag:yaml.org,2002:map", {
  kind: "mapping",
  construct: function(e) {
    return e !== null ? e : {};
  }
}), oq = new nq({
  explicit: [
    rq,
    iq,
    aq
  ]
});
function A6e(e) {
  if (e === null) return !0;
  var t = e.length;
  return t === 1 && e === "~" || t === 4 && (e === "null" || e === "Null" || e === "NULL");
}
function O6e() {
  return null;
}
function R6e(e) {
  return e === null;
}
var sq = new vi("tag:yaml.org,2002:null", {
  kind: "scalar",
  resolve: A6e,
  construct: O6e,
  predicate: R6e,
  represent: {
    canonical: function() {
      return "~";
    },
    lowercase: function() {
      return "null";
    },
    uppercase: function() {
      return "NULL";
    },
    camelcase: function() {
      return "Null";
    },
    empty: function() {
      return "";
    }
  },
  defaultStyle: "lowercase"
});
function w6e(e) {
  if (e === null) return !1;
  var t = e.length;
  return t === 4 && (e === "true" || e === "True" || e === "TRUE") || t === 5 && (e === "false" || e === "False" || e === "FALSE");
}
function x6e(e) {
  return e === "true" || e === "True" || e === "TRUE";
}
function N6e(e) {
  return Object.prototype.toString.call(e) === "[object Boolean]";
}
var lq = new vi("tag:yaml.org,2002:bool", {
  kind: "scalar",
  resolve: w6e,
  construct: x6e,
  predicate: N6e,
  represent: {
    lowercase: function(e) {
      return e ? "true" : "false";
    },
    uppercase: function(e) {
      return e ? "TRUE" : "FALSE";
    },
    camelcase: function(e) {
      return e ? "True" : "False";
    }
  },
  defaultStyle: "lowercase"
});
function D6e(e) {
  return 48 <= e && e <= 57 || 65 <= e && e <= 70 || 97 <= e && e <= 102;
}
function I6e(e) {
  return 48 <= e && e <= 55;
}
function L6e(e) {
  return 48 <= e && e <= 57;
}
function k6e(e) {
  if (e === null) return !1;
  var t = e.length, n = 0, r = !1, i;
  if (!t) return !1;
  if (i = e[n], (i === "-" || i === "+") && (i = e[++n]), i === "0") {
    if (n + 1 === t) return !0;
    if (i = e[++n], i === "b") {
      for (n++; n < t; n++)
        if (i = e[n], i !== "_") {
          if (i !== "0" && i !== "1") return !1;
          r = !0;
        }
      return r && i !== "_";
    }
    if (i === "x") {
      for (n++; n < t; n++)
        if (i = e[n], i !== "_") {
          if (!D6e(e.charCodeAt(n))) return !1;
          r = !0;
        }
      return r && i !== "_";
    }
    if (i === "o") {
      for (n++; n < t; n++)
        if (i = e[n], i !== "_") {
          if (!I6e(e.charCodeAt(n))) return !1;
          r = !0;
        }
      return r && i !== "_";
    }
  }
  if (i === "_") return !1;
  for (; n < t; n++)
    if (i = e[n], i !== "_") {
      if (!L6e(e.charCodeAt(n)))
        return !1;
      r = !0;
    }
  return !(!r || i === "_");
}
function M6e(e) {
  var t = e, n = 1, r;
  if (t.indexOf("_") !== -1 && (t = t.replace(/_/g, "")), r = t[0], (r === "-" || r === "+") && (r === "-" && (n = -1), t = t.slice(1), r = t[0]), t === "0") return 0;
  if (r === "0") {
    if (t[1] === "b") return n * parseInt(t.slice(2), 2);
    if (t[1] === "x") return n * parseInt(t.slice(2), 16);
    if (t[1] === "o") return n * parseInt(t.slice(2), 8);
  }
  return n * parseInt(t, 10);
}
function P6e(e) {
  return Object.prototype.toString.call(e) === "[object Number]" && e % 1 === 0 && !ii.isNegativeZero(e);
}
var uq = new vi("tag:yaml.org,2002:int", {
  kind: "scalar",
  resolve: k6e,
  construct: M6e,
  predicate: P6e,
  represent: {
    binary: function(e) {
      return e >= 0 ? "0b" + e.toString(2) : "-0b" + e.toString(2).slice(1);
    },
    octal: function(e) {
      return e >= 0 ? "0o" + e.toString(8) : "-0o" + e.toString(8).slice(1);
    },
    decimal: function(e) {
      return e.toString(10);
    },
    /* eslint-disable max-len */
    hexadecimal: function(e) {
      return e >= 0 ? "0x" + e.toString(16).toUpperCase() : "-0x" + e.toString(16).toUpperCase().slice(1);
    }
  },
  defaultStyle: "decimal",
  styleAliases: {
    binary: [2, "bin"],
    octal: [8, "oct"],
    decimal: [10, "dec"],
    hexadecimal: [16, "hex"]
  }
}), F6e = new RegExp(
  // 2.5e4, 2.5 and integers
  "^(?:[-+]?(?:[0-9][0-9_]*)(?:\\.[0-9_]*)?(?:[eE][-+]?[0-9]+)?|\\.[0-9_]+(?:[eE][-+]?[0-9]+)?|[-+]?\\.(?:inf|Inf|INF)|\\.(?:nan|NaN|NAN))$"
);
function B6e(e) {
  return !(e === null || !F6e.test(e) || // Quick hack to not allow integers end with `_`
  // Probably should update regexp & check speed
  e[e.length - 1] === "_");
}
function $6e(e) {
  var t, n;
  return t = e.replace(/_/g, "").toLowerCase(), n = t[0] === "-" ? -1 : 1, "+-".indexOf(t[0]) >= 0 && (t = t.slice(1)), t === ".inf" ? n === 1 ? Number.POSITIVE_INFINITY : Number.NEGATIVE_INFINITY : t === ".nan" ? NaN : n * parseFloat(t, 10);
}
var U6e = /^[-+]?[0-9]+e/;
function q6e(e, t) {
  var n;
  if (isNaN(e))
    switch (t) {
      case "lowercase":
        return ".nan";
      case "uppercase":
        return ".NAN";
      case "camelcase":
        return ".NaN";
    }
  else if (Number.POSITIVE_INFINITY === e)
    switch (t) {
      case "lowercase":
        return ".inf";
      case "uppercase":
        return ".INF";
      case "camelcase":
        return ".Inf";
    }
  else if (Number.NEGATIVE_INFINITY === e)
    switch (t) {
      case "lowercase":
        return "-.inf";
      case "uppercase":
        return "-.INF";
      case "camelcase":
        return "-.Inf";
    }
  else if (ii.isNegativeZero(e))
    return "-0.0";
  return n = e.toString(10), U6e.test(n) ? n.replace("e", ".e") : n;
}
function G6e(e) {
  return Object.prototype.toString.call(e) === "[object Number]" && (e % 1 !== 0 || ii.isNegativeZero(e));
}
var cq = new vi("tag:yaml.org,2002:float", {
  kind: "scalar",
  resolve: B6e,
  construct: $6e,
  predicate: G6e,
  represent: q6e,
  defaultStyle: "lowercase"
}), dq = oq.extend({
  implicit: [
    sq,
    lq,
    uq,
    cq
  ]
}), fq = dq, pq = new RegExp(
  "^([0-9][0-9][0-9][0-9])-([0-9][0-9])-([0-9][0-9])$"
), mq = new RegExp(
  "^([0-9][0-9][0-9][0-9])-([0-9][0-9]?)-([0-9][0-9]?)(?:[Tt]|[ \\t]+)([0-9][0-9]?):([0-9][0-9]):([0-9][0-9])(?:\\.([0-9]*))?(?:[ \\t]*(Z|([-+])([0-9][0-9]?)(?::([0-9][0-9]))?))?$"
);
function Y6e(e) {
  return e === null ? !1 : pq.exec(e) !== null || mq.exec(e) !== null;
}
function H6e(e) {
  var t, n, r, i, a, o, s, l = 0, u = null, c, d, f;
  if (t = pq.exec(e), t === null && (t = mq.exec(e)), t === null) throw new Error("Date resolve error");
  if (n = +t[1], r = +t[2] - 1, i = +t[3], !t[4])
    return new Date(Date.UTC(n, r, i));
  if (a = +t[4], o = +t[5], s = +t[6], t[7]) {
    for (l = t[7].slice(0, 3); l.length < 3; )
      l += "0";
    l = +l;
  }
  return t[9] && (c = +t[10], d = +(t[11] || 0), u = (c * 60 + d) * 6e4, t[9] === "-" && (u = -u)), f = new Date(Date.UTC(n, r, i, a, o, s, l)), u && f.setTime(f.getTime() - u), f;
}
function z6e(e) {
  return e.toISOString();
}
var hq = new vi("tag:yaml.org,2002:timestamp", {
  kind: "scalar",
  resolve: Y6e,
  construct: H6e,
  instanceOf: Date,
  represent: z6e
});
function V6e(e) {
  return e === "<<" || e === null;
}
var gq = new vi("tag:yaml.org,2002:merge", {
  kind: "scalar",
  resolve: V6e
}), SO = `ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/=
\r`;
function W6e(e) {
  if (e === null) return !1;
  var t, n, r = 0, i = e.length, a = SO;
  for (n = 0; n < i; n++)
    if (t = a.indexOf(e.charAt(n)), !(t > 64)) {
      if (t < 0) return !1;
      r += 6;
    }
  return r % 8 === 0;
}
function K6e(e) {
  var t, n, r = e.replace(/[\r\n=]/g, ""), i = r.length, a = SO, o = 0, s = [];
  for (t = 0; t < i; t++)
    t % 4 === 0 && t && (s.push(o >> 16 & 255), s.push(o >> 8 & 255), s.push(o & 255)), o = o << 6 | a.indexOf(r.charAt(t));
  return n = i % 4 * 6, n === 0 ? (s.push(o >> 16 & 255), s.push(o >> 8 & 255), s.push(o & 255)) : n === 18 ? (s.push(o >> 10 & 255), s.push(o >> 2 & 255)) : n === 12 && s.push(o >> 4 & 255), new Uint8Array(s);
}
function j6e(e) {
  var t = "", n = 0, r, i, a = e.length, o = SO;
  for (r = 0; r < a; r++)
    r % 3 === 0 && r && (t += o[n >> 18 & 63], t += o[n >> 12 & 63], t += o[n >> 6 & 63], t += o[n & 63]), n = (n << 8) + e[r];
  return i = a % 3, i === 0 ? (t += o[n >> 18 & 63], t += o[n >> 12 & 63], t += o[n >> 6 & 63], t += o[n & 63]) : i === 2 ? (t += o[n >> 10 & 63], t += o[n >> 4 & 63], t += o[n << 2 & 63], t += o[64]) : i === 1 && (t += o[n >> 2 & 63], t += o[n << 4 & 63], t += o[64], t += o[64]), t;
}
function Q6e(e) {
  return Object.prototype.toString.call(e) === "[object Uint8Array]";
}
var _q = new vi("tag:yaml.org,2002:binary", {
  kind: "scalar",
  resolve: W6e,
  construct: K6e,
  predicate: Q6e,
  represent: j6e
}), X6e = Object.prototype.hasOwnProperty, Z6e = Object.prototype.toString;
function J6e(e) {
  if (e === null) return !0;
  var t = [], n, r, i, a, o, s = e;
  for (n = 0, r = s.length; n < r; n += 1) {
    if (i = s[n], o = !1, Z6e.call(i) !== "[object Object]") return !1;
    for (a in i)
      if (X6e.call(i, a))
        if (!o) o = !0;
        else return !1;
    if (!o) return !1;
    if (t.indexOf(a) === -1) t.push(a);
    else return !1;
  }
  return !0;
}
function e4e(e) {
  return e !== null ? e : [];
}
var vq = new vi("tag:yaml.org,2002:omap", {
  kind: "sequence",
  resolve: J6e,
  construct: e4e
}), t4e = Object.prototype.toString;
function n4e(e) {
  if (e === null) return !0;
  var t, n, r, i, a, o = e;
  for (a = new Array(o.length), t = 0, n = o.length; t < n; t += 1) {
    if (r = o[t], t4e.call(r) !== "[object Object]" || (i = Object.keys(r), i.length !== 1)) return !1;
    a[t] = [i[0], r[i[0]]];
  }
  return !0;
}
function r4e(e) {
  if (e === null) return [];
  var t, n, r, i, a, o = e;
  for (a = new Array(o.length), t = 0, n = o.length; t < n; t += 1)
    r = o[t], i = Object.keys(r), a[t] = [i[0], r[i[0]]];
  return a;
}
var bq = new vi("tag:yaml.org,2002:pairs", {
  kind: "sequence",
  resolve: n4e,
  construct: r4e
}), i4e = Object.prototype.hasOwnProperty;
function a4e(e) {
  if (e === null) return !0;
  var t, n = e;
  for (t in n)
    if (i4e.call(n, t) && n[t] !== null)
      return !1;
  return !0;
}
function o4e(e) {
  return e !== null ? e : {};
}
var Eq = new vi("tag:yaml.org,2002:set", {
  kind: "mapping",
  resolve: a4e,
  construct: o4e
}), yO = fq.extend({
  implicit: [
    hq,
    gq
  ],
  explicit: [
    _q,
    vq,
    bq,
    Eq
  ]
}), Gl = Object.prototype.hasOwnProperty, T_ = 1, Sq = 2, yq = 3, C_ = 4, YT = 1, s4e = 2, cP = 3, l4e = /[\x00-\x08\x0B\x0C\x0E-\x1F\x7F-\x84\x86-\x9F\uFFFE\uFFFF]|[\uD800-\uDBFF](?![\uDC00-\uDFFF])|(?:[^\uD800-\uDBFF]|^)[\uDC00-\uDFFF]/, u4e = /[\x85\u2028\u2029]/, c4e = /[,\[\]\{\}]/, Tq = /^(?:!|!!|![a-z\-]+!)$/i, Cq = /^(?:!|[^,\[\]\{\}])(?:%[0-9a-f]{2}|[0-9a-z\-#;\/\?:@&=\+\$,_\.!~\*'\(\)\[\]])*$/i;
function dP(e) {
  return Object.prototype.toString.call(e);
}
function Vo(e) {
  return e === 10 || e === 13;
}
function Uu(e) {
  return e === 9 || e === 32;
}
function ca(e) {
  return e === 9 || e === 32 || e === 10 || e === 13;
}
function Kc(e) {
  return e === 44 || e === 91 || e === 93 || e === 123 || e === 125;
}
function d4e(e) {
  var t;
  return 48 <= e && e <= 57 ? e - 48 : (t = e | 32, 97 <= t && t <= 102 ? t - 97 + 10 : -1);
}
function f4e(e) {
  return e === 120 ? 2 : e === 117 ? 4 : e === 85 ? 8 : 0;
}
function p4e(e) {
  return 48 <= e && e <= 57 ? e - 48 : -1;
}
function fP(e) {
  return e === 48 ? "\0" : e === 97 ? "\x07" : e === 98 ? "\b" : e === 116 || e === 9 ? "	" : e === 110 ? `
` : e === 118 ? "\v" : e === 102 ? "\f" : e === 114 ? "\r" : e === 101 ? "\x1B" : e === 32 ? " " : e === 34 ? '"' : e === 47 ? "/" : e === 92 ? "\\" : e === 78 ? "" : e === 95 ? " " : e === 76 ? "\u2028" : e === 80 ? "\u2029" : "";
}
function m4e(e) {
  return e <= 65535 ? String.fromCharCode(e) : String.fromCharCode(
    (e - 65536 >> 10) + 55296,
    (e - 65536 & 1023) + 56320
  );
}
var Aq = new Array(256), Oq = new Array(256);
for (var Lc = 0; Lc < 256; Lc++)
  Aq[Lc] = fP(Lc) ? 1 : 0, Oq[Lc] = fP(Lc);
function h4e(e, t) {
  this.input = e, this.filename = t.filename || null, this.schema = t.schema || yO, this.onWarning = t.onWarning || null, this.legacy = t.legacy || !1, this.json = t.json || !1, this.listener = t.listener || null, this.implicitTypes = this.schema.compiledImplicit, this.typeMap = this.schema.compiledTypeMap, this.length = e.length, this.position = 0, this.line = 0, this.lineStart = 0, this.lineIndent = 0, this.firstTabInLine = -1, this.documents = [];
}
function Rq(e, t) {
  var n = {
    name: e.filename,
    buffer: e.input.slice(0, -1),
    // omit trailing \0
    position: e.position,
    line: e.line,
    column: e.position - e.lineStart
  };
  return n.snippet = b6e(n), new zi(t, n);
}
function Dt(e, t) {
  throw Rq(e, t);
}
function A_(e, t) {
  e.onWarning && e.onWarning.call(null, Rq(e, t));
}
var pP = {
  YAML: function(t, n, r) {
    var i, a, o;
    t.version !== null && Dt(t, "duplication of %YAML directive"), r.length !== 1 && Dt(t, "YAML directive accepts exactly one argument"), i = /^([0-9]+)\.([0-9]+)$/.exec(r[0]), i === null && Dt(t, "ill-formed argument of the YAML directive"), a = parseInt(i[1], 10), o = parseInt(i[2], 10), a !== 1 && Dt(t, "unacceptable YAML version of the document"), t.version = r[0], t.checkLineBreaks = o < 2, o !== 1 && o !== 2 && A_(t, "unsupported YAML version of the document");
  },
  TAG: function(t, n, r) {
    var i, a;
    r.length !== 2 && Dt(t, "TAG directive accepts exactly two arguments"), i = r[0], a = r[1], Tq.test(i) || Dt(t, "ill-formed tag handle (first argument) of the TAG directive"), Gl.call(t.tagMap, i) && Dt(t, 'there is a previously declared suffix for "' + i + '" tag handle'), Cq.test(a) || Dt(t, "ill-formed tag prefix (second argument) of the TAG directive");
    try {
      a = decodeURIComponent(a);
    } catch {
      Dt(t, "tag prefix is malformed: " + a);
    }
    t.tagMap[i] = a;
  }
};
function Pl(e, t, n, r) {
  var i, a, o, s;
  if (t < n) {
    if (s = e.input.slice(t, n), r)
      for (i = 0, a = s.length; i < a; i += 1)
        o = s.charCodeAt(i), o === 9 || 32 <= o && o <= 1114111 || Dt(e, "expected valid JSON character");
    else l4e.test(s) && Dt(e, "the stream contains non-printable characters");
    e.result += s;
  }
}
function mP(e, t, n, r) {
  var i, a, o, s;
  for (ii.isObject(n) || Dt(e, "cannot merge mappings; the provided source object is unacceptable"), i = Object.keys(n), o = 0, s = i.length; o < s; o += 1)
    a = i[o], Gl.call(t, a) || (t[a] = n[a], r[a] = !0);
}
function jc(e, t, n, r, i, a, o, s, l) {
  var u, c;
  if (Array.isArray(i))
    for (i = Array.prototype.slice.call(i), u = 0, c = i.length; u < c; u += 1)
      Array.isArray(i[u]) && Dt(e, "nested arrays are not supported inside keys"), typeof i == "object" && dP(i[u]) === "[object Object]" && (i[u] = "[object Object]");
  if (typeof i == "object" && dP(i) === "[object Object]" && (i = "[object Object]"), i = String(i), t === null && (t = {}), r === "tag:yaml.org,2002:merge")
    if (Array.isArray(a))
      for (u = 0, c = a.length; u < c; u += 1)
        mP(e, t, a[u], n);
    else
      mP(e, t, a, n);
  else
    !e.json && !Gl.call(n, i) && Gl.call(t, i) && (e.line = o || e.line, e.lineStart = s || e.lineStart, e.position = l || e.position, Dt(e, "duplicated mapping key")), i === "__proto__" ? Object.defineProperty(t, i, {
      configurable: !0,
      enumerable: !0,
      writable: !0,
      value: a
    }) : t[i] = a, delete n[i];
  return t;
}
function TO(e) {
  var t;
  t = e.input.charCodeAt(e.position), t === 10 ? e.position++ : t === 13 ? (e.position++, e.input.charCodeAt(e.position) === 10 && e.position++) : Dt(e, "a line break is expected"), e.line += 1, e.lineStart = e.position, e.firstTabInLine = -1;
}
function Xr(e, t, n) {
  for (var r = 0, i = e.input.charCodeAt(e.position); i !== 0; ) {
    for (; Uu(i); )
      i === 9 && e.firstTabInLine === -1 && (e.firstTabInLine = e.position), i = e.input.charCodeAt(++e.position);
    if (t && i === 35)
      do
        i = e.input.charCodeAt(++e.position);
      while (i !== 10 && i !== 13 && i !== 0);
    if (Vo(i))
      for (TO(e), i = e.input.charCodeAt(e.position), r++, e.lineIndent = 0; i === 32; )
        e.lineIndent++, i = e.input.charCodeAt(++e.position);
    else
      break;
  }
  return n !== -1 && r !== 0 && e.lineIndent < n && A_(e, "deficient indentation"), r;
}
function Wv(e) {
  var t = e.position, n;
  return n = e.input.charCodeAt(t), !!((n === 45 || n === 46) && n === e.input.charCodeAt(t + 1) && n === e.input.charCodeAt(t + 2) && (t += 3, n = e.input.charCodeAt(t), n === 0 || ca(n)));
}
function CO(e, t) {
  t === 1 ? e.result += " " : t > 1 && (e.result += ii.repeat(`
`, t - 1));
}
function g4e(e, t, n) {
  var r, i, a, o, s, l, u, c, d = e.kind, f = e.result, h;
  if (h = e.input.charCodeAt(e.position), ca(h) || Kc(h) || h === 35 || h === 38 || h === 42 || h === 33 || h === 124 || h === 62 || h === 39 || h === 34 || h === 37 || h === 64 || h === 96 || (h === 63 || h === 45) && (i = e.input.charCodeAt(e.position + 1), ca(i) || n && Kc(i)))
    return !1;
  for (e.kind = "scalar", e.result = "", a = o = e.position, s = !1; h !== 0; ) {
    if (h === 58) {
      if (i = e.input.charCodeAt(e.position + 1), ca(i) || n && Kc(i))
        break;
    } else if (h === 35) {
      if (r = e.input.charCodeAt(e.position - 1), ca(r))
        break;
    } else {
      if (e.position === e.lineStart && Wv(e) || n && Kc(h))
        break;
      if (Vo(h))
        if (l = e.line, u = e.lineStart, c = e.lineIndent, Xr(e, !1, -1), e.lineIndent >= t) {
          s = !0, h = e.input.charCodeAt(e.position);
          continue;
        } else {
          e.position = o, e.line = l, e.lineStart = u, e.lineIndent = c;
          break;
        }
    }
    s && (Pl(e, a, o, !1), CO(e, e.line - l), a = o = e.position, s = !1), Uu(h) || (o = e.position + 1), h = e.input.charCodeAt(++e.position);
  }
  return Pl(e, a, o, !1), e.result ? !0 : (e.kind = d, e.result = f, !1);
}
function _4e(e, t) {
  var n, r, i;
  if (n = e.input.charCodeAt(e.position), n !== 39)
    return !1;
  for (e.kind = "scalar", e.result = "", e.position++, r = i = e.position; (n = e.input.charCodeAt(e.position)) !== 0; )
    if (n === 39)
      if (Pl(e, r, e.position, !0), n = e.input.charCodeAt(++e.position), n === 39)
        r = e.position, e.position++, i = e.position;
      else
        return !0;
    else Vo(n) ? (Pl(e, r, i, !0), CO(e, Xr(e, !1, t)), r = i = e.position) : e.position === e.lineStart && Wv(e) ? Dt(e, "unexpected end of the document within a single quoted scalar") : (e.position++, i = e.position);
  Dt(e, "unexpected end of the stream within a single quoted scalar");
}
function v4e(e, t) {
  var n, r, i, a, o, s;
  if (s = e.input.charCodeAt(e.position), s !== 34)
    return !1;
  for (e.kind = "scalar", e.result = "", e.position++, n = r = e.position; (s = e.input.charCodeAt(e.position)) !== 0; ) {
    if (s === 34)
      return Pl(e, n, e.position, !0), e.position++, !0;
    if (s === 92) {
      if (Pl(e, n, e.position, !0), s = e.input.charCodeAt(++e.position), Vo(s))
        Xr(e, !1, t);
      else if (s < 256 && Aq[s])
        e.result += Oq[s], e.position++;
      else if ((o = f4e(s)) > 0) {
        for (i = o, a = 0; i > 0; i--)
          s = e.input.charCodeAt(++e.position), (o = d4e(s)) >= 0 ? a = (a << 4) + o : Dt(e, "expected hexadecimal character");
        e.result += m4e(a), e.position++;
      } else
        Dt(e, "unknown escape sequence");
      n = r = e.position;
    } else Vo(s) ? (Pl(e, n, r, !0), CO(e, Xr(e, !1, t)), n = r = e.position) : e.position === e.lineStart && Wv(e) ? Dt(e, "unexpected end of the document within a double quoted scalar") : (e.position++, r = e.position);
  }
  Dt(e, "unexpected end of the stream within a double quoted scalar");
}
function b4e(e, t) {
  var n = !0, r, i, a, o = e.tag, s, l = e.anchor, u, c, d, f, h, m = /* @__PURE__ */ Object.create(null), v, b, y, g;
  if (g = e.input.charCodeAt(e.position), g === 91)
    c = 93, h = !1, s = [];
  else if (g === 123)
    c = 125, h = !0, s = {};
  else
    return !1;
  for (e.anchor !== null && (e.anchorMap[e.anchor] = s), g = e.input.charCodeAt(++e.position); g !== 0; ) {
    if (Xr(e, !0, t), g = e.input.charCodeAt(e.position), g === c)
      return e.position++, e.tag = o, e.anchor = l, e.kind = h ? "mapping" : "sequence", e.result = s, !0;
    n ? g === 44 && Dt(e, "expected the node content, but found ','") : Dt(e, "missed comma between flow collection entries"), b = v = y = null, d = f = !1, g === 63 && (u = e.input.charCodeAt(e.position + 1), ca(u) && (d = f = !0, e.position++, Xr(e, !0, t))), r = e.line, i = e.lineStart, a = e.position, vd(e, t, T_, !1, !0), b = e.tag, v = e.result, Xr(e, !0, t), g = e.input.charCodeAt(e.position), (f || e.line === r) && g === 58 && (d = !0, g = e.input.charCodeAt(++e.position), Xr(e, !0, t), vd(e, t, T_, !1, !0), y = e.result), h ? jc(e, s, m, b, v, y, r, i, a) : d ? s.push(jc(e, null, m, b, v, y, r, i, a)) : s.push(v), Xr(e, !0, t), g = e.input.charCodeAt(e.position), g === 44 ? (n = !0, g = e.input.charCodeAt(++e.position)) : n = !1;
  }
  Dt(e, "unexpected end of the stream within a flow collection");
}
function E4e(e, t) {
  var n, r, i = YT, a = !1, o = !1, s = t, l = 0, u = !1, c, d;
  if (d = e.input.charCodeAt(e.position), d === 124)
    r = !1;
  else if (d === 62)
    r = !0;
  else
    return !1;
  for (e.kind = "scalar", e.result = ""; d !== 0; )
    if (d = e.input.charCodeAt(++e.position), d === 43 || d === 45)
      YT === i ? i = d === 43 ? cP : s4e : Dt(e, "repeat of a chomping mode identifier");
    else if ((c = p4e(d)) >= 0)
      c === 0 ? Dt(e, "bad explicit indentation width of a block scalar; it cannot be less than one") : o ? Dt(e, "repeat of an indentation width identifier") : (s = t + c - 1, o = !0);
    else
      break;
  if (Uu(d)) {
    do
      d = e.input.charCodeAt(++e.position);
    while (Uu(d));
    if (d === 35)
      do
        d = e.input.charCodeAt(++e.position);
      while (!Vo(d) && d !== 0);
  }
  for (; d !== 0; ) {
    for (TO(e), e.lineIndent = 0, d = e.input.charCodeAt(e.position); (!o || e.lineIndent < s) && d === 32; )
      e.lineIndent++, d = e.input.charCodeAt(++e.position);
    if (!o && e.lineIndent > s && (s = e.lineIndent), Vo(d)) {
      l++;
      continue;
    }
    if (e.lineIndent < s) {
      i === cP ? e.result += ii.repeat(`
`, a ? 1 + l : l) : i === YT && a && (e.result += `
`);
      break;
    }
    for (r ? Uu(d) ? (u = !0, e.result += ii.repeat(`
`, a ? 1 + l : l)) : u ? (u = !1, e.result += ii.repeat(`
`, l + 1)) : l === 0 ? a && (e.result += " ") : e.result += ii.repeat(`
`, l) : e.result += ii.repeat(`
`, a ? 1 + l : l), a = !0, o = !0, l = 0, n = e.position; !Vo(d) && d !== 0; )
      d = e.input.charCodeAt(++e.position);
    Pl(e, n, e.position, !1);
  }
  return !0;
}
function hP(e, t) {
  var n, r = e.tag, i = e.anchor, a = [], o, s = !1, l;
  if (e.firstTabInLine !== -1) return !1;
  for (e.anchor !== null && (e.anchorMap[e.anchor] = a), l = e.input.charCodeAt(e.position); l !== 0 && (e.firstTabInLine !== -1 && (e.position = e.firstTabInLine, Dt(e, "tab characters must not be used in indentation")), !(l !== 45 || (o = e.input.charCodeAt(e.position + 1), !ca(o)))); ) {
    if (s = !0, e.position++, Xr(e, !0, -1) && e.lineIndent <= t) {
      a.push(null), l = e.input.charCodeAt(e.position);
      continue;
    }
    if (n = e.line, vd(e, t, yq, !1, !0), a.push(e.result), Xr(e, !0, -1), l = e.input.charCodeAt(e.position), (e.line === n || e.lineIndent > t) && l !== 0)
      Dt(e, "bad indentation of a sequence entry");
    else if (e.lineIndent < t)
      break;
  }
  return s ? (e.tag = r, e.anchor = i, e.kind = "sequence", e.result = a, !0) : !1;
}
function S4e(e, t, n) {
  var r, i, a, o, s, l, u = e.tag, c = e.anchor, d = {}, f = /* @__PURE__ */ Object.create(null), h = null, m = null, v = null, b = !1, y = !1, g;
  if (e.firstTabInLine !== -1) return !1;
  for (e.anchor !== null && (e.anchorMap[e.anchor] = d), g = e.input.charCodeAt(e.position); g !== 0; ) {
    if (!b && e.firstTabInLine !== -1 && (e.position = e.firstTabInLine, Dt(e, "tab characters must not be used in indentation")), r = e.input.charCodeAt(e.position + 1), a = e.line, (g === 63 || g === 58) && ca(r))
      g === 63 ? (b && (jc(e, d, f, h, m, null, o, s, l), h = m = v = null), y = !0, b = !0, i = !0) : b ? (b = !1, i = !0) : Dt(e, "incomplete explicit mapping pair; a key node is missed; or followed by a non-tabulated empty line"), e.position += 1, g = r;
    else {
      if (o = e.line, s = e.lineStart, l = e.position, !vd(e, n, Sq, !1, !0))
        break;
      if (e.line === a) {
        for (g = e.input.charCodeAt(e.position); Uu(g); )
          g = e.input.charCodeAt(++e.position);
        if (g === 58)
          g = e.input.charCodeAt(++e.position), ca(g) || Dt(e, "a whitespace character is expected after the key-value separator within a block mapping"), b && (jc(e, d, f, h, m, null, o, s, l), h = m = v = null), y = !0, b = !1, i = !1, h = e.tag, m = e.result;
        else if (y)
          Dt(e, "can not read an implicit mapping pair; a colon is missed");
        else
          return e.tag = u, e.anchor = c, !0;
      } else if (y)
        Dt(e, "can not read a block mapping entry; a multiline key may not be an implicit key");
      else
        return e.tag = u, e.anchor = c, !0;
    }
    if ((e.line === a || e.lineIndent > t) && (b && (o = e.line, s = e.lineStart, l = e.position), vd(e, t, C_, !0, i) && (b ? m = e.result : v = e.result), b || (jc(e, d, f, h, m, v, o, s, l), h = m = v = null), Xr(e, !0, -1), g = e.input.charCodeAt(e.position)), (e.line === a || e.lineIndent > t) && g !== 0)
      Dt(e, "bad indentation of a mapping entry");
    else if (e.lineIndent < t)
      break;
  }
  return b && jc(e, d, f, h, m, null, o, s, l), y && (e.tag = u, e.anchor = c, e.kind = "mapping", e.result = d), y;
}
function y4e(e) {
  var t, n = !1, r = !1, i, a, o;
  if (o = e.input.charCodeAt(e.position), o !== 33) return !1;
  if (e.tag !== null && Dt(e, "duplication of a tag property"), o = e.input.charCodeAt(++e.position), o === 60 ? (n = !0, o = e.input.charCodeAt(++e.position)) : o === 33 ? (r = !0, i = "!!", o = e.input.charCodeAt(++e.position)) : i = "!", t = e.position, n) {
    do
      o = e.input.charCodeAt(++e.position);
    while (o !== 0 && o !== 62);
    e.position < e.length ? (a = e.input.slice(t, e.position), o = e.input.charCodeAt(++e.position)) : Dt(e, "unexpected end of the stream within a verbatim tag");
  } else {
    for (; o !== 0 && !ca(o); )
      o === 33 && (r ? Dt(e, "tag suffix cannot contain exclamation marks") : (i = e.input.slice(t - 1, e.position + 1), Tq.test(i) || Dt(e, "named tag handle cannot contain such characters"), r = !0, t = e.position + 1)), o = e.input.charCodeAt(++e.position);
    a = e.input.slice(t, e.position), c4e.test(a) && Dt(e, "tag suffix cannot contain flow indicator characters");
  }
  a && !Cq.test(a) && Dt(e, "tag name cannot contain such characters: " + a);
  try {
    a = decodeURIComponent(a);
  } catch {
    Dt(e, "tag name is malformed: " + a);
  }
  return n ? e.tag = a : Gl.call(e.tagMap, i) ? e.tag = e.tagMap[i] + a : i === "!" ? e.tag = "!" + a : i === "!!" ? e.tag = "tag:yaml.org,2002:" + a : Dt(e, 'undeclared tag handle "' + i + '"'), !0;
}
function T4e(e) {
  var t, n;
  if (n = e.input.charCodeAt(e.position), n !== 38) return !1;
  for (e.anchor !== null && Dt(e, "duplication of an anchor property"), n = e.input.charCodeAt(++e.position), t = e.position; n !== 0 && !ca(n) && !Kc(n); )
    n = e.input.charCodeAt(++e.position);
  return e.position === t && Dt(e, "name of an anchor node must contain at least one character"), e.anchor = e.input.slice(t, e.position), !0;
}
function C4e(e) {
  var t, n, r;
  if (r = e.input.charCodeAt(e.position), r !== 42) return !1;
  for (r = e.input.charCodeAt(++e.position), t = e.position; r !== 0 && !ca(r) && !Kc(r); )
    r = e.input.charCodeAt(++e.position);
  return e.position === t && Dt(e, "name of an alias node must contain at least one character"), n = e.input.slice(t, e.position), Gl.call(e.anchorMap, n) || Dt(e, 'unidentified alias "' + n + '"'), e.result = e.anchorMap[n], Xr(e, !0, -1), !0;
}
function vd(e, t, n, r, i) {
  var a, o, s, l = 1, u = !1, c = !1, d, f, h, m, v, b;
  if (e.listener !== null && e.listener("open", e), e.tag = null, e.anchor = null, e.kind = null, e.result = null, a = o = s = C_ === n || yq === n, r && Xr(e, !0, -1) && (u = !0, e.lineIndent > t ? l = 1 : e.lineIndent === t ? l = 0 : e.lineIndent < t && (l = -1)), l === 1)
    for (; y4e(e) || T4e(e); )
      Xr(e, !0, -1) ? (u = !0, s = a, e.lineIndent > t ? l = 1 : e.lineIndent === t ? l = 0 : e.lineIndent < t && (l = -1)) : s = !1;
  if (s && (s = u || i), (l === 1 || C_ === n) && (T_ === n || Sq === n ? v = t : v = t + 1, b = e.position - e.lineStart, l === 1 ? s && (hP(e, b) || S4e(e, b, v)) || b4e(e, v) ? c = !0 : (o && E4e(e, v) || _4e(e, v) || v4e(e, v) ? c = !0 : C4e(e) ? (c = !0, (e.tag !== null || e.anchor !== null) && Dt(e, "alias node should not have any properties")) : g4e(e, v, T_ === n) && (c = !0, e.tag === null && (e.tag = "?")), e.anchor !== null && (e.anchorMap[e.anchor] = e.result)) : l === 0 && (c = s && hP(e, b))), e.tag === null)
    e.anchor !== null && (e.anchorMap[e.anchor] = e.result);
  else if (e.tag === "?") {
    for (e.result !== null && e.kind !== "scalar" && Dt(e, 'unacceptable node kind for !<?> tag; it should be "scalar", not "' + e.kind + '"'), d = 0, f = e.implicitTypes.length; d < f; d += 1)
      if (m = e.implicitTypes[d], m.resolve(e.result)) {
        e.result = m.construct(e.result), e.tag = m.tag, e.anchor !== null && (e.anchorMap[e.anchor] = e.result);
        break;
      }
  } else if (e.tag !== "!") {
    if (Gl.call(e.typeMap[e.kind || "fallback"], e.tag))
      m = e.typeMap[e.kind || "fallback"][e.tag];
    else
      for (m = null, h = e.typeMap.multi[e.kind || "fallback"], d = 0, f = h.length; d < f; d += 1)
        if (e.tag.slice(0, h[d].tag.length) === h[d].tag) {
          m = h[d];
          break;
        }
    m || Dt(e, "unknown tag !<" + e.tag + ">"), e.result !== null && m.kind !== e.kind && Dt(e, "unacceptable node kind for !<" + e.tag + '> tag; it should be "' + m.kind + '", not "' + e.kind + '"'), m.resolve(e.result, e.tag) ? (e.result = m.construct(e.result, e.tag), e.anchor !== null && (e.anchorMap[e.anchor] = e.result)) : Dt(e, "cannot resolve a node with !<" + e.tag + "> explicit tag");
  }
  return e.listener !== null && e.listener("close", e), e.tag !== null || e.anchor !== null || c;
}
function A4e(e) {
  var t = e.position, n, r, i, a = !1, o;
  for (e.version = null, e.checkLineBreaks = e.legacy, e.tagMap = /* @__PURE__ */ Object.create(null), e.anchorMap = /* @__PURE__ */ Object.create(null); (o = e.input.charCodeAt(e.position)) !== 0 && (Xr(e, !0, -1), o = e.input.charCodeAt(e.position), !(e.lineIndent > 0 || o !== 37)); ) {
    for (a = !0, o = e.input.charCodeAt(++e.position), n = e.position; o !== 0 && !ca(o); )
      o = e.input.charCodeAt(++e.position);
    for (r = e.input.slice(n, e.position), i = [], r.length < 1 && Dt(e, "directive name must not be less than one character in length"); o !== 0; ) {
      for (; Uu(o); )
        o = e.input.charCodeAt(++e.position);
      if (o === 35) {
        do
          o = e.input.charCodeAt(++e.position);
        while (o !== 0 && !Vo(o));
        break;
      }
      if (Vo(o)) break;
      for (n = e.position; o !== 0 && !ca(o); )
        o = e.input.charCodeAt(++e.position);
      i.push(e.input.slice(n, e.position));
    }
    o !== 0 && TO(e), Gl.call(pP, r) ? pP[r](e, r, i) : A_(e, 'unknown document directive "' + r + '"');
  }
  if (Xr(e, !0, -1), e.lineIndent === 0 && e.input.charCodeAt(e.position) === 45 && e.input.charCodeAt(e.position + 1) === 45 && e.input.charCodeAt(e.position + 2) === 45 ? (e.position += 3, Xr(e, !0, -1)) : a && Dt(e, "directives end mark is expected"), vd(e, e.lineIndent - 1, C_, !1, !0), Xr(e, !0, -1), e.checkLineBreaks && u4e.test(e.input.slice(t, e.position)) && A_(e, "non-ASCII line breaks are interpreted as content"), e.documents.push(e.result), e.position === e.lineStart && Wv(e)) {
    e.input.charCodeAt(e.position) === 46 && (e.position += 3, Xr(e, !0, -1));
    return;
  }
  if (e.position < e.length - 1)
    Dt(e, "end of the stream or a document separator is expected");
  else
    return;
}
function wq(e, t) {
  e = String(e), t = t || {}, e.length !== 0 && (e.charCodeAt(e.length - 1) !== 10 && e.charCodeAt(e.length - 1) !== 13 && (e += `
`), e.charCodeAt(0) === 65279 && (e = e.slice(1)));
  var n = new h4e(e, t), r = e.indexOf("\0");
  for (r !== -1 && (n.position = r, Dt(n, "null byte is not allowed in input")), n.input += "\0"; n.input.charCodeAt(n.position) === 32; )
    n.lineIndent += 1, n.position += 1;
  for (; n.position < n.length - 1; )
    A4e(n);
  return n.documents;
}
function O4e(e, t, n) {
  t !== null && typeof t == "object" && typeof n > "u" && (n = t, t = null);
  var r = wq(e, n);
  if (typeof t != "function")
    return r;
  for (var i = 0, a = r.length; i < a; i += 1)
    t(r[i]);
}
function R4e(e, t) {
  var n = wq(e, t);
  if (n.length !== 0) {
    if (n.length === 1)
      return n[0];
    throw new zi("expected a single document in the stream, but found more");
  }
}
var w4e = O4e, x4e = R4e, xq = {
  loadAll: w4e,
  load: x4e
}, Nq = Object.prototype.toString, Dq = Object.prototype.hasOwnProperty, AO = 65279, N4e = 9, zp = 10, D4e = 13, I4e = 32, L4e = 33, k4e = 34, XC = 35, M4e = 37, P4e = 38, F4e = 39, B4e = 42, Iq = 44, $4e = 45, O_ = 58, U4e = 61, q4e = 62, G4e = 63, Y4e = 64, Lq = 91, kq = 93, H4e = 96, Mq = 123, z4e = 124, Pq = 125, Pi = {};
Pi[0] = "\\0";
Pi[7] = "\\a";
Pi[8] = "\\b";
Pi[9] = "\\t";
Pi[10] = "\\n";
Pi[11] = "\\v";
Pi[12] = "\\f";
Pi[13] = "\\r";
Pi[27] = "\\e";
Pi[34] = '\\"';
Pi[92] = "\\\\";
Pi[133] = "\\N";
Pi[160] = "\\_";
Pi[8232] = "\\L";
Pi[8233] = "\\P";
var V4e = [
  "y",
  "Y",
  "yes",
  "Yes",
  "YES",
  "on",
  "On",
  "ON",
  "n",
  "N",
  "no",
  "No",
  "NO",
  "off",
  "Off",
  "OFF"
], W4e = /^[-+]?[0-9_]+(?::[0-9_]+)+(?:\.[0-9_]*)?$/;
function K4e(e, t) {
  var n, r, i, a, o, s, l;
  if (t === null) return {};
  for (n = {}, r = Object.keys(t), i = 0, a = r.length; i < a; i += 1)
    o = r[i], s = String(t[o]), o.slice(0, 2) === "!!" && (o = "tag:yaml.org,2002:" + o.slice(2)), l = e.compiledTypeMap.fallback[o], l && Dq.call(l.styleAliases, s) && (s = l.styleAliases[s]), n[o] = s;
  return n;
}
function j4e(e) {
  var t, n, r;
  if (t = e.toString(16).toUpperCase(), e <= 255)
    n = "x", r = 2;
  else if (e <= 65535)
    n = "u", r = 4;
  else if (e <= 4294967295)
    n = "U", r = 8;
  else
    throw new zi("code point within a string may not be greater than 0xFFFFFFFF");
  return "\\" + n + ii.repeat("0", r - t.length) + t;
}
var Q4e = 1, Vp = 2;
function X4e(e) {
  this.schema = e.schema || yO, this.indent = Math.max(1, e.indent || 2), this.noArrayIndent = e.noArrayIndent || !1, this.skipInvalid = e.skipInvalid || !1, this.flowLevel = ii.isNothing(e.flowLevel) ? -1 : e.flowLevel, this.styleMap = K4e(this.schema, e.styles || null), this.sortKeys = e.sortKeys || !1, this.lineWidth = e.lineWidth || 80, this.noRefs = e.noRefs || !1, this.noCompatMode = e.noCompatMode || !1, this.condenseFlow = e.condenseFlow || !1, this.quotingType = e.quotingType === '"' ? Vp : Q4e, this.forceQuotes = e.forceQuotes || !1, this.replacer = typeof e.replacer == "function" ? e.replacer : null, this.implicitTypes = this.schema.compiledImplicit, this.explicitTypes = this.schema.compiledExplicit, this.tag = null, this.result = "", this.duplicates = [], this.usedDuplicates = null;
}
function gP(e, t) {
  for (var n = ii.repeat(" ", t), r = 0, i = -1, a = "", o, s = e.length; r < s; )
    i = e.indexOf(`
`, r), i === -1 ? (o = e.slice(r), r = s) : (o = e.slice(r, i + 1), r = i + 1), o.length && o !== `
` && (a += n), a += o;
  return a;
}
function ZC(e, t) {
  return `
` + ii.repeat(" ", e.indent * t);
}
function Z4e(e, t) {
  var n, r, i;
  for (n = 0, r = e.implicitTypes.length; n < r; n += 1)
    if (i = e.implicitTypes[n], i.resolve(t))
      return !0;
  return !1;
}
function R_(e) {
  return e === I4e || e === N4e;
}
function Wp(e) {
  return 32 <= e && e <= 126 || 161 <= e && e <= 55295 && e !== 8232 && e !== 8233 || 57344 <= e && e <= 65533 && e !== AO || 65536 <= e && e <= 1114111;
}
function _P(e) {
  return Wp(e) && e !== AO && e !== D4e && e !== zp;
}
function vP(e, t, n) {
  var r = _P(e), i = r && !R_(e);
  return (
    // ns-plain-safe
    (n ? (
      // c = flow-in
      r
    ) : r && e !== Iq && e !== Lq && e !== kq && e !== Mq && e !== Pq) && e !== XC && !(t === O_ && !i) || _P(t) && !R_(t) && e === XC || t === O_ && i
  );
}
function J4e(e) {
  return Wp(e) && e !== AO && !R_(e) && e !== $4e && e !== G4e && e !== O_ && e !== Iq && e !== Lq && e !== kq && e !== Mq && e !== Pq && e !== XC && e !== P4e && e !== B4e && e !== L4e && e !== z4e && e !== U4e && e !== q4e && e !== F4e && e !== k4e && e !== M4e && e !== Y4e && e !== H4e;
}
function e$e(e) {
  return !R_(e) && e !== O_;
}
function Vf(e, t) {
  var n = e.charCodeAt(t), r;
  return n >= 55296 && n <= 56319 && t + 1 < e.length && (r = e.charCodeAt(t + 1), r >= 56320 && r <= 57343) ? (n - 55296) * 1024 + r - 56320 + 65536 : n;
}
function Fq(e) {
  var t = /^\n* /;
  return t.test(e);
}
var Bq = 1, JC = 2, $q = 3, Uq = 4, qc = 5;
function t$e(e, t, n, r, i, a, o, s) {
  var l, u = 0, c = null, d = !1, f = !1, h = r !== -1, m = -1, v = J4e(Vf(e, 0)) && e$e(Vf(e, e.length - 1));
  if (t || o)
    for (l = 0; l < e.length; u >= 65536 ? l += 2 : l++) {
      if (u = Vf(e, l), !Wp(u))
        return qc;
      v = v && vP(u, c, s), c = u;
    }
  else {
    for (l = 0; l < e.length; u >= 65536 ? l += 2 : l++) {
      if (u = Vf(e, l), u === zp)
        d = !0, h && (f = f || // Foldable line = too long, and not more-indented.
        l - m - 1 > r && e[m + 1] !== " ", m = l);
      else if (!Wp(u))
        return qc;
      v = v && vP(u, c, s), c = u;
    }
    f = f || h && l - m - 1 > r && e[m + 1] !== " ";
  }
  return !d && !f ? v && !o && !i(e) ? Bq : a === Vp ? qc : JC : n > 9 && Fq(e) ? qc : o ? a === Vp ? qc : JC : f ? Uq : $q;
}
function n$e(e, t, n, r, i) {
  e.dump = function() {
    if (t.length === 0)
      return e.quotingType === Vp ? '""' : "''";
    if (!e.noCompatMode && (V4e.indexOf(t) !== -1 || W4e.test(t)))
      return e.quotingType === Vp ? '"' + t + '"' : "'" + t + "'";
    var a = e.indent * Math.max(1, n), o = e.lineWidth === -1 ? -1 : Math.max(Math.min(e.lineWidth, 40), e.lineWidth - a), s = r || e.flowLevel > -1 && n >= e.flowLevel;
    function l(u) {
      return Z4e(e, u);
    }
    switch (t$e(
      t,
      s,
      e.indent,
      o,
      l,
      e.quotingType,
      e.forceQuotes && !r,
      i
    )) {
      case Bq:
        return t;
      case JC:
        return "'" + t.replace(/'/g, "''") + "'";
      case $q:
        return "|" + bP(t, e.indent) + EP(gP(t, a));
      case Uq:
        return ">" + bP(t, e.indent) + EP(gP(r$e(t, o), a));
      case qc:
        return '"' + i$e(t) + '"';
      default:
        throw new zi("impossible error: invalid scalar style");
    }
  }();
}
function bP(e, t) {
  var n = Fq(e) ? String(t) : "", r = e[e.length - 1] === `
`, i = r && (e[e.length - 2] === `
` || e === `
`), a = i ? "+" : r ? "" : "-";
  return n + a + `
`;
}
function EP(e) {
  return e[e.length - 1] === `
` ? e.slice(0, -1) : e;
}
function r$e(e, t) {
  for (var n = /(\n+)([^\n]*)/g, r = function() {
    var u = e.indexOf(`
`);
    return u = u !== -1 ? u : e.length, n.lastIndex = u, SP(e.slice(0, u), t);
  }(), i = e[0] === `
` || e[0] === " ", a, o; o = n.exec(e); ) {
    var s = o[1], l = o[2];
    a = l[0] === " ", r += s + (!i && !a && l !== "" ? `
` : "") + SP(l, t), i = a;
  }
  return r;
}
function SP(e, t) {
  if (e === "" || e[0] === " ") return e;
  for (var n = / [^ ]/g, r, i = 0, a, o = 0, s = 0, l = ""; r = n.exec(e); )
    s = r.index, s - i > t && (a = o > i ? o : s, l += `
` + e.slice(i, a), i = a + 1), o = s;
  return l += `
`, e.length - i > t && o > i ? l += e.slice(i, o) + `
` + e.slice(o + 1) : l += e.slice(i), l.slice(1);
}
function i$e(e) {
  for (var t = "", n = 0, r, i = 0; i < e.length; n >= 65536 ? i += 2 : i++)
    n = Vf(e, i), r = Pi[n], !r && Wp(n) ? (t += e[i], n >= 65536 && (t += e[i + 1])) : t += r || j4e(n);
  return t;
}
function a$e(e, t, n) {
  var r = "", i = e.tag, a, o, s;
  for (a = 0, o = n.length; a < o; a += 1)
    s = n[a], e.replacer && (s = e.replacer.call(n, String(a), s)), (Ys(e, t, s, !1, !1) || typeof s > "u" && Ys(e, t, null, !1, !1)) && (r !== "" && (r += "," + (e.condenseFlow ? "" : " ")), r += e.dump);
  e.tag = i, e.dump = "[" + r + "]";
}
function yP(e, t, n, r) {
  var i = "", a = e.tag, o, s, l;
  for (o = 0, s = n.length; o < s; o += 1)
    l = n[o], e.replacer && (l = e.replacer.call(n, String(o), l)), (Ys(e, t + 1, l, !0, !0, !1, !0) || typeof l > "u" && Ys(e, t + 1, null, !0, !0, !1, !0)) && ((!r || i !== "") && (i += ZC(e, t)), e.dump && zp === e.dump.charCodeAt(0) ? i += "-" : i += "- ", i += e.dump);
  e.tag = a, e.dump = i || "[]";
}
function o$e(e, t, n) {
  var r = "", i = e.tag, a = Object.keys(n), o, s, l, u, c;
  for (o = 0, s = a.length; o < s; o += 1)
    c = "", r !== "" && (c += ", "), e.condenseFlow && (c += '"'), l = a[o], u = n[l], e.replacer && (u = e.replacer.call(n, l, u)), Ys(e, t, l, !1, !1) && (e.dump.length > 1024 && (c += "? "), c += e.dump + (e.condenseFlow ? '"' : "") + ":" + (e.condenseFlow ? "" : " "), Ys(e, t, u, !1, !1) && (c += e.dump, r += c));
  e.tag = i, e.dump = "{" + r + "}";
}
function s$e(e, t, n, r) {
  var i = "", a = e.tag, o = Object.keys(n), s, l, u, c, d, f;
  if (e.sortKeys === !0)
    o.sort();
  else if (typeof e.sortKeys == "function")
    o.sort(e.sortKeys);
  else if (e.sortKeys)
    throw new zi("sortKeys must be a boolean or a function");
  for (s = 0, l = o.length; s < l; s += 1)
    f = "", (!r || i !== "") && (f += ZC(e, t)), u = o[s], c = n[u], e.replacer && (c = e.replacer.call(n, u, c)), Ys(e, t + 1, u, !0, !0, !0) && (d = e.tag !== null && e.tag !== "?" || e.dump && e.dump.length > 1024, d && (e.dump && zp === e.dump.charCodeAt(0) ? f += "?" : f += "? "), f += e.dump, d && (f += ZC(e, t)), Ys(e, t + 1, c, !0, d) && (e.dump && zp === e.dump.charCodeAt(0) ? f += ":" : f += ": ", f += e.dump, i += f));
  e.tag = a, e.dump = i || "{}";
}
function TP(e, t, n) {
  var r, i, a, o, s, l;
  for (i = n ? e.explicitTypes : e.implicitTypes, a = 0, o = i.length; a < o; a += 1)
    if (s = i[a], (s.instanceOf || s.predicate) && (!s.instanceOf || typeof t == "object" && t instanceof s.instanceOf) && (!s.predicate || s.predicate(t))) {
      if (n ? s.multi && s.representName ? e.tag = s.representName(t) : e.tag = s.tag : e.tag = "?", s.represent) {
        if (l = e.styleMap[s.tag] || s.defaultStyle, Nq.call(s.represent) === "[object Function]")
          r = s.represent(t, l);
        else if (Dq.call(s.represent, l))
          r = s.represent[l](t, l);
        else
          throw new zi("!<" + s.tag + '> tag resolver accepts not "' + l + '" style');
        e.dump = r;
      }
      return !0;
    }
  return !1;
}
function Ys(e, t, n, r, i, a, o) {
  e.tag = null, e.dump = n, TP(e, n, !1) || TP(e, n, !0);
  var s = Nq.call(e.dump), l = r, u;
  r && (r = e.flowLevel < 0 || e.flowLevel > t);
  var c = s === "[object Object]" || s === "[object Array]", d, f;
  if (c && (d = e.duplicates.indexOf(n), f = d !== -1), (e.tag !== null && e.tag !== "?" || f || e.indent !== 2 && t > 0) && (i = !1), f && e.usedDuplicates[d])
    e.dump = "*ref_" + d;
  else {
    if (c && f && !e.usedDuplicates[d] && (e.usedDuplicates[d] = !0), s === "[object Object]")
      r && Object.keys(e.dump).length !== 0 ? (s$e(e, t, e.dump, i), f && (e.dump = "&ref_" + d + e.dump)) : (o$e(e, t, e.dump), f && (e.dump = "&ref_" + d + " " + e.dump));
    else if (s === "[object Array]")
      r && e.dump.length !== 0 ? (e.noArrayIndent && !o && t > 0 ? yP(e, t - 1, e.dump, i) : yP(e, t, e.dump, i), f && (e.dump = "&ref_" + d + e.dump)) : (a$e(e, t, e.dump), f && (e.dump = "&ref_" + d + " " + e.dump));
    else if (s === "[object String]")
      e.tag !== "?" && n$e(e, e.dump, t, a, l);
    else {
      if (s === "[object Undefined]")
        return !1;
      if (e.skipInvalid) return !1;
      throw new zi("unacceptable kind of an object to dump " + s);
    }
    e.tag !== null && e.tag !== "?" && (u = encodeURI(
      e.tag[0] === "!" ? e.tag.slice(1) : e.tag
    ).replace(/!/g, "%21"), e.tag[0] === "!" ? u = "!" + u : u.slice(0, 18) === "tag:yaml.org,2002:" ? u = "!!" + u.slice(18) : u = "!<" + u + ">", e.dump = u + " " + e.dump);
  }
  return !0;
}
function l$e(e, t) {
  var n = [], r = [], i, a;
  for (e1(e, n, r), i = 0, a = r.length; i < a; i += 1)
    t.duplicates.push(n[r[i]]);
  t.usedDuplicates = new Array(a);
}
function e1(e, t, n) {
  var r, i, a;
  if (e !== null && typeof e == "object")
    if (i = t.indexOf(e), i !== -1)
      n.indexOf(i) === -1 && n.push(i);
    else if (t.push(e), Array.isArray(e))
      for (i = 0, a = e.length; i < a; i += 1)
        e1(e[i], t, n);
    else
      for (r = Object.keys(e), i = 0, a = r.length; i < a; i += 1)
        e1(e[r[i]], t, n);
}
function u$e(e, t) {
  t = t || {};
  var n = new X4e(t);
  n.noRefs || l$e(e, n);
  var r = e;
  return n.replacer && (r = n.replacer.call({ "": r }, "", r)), Ys(n, 0, r, !0, !0) ? n.dump + `
` : "";
}
var c$e = u$e, d$e = {
  dump: c$e
};
function OO(e, t) {
  return function() {
    throw new Error("Function yaml." + e + " is removed in js-yaml 4. Use yaml." + t + " instead, which is now safe by default.");
  };
}
var f$e = vi, p$e = nq, m$e = oq, h$e = dq, g$e = fq, _$e = yO, v$e = xq.load, b$e = xq.loadAll, E$e = d$e.dump, S$e = zi, y$e = {
  binary: _q,
  float: cq,
  map: aq,
  null: sq,
  pairs: bq,
  set: Eq,
  timestamp: hq,
  bool: lq,
  int: uq,
  merge: gq,
  omap: vq,
  seq: iq,
  str: rq
}, T$e = OO("safeLoad", "load"), C$e = OO("safeLoadAll", "loadAll"), A$e = OO("safeDump", "dump"), O$e = {
  Type: f$e,
  Schema: p$e,
  FAILSAFE_SCHEMA: m$e,
  JSON_SCHEMA: h$e,
  CORE_SCHEMA: g$e,
  DEFAULT_SCHEMA: _$e,
  load: v$e,
  loadAll: b$e,
  dump: E$e,
  YAMLException: S$e,
  types: y$e,
  safeLoad: T$e,
  safeLoadAll: C$e,
  safeDump: A$e
};
const Zs = (e, t) => {
  const n = e.__vccOpts || e;
  for (const [r, i] of t)
    n[r] = i;
  return n;
}, R$e = {
  components: {
    Vueform: Fv
  },
  props: ["yamlSchema", "jsonSchema"],
  setup(e) {
    const t = he({
      schema: {}
    });
    En("send_ws");
    const n = (r) => {
      const i = Object.keys(r).find((o) => o !== "form_id"), a = t.value.schema[i];
      if (console.log("Change event:", r), console.log("Field schema:", a), a != null && a.ws_send) {
        const o = {
          cmd: a.ws_send,
          form_id: r.form_id,
          data: r
        };
        console.log("Sending WS message:", o), window.send_ws(o.cmd, o);
      }
    };
    return et(() => e.yamlSchema, (r) => {
      if (r) {
        const i = O$e.load(r);
        i.schema.form_id = {
          type: "hidden",
          default: i.id
        }, console.log("YAML", i), t.value.schema = i.schema;
      }
    }, { immediate: !0 }), et(() => e.jsonSchema, (r) => {
      if (r) {
        const i = JSON.parse(r);
        i.schema.form_id = {
          type: "hidden",
          default: i.id
        }, console.log("JSON:", i), t.value.schema = i.schema;
      }
    }, { immediate: !0 }), {
      vueform: t,
      handleChange: n
    };
  }
};
function w$e(e, t, n, r, i, a) {
  const o = Bt("Vueform");
  return U(), Ae(o, $e(r.vueform, { onChange: r.handleChange }), null, 16, ["onChange"]);
}
const Kp = /* @__PURE__ */ Zs(R$e, [["render", w$e]]);
tC.registerLanguage("python", ute);
function x$e(e) {
  const t = Math.floor((Date.now() - new Date(e).getTime()) / 1e3), n = Math.floor(t / (24 * 60 * 60)), r = Math.floor(t % (24 * 60 * 60) / (60 * 60)), i = Math.floor(t % (60 * 60) / 60), a = t % 60;
  let o = "";
  return n > 0 && (o += `${n}d`), r > 0 && (o += `${r}h`), i > 0 && (o += `${i}m`), (a > 0 || o === "") && (o += `${a}s`), o;
}
const Fm = new Za({
  html: !0,
  linkify: !0,
  typographer: !1,
  highlight: function(e, t) {
    if (t && tC.getLanguage(t))
      try {
        return tC.highlight(e, { language: t, ignoreIllegals: !0 }).value;
      } catch {
      }
    return "";
  }
}), N$e = Fm.renderer.rules.link_open || function(e, t, n, r, i) {
  return i.renderToken(e, t, n);
};
Fm.renderer.rules.link_open = function(e, t, n, r, i) {
  const a = e[t], o = a.attrIndex("href");
  if (o >= 0) {
    const s = a.attrs[o][1];
    if (s.startsWith("ws_send:")) {
      const [l, u] = s.replace("ws_send:", "").split("?"), c = u ? Object.fromEntries(new URLSearchParams(u)) : {}, d = `send_ws('${l}', ${JSON.stringify(c)})`.replace(/"/g, "&quot;");
      return console.log(`Converting link: ${s} -> onclick:${d}`), `<a href="#" onclick="${d};return false;">`;
    }
  }
  return N$e(e, t, n, r, i);
};
Fm.inline.ruler.after("emphasis", "elapsed_time", function(t, n) {
  const r = t.pos, i = /^\[since\|(\d{4}-\d{2}-\d{2}T\d{2}:\d{2}:\d{2}(?:\.\d+)?(?:Z|[+-]\d{2}:\d{2})?)\]/, o = t.src.slice(r).match(i);
  if (!o) return !1;
  if (n)
    t.pos = r + o[0].length;
  else {
    const s = o[0], l = o[1];
    console.log(`Found timestamp match: ${s} -> ${l}`);
    const u = t.push("elapsed_time", "", 0);
    u.content = l, u.markup = s, u.map = [r, r + s.length], t.pos = r + s.length;
  }
  return !0;
});
Fm.renderer.rules.elapsed_time = function(e, t) {
  const n = e[t].content, r = `elapsed-${Math.random().toString(36).substring(2, 9)}`;
  return console.log(`Rendering elapsed time for ${n}`), setTimeout(() => {
    const i = document.getElementById(r);
    if (i) {
      const a = () => {
        i.textContent = x$e(n);
      };
      a(), setInterval(a, 1e3);
    }
  }, 0), `<span id="${r}">...</span>`;
};
function RO(e) {
  return Fm.render(e);
}
function cp() {
  typeof Ia < "u" ? Ia.init(void 0, document.querySelectorAll(".language-mermaid")) : console.warn("Mermaid not loaded."), document.querySelectorAll(".language-form-yaml").forEach((e) => {
    const t = e.textContent || e.innerText, n = document.createElement("div"), r = WT(Kp, { yamlSchema: t });
    r.use(y_), e.parentNode.parentNode.replaceChild(n, e.parentNode), r.mount(n);
  }), document.querySelectorAll(".language-form-json").forEach((e) => {
    const t = e.textContent || e.innerText, n = document.createElement("div"), r = WT(Kp, { jsonSchema: t });
    r.use(y_), e.parentNode.parentNode.replaceChild(n, e.parentNode), r.mount(n);
  }), window.MathJax ? window.MathJax.typesetPromise() : console.warn("MathJax not loaded.");
}
const qq = {
  install(e, t) {
    e.provide("processMarkdown", RO), e.provide("postRender", cp);
  }
}, t1 = u1({}), D$e = {
  install(e, t) {
    e.provide("userData", t1);
  }
};
function I$e(e) {
  return { all: e = e || /* @__PURE__ */ new Map(), on: function(t, n) {
    var r = e.get(t);
    r ? r.push(n) : e.set(t, [n]);
  }, off: function(t, n) {
    var r = e.get(t);
    r && (n ? r.splice(r.indexOf(n) >>> 0, 1) : e.set(t, []));
  }, emit: function(t, n) {
    var r = e.get(t);
    r && r.slice().map(function(i) {
      i(n);
    }), (r = e.get("*")) && r.slice().map(function(i) {
      i(t, n);
    });
  } };
}
const Qc = I$e();
function Bm(e) {
  Object.entries(e).forEach(([t, n]) => {
    typeof n == "function" && (console.log("Binding handler", t), Qc.on(t, n));
  });
}
function $m(e) {
  Object.entries(e).forEach(([t, n]) => {
    typeof n == "function" && Qc.off(t, n);
  });
}
var L$e = {
  root: function(t) {
    var n = t.props;
    return ["p-avatar p-component", {
      "p-avatar-image": n.image != null,
      "p-avatar-circle": n.shape === "circle",
      "p-avatar-lg": n.size === "large",
      "p-avatar-xl": n.size === "xlarge"
    }];
  },
  label: "p-avatar-text",
  icon: "p-avatar-icon"
}, k$e = Wo.extend({
  name: "avatar",
  classes: L$e
}), M$e = {
  name: "BaseAvatar",
  extends: Cd,
  props: {
    label: {
      type: String,
      default: null
    },
    icon: {
      type: String,
      default: null
    },
    image: {
      type: String,
      default: null
    },
    size: {
      type: String,
      default: "normal"
    },
    shape: {
      type: String,
      default: "square"
    },
    ariaLabelledby: {
      type: String,
      default: null
    },
    ariaLabel: {
      type: String,
      default: null
    }
  },
  style: k$e,
  provide: function() {
    return {
      $parentInstance: this
    };
  }
}, Gq = {
  name: "Avatar",
  extends: M$e,
  emits: ["error"],
  methods: {
    onError: function(t) {
      this.$emit("error", t);
    }
  }
}, P$e = ["aria-labelledby", "aria-label"], F$e = ["src", "alt"];
function B$e(e, t, n, r, i, a) {
  return U(), ee("div", $e({
    class: e.cx("root"),
    "aria-labelledby": e.ariaLabelledby,
    "aria-label": e.ariaLabel
  }, e.ptm("root")), [Me(e.$slots, "default", {}, function() {
    return [e.label ? (U(), ee("span", $e({
      key: 0,
      class: e.cx("label")
    }, e.ptm("label")), zt(e.label), 17)) : e.$slots.icon ? (U(), Ae(ze(e.$slots.icon), {
      key: 1,
      class: re(e.cx("icon"))
    }, null, 8, ["class"])) : e.icon ? (U(), ee("span", $e({
      key: 2,
      class: [e.cx("icon"), e.icon]
    }, e.ptm("icon")), null, 16)) : e.image ? (U(), ee("img", $e({
      key: 3,
      src: e.image,
      alt: e.ariaLabel,
      onError: t[0] || (t[0] = function() {
        return a.onError && a.onError.apply(a, arguments);
      })
    }, e.ptm("image")), null, 16, F$e)) : se("", !0)];
  })], 16, P$e);
}
Gq.render = B$e;
function Yq() {
  let e = null, t = null;
  const n = {
    ws_enable_file_drop: (r) => {
      console.log("Enabling file drop with config:", r), e = {
        accept: r.accept || [],
        maxSize: r.max_size || 1 / 0,
        uploadUrl: r.upload_url,
        multiple: r.multiple || !1,
        progressUpdates: r.progress_updates || !1
      };
      function i(o) {
        if (console.log("Drop event received"), o.preventDefault(), o.stopPropagation(), !e) {
          console.warn("Drop occurred but no configuration set");
          return;
        }
        const s = Array.from(o.dataTransfer.files);
        console.log("Files dropped:", s), s.forEach(async (l) => {
          const u = "." + l.name.split(".").pop().toLowerCase();
          if (!e.accept.includes(u)) {
            console.log("File type not accepted:", u);
            return;
          }
          if (l.size > e.maxSize) {
            console.log("File too large:", l.size);
            return;
          }
          const c = new FormData();
          c.append("file", l);
          const d = window.socket_id;
          if (!d) {
            console.error("No socket_id available");
            return;
          }
          c.append("socket_id", d);
          try {
            console.log(`Uploading ${l.name} to ${e.uploadUrl} with socket_id ${d}`);
            const f = await fetch(e.uploadUrl, {
              method: "POST",
              body: c
            });
            if (!f.ok)
              throw new Error(`HTTP error! status: ${f.status}`);
            console.log(`Upload complete: ${l.name}`);
          } catch (f) {
            console.error("Upload failed:", f);
          }
        });
      }
      function a(o) {
        o.preventDefault(), o.stopPropagation();
      }
      window.addEventListener("dragover", a), window.addEventListener("drop", i), t && t(), t = () => {
        window.removeEventListener("dragover", a), window.removeEventListener("drop", i);
      };
    }
  };
  On(() => {
    Bm(n);
  }), pa(() => {
    t && t(), $m(n);
  });
}
const $$e = (e) => (lF("data-v-316a52b5"), e = e(), uF(), e), U$e = { class: "agi-green-flex-container" }, q$e = {
  id: "messages",
  class: "agi-green-messages"
}, G$e = { class: "agi-green-message-content" }, Y$e = { class: "agi-green-username" }, H$e = ["innerHTML"], z$e = { class: "agi-green-chat-input-container" }, V$e = /* @__PURE__ */ $$e(() => /* @__PURE__ */ de("img", {
  src: eK,
  alt: "Send"
}, null, -1)), W$e = [
  V$e
], K$e = {
  __name: "Chat",
  setup(e) {
    const t = En("send_ws"), n = he([]), r = he(""), i = (d) => {
      const f = document.getElementById("messages"), h = f ? f.scrollTop : 0, m = d.target.style.height;
      d.target.style.height = "auto";
      const v = d.target.scrollHeight + 5 + "px";
      d.target.style.height = v, f && m && parseInt(v) > parseInt(m) && (f.scrollTop = h);
    }, a = (d) => {
      d.shiftKey || (d.preventDefault(), o());
    }, o = () => {
      const d = r.value.trim();
      d && (t("chat_input", { content: d }), r.value = "");
      const f = document.getElementById("chat-input-text");
      f && (f.style.height = "50px");
    };
    fi();
    const s = (d) => t1[d] || { name: d, icon: "/avatars/default_avatar.png" }, l = (d) => s(d).icon, u = {
      ws_append_chat: (d) => {
        n.value.push({
          t: Date.now(),
          user: d.author,
          content: RO(d.content)
        }), Ut(() => {
          cp(), c();
        });
      },
      ws_set_user_data: ({ uid: d, name: f, icon: h }) => {
        console.log("ws_set_user_data received:", { uid: d, name: f, icon: h }), d && (t1[d] = { name: f, icon: h });
      }
    }, c = () => {
      const d = document.getElementById("messages");
      d && (d.scrollTop = d.scrollHeight);
    };
    return On(() => {
      Bm(u), Ut(() => {
        c();
      });
    }), pa(() => {
      $m(u);
    }), (d, f) => (U(), ee("div", U$e, [
      de("div", q$e, [
        (U(!0), ee(gt, null, It(n.value, (h) => (U(), ee("div", {
          key: h.id,
          class: "agi-green-chat-message-block"
        }, [
          rn(ks(Gq), {
            image: l(h.user),
            alt: `${s(h.user).name}'s avatar`,
            title: s(h.user).name,
            shape: "circle"
          }, null, 8, ["image", "alt", "title"]),
          de("div", G$e, [
            de("div", Y$e, zt(s(h.user).name), 1),
            de("div", {
              class: "agi-green-chat-message",
              innerHTML: h.content
            }, null, 8, H$e)
          ])
        ]))), 128)),
        de("div", z$e, [
          Gn(de("textarea", {
            id: "chat-input-text",
            "onUpdate:modelValue": f[0] || (f[0] = (h) => r.value = h),
            onInput: i,
            onKeyup: Zr(a, ["enter"]),
            placeholder: "Type your message here..."
          }, null, 544), [
            [sF, r.value]
          ]),
          de("button", {
            class: "agi-green-chat-send-button",
            onClick: o
          }, W$e)
        ])
      ])
    ]));
  }
}, wO = /* @__PURE__ */ Zs(K$e, [["__scopeId", "data-v-316a52b5"]]);
var j$e = `
.p-icon {
    display: inline-block;
}

.p-icon-spin {
    -webkit-animation: p-icon-spin 2s infinite linear;
    animation: p-icon-spin 2s infinite linear;
}

@-webkit-keyframes p-icon-spin {
    0% {
        -webkit-transform: rotate(0deg);
        transform: rotate(0deg);
    }
    100% {
        -webkit-transform: rotate(359deg);
        transform: rotate(359deg);
    }
}

@keyframes p-icon-spin {
    0% {
        -webkit-transform: rotate(0deg);
        transform: rotate(0deg);
    }
    100% {
        -webkit-transform: rotate(359deg);
        transform: rotate(359deg);
    }
}
`, Q$e = Wo.extend({
  name: "baseicon",
  css: j$e
});
function jp(e) {
  "@babel/helpers - typeof";
  return jp = typeof Symbol == "function" && typeof Symbol.iterator == "symbol" ? function(t) {
    return typeof t;
  } : function(t) {
    return t && typeof Symbol == "function" && t.constructor === Symbol && t !== Symbol.prototype ? "symbol" : typeof t;
  }, jp(e);
}
function CP(e, t) {
  var n = Object.keys(e);
  if (Object.getOwnPropertySymbols) {
    var r = Object.getOwnPropertySymbols(e);
    t && (r = r.filter(function(i) {
      return Object.getOwnPropertyDescriptor(e, i).enumerable;
    })), n.push.apply(n, r);
  }
  return n;
}
function AP(e) {
  for (var t = 1; t < arguments.length; t++) {
    var n = arguments[t] != null ? arguments[t] : {};
    t % 2 ? CP(Object(n), !0).forEach(function(r) {
      X$e(e, r, n[r]);
    }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(n)) : CP(Object(n)).forEach(function(r) {
      Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(n, r));
    });
  }
  return e;
}
function X$e(e, t, n) {
  return t = Z$e(t), t in e ? Object.defineProperty(e, t, { value: n, enumerable: !0, configurable: !0, writable: !0 }) : e[t] = n, e;
}
function Z$e(e) {
  var t = J$e(e, "string");
  return jp(t) == "symbol" ? t : String(t);
}
function J$e(e, t) {
  if (jp(e) != "object" || !e) return e;
  var n = e[Symbol.toPrimitive];
  if (n !== void 0) {
    var r = n.call(e, t || "default");
    if (jp(r) != "object") return r;
    throw new TypeError("@@toPrimitive must return a primitive value.");
  }
  return (t === "string" ? String : Number)(e);
}
var Hq = {
  name: "BaseIcon",
  extends: Cd,
  props: {
    label: {
      type: String,
      default: void 0
    },
    spin: {
      type: Boolean,
      default: !1
    }
  },
  style: Q$e,
  methods: {
    pti: function() {
      var t = cn.isEmpty(this.label);
      return AP(AP({}, !this.isUnstyled && {
        class: ["p-icon", {
          "p-icon-spin": this.spin
        }]
      }), {}, {
        role: t ? void 0 : "img",
        "aria-label": t ? void 0 : this.label,
        "aria-hidden": t
      });
    }
  }
}, zq = {
  name: "ChevronLeftIcon",
  extends: Hq
}, eUe = /* @__PURE__ */ de("path", {
  d: "M9.61296 13C9.50997 13.0005 9.40792 12.9804 9.3128 12.9409C9.21767 12.9014 9.13139 12.8433 9.05902 12.7701L3.83313 7.54416C3.68634 7.39718 3.60388 7.19795 3.60388 6.99022C3.60388 6.78249 3.68634 6.58325 3.83313 6.43628L9.05902 1.21039C9.20762 1.07192 9.40416 0.996539 9.60724 1.00012C9.81032 1.00371 10.0041 1.08597 10.1477 1.22959C10.2913 1.37322 10.3736 1.56698 10.3772 1.77005C10.3808 1.97313 10.3054 2.16968 10.1669 2.31827L5.49496 6.99022L10.1669 11.6622C10.3137 11.8091 10.3962 12.0084 10.3962 12.2161C10.3962 12.4238 10.3137 12.6231 10.1669 12.7701C10.0945 12.8433 10.0083 12.9014 9.91313 12.9409C9.81801 12.9804 9.71596 13.0005 9.61296 13Z",
  fill: "currentColor"
}, null, -1), tUe = [eUe];
function nUe(e, t, n, r, i, a) {
  return U(), ee("svg", $e({
    width: "14",
    height: "14",
    viewBox: "0 0 14 14",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg"
  }, e.pti()), tUe, 16);
}
zq.render = nUe;
var Vq = {
  name: "ChevronRightIcon",
  extends: Hq
}, rUe = /* @__PURE__ */ de("path", {
  d: "M4.38708 13C4.28408 13.0005 4.18203 12.9804 4.08691 12.9409C3.99178 12.9014 3.9055 12.8433 3.83313 12.7701C3.68634 12.6231 3.60388 12.4238 3.60388 12.2161C3.60388 12.0084 3.68634 11.8091 3.83313 11.6622L8.50507 6.99022L3.83313 2.31827C3.69467 2.16968 3.61928 1.97313 3.62287 1.77005C3.62645 1.56698 3.70872 1.37322 3.85234 1.22959C3.99596 1.08597 4.18972 1.00371 4.3928 1.00012C4.59588 0.996539 4.79242 1.07192 4.94102 1.21039L10.1669 6.43628C10.3137 6.58325 10.3962 6.78249 10.3962 6.99022C10.3962 7.19795 10.3137 7.39718 10.1669 7.54416L4.94102 12.7701C4.86865 12.8433 4.78237 12.9014 4.68724 12.9409C4.59212 12.9804 4.49007 13.0005 4.38708 13Z",
  fill: "currentColor"
}, null, -1), iUe = [rUe];
function aUe(e, t, n, r, i, a) {
  return U(), ee("svg", $e({
    width: "14",
    height: "14",
    viewBox: "0 0 14 14",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg"
  }, e.pti()), iUe, 16);
}
Vq.render = aUe;
function Qp(e) {
  "@babel/helpers - typeof";
  return Qp = typeof Symbol == "function" && typeof Symbol.iterator == "symbol" ? function(t) {
    return typeof t;
  } : function(t) {
    return t && typeof Symbol == "function" && t.constructor === Symbol && t !== Symbol.prototype ? "symbol" : typeof t;
  }, Qp(e);
}
function OP(e, t) {
  return uUe(e) || lUe(e, t) || sUe(e, t) || oUe();
}
function oUe() {
  throw new TypeError(`Invalid attempt to destructure non-iterable instance.
In order to be iterable, non-array objects must have a [Symbol.iterator]() method.`);
}
function sUe(e, t) {
  if (e) {
    if (typeof e == "string") return RP(e, t);
    var n = Object.prototype.toString.call(e).slice(8, -1);
    if (n === "Object" && e.constructor && (n = e.constructor.name), n === "Map" || n === "Set") return Array.from(e);
    if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return RP(e, t);
  }
}
function RP(e, t) {
  (t == null || t > e.length) && (t = e.length);
  for (var n = 0, r = new Array(t); n < t; n++) r[n] = e[n];
  return r;
}
function lUe(e, t) {
  var n = e == null ? null : typeof Symbol < "u" && e[Symbol.iterator] || e["@@iterator"];
  if (n != null) {
    var r, i, a, o, s = [], l = !0, u = !1;
    try {
      if (a = (n = n.call(e)).next, t !== 0) for (; !(l = (r = a.call(n)).done) && (s.push(r.value), s.length !== t); l = !0) ;
    } catch (c) {
      u = !0, i = c;
    } finally {
      try {
        if (!l && n.return != null && (o = n.return(), Object(o) !== o)) return;
      } finally {
        if (u) throw i;
      }
    }
    return s;
  }
}
function uUe(e) {
  if (Array.isArray(e)) return e;
}
function wP(e, t) {
  var n = Object.keys(e);
  if (Object.getOwnPropertySymbols) {
    var r = Object.getOwnPropertySymbols(e);
    t && (r = r.filter(function(i) {
      return Object.getOwnPropertyDescriptor(e, i).enumerable;
    })), n.push.apply(n, r);
  }
  return n;
}
function Or(e) {
  for (var t = 1; t < arguments.length; t++) {
    var n = arguments[t] != null ? arguments[t] : {};
    t % 2 ? wP(Object(n), !0).forEach(function(r) {
      n1(e, r, n[r]);
    }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(n)) : wP(Object(n)).forEach(function(r) {
      Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(n, r));
    });
  }
  return e;
}
function n1(e, t, n) {
  return t = cUe(t), t in e ? Object.defineProperty(e, t, { value: n, enumerable: !0, configurable: !0, writable: !0 }) : e[t] = n, e;
}
function cUe(e) {
  var t = dUe(e, "string");
  return Qp(t) == "symbol" ? t : String(t);
}
function dUe(e, t) {
  if (Qp(e) != "object" || !e) return e;
  var n = e[Symbol.toPrimitive];
  if (n !== void 0) {
    var r = n.call(e, t || "default");
    if (Qp(r) != "object") return r;
    throw new TypeError("@@toPrimitive must return a primitive value.");
  }
  return (t === "string" ? String : Number)(e);
}
var In = {
  _getMeta: function() {
    return [cn.isObject(arguments.length <= 0 ? void 0 : arguments[0]) || arguments.length <= 0 ? void 0 : arguments[0], cn.getItemValue(cn.isObject(arguments.length <= 0 ? void 0 : arguments[0]) ? arguments.length <= 0 ? void 0 : arguments[0] : arguments.length <= 1 ? void 0 : arguments[1])];
  },
  _getConfig: function(t, n) {
    var r, i, a;
    return (r = (t == null || (i = t.instance) === null || i === void 0 ? void 0 : i.$primevue) || (n == null || (a = n.ctx) === null || a === void 0 || (a = a.appContext) === null || a === void 0 || (a = a.config) === null || a === void 0 || (a = a.globalProperties) === null || a === void 0 ? void 0 : a.$primevue)) === null || r === void 0 ? void 0 : r.config;
  },
  _getOptionValue: function(t) {
    var n = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : "", r = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : {}, i = cn.toFlatCase(n).split("."), a = i.shift();
    return a ? cn.isObject(t) ? In._getOptionValue(cn.getItemValue(t[Object.keys(t).find(function(o) {
      return cn.toFlatCase(o) === a;
    }) || ""], r), i.join("."), r) : void 0 : cn.getItemValue(t, r);
  },
  _getPTValue: function() {
    var t, n, r = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : {}, i = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : {}, a = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : "", o = arguments.length > 3 && arguments[3] !== void 0 ? arguments[3] : {}, s = arguments.length > 4 && arguments[4] !== void 0 ? arguments[4] : !0, l = function() {
      var g = In._getOptionValue.apply(In, arguments);
      return cn.isString(g) || cn.isArray(g) ? {
        class: g
      } : g;
    }, u = ((t = r.binding) === null || t === void 0 || (t = t.value) === null || t === void 0 ? void 0 : t.ptOptions) || ((n = r.$config) === null || n === void 0 ? void 0 : n.ptOptions) || {}, c = u.mergeSections, d = c === void 0 ? !0 : c, f = u.mergeProps, h = f === void 0 ? !1 : f, m = s ? In._useDefaultPT(r, r.defaultPT(), l, a, o) : void 0, v = In._usePT(r, In._getPT(i, r.$name), l, a, Or(Or({}, o), {}, {
      global: m || {}
    })), b = In._getPTDatasets(r, a);
    return d || !d && v ? h ? In._mergeProps(r, h, m, v, b) : Or(Or(Or({}, m), v), b) : Or(Or({}, v), b);
  },
  _getPTDatasets: function() {
    var t = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : {}, n = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : "", r = "data-pc-";
    return Or(Or({}, n === "root" && n1({}, "".concat(r, "name"), cn.toFlatCase(t.$name))), {}, n1({}, "".concat(r, "section"), cn.toFlatCase(n)));
  },
  _getPT: function(t) {
    var n = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : "", r = arguments.length > 2 ? arguments[2] : void 0, i = function(o) {
      var s, l = r ? r(o) : o, u = cn.toFlatCase(n);
      return (s = l == null ? void 0 : l[u]) !== null && s !== void 0 ? s : l;
    };
    return t != null && t.hasOwnProperty("_usept") ? {
      _usept: t._usept,
      originalValue: i(t.originalValue),
      value: i(t.value)
    } : i(t);
  },
  _usePT: function() {
    var t = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : {}, n = arguments.length > 1 ? arguments[1] : void 0, r = arguments.length > 2 ? arguments[2] : void 0, i = arguments.length > 3 ? arguments[3] : void 0, a = arguments.length > 4 ? arguments[4] : void 0, o = function(b) {
      return r(b, i, a);
    };
    if (n != null && n.hasOwnProperty("_usept")) {
      var s, l = n._usept || ((s = t.$config) === null || s === void 0 ? void 0 : s.ptOptions) || {}, u = l.mergeSections, c = u === void 0 ? !0 : u, d = l.mergeProps, f = d === void 0 ? !1 : d, h = o(n.originalValue), m = o(n.value);
      return h === void 0 && m === void 0 ? void 0 : cn.isString(m) ? m : cn.isString(h) ? h : c || !c && m ? f ? In._mergeProps(t, f, h, m) : Or(Or({}, h), m) : m;
    }
    return o(n);
  },
  _useDefaultPT: function() {
    var t = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : {}, n = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : {}, r = arguments.length > 2 ? arguments[2] : void 0, i = arguments.length > 3 ? arguments[3] : void 0, a = arguments.length > 4 ? arguments[4] : void 0;
    return In._usePT(t, n, r, i, a);
  },
  _hook: function(t, n, r, i, a, o) {
    var s, l, u = "on".concat(cn.toCapitalCase(n)), c = In._getConfig(i, a), d = r == null ? void 0 : r.$instance, f = In._usePT(d, In._getPT(i == null || (s = i.value) === null || s === void 0 ? void 0 : s.pt, t), In._getOptionValue, "hooks.".concat(u)), h = In._useDefaultPT(d, c == null || (l = c.pt) === null || l === void 0 || (l = l.directives) === null || l === void 0 ? void 0 : l[t], In._getOptionValue, "hooks.".concat(u)), m = {
      el: r,
      binding: i,
      vnode: a,
      prevVnode: o
    };
    f == null || f(d, m), h == null || h(d, m);
  },
  _mergeProps: function() {
    for (var t = arguments.length > 1 ? arguments[1] : void 0, n = arguments.length, r = new Array(n > 2 ? n - 2 : 0), i = 2; i < n; i++)
      r[i - 2] = arguments[i];
    return cn.isFunction(t) ? t.apply(void 0, r) : $e.apply(void 0, r);
  },
  _extend: function(t) {
    var n = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : {}, r = function(a, o, s, l, u) {
      var c, d;
      o._$instances = o._$instances || {};
      var f = In._getConfig(s, l), h = o._$instances[t] || {}, m = cn.isEmpty(h) ? Or(Or({}, n), n == null ? void 0 : n.methods) : {};
      o._$instances[t] = Or(Or({}, h), {}, {
        /* new instance variables to pass in directive methods */
        $name: t,
        $host: o,
        $binding: s,
        $modifiers: s == null ? void 0 : s.modifiers,
        $value: s == null ? void 0 : s.value,
        $el: h.$el || o || void 0,
        $style: Or({
          classes: void 0,
          inlineStyles: void 0,
          loadStyle: function() {
          }
        }, n == null ? void 0 : n.style),
        $config: f,
        /* computed instance variables */
        defaultPT: function() {
          return In._getPT(f == null ? void 0 : f.pt, void 0, function(b) {
            var y;
            return b == null || (y = b.directives) === null || y === void 0 ? void 0 : y[t];
          });
        },
        isUnstyled: function() {
          var b, y;
          return ((b = o.$instance) === null || b === void 0 || (b = b.$binding) === null || b === void 0 || (b = b.value) === null || b === void 0 ? void 0 : b.unstyled) !== void 0 ? (y = o.$instance) === null || y === void 0 || (y = y.$binding) === null || y === void 0 || (y = y.value) === null || y === void 0 ? void 0 : y.unstyled : f == null ? void 0 : f.unstyled;
        },
        /* instance's methods */
        ptm: function() {
          var b, y = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : "", g = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : {};
          return In._getPTValue(o.$instance, (b = o.$instance) === null || b === void 0 || (b = b.$binding) === null || b === void 0 || (b = b.value) === null || b === void 0 ? void 0 : b.pt, y, Or({}, g));
        },
        ptmo: function() {
          var b = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : {}, y = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : "", g = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : {};
          return In._getPTValue(o.$instance, b, y, g, !1);
        },
        cx: function() {
          var b, y, g = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : "", E = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : {};
          return (b = o.$instance) !== null && b !== void 0 && b.isUnstyled() ? void 0 : In._getOptionValue((y = o.$instance) === null || y === void 0 || (y = y.$style) === null || y === void 0 ? void 0 : y.classes, g, Or({}, E));
        },
        sx: function() {
          var b, y = arguments.length > 0 && arguments[0] !== void 0 ? arguments[0] : "", g = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : !0, E = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : {};
          return g ? In._getOptionValue((b = o.$instance) === null || b === void 0 || (b = b.$style) === null || b === void 0 ? void 0 : b.inlineStyles, y, Or({}, E)) : void 0;
        }
      }, m), o.$instance = o._$instances[t], (c = (d = o.$instance)[a]) === null || c === void 0 || c.call(d, o, s, l, u), o["$".concat(t)] = o.$instance, In._hook(t, a, o, s, l, u);
    };
    return {
      created: function(a, o, s, l) {
        r("created", a, o, s, l);
      },
      beforeMount: function(a, o, s, l) {
        var u, c, d, f, h = In._getConfig(o, s);
        Wo.loadStyle({
          nonce: h == null || (u = h.csp) === null || u === void 0 ? void 0 : u.nonce
        }), !((c = a.$instance) !== null && c !== void 0 && c.isUnstyled()) && ((d = a.$instance) === null || d === void 0 || (d = d.$style) === null || d === void 0 || d.loadStyle({
          nonce: h == null || (f = h.csp) === null || f === void 0 ? void 0 : f.nonce
        })), r("beforeMount", a, o, s, l);
      },
      mounted: function(a, o, s, l) {
        var u, c, d, f, h = In._getConfig(o, s);
        Wo.loadStyle({
          nonce: h == null || (u = h.csp) === null || u === void 0 ? void 0 : u.nonce
        }), !((c = a.$instance) !== null && c !== void 0 && c.isUnstyled()) && ((d = a.$instance) === null || d === void 0 || (d = d.$style) === null || d === void 0 || d.loadStyle({
          nonce: h == null || (f = h.csp) === null || f === void 0 ? void 0 : f.nonce
        })), r("mounted", a, o, s, l);
      },
      beforeUpdate: function(a, o, s, l) {
        r("beforeUpdate", a, o, s, l);
      },
      updated: function(a, o, s, l) {
        r("updated", a, o, s, l);
      },
      beforeUnmount: function(a, o, s, l) {
        r("beforeUnmount", a, o, s, l);
      },
      unmounted: function(a, o, s, l) {
        r("unmounted", a, o, s, l);
      }
    };
  },
  extend: function() {
    var t = In._getMeta.apply(In, arguments), n = OP(t, 2), r = n[0], i = n[1];
    return Or({
      extend: function() {
        var o = In._getMeta.apply(In, arguments), s = OP(o, 2), l = s[0], u = s[1];
        return In.extend(l, Or(Or(Or({}, i), i == null ? void 0 : i.methods), u));
      }
    }, In._extend(r, i));
  }
}, fUe = {
  root: "p-ink"
}, pUe = Wo.extend({
  name: "ripple",
  classes: fUe
}), mUe = In.extend({
  style: pUe
});
function hUe(e) {
  return bUe(e) || vUe(e) || _Ue(e) || gUe();
}
function gUe() {
  throw new TypeError(`Invalid attempt to spread non-iterable instance.
In order to be iterable, non-array objects must have a [Symbol.iterator]() method.`);
}
function _Ue(e, t) {
  if (e) {
    if (typeof e == "string") return r1(e, t);
    var n = Object.prototype.toString.call(e).slice(8, -1);
    if (n === "Object" && e.constructor && (n = e.constructor.name), n === "Map" || n === "Set") return Array.from(e);
    if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return r1(e, t);
  }
}
function vUe(e) {
  if (typeof Symbol < "u" && e[Symbol.iterator] != null || e["@@iterator"] != null) return Array.from(e);
}
function bUe(e) {
  if (Array.isArray(e)) return r1(e);
}
function r1(e, t) {
  (t == null || t > e.length) && (t = e.length);
  for (var n = 0, r = new Array(t); n < t; n++) r[n] = e[n];
  return r;
}
var EUe = mUe.extend("ripple", {
  mounted: function(t) {
    var n, r = t == null || (n = t.$instance) === null || n === void 0 ? void 0 : n.$config;
    r && r.ripple && (this.create(t), this.bindEvents(t), t.setAttribute("data-pd-ripple", !0));
  },
  unmounted: function(t) {
    this.remove(t);
  },
  timeout: void 0,
  methods: {
    bindEvents: function(t) {
      t.addEventListener("mousedown", this.onMouseDown.bind(this));
    },
    unbindEvents: function(t) {
      t.removeEventListener("mousedown", this.onMouseDown.bind(this));
    },
    create: function(t) {
      var n = on.createElement("span", {
        role: "presentation",
        "aria-hidden": !0,
        "data-p-ink": !0,
        "data-p-ink-active": !1,
        class: !this.isUnstyled() && this.cx("root"),
        onAnimationEnd: this.onAnimationEnd.bind(this),
        "p-bind": this.ptm("root")
      });
      t.appendChild(n), this.$el = n;
    },
    remove: function(t) {
      var n = this.getInk(t);
      n && (this.unbindEvents(t), n.removeEventListener("animationend", this.onAnimationEnd), n.remove());
    },
    onMouseDown: function(t) {
      var n = this, r = t.currentTarget, i = this.getInk(r);
      if (!(!i || getComputedStyle(i, null).display === "none")) {
        if (!this.isUnstyled() && on.removeClass(i, "p-ink-active"), i.setAttribute("data-p-ink-active", "false"), !on.getHeight(i) && !on.getWidth(i)) {
          var a = Math.max(on.getOuterWidth(r), on.getOuterHeight(r));
          i.style.height = a + "px", i.style.width = a + "px";
        }
        var o = on.getOffset(r), s = t.pageX - o.left + document.body.scrollTop - on.getWidth(i) / 2, l = t.pageY - o.top + document.body.scrollLeft - on.getHeight(i) / 2;
        i.style.top = l + "px", i.style.left = s + "px", !this.isUnstyled() && on.addClass(i, "p-ink-active"), i.setAttribute("data-p-ink-active", "true"), this.timeout = setTimeout(function() {
          i && (!n.isUnstyled() && on.removeClass(i, "p-ink-active"), i.setAttribute("data-p-ink-active", "false"));
        }, 401);
      }
    },
    onAnimationEnd: function(t) {
      this.timeout && clearTimeout(this.timeout), !this.isUnstyled() && on.removeClass(t.currentTarget, "p-ink-active"), t.currentTarget.setAttribute("data-p-ink-active", "false");
    },
    getInk: function(t) {
      return t && t.children ? hUe(t.children).find(function(n) {
        return on.getAttribute(n, "data-pc-name") === "ripple";
      }) : void 0;
    }
  }
}), SUe = {
  root: function(t) {
    var n = t.props;
    return ["p-tabview p-component", {
      "p-tabview-scrollable": n.scrollable
    }];
  },
  navContainer: "p-tabview-nav-container",
  previousButton: "p-tabview-nav-prev p-tabview-nav-btn p-link",
  navContent: "p-tabview-nav-content",
  nav: "p-tabview-nav",
  tab: {
    header: function(t) {
      var n = t.instance, r = t.tab, i = t.index;
      return ["p-tabview-header", n.getTabProp(r, "headerClass"), {
        "p-highlight": n.d_activeIndex === i,
        "p-disabled": n.getTabProp(r, "disabled")
      }];
    },
    headerAction: "p-tabview-nav-link p-tabview-header-action",
    headerTitle: "p-tabview-title",
    content: function(t) {
      var n = t.instance, r = t.tab;
      return ["p-tabview-panel", n.getTabProp(r, "contentClass")];
    }
  },
  inkbar: "p-tabview-ink-bar",
  nextButton: "p-tabview-nav-next p-tabview-nav-btn p-link",
  panelContainer: "p-tabview-panels"
}, yUe = Wo.extend({
  name: "tabview",
  classes: SUe
}), TUe = {
  name: "BaseTabView",
  extends: Cd,
  props: {
    activeIndex: {
      type: Number,
      default: 0
    },
    lazy: {
      type: Boolean,
      default: !1
    },
    scrollable: {
      type: Boolean,
      default: !1
    },
    tabindex: {
      type: Number,
      default: 0
    },
    selectOnFocus: {
      type: Boolean,
      default: !1
    },
    previousButtonProps: {
      type: null,
      default: null
    },
    nextButtonProps: {
      type: null,
      default: null
    },
    prevIcon: {
      type: String,
      default: void 0
    },
    nextIcon: {
      type: String,
      default: void 0
    }
  },
  style: yUe,
  provide: function() {
    return {
      $parentInstance: this
    };
  }
}, Wq = {
  name: "TabView",
  extends: TUe,
  emits: ["update:activeIndex", "tab-change", "tab-click"],
  data: function() {
    return {
      id: this.$attrs.id,
      d_activeIndex: this.activeIndex,
      isPrevButtonDisabled: !0,
      isNextButtonDisabled: !1
    };
  },
  watch: {
    "$attrs.id": function(t) {
      this.id = t || zx();
    },
    activeIndex: function(t) {
      this.d_activeIndex = t, this.scrollInView({
        index: t
      });
    }
  },
  mounted: function() {
    this.id = this.id || zx(), this.updateInkBar(), this.scrollable && this.updateButtonState();
  },
  updated: function() {
    this.updateInkBar(), this.scrollable && this.updateButtonState();
  },
  methods: {
    isTabPanel: function(t) {
      return t.type.name === "TabPanel";
    },
    isTabActive: function(t) {
      return this.d_activeIndex === t;
    },
    getTabProp: function(t, n) {
      return t.props ? t.props[n] : void 0;
    },
    getKey: function(t, n) {
      return this.getTabProp(t, "header") || n;
    },
    getTabHeaderActionId: function(t) {
      return "".concat(this.id, "_").concat(t, "_header_action");
    },
    getTabContentId: function(t) {
      return "".concat(this.id, "_").concat(t, "_content");
    },
    getTabPT: function(t, n, r) {
      var i = this.tabs.length, a = {
        props: t.props,
        parent: {
          instance: this,
          props: this.$props,
          state: this.$data
        },
        context: {
          index: r,
          count: i,
          first: r === 0,
          last: r === i - 1,
          active: this.isTabActive(r)
        }
      };
      return $e(this.ptm("tab.".concat(n), {
        tab: a
      }), this.ptm("tabpanel.".concat(n), {
        tabpanel: a
      }), this.ptm("tabpanel.".concat(n), a), this.ptmo(this.getTabProp(t, "pt"), n, a));
    },
    onScroll: function(t) {
      this.scrollable && this.updateButtonState(), t.preventDefault();
    },
    onPrevButtonClick: function() {
      var t = this.$refs.content, n = on.getWidth(t), r = t.scrollLeft - n;
      t.scrollLeft = r <= 0 ? 0 : r;
    },
    onNextButtonClick: function() {
      var t = this.$refs.content, n = on.getWidth(t) - this.getVisibleButtonWidths(), r = t.scrollLeft + n, i = t.scrollWidth - n;
      t.scrollLeft = r >= i ? i : r;
    },
    onTabClick: function(t, n, r) {
      this.changeActiveIndex(t, n, r), this.$emit("tab-click", {
        originalEvent: t,
        index: r
      });
    },
    onTabKeyDown: function(t, n, r) {
      switch (t.code) {
        case "ArrowLeft":
          this.onTabArrowLeftKey(t);
          break;
        case "ArrowRight":
          this.onTabArrowRightKey(t);
          break;
        case "Home":
          this.onTabHomeKey(t);
          break;
        case "End":
          this.onTabEndKey(t);
          break;
        case "PageDown":
          this.onPageDownKey(t);
          break;
        case "PageUp":
          this.onPageUpKey(t);
          break;
        case "Enter":
        case "NumpadEnter":
        case "Space":
          this.onTabEnterKey(t, n, r);
          break;
      }
    },
    onTabArrowRightKey: function(t) {
      var n = this.findNextHeaderAction(t.target.parentElement);
      n ? this.changeFocusedTab(t, n) : this.onTabHomeKey(t), t.preventDefault();
    },
    onTabArrowLeftKey: function(t) {
      var n = this.findPrevHeaderAction(t.target.parentElement);
      n ? this.changeFocusedTab(t, n) : this.onTabEndKey(t), t.preventDefault();
    },
    onTabHomeKey: function(t) {
      var n = this.findFirstHeaderAction();
      this.changeFocusedTab(t, n), t.preventDefault();
    },
    onTabEndKey: function(t) {
      var n = this.findLastHeaderAction();
      this.changeFocusedTab(t, n), t.preventDefault();
    },
    onPageDownKey: function(t) {
      this.scrollInView({
        index: this.$refs.nav.children.length - 2
      }), t.preventDefault();
    },
    onPageUpKey: function(t) {
      this.scrollInView({
        index: 0
      }), t.preventDefault();
    },
    onTabEnterKey: function(t, n, r) {
      this.changeActiveIndex(t, n, r), t.preventDefault();
    },
    findNextHeaderAction: function(t) {
      var n = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : !1, r = n ? t : t.nextElementSibling;
      return r ? on.getAttribute(r, "data-p-disabled") || on.getAttribute(r, "data-pc-section") === "inkbar" ? this.findNextHeaderAction(r) : on.findSingle(r, '[data-pc-section="headeraction"]') : null;
    },
    findPrevHeaderAction: function(t) {
      var n = arguments.length > 1 && arguments[1] !== void 0 ? arguments[1] : !1, r = n ? t : t.previousElementSibling;
      return r ? on.getAttribute(r, "data-p-disabled") || on.getAttribute(r, "data-pc-section") === "inkbar" ? this.findPrevHeaderAction(r) : on.findSingle(r, '[data-pc-section="headeraction"]') : null;
    },
    findFirstHeaderAction: function() {
      return this.findNextHeaderAction(this.$refs.nav.firstElementChild, !0);
    },
    findLastHeaderAction: function() {
      return this.findPrevHeaderAction(this.$refs.nav.lastElementChild, !0);
    },
    changeActiveIndex: function(t, n, r) {
      !this.getTabProp(n, "disabled") && this.d_activeIndex !== r && (this.d_activeIndex = r, this.$emit("update:activeIndex", r), this.$emit("tab-change", {
        originalEvent: t,
        index: r
      }), this.scrollInView({
        index: r
      }));
    },
    changeFocusedTab: function(t, n) {
      if (n && (on.focus(n), this.scrollInView({
        element: n
      }), this.selectOnFocus)) {
        var r = parseInt(n.parentElement.dataset.index, 10), i = this.tabs[r];
        this.changeActiveIndex(t, i, r);
      }
    },
    scrollInView: function(t) {
      var n = t.element, r = t.index, i = r === void 0 ? -1 : r, a = n || this.$refs.nav.children[i];
      a && a.scrollIntoView && a.scrollIntoView({
        block: "nearest"
      });
    },
    updateInkBar: function() {
      var t = this.$refs.nav.children[this.d_activeIndex];
      this.$refs.inkbar.style.width = on.getWidth(t) + "px", this.$refs.inkbar.style.left = on.getOffset(t).left - on.getOffset(this.$refs.nav).left + "px";
    },
    updateButtonState: function() {
      var t = this.$refs.content, n = t.scrollLeft, r = t.scrollWidth, i = on.getWidth(t);
      this.isPrevButtonDisabled = n === 0, this.isNextButtonDisabled = parseInt(n) === r - i;
    },
    getVisibleButtonWidths: function() {
      var t = this.$refs, n = t.prevBtn, r = t.nextBtn;
      return [n, r].reduce(function(i, a) {
        return a ? i + on.getWidth(a) : i;
      }, 0);
    }
  },
  computed: {
    tabs: function() {
      var t = this;
      return this.$slots.default().reduce(function(n, r) {
        return t.isTabPanel(r) ? n.push(r) : r.children && r.children instanceof Array && r.children.forEach(function(i) {
          t.isTabPanel(i) && n.push(i);
        }), n;
      }, []);
    },
    prevButtonAriaLabel: function() {
      return this.$primevue.config.locale.aria ? this.$primevue.config.locale.aria.previous : void 0;
    },
    nextButtonAriaLabel: function() {
      return this.$primevue.config.locale.aria ? this.$primevue.config.locale.aria.next : void 0;
    }
  },
  directives: {
    ripple: EUe
  },
  components: {
    ChevronLeftIcon: zq,
    ChevronRightIcon: Vq
  }
};
function Xp(e) {
  "@babel/helpers - typeof";
  return Xp = typeof Symbol == "function" && typeof Symbol.iterator == "symbol" ? function(t) {
    return typeof t;
  } : function(t) {
    return t && typeof Symbol == "function" && t.constructor === Symbol && t !== Symbol.prototype ? "symbol" : typeof t;
  }, Xp(e);
}
function xP(e, t) {
  var n = Object.keys(e);
  if (Object.getOwnPropertySymbols) {
    var r = Object.getOwnPropertySymbols(e);
    t && (r = r.filter(function(i) {
      return Object.getOwnPropertyDescriptor(e, i).enumerable;
    })), n.push.apply(n, r);
  }
  return n;
}
function za(e) {
  for (var t = 1; t < arguments.length; t++) {
    var n = arguments[t] != null ? arguments[t] : {};
    t % 2 ? xP(Object(n), !0).forEach(function(r) {
      CUe(e, r, n[r]);
    }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(n)) : xP(Object(n)).forEach(function(r) {
      Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(n, r));
    });
  }
  return e;
}
function CUe(e, t, n) {
  return t = AUe(t), t in e ? Object.defineProperty(e, t, { value: n, enumerable: !0, configurable: !0, writable: !0 }) : e[t] = n, e;
}
function AUe(e) {
  var t = OUe(e, "string");
  return Xp(t) == "symbol" ? t : String(t);
}
function OUe(e, t) {
  if (Xp(e) != "object" || !e) return e;
  var n = e[Symbol.toPrimitive];
  if (n !== void 0) {
    var r = n.call(e, t || "default");
    if (Xp(r) != "object") return r;
    throw new TypeError("@@toPrimitive must return a primitive value.");
  }
  return (t === "string" ? String : Number)(e);
}
var RUe = ["tabindex", "aria-label"], wUe = ["data-p-highlight", "data-p-disabled", "data-pc-index", "data-p-active"], xUe = ["id", "tabindex", "aria-disabled", "aria-selected", "aria-controls", "onClick", "onKeydown"], NUe = ["tabindex", "aria-label"], DUe = ["id", "aria-labelledby", "data-pc-index", "data-p-active"];
function IUe(e, t, n, r, i, a) {
  var o = nW("ripple");
  return U(), ee("div", $e({
    class: e.cx("root"),
    role: "tablist"
  }, e.ptm("root")), [de("div", $e({
    class: e.cx("navContainer")
  }, e.ptm("navContainer")), [e.scrollable && !i.isPrevButtonDisabled ? Gn((U(), ee("button", $e({
    key: 0,
    ref: "prevBtn",
    type: "button",
    class: e.cx("previousButton"),
    tabindex: e.tabindex,
    "aria-label": a.prevButtonAriaLabel,
    onClick: t[0] || (t[0] = function() {
      return a.onPrevButtonClick && a.onPrevButtonClick.apply(a, arguments);
    })
  }, za(za({}, e.previousButtonProps), e.ptm("previousButton")), {
    "data-pc-group-section": "navbutton"
  }), [Me(e.$slots, "previcon", {}, function() {
    return [(U(), Ae(ze(e.prevIcon ? "span" : "ChevronLeftIcon"), $e({
      "aria-hidden": "true",
      class: e.prevIcon
    }, e.ptm("previousIcon")), null, 16, ["class"]))];
  })], 16, RUe)), [[o]]) : se("", !0), de("div", $e({
    ref: "content",
    class: e.cx("navContent"),
    onScroll: t[1] || (t[1] = function() {
      return a.onScroll && a.onScroll.apply(a, arguments);
    })
  }, e.ptm("navContent")), [de("ul", $e({
    ref: "nav",
    class: e.cx("nav")
  }, e.ptm("nav")), [(U(!0), ee(gt, null, It(a.tabs, function(s, l) {
    return U(), ee("li", $e({
      key: a.getKey(s, l),
      style: a.getTabProp(s, "headerStyle"),
      class: e.cx("tab.header", {
        tab: s,
        index: l
      }),
      role: "presentation"
    }, za(za(za({}, a.getTabProp(s, "headerProps")), a.getTabPT(s, "root", l)), a.getTabPT(s, "header", l)), {
      "data-pc-name": "tabpanel",
      "data-p-highlight": i.d_activeIndex === l,
      "data-p-disabled": a.getTabProp(s, "disabled"),
      "data-pc-index": l,
      "data-p-active": i.d_activeIndex === l
    }), [Gn((U(), ee("a", $e({
      id: a.getTabHeaderActionId(l),
      class: e.cx("tab.headerAction"),
      tabindex: a.getTabProp(s, "disabled") || !a.isTabActive(l) ? -1 : e.tabindex,
      role: "tab",
      "aria-disabled": a.getTabProp(s, "disabled"),
      "aria-selected": a.isTabActive(l),
      "aria-controls": a.getTabContentId(l),
      onClick: function(c) {
        return a.onTabClick(c, s, l);
      },
      onKeydown: function(c) {
        return a.onTabKeyDown(c, s, l);
      }
    }, za(za({}, a.getTabProp(s, "headerActionProps")), a.getTabPT(s, "headerAction", l))), [s.props && s.props.header ? (U(), ee("span", $e({
      key: 0,
      class: e.cx("tab.headerTitle")
    }, a.getTabPT(s, "headerTitle", l)), zt(s.props.header), 17)) : se("", !0), s.children && s.children.header ? (U(), Ae(ze(s.children.header), {
      key: 1
    })) : se("", !0)], 16, xUe)), [[o]])], 16, wUe);
  }), 128)), de("li", $e({
    ref: "inkbar",
    class: e.cx("inkbar"),
    role: "presentation",
    "aria-hidden": "true"
  }, e.ptm("inkbar")), null, 16)], 16)], 16), e.scrollable && !i.isNextButtonDisabled ? Gn((U(), ee("button", $e({
    key: 1,
    ref: "nextBtn",
    type: "button",
    class: e.cx("nextButton"),
    tabindex: e.tabindex,
    "aria-label": a.nextButtonAriaLabel,
    onClick: t[2] || (t[2] = function() {
      return a.onNextButtonClick && a.onNextButtonClick.apply(a, arguments);
    })
  }, za(za({}, e.nextButtonProps), e.ptm("nextButton")), {
    "data-pc-group-section": "navbutton"
  }), [Me(e.$slots, "nexticon", {}, function() {
    return [(U(), Ae(ze(e.nextIcon ? "span" : "ChevronRightIcon"), $e({
      "aria-hidden": "true",
      class: e.nextIcon
    }, e.ptm("nextIcon")), null, 16, ["class"]))];
  })], 16, NUe)), [[o]]) : se("", !0)], 16), de("div", $e({
    class: e.cx("panelContainer")
  }, e.ptm("panelContainer")), [(U(!0), ee(gt, null, It(a.tabs, function(s, l) {
    return U(), ee(gt, {
      key: a.getKey(s, l)
    }, [!e.lazy || a.isTabActive(l) ? Gn((U(), ee("div", $e({
      key: 0,
      id: a.getTabContentId(l),
      style: a.getTabProp(s, "contentStyle"),
      class: e.cx("tab.content", {
        tab: s
      }),
      role: "tabpanel",
      "aria-labelledby": a.getTabHeaderActionId(l)
    }, za(za(za({}, a.getTabProp(s, "contentProps")), a.getTabPT(s, "root", l)), a.getTabPT(s, "content", l)), {
      "data-pc-name": "tabpanel",
      "data-pc-index": l,
      "data-p-active": i.d_activeIndex === l
    }), [(U(), Ae(ze(s)))], 16, DUe)), [[Wi, e.lazy ? !0 : a.isTabActive(l)]]) : se("", !0)], 64);
  }), 128))], 16)], 16);
}
Wq.render = IUe;
var LUe = {}, kUe = {
  name: "BaseTabPanel",
  extends: Cd,
  props: {
    header: null,
    headerStyle: null,
    headerClass: null,
    headerProps: null,
    headerActionProps: null,
    contentStyle: null,
    contentClass: null,
    contentProps: null,
    disabled: Boolean
  },
  style: LUe
}, Kq = {
  name: "TabPanel",
  extends: kUe
};
function MUe(e, t, n, r, i, a) {
  return Me(e.$slots, "default");
}
Kq.render = MUe;
const PUe = "data:image/png;base64, ", FUe = "data:image/png;base64, ", BUe = ["id"], $Ue = { class: "md-button-container" }, UUe = ["src"], qUe = ["src"], GUe = { class: "md-scroll-container" }, YUe = { class: "md-doc" }, HUe = ["innerHTML"], zUe = {
  __name: "Markdown",
  props: {
    markdownContent: {
      type: String,
      default: ""
    },
    viewMode: {
      type: String,
      default: "rendered"
    },
    id: {
      type: String,
      default: "markdown-default"
    }
  },
  setup(e) {
    const t = e, n = he(t.viewMode), r = he(t.markdownContent), i = he("");
    et(() => t.markdownContent, (l) => {
      r.value = l;
    }, { immediate: !0 }), et(() => t.viewMode, (l) => {
      n.value = l;
    }, { immediate: !0 }), et(() => r.value, (l) => {
      i.value = RO(l), Ut(() => {
        n.value === "rendered" && cp();
      });
    }, { immediate: !0 });
    const a = (l) => {
      n.value = l, l === "rendered" && Ut(() => {
        cp();
      });
    };
    function o(l, u) {
      r.value = l, u && (n.value = u), Ut(() => {
        n.value === "rendered" && cp();
      });
    }
    const s = {
      ws_set_md: ({ content: l, viewMode: u, id: c }) => {
        (!c || c === t.id) && o(l, u || n.value);
      }
    };
    return Yq(), On(() => {
      Bm(s);
    }), pa(() => {
      $m(s);
    }), (l, u) => (U(), ee("div", {
      class: "flex-container",
      id: e.id
    }, [
      de("div", $Ue, [
        de("button", {
          onClick: u[0] || (u[0] = (c) => a("rendered")),
          class: re({ "md-button-selected": n.value === "rendered", "md-button-unselected": n.value !== "rendered" })
        }, [
          de("img", {
            src: ks(FUe),
            alt: "Markdown Rendered"
          }, null, 8, UUe)
        ], 2),
        de("button", {
          onClick: u[1] || (u[1] = (c) => a("source")),
          class: re({ "md-button-selected": n.value === "source", "md-button-unselected": n.value !== "source" })
        }, [
          de("img", {
            src: ks(PUe),
            alt: "Markdown Source"
          }, null, 8, qUe)
        ], 2)
      ]),
      de("div", GUe, [
        Gn(de("div", YUe, [
          de("pre", null, [
            de("code", null, zt(r.value), 1)
          ])
        ], 512), [
          [Wi, n.value === "source"]
        ]),
        Gn(de("div", {
          class: "md-doc",
          innerHTML: i.value,
          ref: "markdownContainer"
        }, null, 8, HUe), [
          [Wi, n.value === "rendered"]
        ])
      ])
    ], 8, BUe));
  }
}, jq = /* @__PURE__ */ Zs(zUe, [["__scopeId", "data-v-0a8712f7"]]), VUe = ["x", "y", "width", "height", "rx", "ry"], WUe = ["x", "y", "font-size", "text-anchor"], NP = {
  __name: "SvgButton",
  props: {
    label: String,
    x: Number,
    y: Number,
    fontSize: Number,
    textAnchor: String
  },
  emits: ["clicked"],
  setup(e, { emit: t }) {
    const n = e, r = t, i = he(null), a = N(() => parseFloat(n.fontSize) * 0.2), o = N(() => {
      if (i.value) {
        const f = i.value.getBBox();
        return n.textAnchor === "end" && -f.width, {
          width: f.width + 2 * a.value,
          height: f.height + 2 * a.value
        };
      }
      return { width: 0, height: 0 };
    }), s = N(() => n.x + (n.textAnchor === "end" ? -o.value.width : 0)), l = N(() => n.y - o.value.height / 2), u = N(() => n.x), c = N(() => n.y), d = () => {
      r("clicked");
    };
    return (f, h) => (U(), ee("svg", {
      onMouseover: h[0] || (h[0] = (m) => f.hover = !0),
      onMouseleave: h[1] || (h[1] = (m) => f.hover = !1),
      onMousedown: h[2] || (h[2] = (m) => f.active = !0),
      onMouseup: h[3] || (h[3] = (m) => f.active = !1),
      onClick: d,
      style: { overflow: "visible", cursor: "pointer" }
    }, [
      de("rect", {
        x: s.value,
        y: l.value,
        width: o.value.width,
        height: o.value.height,
        rx: a.value,
        ry: a.value,
        class: "button-rect"
      }, null, 8, VUe),
      de("text", {
        x: u.value,
        y: c.value,
        "font-size": e.fontSize,
        "text-anchor": e.textAnchor
      }, zt(e.label), 9, WUe)
    ], 32));
  }
}, KUe = (e) => (lF("data-v-f6b7d9b9"), e = e(), uF(), e), jUe = { class: "game-container" }, QUe = ["href"], XUe = ["id", "href", "width", "height"], ZUe = /* @__PURE__ */ KUe(() => /* @__PURE__ */ de("use", {
  href: "#clocksOverlay",
  x: "0",
  y: "0"
}, null, -1)), JUe = ["href", "x", "y"], e8e = ["href", "x", "y"], t8e = {
  x: "0.14",
  y: "0.06",
  class: "player-name",
  "text-anchor": "middle",
  "font-size": "0.027"
}, n8e = {
  x: "0.86",
  y: "0.06",
  class: "player-name",
  "text-anchor": "middle",
  "font-size": "0.027"
}, r8e = {
  x: "0.14",
  y: "0.15",
  class: "clock-text",
  "text-anchor": "middle",
  "font-size": "0.06"
}, i8e = {
  x: "0.86",
  y: "0.15",
  class: "clock-text",
  "text-anchor": "middle",
  "font-size": "0.06"
}, a8e = { key: 0 }, o8e = { key: 1 }, s8e = {
  x: "0.05",
  y: "0.22",
  class: "clock-text",
  "text-anchor": "start",
  "font-size": "0.025"
}, l8e = {
  x: "0.95",
  y: "0.22",
  class: "clock-text",
  "text-anchor": "end",
  "font-size": "0.025"
}, u8e = {
  __name: "GameIO",
  props: {
    board_image: String,
    clocks_image: String,
    locations: Object,
    pieces: Object,
    game_id: String,
    player_names: Object,
    roles: Array
  },
  setup(e) {
    const t = En("send_ws");
    function n(K) {
      return K.reduce((ne, Ee) => (ne[Ee.id] = Ee, ne), {});
    }
    const r = e, i = he(null), a = he(r.board_image), o = he(r.clocks_image), s = he(n(r.pieces)), l = he(n(r.locations)), u = he([]), c = he([]), d = he([]), f = he({}), h = he(r.game_id), m = he(r.player_names), v = he({ b: 0, w: 0 }), b = he(""), y = he(""), g = he(""), E = he(r.roles), S = he(0), C = he([]), T = he("resign"), O = N(() => g.value ? 0 : E.value.includes("b") ? 1 : E.value.includes("w") ? 2 : 0), R = (K) => {
      console.log("Resignation triggered by", K), t("gameio_move", { game_id: h.value, clock: x(), role: K, i: S.value++, lose: "resigned" });
    }, D = () => {
      for (const K of u.value.concat(c.value))
        if (!s.value[K.piece])
          return console.error(`Piece ${K.piece} not defined`), !1;
      return !0;
    }, q = (K) => {
      if (K === void 0)
        return console.error("Time is undefined"), "-:--";
      var ne;
      if (K <= 0 ? ne = -K : (ne = K - Date.now() / 1e3, ne < 0 && (ne = 0)), ne >= 3600) {
        const Ee = Math.floor(ne / 3600), oe = Math.floor(ne % 3600 / 60);
        return `${Ee}:${oe.toString().padStart(2, "0")}`;
      } else if (ne >= 60) {
        const Ee = Math.floor(ne / 60), oe = Math.floor(ne % 60);
        return `${Ee}:${oe.toString().padStart(2, "0")}`;
      } else
        return ne.toFixed(1);
    }, $ = N(() => q(v.value.b)), P = N(() => q(v.value.w)), Y = () => {
      for (const K in v.value)
        if (v.value[K] > 0) {
          if (Date.now() / 1e3 > v.value[K]) {
            v.value[K] = 0, t("gameio_move", { game_id: h.value, clock: v.value, role: K, i: S.value++, lose: "out of time" });
            return;
          }
          Math.floor(v.value[K] * 1e3) % 2 === 0 ? v.value[K] += 1e-3 : v.value[K] -= 1e-3;
        }
    }, L = (K) => {
      for (const ne in K)
        K[ne] > 0 ? v.value[ne] = Date.now() / 1e3 + K[ne] : v.value[ne] = K[ne];
    }, x = () => {
      for (const K in v.value)
        v.value[K] > 0 && (v.value[K] = Date.now() / 1e3 - v.value[K]);
      return { ...v.value };
    }, I = N(() => ({
      backgroundImage: `url(${a.value})`,
      backgroundSize: "cover",
      // Use 'cover' to ensure the image covers without stretching
      backgroundPosition: "center",
      // Center the background image
      width: "100%",
      // Full width
      height: "100%"
      // Full height
    })), k = (K) => (f.value[K] ? f.value[K]++ : f.value[K] = 0, `${K}_${f.value[K]}`), B = (K) => {
      const ne = i.value.getBoundingClientRect(), Ee = K.clientX - ne.left, oe = K.clientY - ne.top, ae = Ee / ne.width, pe = oe / ne.height, Se = W(l.value, ae, pe), Re = d.value.find((Ye) => Ye.dest === Se);
      Re && (Re.game_id = r.game_id, Re.clock = x(), S.value != C.value.length && console.error("Client move index out of sync with client move list", C.value.length, S.value, Re), Re.i = S.value++, Z(Re), t("gameio_move", Re));
    }, W = (K, ne, Ee, oe = 0.05) => {
      let ae = null, pe = 1 / 0;
      for (const Se of Object.values(K)) {
        const [Re, Ye] = Se.coords, nt = Math.sqrt((ne - Re) ** 2 + (Ee - Ye) ** 2);
        nt < oe && nt < pe && (pe = nt, ae = Se.id);
      }
      return ae;
    }, Z = (K) => {
      console.log("doMove:", K), d.value = [];
      var ne = null;
      K.from ? (ne = u.value.find((Ee) => Ee.location === K.from), K.to ? ne.location = K.to : u.value = u.value.filter((Ee) => Ee !== ne)) : K.piece && (ne = {
        uid: k(K.piece),
        piece: K.piece,
        location: K.dest
      }, u.value.push(ne)), K.annotations ? c.value = K.annotations : c.value = [], D();
    }, V = {
      ws_gameio_allow: (K) => {
        K.game_id === r.game_id && (d.value = K.moves);
      },
      ws_gameio_move: (K) => {
        K.game_id === r.game_id && (K.clock && L(K.clock), K.i == S.value ? Z(K) : K.i == S.value - 1 ? console.info("Received echo of move", K.i) : console.error("Incoming move.i out of sync with client board state", S.value, K.i, K), C.value.length == K.i ? (C.value.push(K), S.value = C.value.length) : C.value.length == K.i + 1 ? console.info("Received duplicate or collision of move", K.i) : console.error("Incoming move.i out of sync with client move list", C.value.length, K.i, K));
      },
      ws_gameio_status: (K) => {
        console.log("ws_gameio_status:", K), K.game_id === r.game_id && (g.value = K.winner, K.b && (b.value = K.b), K.w && (y.value = K.w), K.clock && L(K.clock));
      }
    };
    return On(() => {
      Bm(V);
      const K = setInterval(Y, 100);
      pa(() => {
        clearInterval(K), $m(V);
      });
    }), (K, ne) => (U(), ee("div", jUe, [
      de("div", {
        class: "game-board",
        style: am(I.value)
      }, [
        (U(), ee("svg", {
          ref_key: "svgBoard",
          ref: i,
          viewBox: "0 0 1 1",
          style: { width: "100%", height: "100%" },
          onClick: B
        }, [
          de("defs", null, [
            de("image", {
              id: "clocksOverlay",
              href: o.value,
              width: "1",
              height: "1"
            }, null, 8, QUe),
            (U(!0), ee(gt, null, It(s.value, (Ee, oe) => (U(), ee("image", {
              key: oe,
              id: `def_${oe}_${h.value}`,
              href: Ee.image,
              width: Ee.scale,
              height: Ee.scale
            }, null, 8, XUe))), 128))
          ]),
          ZUe,
          (U(!0), ee(gt, null, It(u.value, (Ee) => (U(), ee("use", {
            key: Ee.uid,
            href: `#def_${Ee.piece}_${h.value}`,
            x: l.value[Ee.location].coords[0] - s.value[Ee.piece].scale / 2,
            y: l.value[Ee.location].coords[1] - s.value[Ee.piece].scale / 2
          }, null, 8, JUe))), 128)),
          (U(!0), ee(gt, null, It(c.value, (Ee) => (U(), ee("use", {
            key: Ee.uid,
            href: `#def_${Ee.piece}_${h.value}`,
            x: l.value[Ee.location].coords[0] - s.value[Ee.piece].scale / 2,
            y: l.value[Ee.location].coords[1] - s.value[Ee.piece].scale / 2
          }, null, 8, e8e))), 128)),
          de("text", t8e, zt(m.value.b), 1),
          de("text", n8e, zt(m.value.w), 1),
          de("text", r8e, zt($.value), 1),
          de("text", i8e, zt(P.value), 1),
          O.value === 1 ? (U(), ee("g", a8e, [
            rn(NP, {
              label: T.value,
              x: "0.05",
              y: "0.22",
              "text-anchor": "start",
              "font-size": "0.025",
              onClicked: ne[0] || (ne[0] = (Ee) => R("b"))
            }, null, 8, ["label"])
          ])) : se("", !0),
          O.value === 2 ? (U(), ee("g", o8e, [
            rn(NP, {
              label: T.value,
              x: "0.95",
              y: "0.22",
              "text-anchor": "end",
              "font-size": "0.025",
              onClicked: ne[1] || (ne[1] = (Ee) => R("w"))
            }, null, 8, ["label"])
          ])) : se("", !0),
          de("text", s8e, zt(b.value), 1),
          de("text", l8e, zt(y.value), 1)
        ], 512))
      ], 4)
    ]));
  }
}, Qq = /* @__PURE__ */ Zs(u8e, [["__scopeId", "data-v-f6b7d9b9"]]), xO = {
  __name: "DocTabs",
  setup(e) {
    const t = {
      MarkdownView: jq,
      GameIOView: Qq
    }, n = he([]), r = he(0);
    function i(o, s, l) {
      const u = t[s];
      if (!u) {
        console.error(`Component ${s} not found.`);
        return;
      }
      const c = n.value.findIndex((d) => d.name === o);
      c !== -1 ? (n.value[c].props = l, r.value = c) : (n.value.push({ name: o, component: u, props: l }), r.value = n.value.length - 1);
    }
    const a = {
      ws_open_md: ({ name: o, content: s, viewMode: l }) => {
        i(o, "MarkdownView", {
          markdownContent: s || "Loading...",
          viewMode: l || "rendered"
        });
      },
      ws_open_game: (o) => {
        i(o.game_id, "GameIOView", o);
      }
    };
    return Yq(), On(() => {
      Bm(a);
    }), pa(() => {
      $m(a);
    }), (o, s) => (U(), Ae(ks(Wq), {
      activeIndex: r.value,
      "onUpdate:activeIndex": s[0] || (s[0] = (l) => r.value = l)
    }, {
      default: Qe(() => [
        (U(!0), ee(gt, null, It(n.value, (l) => (U(), Ae(ks(Kq), {
          key: l.name,
          header: l.name
        }, {
          default: Qe(() => [
            (U(), Ae(ze(l.component), bl(cF(l.props)), null, 16))
          ]),
          _: 2
        }, 1032, ["header"]))), 128))
      ]),
      _: 1
    }, 8, ["activeIndex"]));
  }
}, c8e = {
  __name: "TwoPaneLayout",
  setup(e) {
    return Ia.initialize({ startOnLoad: !1 }), (t, n) => (U(), Ae(ks(pF), { style: { height: "100vh", width: "100%" } }, {
      default: Qe(() => [
        rn(ks(XT), { size: 30 }, {
          default: Qe(() => [
            rn(wO),
            rn(Kp)
          ]),
          _: 1
        }),
        rn(ks(XT), { size: 70 }, {
          default: Qe(() => [
            rn(xO, { class: "doc-tabs" })
          ]),
          _: 1
        })
      ]),
      _: 1
    }));
  }
}, Xq = /* @__PURE__ */ Zs(c8e, [["__scopeId", "data-v-f01b06f3"]]), d8e = {
  __name: "App",
  setup(e) {
    const t = Xq;
    return (n, r) => (U(), Ae(ze(ks(t)), null, {
      "left-pane": Qe(() => [
        rn(Kp)
      ]),
      "center-pane": Qe(() => [
        rn(wO)
      ]),
      "right-pane": Qe(() => [
        rn(xO)
      ]),
      _: 1
    }));
  }
};
var Ri = {
  STARTS_WITH: "startsWith",
  CONTAINS: "contains",
  NOT_CONTAINS: "notContains",
  ENDS_WITH: "endsWith",
  EQUALS: "equals",
  NOT_EQUALS: "notEquals",
  IN: "in",
  LESS_THAN: "lt",
  LESS_THAN_OR_EQUAL_TO: "lte",
  GREATER_THAN: "gt",
  GREATER_THAN_OR_EQUAL_TO: "gte",
  BETWEEN: "between",
  DATE_IS: "dateIs",
  DATE_IS_NOT: "dateIsNot",
  DATE_BEFORE: "dateBefore",
  DATE_AFTER: "dateAfter"
};
function Zp(e) {
  "@babel/helpers - typeof";
  return Zp = typeof Symbol == "function" && typeof Symbol.iterator == "symbol" ? function(t) {
    return typeof t;
  } : function(t) {
    return t && typeof Symbol == "function" && t.constructor === Symbol && t !== Symbol.prototype ? "symbol" : typeof t;
  }, Zp(e);
}
function DP(e, t) {
  var n = Object.keys(e);
  if (Object.getOwnPropertySymbols) {
    var r = Object.getOwnPropertySymbols(e);
    t && (r = r.filter(function(i) {
      return Object.getOwnPropertyDescriptor(e, i).enumerable;
    })), n.push.apply(n, r);
  }
  return n;
}
function HT(e) {
  for (var t = 1; t < arguments.length; t++) {
    var n = arguments[t] != null ? arguments[t] : {};
    t % 2 ? DP(Object(n), !0).forEach(function(r) {
      f8e(e, r, n[r]);
    }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(n)) : DP(Object(n)).forEach(function(r) {
      Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(n, r));
    });
  }
  return e;
}
function f8e(e, t, n) {
  return t = p8e(t), t in e ? Object.defineProperty(e, t, { value: n, enumerable: !0, configurable: !0, writable: !0 }) : e[t] = n, e;
}
function p8e(e) {
  var t = m8e(e, "string");
  return Zp(t) == "symbol" ? t : String(t);
}
function m8e(e, t) {
  if (Zp(e) != "object" || !e) return e;
  var n = e[Symbol.toPrimitive];
  if (n !== void 0) {
    var r = n.call(e, t || "default");
    if (Zp(r) != "object") return r;
    throw new TypeError("@@toPrimitive must return a primitive value.");
  }
  return (t === "string" ? String : Number)(e);
}
var IP = {
  ripple: !1,
  inputStyle: null,
  locale: {
    startsWith: "Starts with",
    contains: "Contains",
    notContains: "Not contains",
    endsWith: "Ends with",
    equals: "Equals",
    notEquals: "Not equals",
    noFilter: "No Filter",
    lt: "Less than",
    lte: "Less than or equal to",
    gt: "Greater than",
    gte: "Greater than or equal to",
    dateIs: "Date is",
    dateIsNot: "Date is not",
    dateBefore: "Date is before",
    dateAfter: "Date is after",
    clear: "Clear",
    apply: "Apply",
    matchAll: "Match All",
    matchAny: "Match Any",
    addRule: "Add Rule",
    removeRule: "Remove Rule",
    accept: "Yes",
    reject: "No",
    choose: "Choose",
    upload: "Upload",
    cancel: "Cancel",
    completed: "Completed",
    pending: "Pending",
    fileSizeTypes: ["B", "KB", "MB", "GB", "TB", "PB", "EB", "ZB", "YB"],
    dayNames: ["Sunday", "Monday", "Tuesday", "Wednesday", "Thursday", "Friday", "Saturday"],
    dayNamesShort: ["Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat"],
    dayNamesMin: ["Su", "Mo", "Tu", "We", "Th", "Fr", "Sa"],
    monthNames: ["January", "February", "March", "April", "May", "June", "July", "August", "September", "October", "November", "December"],
    monthNamesShort: ["Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec"],
    chooseYear: "Choose Year",
    chooseMonth: "Choose Month",
    chooseDate: "Choose Date",
    prevDecade: "Previous Decade",
    nextDecade: "Next Decade",
    prevYear: "Previous Year",
    nextYear: "Next Year",
    prevMonth: "Previous Month",
    nextMonth: "Next Month",
    prevHour: "Previous Hour",
    nextHour: "Next Hour",
    prevMinute: "Previous Minute",
    nextMinute: "Next Minute",
    prevSecond: "Previous Second",
    nextSecond: "Next Second",
    am: "am",
    pm: "pm",
    today: "Today",
    weekHeader: "Wk",
    firstDayOfWeek: 0,
    showMonthAfterYear: !1,
    dateFormat: "mm/dd/yy",
    weak: "Weak",
    medium: "Medium",
    strong: "Strong",
    passwordPrompt: "Enter a password",
    emptyFilterMessage: "No results found",
    // @deprecated Use 'emptySearchMessage' option instead.
    searchMessage: "{0} results are available",
    selectionMessage: "{0} items selected",
    emptySelectionMessage: "No selected item",
    emptySearchMessage: "No results found",
    emptyMessage: "No available options",
    aria: {
      trueLabel: "True",
      falseLabel: "False",
      nullLabel: "Not Selected",
      star: "1 star",
      stars: "{star} stars",
      selectAll: "All items selected",
      unselectAll: "All items unselected",
      close: "Close",
      previous: "Previous",
      next: "Next",
      navigation: "Navigation",
      scrollTop: "Scroll Top",
      moveTop: "Move Top",
      moveUp: "Move Up",
      moveDown: "Move Down",
      moveBottom: "Move Bottom",
      moveToTarget: "Move to Target",
      moveToSource: "Move to Source",
      moveAllToTarget: "Move All to Target",
      moveAllToSource: "Move All to Source",
      pageLabel: "Page {page}",
      firstPageLabel: "First Page",
      lastPageLabel: "Last Page",
      nextPageLabel: "Next Page",
      prevPageLabel: "Previous Page",
      rowsPerPageLabel: "Rows per page",
      jumpToPageDropdownLabel: "Jump to Page Dropdown",
      jumpToPageInputLabel: "Jump to Page Input",
      selectRow: "Row Selected",
      unselectRow: "Row Unselected",
      expandRow: "Row Expanded",
      collapseRow: "Row Collapsed",
      showFilterMenu: "Show Filter Menu",
      hideFilterMenu: "Hide Filter Menu",
      filterOperator: "Filter Operator",
      filterConstraint: "Filter Constraint",
      editRow: "Row Edit",
      saveEdit: "Save Edit",
      cancelEdit: "Cancel Edit",
      listView: "List View",
      gridView: "Grid View",
      slide: "Slide",
      slideNumber: "{slideNumber}",
      zoomImage: "Zoom Image",
      zoomIn: "Zoom In",
      zoomOut: "Zoom Out",
      rotateRight: "Rotate Right",
      rotateLeft: "Rotate Left"
    }
  },
  filterMatchModeOptions: {
    text: [Ri.STARTS_WITH, Ri.CONTAINS, Ri.NOT_CONTAINS, Ri.ENDS_WITH, Ri.EQUALS, Ri.NOT_EQUALS],
    numeric: [Ri.EQUALS, Ri.NOT_EQUALS, Ri.LESS_THAN, Ri.LESS_THAN_OR_EQUAL_TO, Ri.GREATER_THAN, Ri.GREATER_THAN_OR_EQUAL_TO],
    date: [Ri.DATE_IS, Ri.DATE_IS_NOT, Ri.DATE_BEFORE, Ri.DATE_AFTER]
  },
  zIndex: {
    modal: 1100,
    overlay: 1e3,
    menu: 1e3,
    tooltip: 1100
  },
  pt: void 0,
  ptOptions: {
    mergeSections: !0,
    mergeProps: !1
  },
  unstyled: !1,
  csp: {
    nonce: void 0
  }
}, h8e = Symbol();
function g8e(e, t, n, r) {
  if (e !== t) {
    var i = document.getElementById(n), a = i.cloneNode(!0), o = i.getAttribute("href").replace(e, t);
    a.setAttribute("id", n + "-clone"), a.setAttribute("href", o), a.addEventListener("load", function() {
      i.remove(), a.setAttribute("id", n), r && r();
    }), i.parentNode && i.parentNode.insertBefore(a, i.nextSibling);
  }
}
var _8e = {
  install: function(t, n) {
    var r = n ? HT(HT({}, IP), n) : HT({}, IP), i = {
      config: u1(r),
      changeTheme: g8e
    };
    t.config.globalProperties.$primevue = i, t.provide(h8e, i);
  }
};
function v8e() {
  return Math.random().toString(16).substring(2, 10);
}
const b8e = {
  install(e, t) {
    if (window.AGI_GREEN_WEBSOCKET_INSTALLED) {
      console.log("websocketPlugin already installed, using existing WebSocket"), e.provide("send_ws", window.send_ws);
      return;
    }
    window.AGI_GREEN_WEBSOCKET_INSTALLED = !0;
    const n = window.location.protocol, r = window.location.hostname, i = window.location.port, o = `${n === "https:" ? "wss:" : "ws:"}//${r}:${i}/ws`;
    console.log("ws_host:", o);
    const s = v8e();
    window.socket_id = s, console.log("Generated socket_id:", s);
    const l = `${o}?socket_id=${s}`;
    let u = new WebSocket(l);
    console.log("WebSocket created:", u);
    let c = null, d = [];
    const f = () => {
      console.log("Connecting WebSocket, current readyState:", u == null ? void 0 : u.readyState), u.readyState === WebSocket.CLOSED && (console.log("Attempting to reconnect WebSocket..."), u = new WebSocket(l), console.log("New WebSocket created:", u), u.onmessage = m, u.onopen = v, u.onerror = b, u.onclose = y);
    }, h = (g, E = {}) => {
      if (console.log("Attempting to send:", g, E, "Socket state:", u == null ? void 0 : u.readyState), u.readyState === WebSocket.OPEN) {
        const S = {
          cmd: g,
          socket_id: s,
          // Include socket_id in all outgoing messages
          ...E
        };
        u.send(JSON.stringify(S)), console.log("sending ws:", g, S);
      } else
        console.log("WebSocket not open, queueing message:", g, E), d.push({ cmd: g, data: E }), f();
    };
    e.provide("send_ws", h), window.send_ws = h;
    const m = (g) => {
      console.log("WebSocket message received:", g.data);
      const E = JSON.parse(g.data), S = E.cmd;
      S ? (delete E.cmd, console.log("received ws message:", S, E), Qc.emit("ws_" + S, E)) : console.error("No cmd in ws message:", E);
    }, v = () => {
      for (console.log("WebSocket connected"), Qc.emit("ws_open"), c && (clearTimeout(c), c = null); d.length > 0; ) {
        const { cmd: g, data: E } = d.shift();
        h(g, E);
      }
    }, b = (g) => {
      console.error("WebSocket error:", g), Qc.emit("ws_error", g);
    }, y = () => {
      console.log("WebSocket closed"), Qc.emit("ws_close"), c || (c = setTimeout(f, 2e3));
    };
    u.onmessage = m, u.onopen = v, u.onerror = b, u.onclose = y, window.addEventListener("dragover", (g) => {
      g.preventDefault(), g.stopPropagation();
    }), window.addEventListener("drop", (g) => {
      console.log("Drop event received:", g), g.preventDefault(), g.stopPropagation();
    });
  }
}, E8e = {
  name: "ResizableLayout",
  props: {
    // Pane configuration: array of {name, class, width, minWidth, maxWidth}
    config: {
      type: Array,
      required: !0
    }
  },
  data() {
    return {
      isResizing: !1,
      currentSplitter: null,
      startX: 0,
      panes: [],
      splitters: []
    };
  },
  created() {
    this.initializeLayout();
  },
  mounted() {
    window.addEventListener("mousemove", this.onMouseMove), window.addEventListener("mouseup", this.onMouseUp), window.addEventListener("mouseleave", this.onMouseUp);
  },
  beforeUnmount() {
    window.removeEventListener("mousemove", this.onMouseMove), window.removeEventListener("mouseup", this.onMouseUp), window.removeEventListener("mouseleave", this.onMouseUp);
  },
  methods: {
    initializeLayout() {
      this.panes = this.config.map((t, n) => ({
        name: t.name || `pane-${n}`,
        class: t.class || "",
        width: t.width || 100 / this.config.length,
        minWidth: t.minWidth || 10,
        maxWidth: t.maxWidth || 80
      }));
      const e = this.panes.reduce((t, n) => t + n.width, 0);
      if (Math.abs(e - 100) > 0.1) {
        const t = 100 / e;
        this.panes.forEach((n) => {
          n.width = n.width * t;
        });
      }
    },
    startResize(e, t) {
      this.isResizing = !0, this.currentSplitter = {
        leftPaneIndex: t,
        rightPaneIndex: t + 1
      }, this.startX = e.clientX, document.body.classList.add("agi-green-resizing"), e.preventDefault();
    },
    onMouseMove(e) {
      if (!this.isResizing || !this.currentSplitter) return;
      const t = e.clientX - this.startX;
      if (t === 0) return;
      const n = this.$el.clientWidth, r = t / n * 100, i = this.currentSplitter.leftPaneIndex, a = this.currentSplitter.rightPaneIndex, o = this.panes[i].width, s = this.panes[a].width;
      let l = o + r, u = s - r;
      const c = this.panes[i].minWidth, d = this.panes[i].maxWidth, f = this.panes[a].minWidth, h = this.panes[a].maxWidth;
      l < c ? (l = c, u = s - (l - o)) : l > d && (l = d, u = s - (l - o)), u < f ? (u = f, l = o + (s - u)) : u > h && (u = h, l = o + (s - u));
      const m = l + u - (o + s);
      Math.abs(m) > 0.01 && (u = s + (o - l)), this.panes[i].width = l, this.panes[a].width = u, this.startX = e.clientX;
    },
    onMouseUp() {
      this.isResizing && (this.isResizing = !1, this.currentSplitter = null, document.body.classList.remove("agi-green-resizing"));
    }
  }
}, S8e = { class: "agi-green-layout-container" }, y8e = ["onMousedown"];
function T8e(e, t, n, r, i, a) {
  return U(), ee("div", S8e, [
    (U(!0), ee(gt, null, It(i.panes, (o, s) => (U(), ee(gt, {
      key: "pane-" + s
    }, [
      de("div", {
        class: re(["agi-green-pane", o.class]),
        style: am({ width: o.width + "%" })
      }, [
        Me(e.$slots, o.name)
      ], 6),
      s < i.panes.length - 1 ? (U(), ee("div", {
        key: 0,
        class: re(["agi-green-splitter", "splitter-" + s]),
        onMousedown: (l) => a.startResize(l, s)
      }, null, 42, y8e)) : se("", !0)
    ], 64))), 128))
  ]);
}
const C8e = /* @__PURE__ */ Zs(E8e, [["render", T8e]]);
/*!
 * perfect-scrollbar v1.5.3
 * Copyright 2021 Hyunje Jun, MDBootstrap and Contributors
 * Licensed under MIT
 */
function qo(e) {
  return getComputedStyle(e);
}
function sa(e, t) {
  for (var n in t) {
    var r = t[n];
    typeof r == "number" && (r = r + "px"), e.style[n] = r;
  }
  return e;
}
function ng(e) {
  var t = document.createElement("div");
  return t.className = e, t;
}
var LP = typeof Element < "u" && (Element.prototype.matches || Element.prototype.webkitMatchesSelector || Element.prototype.mozMatchesSelector || Element.prototype.msMatchesSelector);
function Il(e, t) {
  if (!LP)
    throw new Error("No element matching method supported");
  return LP.call(e, t);
}
function Xc(e) {
  e.remove ? e.remove() : e.parentNode && e.parentNode.removeChild(e);
}
function kP(e, t) {
  return Array.prototype.filter.call(
    e.children,
    function(n) {
      return Il(n, t);
    }
  );
}
var Vr = {
  main: "ps",
  rtl: "ps__rtl",
  element: {
    thumb: function(e) {
      return "ps__thumb-" + e;
    },
    rail: function(e) {
      return "ps__rail-" + e;
    },
    consuming: "ps__child--consume"
  },
  state: {
    focus: "ps--focus",
    clicking: "ps--clicking",
    active: function(e) {
      return "ps--active-" + e;
    },
    scrolling: function(e) {
      return "ps--scrolling-" + e;
    }
  }
}, Zq = { x: null, y: null };
function Jq(e, t) {
  var n = e.element.classList, r = Vr.state.scrolling(t);
  n.contains(r) ? clearTimeout(Zq[t]) : n.add(r);
}
function e9(e, t) {
  Zq[t] = setTimeout(
    function() {
      return e.isAlive && e.element.classList.remove(Vr.state.scrolling(t));
    },
    e.settings.scrollingThreshold
  );
}
function A8e(e, t) {
  Jq(e, t), e9(e, t);
}
var Um = function(t) {
  this.element = t, this.handlers = {};
}, t9 = { isEmpty: { configurable: !0 } };
Um.prototype.bind = function(t, n) {
  typeof this.handlers[t] > "u" && (this.handlers[t] = []), this.handlers[t].push(n), this.element.addEventListener(t, n, !1);
};
Um.prototype.unbind = function(t, n) {
  var r = this;
  this.handlers[t] = this.handlers[t].filter(function(i) {
    return n && i !== n ? !0 : (r.element.removeEventListener(t, i, !1), !1);
  });
};
Um.prototype.unbindAll = function() {
  for (var t in this.handlers)
    this.unbind(t);
};
t9.isEmpty.get = function() {
  var e = this;
  return Object.keys(this.handlers).every(
    function(t) {
      return e.handlers[t].length === 0;
    }
  );
};
Object.defineProperties(Um.prototype, t9);
var Xd = function() {
  this.eventElements = [];
};
Xd.prototype.eventElement = function(t) {
  var n = this.eventElements.filter(function(r) {
    return r.element === t;
  })[0];
  return n || (n = new Um(t), this.eventElements.push(n)), n;
};
Xd.prototype.bind = function(t, n, r) {
  this.eventElement(t).bind(n, r);
};
Xd.prototype.unbind = function(t, n, r) {
  var i = this.eventElement(t);
  i.unbind(n, r), i.isEmpty && this.eventElements.splice(this.eventElements.indexOf(i), 1);
};
Xd.prototype.unbindAll = function() {
  this.eventElements.forEach(function(t) {
    return t.unbindAll();
  }), this.eventElements = [];
};
Xd.prototype.once = function(t, n, r) {
  var i = this.eventElement(t), a = function(o) {
    i.unbind(n, a), r(o);
  };
  i.bind(n, a);
};
function rg(e) {
  if (typeof window.CustomEvent == "function")
    return new CustomEvent(e);
  var t = document.createEvent("CustomEvent");
  return t.initCustomEvent(e, !1, !1, void 0), t;
}
function w_(e, t, n, r, i) {
  r === void 0 && (r = !0), i === void 0 && (i = !1);
  var a;
  if (t === "top")
    a = [
      "contentHeight",
      "containerHeight",
      "scrollTop",
      "y",
      "up",
      "down"
    ];
  else if (t === "left")
    a = [
      "contentWidth",
      "containerWidth",
      "scrollLeft",
      "x",
      "left",
      "right"
    ];
  else
    throw new Error("A proper axis should be provided");
  O8e(e, n, a, r, i);
}
function O8e(e, t, n, r, i) {
  var a = n[0], o = n[1], s = n[2], l = n[3], u = n[4], c = n[5];
  r === void 0 && (r = !0), i === void 0 && (i = !1);
  var d = e.element;
  e.reach[l] = null, d[s] < 1 && (e.reach[l] = "start"), d[s] > e[a] - e[o] - 1 && (e.reach[l] = "end"), t && (d.dispatchEvent(rg("ps-scroll-" + l)), t < 0 ? d.dispatchEvent(rg("ps-scroll-" + u)) : t > 0 && d.dispatchEvent(rg("ps-scroll-" + c)), r && A8e(e, l)), e.reach[l] && (t || i) && d.dispatchEvent(rg("ps-" + l + "-reach-" + e.reach[l]));
}
function wr(e) {
  return parseInt(e, 10) || 0;
}
function R8e(e) {
  return Il(e, "input,[contenteditable]") || Il(e, "select,[contenteditable]") || Il(e, "textarea,[contenteditable]") || Il(e, "button,[contenteditable]");
}
function w8e(e) {
  var t = qo(e);
  return wr(t.width) + wr(t.paddingLeft) + wr(t.paddingRight) + wr(t.borderLeftWidth) + wr(t.borderRightWidth);
}
var Gc = {
  isWebKit: typeof document < "u" && "WebkitAppearance" in document.documentElement.style,
  supportsTouch: typeof window < "u" && ("ontouchstart" in window || "maxTouchPoints" in window.navigator && window.navigator.maxTouchPoints > 0 || window.DocumentTouch && document instanceof window.DocumentTouch),
  supportsIePointer: typeof navigator < "u" && navigator.msMaxTouchPoints,
  isChrome: typeof navigator < "u" && /Chrome/i.test(navigator && navigator.userAgent)
};
function Hs(e) {
  var t = e.element, n = Math.floor(t.scrollTop), r = t.getBoundingClientRect();
  e.containerWidth = Math.round(r.width), e.containerHeight = Math.round(r.height), e.contentWidth = t.scrollWidth, e.contentHeight = t.scrollHeight, t.contains(e.scrollbarXRail) || (kP(t, Vr.element.rail("x")).forEach(
    function(i) {
      return Xc(i);
    }
  ), t.appendChild(e.scrollbarXRail)), t.contains(e.scrollbarYRail) || (kP(t, Vr.element.rail("y")).forEach(
    function(i) {
      return Xc(i);
    }
  ), t.appendChild(e.scrollbarYRail)), !e.settings.suppressScrollX && e.containerWidth + e.settings.scrollXMarginOffset < e.contentWidth ? (e.scrollbarXActive = !0, e.railXWidth = e.containerWidth - e.railXMarginWidth, e.railXRatio = e.containerWidth / e.railXWidth, e.scrollbarXWidth = MP(
    e,
    wr(e.railXWidth * e.containerWidth / e.contentWidth)
  ), e.scrollbarXLeft = wr(
    (e.negativeScrollAdjustment + t.scrollLeft) * (e.railXWidth - e.scrollbarXWidth) / (e.contentWidth - e.containerWidth)
  )) : e.scrollbarXActive = !1, !e.settings.suppressScrollY && e.containerHeight + e.settings.scrollYMarginOffset < e.contentHeight ? (e.scrollbarYActive = !0, e.railYHeight = e.containerHeight - e.railYMarginHeight, e.railYRatio = e.containerHeight / e.railYHeight, e.scrollbarYHeight = MP(
    e,
    wr(e.railYHeight * e.containerHeight / e.contentHeight)
  ), e.scrollbarYTop = wr(
    n * (e.railYHeight - e.scrollbarYHeight) / (e.contentHeight - e.containerHeight)
  )) : e.scrollbarYActive = !1, e.scrollbarXLeft >= e.railXWidth - e.scrollbarXWidth && (e.scrollbarXLeft = e.railXWidth - e.scrollbarXWidth), e.scrollbarYTop >= e.railYHeight - e.scrollbarYHeight && (e.scrollbarYTop = e.railYHeight - e.scrollbarYHeight), x8e(t, e), e.scrollbarXActive ? t.classList.add(Vr.state.active("x")) : (t.classList.remove(Vr.state.active("x")), e.scrollbarXWidth = 0, e.scrollbarXLeft = 0, t.scrollLeft = e.isRtl === !0 ? e.contentWidth : 0), e.scrollbarYActive ? t.classList.add(Vr.state.active("y")) : (t.classList.remove(Vr.state.active("y")), e.scrollbarYHeight = 0, e.scrollbarYTop = 0, t.scrollTop = 0);
}
function MP(e, t) {
  return e.settings.minScrollbarLength && (t = Math.max(t, e.settings.minScrollbarLength)), e.settings.maxScrollbarLength && (t = Math.min(t, e.settings.maxScrollbarLength)), t;
}
function x8e(e, t) {
  var n = { width: t.railXWidth }, r = Math.floor(e.scrollTop);
  t.isRtl ? n.left = t.negativeScrollAdjustment + e.scrollLeft + t.containerWidth - t.contentWidth : n.left = e.scrollLeft, t.isScrollbarXUsingBottom ? n.bottom = t.scrollbarXBottom - r : n.top = t.scrollbarXTop + r, sa(t.scrollbarXRail, n);
  var i = { top: r, height: t.railYHeight };
  t.isScrollbarYUsingRight ? t.isRtl ? i.right = t.contentWidth - (t.negativeScrollAdjustment + e.scrollLeft) - t.scrollbarYRight - t.scrollbarYOuterWidth - 9 : i.right = t.scrollbarYRight - e.scrollLeft : t.isRtl ? i.left = t.negativeScrollAdjustment + e.scrollLeft + t.containerWidth * 2 - t.contentWidth - t.scrollbarYLeft - t.scrollbarYOuterWidth : i.left = t.scrollbarYLeft + e.scrollLeft, sa(t.scrollbarYRail, i), sa(t.scrollbarX, {
    left: t.scrollbarXLeft,
    width: t.scrollbarXWidth - t.railBorderXWidth
  }), sa(t.scrollbarY, {
    top: t.scrollbarYTop,
    height: t.scrollbarYHeight - t.railBorderYWidth
  });
}
function N8e(e) {
  e.element, e.event.bind(e.scrollbarY, "mousedown", function(t) {
    return t.stopPropagation();
  }), e.event.bind(e.scrollbarYRail, "mousedown", function(t) {
    var n = t.pageY - window.pageYOffset - e.scrollbarYRail.getBoundingClientRect().top, r = n > e.scrollbarYTop ? 1 : -1;
    e.element.scrollTop += r * e.containerHeight, Hs(e), t.stopPropagation();
  }), e.event.bind(e.scrollbarX, "mousedown", function(t) {
    return t.stopPropagation();
  }), e.event.bind(e.scrollbarXRail, "mousedown", function(t) {
    var n = t.pageX - window.pageXOffset - e.scrollbarXRail.getBoundingClientRect().left, r = n > e.scrollbarXLeft ? 1 : -1;
    e.element.scrollLeft += r * e.containerWidth, Hs(e), t.stopPropagation();
  });
}
function D8e(e) {
  PP(e, [
    "containerWidth",
    "contentWidth",
    "pageX",
    "railXWidth",
    "scrollbarX",
    "scrollbarXWidth",
    "scrollLeft",
    "x",
    "scrollbarXRail"
  ]), PP(e, [
    "containerHeight",
    "contentHeight",
    "pageY",
    "railYHeight",
    "scrollbarY",
    "scrollbarYHeight",
    "scrollTop",
    "y",
    "scrollbarYRail"
  ]);
}
function PP(e, t) {
  var n = t[0], r = t[1], i = t[2], a = t[3], o = t[4], s = t[5], l = t[6], u = t[7], c = t[8], d = e.element, f = null, h = null, m = null;
  function v(g) {
    g.touches && g.touches[0] && (g[i] = g.touches[0].pageY), d[l] = f + m * (g[i] - h), Jq(e, u), Hs(e), g.stopPropagation(), g.type.startsWith("touch") && g.changedTouches.length > 1 && g.preventDefault();
  }
  function b() {
    e9(e, u), e[c].classList.remove(Vr.state.clicking), e.event.unbind(e.ownerDocument, "mousemove", v);
  }
  function y(g, E) {
    f = d[l], E && g.touches && (g[i] = g.touches[0].pageY), h = g[i], m = (e[r] - e[n]) / (e[a] - e[s]), E ? e.event.bind(e.ownerDocument, "touchmove", v) : (e.event.bind(e.ownerDocument, "mousemove", v), e.event.once(e.ownerDocument, "mouseup", b), g.preventDefault()), e[c].classList.add(Vr.state.clicking), g.stopPropagation();
  }
  e.event.bind(e[o], "mousedown", function(g) {
    y(g);
  }), e.event.bind(e[o], "touchstart", function(g) {
    y(g, !0);
  });
}
function I8e(e) {
  var t = e.element, n = function() {
    return Il(t, ":hover");
  }, r = function() {
    return Il(e.scrollbarX, ":focus") || Il(e.scrollbarY, ":focus");
  };
  function i(a, o) {
    var s = Math.floor(t.scrollTop);
    if (a === 0) {
      if (!e.scrollbarYActive)
        return !1;
      if (s === 0 && o > 0 || s >= e.contentHeight - e.containerHeight && o < 0)
        return !e.settings.wheelPropagation;
    }
    var l = t.scrollLeft;
    if (o === 0) {
      if (!e.scrollbarXActive)
        return !1;
      if (l === 0 && a < 0 || l >= e.contentWidth - e.containerWidth && a > 0)
        return !e.settings.wheelPropagation;
    }
    return !0;
  }
  e.event.bind(e.ownerDocument, "keydown", function(a) {
    if (!(a.isDefaultPrevented && a.isDefaultPrevented() || a.defaultPrevented) && !(!n() && !r())) {
      var o = document.activeElement ? document.activeElement : e.ownerDocument.activeElement;
      if (o) {
        if (o.tagName === "IFRAME")
          o = o.contentDocument.activeElement;
        else
          for (; o.shadowRoot; )
            o = o.shadowRoot.activeElement;
        if (R8e(o))
          return;
      }
      var s = 0, l = 0;
      switch (a.which) {
        case 37:
          a.metaKey ? s = -e.contentWidth : a.altKey ? s = -e.containerWidth : s = -30;
          break;
        case 38:
          a.metaKey ? l = e.contentHeight : a.altKey ? l = e.containerHeight : l = 30;
          break;
        case 39:
          a.metaKey ? s = e.contentWidth : a.altKey ? s = e.containerWidth : s = 30;
          break;
        case 40:
          a.metaKey ? l = -e.contentHeight : a.altKey ? l = -e.containerHeight : l = -30;
          break;
        case 32:
          a.shiftKey ? l = e.containerHeight : l = -e.containerHeight;
          break;
        case 33:
          l = e.containerHeight;
          break;
        case 34:
          l = -e.containerHeight;
          break;
        case 36:
          l = e.contentHeight;
          break;
        case 35:
          l = -e.contentHeight;
          break;
        default:
          return;
      }
      e.settings.suppressScrollX && s !== 0 || e.settings.suppressScrollY && l !== 0 || (t.scrollTop -= l, t.scrollLeft += s, Hs(e), i(s, l) && a.preventDefault());
    }
  });
}
function L8e(e) {
  var t = e.element;
  function n(o, s) {
    var l = Math.floor(t.scrollTop), u = t.scrollTop === 0, c = l + t.offsetHeight === t.scrollHeight, d = t.scrollLeft === 0, f = t.scrollLeft + t.offsetWidth === t.scrollWidth, h;
    return Math.abs(s) > Math.abs(o) ? h = u || c : h = d || f, h ? !e.settings.wheelPropagation : !0;
  }
  function r(o) {
    var s = o.deltaX, l = -1 * o.deltaY;
    return (typeof s > "u" || typeof l > "u") && (s = -1 * o.wheelDeltaX / 6, l = o.wheelDeltaY / 6), o.deltaMode && o.deltaMode === 1 && (s *= 10, l *= 10), s !== s && l !== l && (s = 0, l = o.wheelDelta), o.shiftKey ? [-l, -s] : [s, l];
  }
  function i(o, s, l) {
    if (!Gc.isWebKit && t.querySelector("select:focus"))
      return !0;
    if (!t.contains(o))
      return !1;
    for (var u = o; u && u !== t; ) {
      if (u.classList.contains(Vr.element.consuming))
        return !0;
      var c = qo(u);
      if (l && c.overflowY.match(/(scroll|auto)/)) {
        var d = u.scrollHeight - u.clientHeight;
        if (d > 0 && (u.scrollTop > 0 && l < 0 || u.scrollTop < d && l > 0))
          return !0;
      }
      if (s && c.overflowX.match(/(scroll|auto)/)) {
        var f = u.scrollWidth - u.clientWidth;
        if (f > 0 && (u.scrollLeft > 0 && s < 0 || u.scrollLeft < f && s > 0))
          return !0;
      }
      u = u.parentNode;
    }
    return !1;
  }
  function a(o) {
    var s = r(o), l = s[0], u = s[1];
    if (!i(o.target, l, u)) {
      var c = !1;
      e.settings.useBothWheelAxes ? e.scrollbarYActive && !e.scrollbarXActive ? (u ? t.scrollTop -= u * e.settings.wheelSpeed : t.scrollTop += l * e.settings.wheelSpeed, c = !0) : e.scrollbarXActive && !e.scrollbarYActive && (l ? t.scrollLeft += l * e.settings.wheelSpeed : t.scrollLeft -= u * e.settings.wheelSpeed, c = !0) : (t.scrollTop -= u * e.settings.wheelSpeed, t.scrollLeft += l * e.settings.wheelSpeed), Hs(e), c = c || n(l, u), c && !o.ctrlKey && (o.stopPropagation(), o.preventDefault());
    }
  }
  typeof window.onwheel < "u" ? e.event.bind(t, "wheel", a) : typeof window.onmousewheel < "u" && e.event.bind(t, "mousewheel", a);
}
function k8e(e) {
  if (!Gc.supportsTouch && !Gc.supportsIePointer)
    return;
  var t = e.element;
  function n(m, v) {
    var b = Math.floor(t.scrollTop), y = t.scrollLeft, g = Math.abs(m), E = Math.abs(v);
    if (E > g) {
      if (v < 0 && b === e.contentHeight - e.containerHeight || v > 0 && b === 0)
        return window.scrollY === 0 && v > 0 && Gc.isChrome;
    } else if (g > E && (m < 0 && y === e.contentWidth - e.containerWidth || m > 0 && y === 0))
      return !0;
    return !0;
  }
  function r(m, v) {
    t.scrollTop -= v, t.scrollLeft -= m, Hs(e);
  }
  var i = {}, a = 0, o = {}, s = null;
  function l(m) {
    return m.targetTouches ? m.targetTouches[0] : m;
  }
  function u(m) {
    return m.pointerType && m.pointerType === "pen" && m.buttons === 0 ? !1 : !!(m.targetTouches && m.targetTouches.length === 1 || m.pointerType && m.pointerType !== "mouse" && m.pointerType !== m.MSPOINTER_TYPE_MOUSE);
  }
  function c(m) {
    if (u(m)) {
      var v = l(m);
      i.pageX = v.pageX, i.pageY = v.pageY, a = (/* @__PURE__ */ new Date()).getTime(), s !== null && clearInterval(s);
    }
  }
  function d(m, v, b) {
    if (!t.contains(m))
      return !1;
    for (var y = m; y && y !== t; ) {
      if (y.classList.contains(Vr.element.consuming))
        return !0;
      var g = qo(y);
      if (b && g.overflowY.match(/(scroll|auto)/)) {
        var E = y.scrollHeight - y.clientHeight;
        if (E > 0 && (y.scrollTop > 0 && b < 0 || y.scrollTop < E && b > 0))
          return !0;
      }
      if (v && g.overflowX.match(/(scroll|auto)/)) {
        var S = y.scrollWidth - y.clientWidth;
        if (S > 0 && (y.scrollLeft > 0 && v < 0 || y.scrollLeft < S && v > 0))
          return !0;
      }
      y = y.parentNode;
    }
    return !1;
  }
  function f(m) {
    if (u(m)) {
      var v = l(m), b = { pageX: v.pageX, pageY: v.pageY }, y = b.pageX - i.pageX, g = b.pageY - i.pageY;
      if (d(m.target, y, g))
        return;
      r(y, g), i = b;
      var E = (/* @__PURE__ */ new Date()).getTime(), S = E - a;
      S > 0 && (o.x = y / S, o.y = g / S, a = E), n(y, g) && m.preventDefault();
    }
  }
  function h() {
    e.settings.swipeEasing && (clearInterval(s), s = setInterval(function() {
      if (e.isInitialized) {
        clearInterval(s);
        return;
      }
      if (!o.x && !o.y) {
        clearInterval(s);
        return;
      }
      if (Math.abs(o.x) < 0.01 && Math.abs(o.y) < 0.01) {
        clearInterval(s);
        return;
      }
      if (!e.element) {
        clearInterval(s);
        return;
      }
      r(o.x * 30, o.y * 30), o.x *= 0.8, o.y *= 0.8;
    }, 10));
  }
  Gc.supportsTouch ? (e.event.bind(t, "touchstart", c), e.event.bind(t, "touchmove", f), e.event.bind(t, "touchend", h)) : Gc.supportsIePointer && (window.PointerEvent ? (e.event.bind(t, "pointerdown", c), e.event.bind(t, "pointermove", f), e.event.bind(t, "pointerup", h)) : window.MSPointerEvent && (e.event.bind(t, "MSPointerDown", c), e.event.bind(t, "MSPointerMove", f), e.event.bind(t, "MSPointerUp", h)));
}
var M8e = function() {
  return {
    handlers: ["click-rail", "drag-thumb", "keyboard", "wheel", "touch"],
    maxScrollbarLength: null,
    minScrollbarLength: null,
    scrollingThreshold: 1e3,
    scrollXMarginOffset: 0,
    scrollYMarginOffset: 0,
    suppressScrollX: !1,
    suppressScrollY: !1,
    swipeEasing: !0,
    useBothWheelAxes: !1,
    wheelPropagation: !0,
    wheelSpeed: 1
  };
}, P8e = {
  "click-rail": N8e,
  "drag-thumb": D8e,
  keyboard: I8e,
  wheel: L8e,
  touch: k8e
}, qm = function(t, n) {
  var r = this;
  if (n === void 0 && (n = {}), typeof t == "string" && (t = document.querySelector(t)), !t || !t.nodeName)
    throw new Error("no element is specified to initialize PerfectScrollbar");
  this.element = t, t.classList.add(Vr.main), this.settings = M8e();
  for (var i in n)
    this.settings[i] = n[i];
  this.containerWidth = null, this.containerHeight = null, this.contentWidth = null, this.contentHeight = null;
  var a = function() {
    return t.classList.add(Vr.state.focus);
  }, o = function() {
    return t.classList.remove(Vr.state.focus);
  };
  this.isRtl = qo(t).direction === "rtl", this.isRtl === !0 && t.classList.add(Vr.rtl), this.isNegativeScroll = function() {
    var u = t.scrollLeft, c = null;
    return t.scrollLeft = -1, c = t.scrollLeft < 0, t.scrollLeft = u, c;
  }(), this.negativeScrollAdjustment = this.isNegativeScroll ? t.scrollWidth - t.clientWidth : 0, this.event = new Xd(), this.ownerDocument = t.ownerDocument || document, this.scrollbarXRail = ng(Vr.element.rail("x")), t.appendChild(this.scrollbarXRail), this.scrollbarX = ng(Vr.element.thumb("x")), this.scrollbarXRail.appendChild(this.scrollbarX), this.scrollbarX.setAttribute("tabindex", 0), this.event.bind(this.scrollbarX, "focus", a), this.event.bind(this.scrollbarX, "blur", o), this.scrollbarXActive = null, this.scrollbarXWidth = null, this.scrollbarXLeft = null;
  var s = qo(this.scrollbarXRail);
  this.scrollbarXBottom = parseInt(s.bottom, 10), isNaN(this.scrollbarXBottom) ? (this.isScrollbarXUsingBottom = !1, this.scrollbarXTop = wr(s.top)) : this.isScrollbarXUsingBottom = !0, this.railBorderXWidth = wr(s.borderLeftWidth) + wr(s.borderRightWidth), sa(this.scrollbarXRail, { display: "block" }), this.railXMarginWidth = wr(s.marginLeft) + wr(s.marginRight), sa(this.scrollbarXRail, { display: "" }), this.railXWidth = null, this.railXRatio = null, this.scrollbarYRail = ng(Vr.element.rail("y")), t.appendChild(this.scrollbarYRail), this.scrollbarY = ng(Vr.element.thumb("y")), this.scrollbarYRail.appendChild(this.scrollbarY), this.scrollbarY.setAttribute("tabindex", 0), this.event.bind(this.scrollbarY, "focus", a), this.event.bind(this.scrollbarY, "blur", o), this.scrollbarYActive = null, this.scrollbarYHeight = null, this.scrollbarYTop = null;
  var l = qo(this.scrollbarYRail);
  this.scrollbarYRight = parseInt(l.right, 10), isNaN(this.scrollbarYRight) ? (this.isScrollbarYUsingRight = !1, this.scrollbarYLeft = wr(l.left)) : this.isScrollbarYUsingRight = !0, this.scrollbarYOuterWidth = this.isRtl ? w8e(this.scrollbarY) : null, this.railBorderYWidth = wr(l.borderTopWidth) + wr(l.borderBottomWidth), sa(this.scrollbarYRail, { display: "block" }), this.railYMarginHeight = wr(l.marginTop) + wr(l.marginBottom), sa(this.scrollbarYRail, { display: "" }), this.railYHeight = null, this.railYRatio = null, this.reach = {
    x: t.scrollLeft <= 0 ? "start" : t.scrollLeft >= this.contentWidth - this.containerWidth ? "end" : null,
    y: t.scrollTop <= 0 ? "start" : t.scrollTop >= this.contentHeight - this.containerHeight ? "end" : null
  }, this.isAlive = !0, this.settings.handlers.forEach(function(u) {
    return P8e[u](r);
  }), this.lastScrollTop = Math.floor(t.scrollTop), this.lastScrollLeft = t.scrollLeft, this.event.bind(this.element, "scroll", function(u) {
    return r.onScroll(u);
  }), Hs(this);
};
qm.prototype.update = function() {
  this.isAlive && (this.negativeScrollAdjustment = this.isNegativeScroll ? this.element.scrollWidth - this.element.clientWidth : 0, sa(this.scrollbarXRail, { display: "block" }), sa(this.scrollbarYRail, { display: "block" }), this.railXMarginWidth = wr(qo(this.scrollbarXRail).marginLeft) + wr(qo(this.scrollbarXRail).marginRight), this.railYMarginHeight = wr(qo(this.scrollbarYRail).marginTop) + wr(qo(this.scrollbarYRail).marginBottom), sa(this.scrollbarXRail, { display: "none" }), sa(this.scrollbarYRail, { display: "none" }), Hs(this), w_(this, "top", 0, !1, !0), w_(this, "left", 0, !1, !0), sa(this.scrollbarXRail, { display: "" }), sa(this.scrollbarYRail, { display: "" }));
};
qm.prototype.onScroll = function(t) {
  this.isAlive && (Hs(this), w_(this, "top", this.element.scrollTop - this.lastScrollTop), w_(
    this,
    "left",
    this.element.scrollLeft - this.lastScrollLeft
  ), this.lastScrollTop = Math.floor(this.element.scrollTop), this.lastScrollLeft = this.element.scrollLeft);
};
qm.prototype.destroy = function() {
  this.isAlive && (this.event.unbindAll(), Xc(this.scrollbarX), Xc(this.scrollbarY), Xc(this.scrollbarXRail), Xc(this.scrollbarYRail), this.removePsClasses(), this.element = null, this.scrollbarX = null, this.scrollbarY = null, this.scrollbarXRail = null, this.scrollbarYRail = null, this.isAlive = !1);
};
qm.prototype.removePsClasses = function() {
  this.element.className = this.element.className.split(" ").filter(function(t) {
    return !t.match(/^ps([-_].+|)$/);
  }).join(" ");
};
const FP = [
  "scroll",
  "ps-scroll-y",
  "ps-scroll-x",
  "ps-scroll-up",
  "ps-scroll-down",
  "ps-scroll-left",
  "ps-scroll-right",
  "ps-y-reach-start",
  "ps-y-reach-end",
  "ps-x-reach-start",
  "ps-x-reach-end"
];
var kc = {
  name: "PerfectScrollbar",
  props: {
    options: {
      type: Object,
      required: !1,
      default: () => {
      }
    },
    tag: {
      type: String,
      required: !1,
      default: "div"
    },
    watchOptions: {
      type: Boolean,
      required: !1,
      default: !1
    }
  },
  emits: FP,
  data() {
    return {
      ps: null
    };
  },
  watch: {
    watchOptions(e) {
      !e && this.watcher ? this.watcher() : this.createWatcher();
    }
  },
  mounted() {
    this.create(), this.watchOptions && this.createWatcher();
  },
  updated() {
    this.$nextTick(() => {
      this.update();
    });
  },
  beforeUnmount() {
    this.destroy();
  },
  methods: {
    create() {
      this.ps && this.$isServer || (this.ps = new qm(this.$el, this.options), FP.forEach((e) => {
        this.ps.element.addEventListener(e, (t) => this.$emit(e, t));
      }));
    },
    createWatcher() {
      this.watcher = this.$watch("options", () => {
        this.destroy(), this.create();
      }, {
        deep: !0
      });
    },
    update() {
      this.ps && this.ps.update();
    },
    destroy() {
      this.ps && (this.ps.destroy(), this.ps = null);
    }
  },
  render() {
    return oF(
      this.tag,
      {
        class: "ps"
      },
      this.$slots.default && this.$slots.default()
    );
  }
}, F8e = {
  install: (e, t) => {
    t && (t.name && typeof t.name == "string" && (kc.name = t.name), t.options && typeof t.options == "object" && (kc.props.options.default = () => t.options), t.tag && typeof t.tag == "string" && (kc.props.tag.default = t.tag), t.watchOptions && typeof t.watchOptions == "boolean" && (kc.props.watchOptions = t.watchOptions)), e.component(
      kc.name,
      kc
    );
  }
};
const B8e = {
  vueform: {
    elements: {
      list: {
        add: "+ Add",
        remove: "&times;"
      },
      file: {
        defaultName: "File",
        dndTitle: "Upload file",
        dndDescription: "Drop file or click here to upload",
        removeConfirm: "By removing the file it will be permanently deleted. Are you sure to continue?",
        select: "Select file",
        upload: "Upload"
      },
      multifile: {
        uploadButton: "Upload files",
        dndTitle: "Upload files",
        dndDescription: "Drop files or click here to upload"
      },
      gallery: {
        uploadButton: "Upload images",
        dndTitle: "Upload images",
        dndDescription: "Drop images or click here to upload"
      }
    },
    steps: {
      finish: "Finish",
      next: "Next",
      previous: "Previous"
    },
    editor: {
      acceptedMimesError: "Accepted mimes are: :mimes",
      acceptedExtensionsError: "Accepted extenions are: :extensions"
    },
    datepicker: {
      weekdays: {
        shorthand: [
          "Sun",
          "Mon",
          "Tue",
          "Wed",
          "Thu",
          "Fri",
          "Sat"
        ],
        longhand: [
          "Sunday",
          "Monday",
          "Tuesday",
          "Wednesday",
          "Thursday",
          "Friday",
          "Saturday"
        ]
      },
      months: {
        shorthand: [
          "Jan",
          "Feb",
          "Mar",
          "Apr",
          "May",
          "Jun",
          "Jul",
          "Aug",
          "Sep",
          "Oct",
          "Nov",
          "Dec"
        ],
        longhand: [
          "January",
          "February",
          "March",
          "April",
          "May",
          "June",
          "July",
          "August",
          "September",
          "October",
          "November",
          "December"
        ]
      },
      daysInMonth: [
        31,
        28,
        31,
        30,
        31,
        30,
        31,
        31,
        30,
        31,
        30,
        31
      ],
      firstDayOfWeek: 0,
      ordinal: function(e) {
        var t = e % 100;
        if (t > 3 && t < 21) return "th";
        switch (t % 10) {
          case 1:
            return "st";
          case 2:
            return "nd";
          case 3:
            return "rd";
          default:
            return "th";
        }
      },
      rangeSeparator: " to ",
      weekAbbreviation: "Wk",
      scrollTitle: "Scroll to increment",
      toggleTitle: "Click to toggle",
      amPM: [
        "AM",
        "PM"
      ],
      yearAriaLabel: "Year",
      monthAriaLabel: "Month",
      hourAriaLabel: "Hour",
      minuteAriaLabel: "Minute"
    },
    dateFormats: {
      datetimeSeconds24: "YYYY-MM-DD HH:mm:ss",
      datetimeSeconds12: "YYYY-MM-DD hh:mm:ss a",
      datetime24: "YYYY-MM-DD HH:mm",
      datetime12: "YYYY-MM-DD hh:mm a",
      timeSeconds24: "HH:mm:ss",
      timeSeconds12: "hh:mm:ss a",
      time24: "HH:mm",
      time12: "hh:mm a",
      date: "YYYY-MM-DD"
    },
    multiselect: {
      multipleLabelOne: "1 option selected",
      multipleLabelMore: ":options options selected",
      noResults: "No options found",
      noOptions: "The list is empty"
    },
    defaultMessage: "Invalid field",
    a11y: {
      file: {
        description: "Press Backspace to remove"
      },
      list: {
        remove: "Remove item button"
      }
    }
  },
  validation: {
    accepted: "The :attribute must be accepted.",
    active_url: "The :attribute is not a valid URL.",
    after: "The :attribute must be a date after :date.",
    after_or_equal: "The :attribute must be a date after or equal to :date.",
    alpha: "The :attribute may only contain letters.",
    alpha_dash: "The :attribute may only contain letters, numbers, dashes and underscores.",
    alpha_num: "The :attribute may only contain letters and numbers.",
    array: "The :attribute must be an array.",
    before: "The :attribute must be a date before :date.",
    before_or_equal: "The :attribute must be a date before or equal to :date.",
    between: {
      numeric: "The :attribute must be between :min and :max.",
      file: "The :attribute must be between :min and :max kilobytes.",
      string: "The :attribute must be between :min and :max characters.",
      array: "The :attribute must have between :min and :max items."
    },
    boolean: "The :attribute field must be true or false.",
    confirmed: "The :attribute confirmation does not match.",
    date: "The :attribute is not a valid date.",
    date_format: "The :attribute does not match the format :format.",
    date_equals: "The :attribute must be equal to :date.",
    different: "The :attribute and :other must be different.",
    digits: "The :attribute must be :digits digits.",
    digits_between: "The :attribute must be between :min and :max digits.",
    dimensions: "The :attribute has invalid image dimensions.",
    distinct: "The :attribute field has a duplicate value.",
    email: "The :attribute must be a valid email address.",
    exists: "The selected :attribute is invalid.",
    file: "The :attribute must be a file.",
    filled: "The :attribute field must have a value.",
    gt: {
      numeric: "The :attribute must be greater than :value.",
      file: "The :attribute must be greater than :value kilobytes.",
      string: "The :attribute must be greater than :value characters.",
      array: "The :attribute must have more than :value items."
    },
    gte: {
      numeric: "The :attribute must be greater than or equal :value.",
      file: "The :attribute must be greater than or equal :value kilobytes.",
      string: "The :attribute must be greater than or equal :value characters.",
      array: "The :attribute must have :value items or more."
    },
    image: "The :attribute must be an image.",
    in: "The selected :attribute is invalid.",
    in_array: "The :attribute field does not exist in :other.",
    integer: "The :attribute must be an integer.",
    ip: "The :attribute must be a valid IP address.",
    ipv4: "The :attribute must be a valid IPv4 address.",
    ipv6: "The :attribute must be a valid IPv6 address.",
    json: "The :attribute must be a valid JSON string.",
    lt: {
      numeric: "The :attribute must be less than :value.",
      file: "The :attribute must be less than :value kilobytes.",
      string: "The :attribute must be less than :value characters.",
      array: "The :attribute must have less than :value items."
    },
    lte: {
      numeric: "The :attribute must be less than or equal :value.",
      file: "The :attribute must be less than or equal :value kilobytes.",
      string: "The :attribute must be less than or equal :value characters.",
      array: "The :attribute must not have more than :value items."
    },
    max: {
      numeric: "The :attribute may not be greater than :max.",
      file: "The :attribute may not be greater than :max kilobytes.",
      string: "The :attribute may not be greater than :max characters.",
      array: "The :attribute may not have more than :max items."
    },
    mimes: "The :attribute must be a file of type: :values.",
    mimetypes: "The :attribute must be a file of type: :values.",
    min: {
      numeric: "The :attribute must be at least :min.",
      file: "The :attribute must be at least :min kilobytes.",
      string: "The :attribute must be at least :min characters.",
      array: "The :attribute must have at least :min items."
    },
    not_in: "The selected :attribute is invalid.",
    not_regex: "The :attribute format is invalid.",
    numeric: "The :attribute must be a number.",
    present: "The :attribute field must be present.",
    regex: "The :attribute format is invalid.",
    required: "The :attribute field is required.",
    required_if: "The :attribute field is required when :other is :value.",
    required_unless: "The :attribute field is required unless :other is in :values.",
    required_with: "The :attribute field is required when :values is present.",
    required_with_all: "The :attribute field is required when :values are present.",
    required_without: "The :attribute field is required when :values is not present.",
    required_without_all: "The :attribute field is required when none of :values are present.",
    same: "The :attribute and :other must match.",
    size: {
      numeric: "The :attribute must be :size.",
      file: "The :attribute must be :size kilobytes.",
      string: "The :attribute must be :size characters.",
      array: "The :attribute must contain :size items."
    },
    string: "The :attribute must be a string.",
    timezone: "The :attribute must be a valid zone.",
    unique: "The :attribute has already been taken.",
    uploaded: "The :attribute failed to upload.",
    url: "The :attribute format is invalid.",
    uuid: "The :attribute must be a valid UUID.",
    remote: "The :attribute field is invalid."
  }
};
/*!
 * Vueform v1.7.3 (https://github.com/vueform/vueform)
 * Copyright (c) 2024 Adam Berecz <adam@vueform.com>
 * Licensed under the MIT License
 */
var NO = {
  data() {
    return {
      merge: !0,
      defaultClasses: {
        form: ""
      }
    };
  }
};
function $8e(e, t, n, r, i, a) {
  const o = Bt("FormElements");
  return U(), ee(
    "form",
    {
      class: re(e.classes.form),
      onSubmit: t[0] || (t[0] = An((...s) => e.submit && e.submit(...s), ["prevent"]))
    },
    [
      Me(e.$slots, "empty", {}, () => [
        e.showMessages ? (U(), Ae(ze("FormMessages"), { key: 0 })) : se("v-if", !0),
        e.showErrors ? (U(), Ae(ze("FormErrors"), { key: 1 })) : se("v-if", !0),
        e.showLanguages ? (U(), Ae(ze("FormLanguages"), { key: 2 })) : se("v-if", !0),
        e.showTabs ? (U(), Ae(ze("FormTabs"), { key: 3 })) : se("v-if", !0),
        e.showSteps ? (U(), Ae(ze("FormSteps"), { key: 4 })) : se("v-if", !0),
        rn(o, null, {
          default: Qe(() => [
            Me(e.$slots, "default")
          ]),
          _: 3
          /* FORWARDED */
        }),
        e.showStepsControls ? (U(), Ae(ze("FormStepsControls"), { key: 5 })) : se("v-if", !0)
      ])
    ],
    34
    /* CLASS, NEED_HYDRATION */
  );
}
NO.render = $8e;
NO.__file = "themes/blank/templates/Vueform.vue";
var DO = {
  name: "FormErrors",
  data() {
    return {
      merge: !0,
      defaultClasses: {
        container: "",
        error: ""
      }
    };
  }
};
const U8e = ["innerHTML"];
function q8e(e, t, n, r, i, a) {
  return U(), ee(
    "div",
    {
      class: re(e.classes.container)
    },
    [
      (U(!0), ee(
        gt,
        null,
        It(e.errors, (o, s, l) => (U(), ee("div", {
          class: re(e.classes.error),
          innerHTML: o,
          key: l
        }, null, 10, U8e))),
        128
        /* KEYED_FRAGMENT */
      ))
    ],
    2
    /* CLASS */
  );
}
DO.render = q8e;
DO.__file = "themes/blank/templates/FormErrors.vue";
var IO = {
  name: "FormMessages",
  data() {
    return {
      merge: !0,
      defaultClasses: {
        container: "",
        message: ""
      }
    };
  }
};
const G8e = ["innerHTML"];
function Y8e(e, t, n, r, i, a) {
  return U(), ee(
    "div",
    {
      class: re(e.classes.container)
    },
    [
      (U(!0), ee(
        gt,
        null,
        It(e.messages, (o, s, l) => (U(), ee("div", {
          class: re(e.classes.message),
          innerHTML: o,
          key: l
        }, null, 10, G8e))),
        128
        /* KEYED_FRAGMENT */
      ))
    ],
    2
    /* CLASS */
  );
}
IO.render = Y8e;
IO.__file = "themes/blank/templates/FormMessages.vue";
var LO = {
  name: "FormLanguages",
  data() {
    return {
      merge: !0,
      defaultClasses: {
        container: ""
      }
    };
  }
};
function H8e(e, t, n, r, i, a) {
  const o = Bt("FormLanguage");
  return U(), ee(
    "ul",
    {
      class: re(e.classes.container)
    },
    [
      Me(e.$slots, "default", {}, () => [
        (U(!0), ee(
          gt,
          null,
          It(e.languages, (s, l, u) => (U(), Ae(o, {
            language: s,
            code: l,
            key: u,
            onSelect: e.handleSelect
          }, null, 8, ["language", "code", "onSelect"]))),
          128
          /* KEYED_FRAGMENT */
        ))
      ])
    ],
    2
    /* CLASS */
  );
}
LO.render = H8e;
LO.__file = "themes/blank/templates/FormLanguages.vue";
var kO = {
  name: "FormLanguage",
  data() {
    return {
      merge: !0,
      defaultClasses: {
        container: "",
        wrapper: ""
      }
    };
  }
};
function z8e(e, t, n, r, i, a) {
  return U(), ee(
    "li",
    {
      class: re(e.classes.container)
    },
    [
      de(
        "a",
        {
          href: "#",
          class: re(e.classes.wrapper),
          onClick: t[0] || (t[0] = An((...o) => e.select && e.select(...o), ["prevent"]))
        },
        zt(e.language),
        3
        /* TEXT, CLASS */
      )
    ],
    2
    /* CLASS */
  );
}
kO.render = z8e;
kO.__file = "themes/blank/templates/FormLanguage.vue";
var MO = {
  name: "FormTabs",
  data() {
    return {
      merge: !0,
      defaultClasses: {
        container: ""
      }
    };
  }
};
function V8e(e, t, n, r, i, a) {
  const o = Bt("FormTab");
  return U(), ee(
    "ul",
    {
      class: re(e.classes.container),
      role: "tablist"
    },
    [
      Me(e.$slots, "default", {}, () => [
        (U(!0), ee(
          gt,
          null,
          It(e.tabs, (s, l, u) => (U(), Ae(o, $e(s, {
            name: l,
            index: u,
            key: l
          }), null, 16, ["name", "index"]))),
          128
          /* KEYED_FRAGMENT */
        ))
      ])
    ],
    2
    /* CLASS */
  );
}
MO.render = V8e;
MO.__file = "themes/blank/templates/FormTabs.vue";
var PO = {
  name: "FormTab",
  data() {
    return {
      merge: !0,
      defaultClasses: {
        container: "",
        wrapper: ""
      }
    };
  }
};
const W8e = ["aria-selected"], K8e = { key: 0 }, j8e = ["innerHTML"];
function Q8e(e, t, n, r, i, a) {
  return Gn((U(), ee(
    "li",
    {
      class: re(e.classes.container)
    },
    [
      de("div", {
        class: re(e.classes.wrapper),
        tabindex: "0",
        role: "tab",
        "aria-selected": e.active,
        onClick: t[0] || (t[0] = An((...o) => e.select && e.select(...o), ["prevent"])),
        onKeypress: t[1] || (t[1] = Zr(An((...o) => e.select && e.select(...o), ["prevent"]), ["enter", "space"]))
      }, [
        Me(e.$slots, "default", {}, () => [
          se(" If label is a component "),
          e.isLabelComponent ? (U(), ee("span", K8e, [
            (U(), Ae(ze(e.tabLabel), { form$: e.form$ }, null, 8, ["form$"]))
          ])) : (U(), ee(
            gt,
            { key: 1 },
            [
              se(" If label is HTML "),
              de("span", { innerHTML: e.tabLabel }, null, 8, j8e)
            ],
            2112
            /* STABLE_FRAGMENT, DEV_ROOT_FRAGMENT */
          ))
        ])
      ], 42, W8e)
    ],
    2
    /* CLASS */
  )), [
    [Wi, e.visible]
  ]);
}
PO.render = Q8e;
PO.__file = "themes/blank/templates/FormTab.vue";
var FO = {
  name: "FormSteps",
  data() {
    return {
      merge: !0,
      defaultClasses: {
        container: "",
        wrapper: ""
      }
    };
  }
};
function X8e(e, t, n, r, i, a) {
  const o = Bt("FormStep");
  return U(), ee(
    "div",
    {
      class: re(e.classes.container),
      role: "tablist"
    },
    [
      de(
        "ul",
        {
          class: re(e.classes.wrapper)
        },
        [
          Me(e.$slots, "default", {}, () => [
            (U(!0), ee(
              gt,
              null,
              It(e.steps, (s, l) => (U(), Ae(o, $e(s, {
                name: l,
                key: l
              }), null, 16, ["name"]))),
              128
              /* KEYED_FRAGMENT */
            ))
          ])
        ],
        2
        /* CLASS */
      )
    ],
    2
    /* CLASS */
  );
}
FO.render = X8e;
FO.__file = "themes/blank/templates/FormSteps.vue";
var BO = {
  name: "FormStepsControls",
  data() {
    return {
      merge: !0,
      defaultClasses: {
        container: ""
      }
    };
  }
};
function Z8e(e, t, n, r, i, a) {
  const o = Bt("FormStepsControl");
  return U(), ee(
    "div",
    {
      class: re(e.classes.container)
    },
    [
      rn(o, {
        type: "previous",
        labels: e.labels
      }, {
        default: Qe(() => [
          Me(e.$slots, "previous")
        ]),
        _: 3
        /* FORWARDED */
      }, 8, ["labels"]),
      rn(o, {
        type: "next",
        labels: e.labels
      }, {
        default: Qe(() => [
          Me(e.$slots, "next")
        ]),
        _: 3
        /* FORWARDED */
      }, 8, ["labels"]),
      rn(o, {
        type: "finish",
        labels: e.labels
      }, {
        default: Qe(() => [
          Me(e.$slots, "finish")
        ]),
        _: 3
        /* FORWARDED */
      }, 8, ["labels"])
    ],
    2
    /* CLASS */
  );
}
BO.render = Z8e;
BO.__file = "themes/blank/templates/FormStepsControls.vue";
var $O = {
  name: "FormStepsControl",
  data() {
    return {
      merge: !0,
      defaultClasses: {
        button: ""
      }
    };
  }
};
const J8e = ["disabled"], e5e = ["innerHTML", "disabled"], t5e = ["disabled"];
function n5e(e, t, n, r, i, a) {
  return U(), ee(
    gt,
    null,
    [
      se(" If label is a component "),
      e.visible && e.label && e.isLabelComponent ? (U(), ee("button", {
        key: 0,
        disabled: e.isDisabled,
        class: re(e.classes.button),
        onClick: t[0] || (t[0] = An((...o) => e.handleClick && e.handleClick(...o), ["prevent"])),
        onKeypress: t[1] || (t[1] = Zr(An((...o) => e.handleClick && e.handleClick(...o), ["prevent"]), ["enter", "space"]))
      }, [
        (U(), Ae(ze(e.label), { step$: e.current$ }, null, 8, ["step$"]))
      ], 42, J8e)) : e.visible && e.label ? (U(), ee(
        gt,
        { key: 1 },
        [
          se(" If label is HTML "),
          de("button", {
            innerHTML: e.label,
            disabled: e.isDisabled,
            class: re(e.classes.button),
            onClick: t[2] || (t[2] = An((...o) => e.handleClick && e.handleClick(...o), ["prevent"])),
            onKeypress: t[3] || (t[3] = Zr(An((...o) => e.handleClick && e.handleClick(...o), ["prevent"]), ["enter", "space"]))
          }, null, 42, e5e)
        ],
        2112
        /* STABLE_FRAGMENT, DEV_ROOT_FRAGMENT */
      )) : e.visible ? (U(), ee(
        gt,
        { key: 2 },
        [
          se(" If label is a slot "),
          de("button", {
            disabled: e.isDisabled,
            class: re(e.classes.button),
            onClick: t[4] || (t[4] = An((...o) => e.handleClick && e.handleClick(...o), ["prevent"])),
            onKeypress: t[5] || (t[5] = Zr(An((...o) => e.handleClick && e.handleClick(...o), ["prevent"]), ["enter", "space"]))
          }, [
            Me(e.$slots, "default")
          ], 42, t5e)
        ],
        2112
        /* STABLE_FRAGMENT, DEV_ROOT_FRAGMENT */
      )) : se("v-if", !0)
    ],
    2112
    /* STABLE_FRAGMENT, DEV_ROOT_FRAGMENT */
  );
}
$O.render = n5e;
$O.__file = "themes/blank/templates/FormStepsControl.vue";
var UO = {
  name: "FormStep",
  data() {
    return {
      merge: !0,
      defaultClasses: {
        container: "",
        wrapper: ""
      }
    };
  }
};
const r5e = ["tabindex", "aria-selected"], i5e = { key: 0 }, a5e = ["innerHTML"];
function o5e(e, t, n, r, i, a) {
  return e.visible ? (U(), ee(
    "li",
    {
      key: 0,
      class: re(e.classes.container)
    },
    [
      de("a", {
        href: "",
        class: re(e.classes.wrapper),
        tabindex: e.isDisabled ? -1 : 0,
        role: "tab",
        "aria-selected": e.active,
        onClick: t[0] || (t[0] = An((...o) => e.select && e.select(...o), ["prevent"])),
        onKeypress: t[1] || (t[1] = Zr(An((...o) => e.select && e.select(...o), ["prevent"]), ["enter", "space"]))
      }, [
        Me(e.$slots, "default", {}, () => [
          se(" If label is a component "),
          e.isLabelComponent ? (U(), ee("span", i5e, [
            (U(), Ae(ze(e.stepLabel), { form$: e.form$ }, null, 8, ["form$"]))
          ])) : (U(), ee(
            gt,
            { key: 1 },
            [
              se(" If label is HTML "),
              de("span", { innerHTML: e.stepLabel }, null, 8, a5e)
            ],
            2112
            /* STABLE_FRAGMENT, DEV_ROOT_FRAGMENT */
          ))
        ])
      ], 42, r5e)
    ],
    2
    /* CLASS */
  )) : se("v-if", !0);
}
UO.render = o5e;
UO.__file = "themes/blank/templates/FormStep.vue";
var qO = {
  name: "FormElements",
  data() {
    return {
      merge: !0,
      defaultClasses: {
        container: ""
      }
    };
  }
};
function s5e(e, t, n, r, i, a) {
  return U(), ee(
    "div",
    {
      class: re(e.classes.container)
    },
    [
      Me(e.$slots, "default", {}, () => [
        (U(!0), ee(
          gt,
          null,
          It(e.schema, (o, s) => (U(), Ae(ze(e.component(o)), $e(o, {
            name: s,
            key: s
          }), null, 16, ["name"]))),
          128
          /* KEYED_FRAGMENT */
        ))
      ])
    ],
    2
    /* CLASS */
  );
}
qO.render = s5e;
qO.__file = "themes/blank/templates/FormElements.vue";
var GO = {
  name: "ElementLayout",
  data() {
    return {
      merge: !0,
      defaultClasses: {
        container: "",
        outerWrapper: "",
        innerContainer: "",
        innerWrapperBefore: "",
        innerWrapper: "",
        innerWrapperAfter: ""
      }
    };
  }
};
function l5e(e, t, n, r, i, a) {
  const o = Bt("ElementLabel"), s = Bt("ElementText"), l = Bt("ElementDescription"), u = Bt("ElementError"), c = Bt("ElementMessage");
  return Gn((U(), ee(
    "div",
    {
      class: re(e.classes.container)
    },
    [
      de(
        "div",
        {
          class: re(e.classes.outerWrapper)
        },
        [
          rn(o, null, {
            default: Qe(() => [
              Me(e.$slots, "label")
            ]),
            info: Qe(() => [
              Me(e.$slots, "info")
            ]),
            _: 3
            /* FORWARDED */
          }),
          de(
            "div",
            {
              class: re(e.classes.innerContainer)
            },
            [
              de(
                "div",
                {
                  class: re(e.classes.innerWrapperBefore)
                },
                [
                  rn(s, { type: "before" }, {
                    default: Qe(() => [
                      Me(e.$slots, "before")
                    ]),
                    _: 3
                    /* FORWARDED */
                  })
                ],
                2
                /* CLASS */
              ),
              de(
                "div",
                {
                  class: re(e.classes.innerWrapper)
                },
                [
                  Me(e.$slots, "element")
                ],
                2
                /* CLASS */
              ),
              de(
                "div",
                {
                  class: re(e.classes.innerWrapperAfter)
                },
                [
                  rn(s, { type: "between" }, {
                    default: Qe(() => [
                      Me(e.$slots, "between")
                    ]),
                    _: 3
                    /* FORWARDED */
                  }),
                  rn(l, null, {
                    default: Qe(() => [
                      Me(e.$slots, "description")
                    ]),
                    _: 3
                    /* FORWARDED */
                  }),
                  rn(u),
                  rn(c),
                  rn(s, { type: "after" }, {
                    default: Qe(() => [
                      Me(e.$slots, "after")
                    ]),
                    _: 3
                    /* FORWARDED */
                  })
                ],
                2
                /* CLASS */
              )
            ],
            2
            /* CLASS */
          )
        ],
        2
        /* CLASS */
      )
    ],
    2
    /* CLASS */
  )), [
    [Wi, e.visible]
  ]);
}
GO.render = l5e;
GO.__file = "themes/blank/templates/ElementLayout.vue";
var YO = {
  name: "ElementLayoutInline",
  data() {
    return {
      merge: !0,
      defaultClasses: {
        container: ""
      }
    };
  }
};
function u5e(e, t, n, r, i, a) {
  const o = Bt("ElementLabel"), s = Bt("ElementText"), l = Bt("ElementDescription"), u = Bt("ElementError"), c = Bt("ElementMessage");
  return Gn((U(), ee(
    "span",
    {
      class: re(e.classes.container)
    },
    [
      rn(o, null, {
        default: Qe(() => [
          Me(e.$slots, "label")
        ]),
        _: 3
        /* FORWARDED */
      }),
      rn(s, { type: "before" }, {
        default: Qe(() => [
          Me(e.$slots, "before")
        ]),
        _: 3
        /* FORWARDED */
      }),
      Me(e.$slots, "element"),
      rn(s, { type: "between" }, {
        default: Qe(() => [
          Me(e.$slots, "between")
        ]),
        _: 3
        /* FORWARDED */
      }),
      rn(l, null, {
        default: Qe(() => [
          Me(e.$slots, "description")
        ]),
        _: 3
        /* FORWARDED */
      }),
      rn(u),
      rn(c),
      rn(s, { type: "after" }, {
        default: Qe(() => [
          Me(e.$slots, "after")
        ]),
        _: 3
        /* FORWARDED */
      })
    ],
    2
    /* CLASS */
  )), [
    [Wi, e.visible]
  ]);
}
YO.render = u5e;
YO.__file = "themes/blank/templates/ElementLayoutInline.vue";
var HO = {
  name: "ElementLoader",
  data() {
    return {
      merge: !0,
      defaultClasses: {
        container: "",
        loader: ""
      }
    };
  }
};
function c5e(e, t, n, r, i, a) {
  return U(), ee(
    "div",
    {
      class: re(e.classes.container)
    },
    [
      de(
        "span",
        {
          class: re(e.classes.loader)
        },
        null,
        2
        /* CLASS */
      )
    ],
    2
    /* CLASS */
  );
}
HO.render = c5e;
HO.__file = "themes/blank/templates/ElementLoader.vue";
var zO = {
  name: "ElementLabelFloating",
  data() {
    return {
      merge: !0,
      defaultClasses: {
        container: "",
        label: ""
      }
    };
  }
};
const d5e = ["innerHTML"];
function f5e(e, t, n, r, i, a) {
  return U(), ee(
    "div",
    {
      class: re(e.classes.container)
    },
    [
      de("span", {
        class: re(e.classes.label),
        innerHTML: e.floating
      }, null, 10, d5e)
    ],
    2
    /* CLASS */
  );
}
zO.render = f5e;
zO.__file = "themes/blank/templates/ElementLabelFloating.vue";
var VO = {
  name: "ElementLabel",
  data() {
    return {
      merge: !0,
      defaultClasses: {
        container: "",
        wrapper: ""
      }
    };
  }
};
const p5e = ["for", "id"], m5e = ["for", "id"], h5e = ["innerHTML"], g5e = ["for", "id"], _5e = ["for", "id"];
function v5e(e, t, n, r, i, a) {
  const o = Bt("ElementInfo");
  return U(), ee(
    gt,
    null,
    [
      se(" If label is a component "),
      e.label && e.isLabelComponent ? (U(), ee("label", {
        key: 0,
        class: re(e.classes.container),
        for: e.name,
        id: e.id
      }, [
        de(
          "span",
          {
            class: re(e.classes.wrapper)
          },
          [
            e.isLabelComponent ? (U(), Ae(ze(e.label), { key: 0 })) : se("v-if", !0)
          ],
          2
          /* CLASS */
        ),
        rn(o, null, {
          default: Qe(() => [
            Me(e.$slots, "info")
          ]),
          _: 3
          /* FORWARDED */
        })
      ], 10, p5e)) : e.label ? (U(), ee(
        gt,
        { key: 1 },
        [
          se(" If label is HTML "),
          de("label", {
            class: re(e.classes.container),
            for: e.name,
            id: e.id
          }, [
            de("span", {
              class: re(e.classes.wrapper),
              innerHTML: e.label
            }, null, 10, h5e),
            rn(o, null, {
              default: Qe(() => [
                Me(e.$slots, "info")
              ]),
              _: 3
              /* FORWARDED */
            })
          ], 10, m5e)
        ],
        2112
        /* STABLE_FRAGMENT, DEV_ROOT_FRAGMENT */
      )) : e.isSlot ? (U(), ee(
        gt,
        { key: 2 },
        [
          se(" If label is a slot "),
          de("label", {
            class: re(e.classes.container),
            for: e.name,
            id: e.id
          }, [
            de(
              "span",
              {
                class: re(e.classes.wrapper)
              },
              [
                Me(e.$slots, "default")
              ],
              2
              /* CLASS */
            ),
            rn(o, null, {
              default: Qe(() => [
                Me(e.$slots, "info")
              ]),
              _: 3
              /* FORWARDED */
            })
          ], 10, g5e)
        ],
        2112
        /* STABLE_FRAGMENT, DEV_ROOT_FRAGMENT */
      )) : e.hasLabel ? (U(), ee(
        gt,
        { key: 3 },
        [
          se(" If labels are forced but has no value "),
          de("label", {
            class: re(e.classes.container),
            for: e.name,
            id: e.id
          }, null, 10, _5e)
        ],
        2112
        /* STABLE_FRAGMENT, DEV_ROOT_FRAGMENT */
      )) : se("v-if", !0)
    ],
    2112
    /* STABLE_FRAGMENT, DEV_ROOT_FRAGMENT */
  );
}
VO.render = v5e;
VO.__file = "themes/blank/templates/ElementLabel.vue";
var WO = {
  name: "ElementInfo",
  data() {
    return {
      merge: !0,
      defaultClasses: {
        container: "",
        wrapper: "",
        content: ""
      }
    };
  }
};
const b5e = ["id"], E5e = ["innerHTML"];
function S5e(e, t, n, r, i, a) {
  return e.info || e.isSlot ? (U(), ee(
    "span",
    {
      key: 0,
      class: re(e.classes.container),
      onMouseover: t[0] || (t[0] = (...o) => e.handleMouseOver && e.handleMouseOver(...o))
    },
    [
      de("div", {
        class: re(e.classes.wrapper),
        id: e.id
      }, [
        e.isSlot ? (U(), ee(
          "span",
          {
            key: 0,
            class: re(e.classes.content)
          },
          [
            Me(e.$slots, "default")
          ],
          2
          /* CLASS */
        )) : (U(), ee("span", {
          key: 1,
          class: re(e.classes.content),
          innerHTML: e.info
        }, null, 10, E5e))
      ], 10, b5e)
    ],
    34
    /* CLASS, NEED_HYDRATION */
  )) : se("v-if", !0);
}
WO.render = S5e;
WO.__file = "themes/blank/templates/ElementInfo.vue";
var KO = {
  name: "ElementDescription",
  data() {
    return {
      merge: !0,
      defaultClasses: {
        container: ""
      }
    };
  }
};
const y5e = ["innerHTML", "id"], T5e = ["id"];
function C5e(e, t, n, r, i, a) {
  return U(), ee(
    gt,
    null,
    [
      se(" If description is HTML "),
      e.description ? (U(), ee("div", {
        key: 0,
        class: re(e.classes.container),
        innerHTML: e.description,
        id: e.id
      }, null, 10, y5e)) : e.isSlot ? (U(), ee(
        gt,
        { key: 1 },
        [
          se(" If description is a slot "),
          de("div", {
            class: re(e.classes.container),
            id: e.id
          }, [
            Me(e.$slots, "default")
          ], 10, T5e)
        ],
        2112
        /* STABLE_FRAGMENT, DEV_ROOT_FRAGMENT */
      )) : se("v-if", !0)
    ],
    2112
    /* STABLE_FRAGMENT, DEV_ROOT_FRAGMENT */
  );
}
KO.render = C5e;
KO.__file = "themes/blank/templates/ElementDescription.vue";
var jO = {
  name: "ElementError",
  data() {
    return {
      merge: !0,
      defaultClasses: {
        container: ""
      }
    };
  }
};
const A5e = ["id", "innerHTML"];
function O5e(e, t, n, r, i, a) {
  return e.error ? (U(), ee("div", {
    key: 0,
    class: re(e.classes.container),
    id: e.id,
    "aria-live": "assertive",
    innerHTML: e.error
  }, null, 10, A5e)) : se("v-if", !0);
}
jO.render = O5e;
jO.__file = "themes/blank/templates/ElementError.vue";
var QO = {
  name: "ElementMessage",
  data() {
    return {
      merge: !0,
      defaultClasses: {
        container: ""
      }
    };
  }
};
const R5e = ["innerHTML"];
function w5e(e, t, n, r, i, a) {
  return e.message ? (U(), ee("div", {
    key: 0,
    class: re(e.classes.container),
    innerHTML: e.message
  }, null, 10, R5e)) : se("v-if", !0);
}
QO.render = w5e;
QO.__file = "themes/blank/templates/ElementMessage.vue";
var XO = {
  name: "ElementText",
  data() {
    return {
      merge: !0,
      defaultClasses: {
        container: ""
      }
    };
  }
};
const x5e = ["innerHTML"];
function N5e(e, t, n, r, i, a) {
  return U(), ee(
    gt,
    null,
    [
      se(" If content is HTML "),
      e.content ? (U(), ee("div", {
        key: 0,
        class: re(e.classes.container),
        innerHTML: e.content
      }, null, 10, x5e)) : e.isSlot ? (U(), ee(
        gt,
        { key: 1 },
        [
          se(" If content is a slot "),
          de(
            "div",
            {
              class: re(e.classes.container)
            },
            [
              Me(e.$slots, "default")
            ],
            2
            /* CLASS */
          )
        ],
        2112
        /* STABLE_FRAGMENT, DEV_ROOT_FRAGMENT */
      )) : se("v-if", !0)
    ],
    2112
    /* STABLE_FRAGMENT, DEV_ROOT_FRAGMENT */
  );
}
XO.render = N5e;
XO.__file = "themes/blank/templates/ElementText.vue";
var ZO = {
  name: "ElementAddon",
  data() {
    return {
      merge: !0,
      defaultClasses: {
        container: "",
        wrapper: ""
      }
    };
  }
};
const D5e = ["innerHTML"];
function I5e(e, t, n, r, i, a) {
  return U(), ee(
    gt,
    null,
    [
      se(" If addon is a component "),
      e.addon && e.isAddonComponent ? (U(), ee(
        "div",
        {
          key: 0,
          class: re(e.classes.container)
        },
        [
          de(
            "div",
            {
              class: re(e.classes.wrapper)
            },
            [
              (U(), Ae(ze(e.addon)))
            ],
            2
            /* CLASS */
          )
        ],
        2
        /* CLASS */
      )) : e.addon ? (U(), ee(
        gt,
        { key: 1 },
        [
          se(" If addon is HTML "),
          de(
            "div",
            {
              class: re(e.classes.container)
            },
            [
              de("div", {
                class: re(e.classes.wrapper),
                innerHTML: e.addon
              }, null, 10, D5e)
            ],
            2
            /* CLASS */
          )
        ],
        2112
        /* STABLE_FRAGMENT, DEV_ROOT_FRAGMENT */
      )) : e.isSlot ? (U(), ee(
        gt,
        { key: 2 },
        [
          se(" If addon is a slot "),
          de(
            "div",
            {
              class: re(e.classes.container)
            },
            [
              de(
                "div",
                {
                  class: re(e.classes.wrapper)
                },
                [
                  Me(e.$slots, "default")
                ],
                2
                /* CLASS */
              )
            ],
            2
            /* CLASS */
          )
        ],
        2112
        /* STABLE_FRAGMENT, DEV_ROOT_FRAGMENT */
      )) : se("v-if", !0)
    ],
    2112
    /* STABLE_FRAGMENT, DEV_ROOT_FRAGMENT */
  );
}
ZO.render = I5e;
ZO.__file = "themes/blank/templates/ElementAddon.vue";
var JO = {
  name: "ButtonElement",
  data() {
    return {
      merge: !0,
      defaultClasses: {
        container: "",
        button: ""
      }
    };
  }
};
const L5e = ["tabindex", "disabled"], k5e = ["innerHTML", "tabindex", "disabled"], M5e = ["tabindex", "disabled"], P5e = ["tabindex"], F5e = ["innerHTML", "tabindex"], B5e = ["tabindex"];
function $5e(e, t, n, r, i, a) {
  return U(), Ae(
    ze(e.elementLayout),
    { ref: "container" },
    nr({
      element: Qe(() => [
        se(" Use `button` tag "),
        e.buttonType === "button" ? (U(), ee(
          gt,
          { key: 0 },
          [
            se(" Use it as a component "),
            e.buttonLabel && e.isButtonLabelComponent ? (U(), ee("button", $e({ key: 0 }, {
              ...e.button,
              ...e.aria
            }, {
              tabindex: e.isDisabled || e.isLoading ? -1 : void 0,
              disabled: e.isDisabled,
              class: e.classes.button,
              onClick: t[0] || (t[0] = An((...o) => e.handleClick && e.handleClick(...o), ["prevent"]))
            }), [
              (U(), Ae(ze(e.buttonLabel)))
            ], 16, L5e)) : e.buttonLabel ? (U(), ee(
              gt,
              { key: 1 },
              [
                se(" Use it as HTML "),
                de("button", $e({
                  ...e.button,
                  ...e.aria
                }, {
                  innerHTML: e.buttonLabel,
                  tabindex: e.isDisabled || e.isLoading ? -1 : void 0,
                  class: e.classes.button,
                  disabled: e.isDisabled,
                  onClick: t[1] || (t[1] = An((...o) => e.handleClick && e.handleClick(...o), ["prevent"]))
                }), null, 16, k5e)
              ],
              2112
              /* STABLE_FRAGMENT, DEV_ROOT_FRAGMENT */
            )) : (U(), ee(
              gt,
              { key: 2 },
              [
                se(" Use it as slot "),
                de("button", $e({
                  ...e.button,
                  ...e.aria
                }, {
                  tabindex: e.isDisabled || e.isLoading ? -1 : void 0,
                  class: e.classes.button,
                  disabled: e.isDisabled,
                  onClick: t[2] || (t[2] = An((...o) => e.handleClick && e.handleClick(...o), ["prevent"]))
                }), [
                  Me(e.$slots, "default", { el$: e.el$ }, () => [
                    (U(), Ae(ze(e.fieldSlots.default), { el$: e.el$ }, null, 8, ["el$"]))
                  ])
                ], 16, M5e)
              ],
              2112
              /* STABLE_FRAGMENT, DEV_ROOT_FRAGMENT */
            ))
          ],
          64
          /* STABLE_FRAGMENT */
        )) : (U(), ee(
          gt,
          { key: 1 },
          [
            se(" Use `anchor` tag "),
            se(" Use it as a component "),
            e.buttonLabel && e.isButtonLabelComponent ? (U(), ee("a", $e({ key: 0 }, {
              ...e.button,
              ...e.aria
            }, {
              tabindex: e.isDisabled || e.isLoading ? -1 : void 0,
              class: e.classes.button,
              onClick: t[3] || (t[3] = (...o) => e.handleClick && e.handleClick(...o))
            }), [
              (U(), Ae(ze(e.buttonLabel)))
            ], 16, P5e)) : e.buttonLabel ? (U(), ee(
              gt,
              { key: 1 },
              [
                se(" Use it as HTML "),
                de("a", $e({
                  ...e.button,
                  ...e.aria
                }, {
                  innerHTML: e.buttonLabel,
                  tabindex: e.isDisabled || e.isLoading ? -1 : void 0,
                  class: e.classes.button,
                  onClick: t[4] || (t[4] = (...o) => e.handleClick && e.handleClick(...o))
                }), null, 16, F5e)
              ],
              2112
              /* STABLE_FRAGMENT, DEV_ROOT_FRAGMENT */
            )) : (U(), ee(
              gt,
              { key: 2 },
              [
                se(" Use it as slot "),
                de("a", $e({
                  ...e.button,
                  ...e.aria
                }, {
                  tabindex: e.isDisabled || e.isLoading ? -1 : void 0,
                  class: e.classes.button,
                  onClick: t[5] || (t[5] = (...o) => e.handleClick && e.handleClick(...o))
                }), [
                  Me(e.$slots, "default", { el$: e.el$ }, () => [
                    (U(), Ae(ze(e.fieldSlots.default), { el$: e.el$ }, null, 8, ["el$"]))
                  ])
                ], 16, B5e)
              ],
              2112
              /* STABLE_FRAGMENT, DEV_ROOT_FRAGMENT */
            ))
          ],
          64
          /* STABLE_FRAGMENT */
        ))
      ]),
      _: 2
      /* DYNAMIC */
    }, [
      It(e.elementSlots, (o, s) => ({
        name: s,
        fn: Qe(() => [
          Me(e.$slots, s, { el$: e.el$ }, () => [
            (U(), Ae(ze(o), { el$: e.el$ }, null, 8, ["el$"]))
          ])
        ])
      }))
    ]),
    1536
    /* NEED_PATCH, DYNAMIC_SLOTS */
  );
}
JO.render = $5e;
JO.__file = "themes/blank/templates/elements/ButtonElement.vue";
var eR = {
  name: "CheckboxElement",
  data() {
    return {
      merge: !0,
      defaultClasses: {
        container: "",
        wrapper: "",
        input: "",
        text: ""
      }
    };
  }
};
const U5e = ["name", "id", "true-value", "false-value", "disabled"], q5e = ["innerHTML"];
function G5e(e, t, n, r, i, a) {
  return U(), Ae(
    ze(e.elementLayout),
    { ref: "container" },
    nr({
      element: Qe(() => [
        de(
          "label",
          {
            class: re(e.classes.wrapper)
          },
          [
            Gn(de("input", $e({
              type: "checkbox",
              "onUpdate:modelValue": t[0] || (t[0] = (o) => e.value = o)
            }, e.aria, {
              class: e.classes.input,
              name: e.path,
              id: e.fieldId,
              "true-value": e.trueValue,
              "false-value": e.falseValue,
              disabled: e.isDisabled,
              ref: "input"
            }), null, 16, U5e), [
              [M_, e.value]
            ]),
            se(" If label is HTML "),
            e.Text ? (U(), ee("span", {
              key: 0,
              class: re(e.classes.text),
              innerHTML: e.Text
            }, null, 10, q5e)) : (U(), ee(
              gt,
              { key: 1 },
              [
                se(" If label is slot "),
                de(
                  "span",
                  {
                    class: re(e.classes.text)
                  },
                  [
                    Me(e.$slots, "default", { el$: e.el$ }, () => [
                      (U(), Ae(ze(e.fieldSlots.default), { el$: e.el$ }, null, 8, ["el$"]))
                    ])
                  ],
                  2
                  /* CLASS */
                )
              ],
              2112
              /* STABLE_FRAGMENT, DEV_ROOT_FRAGMENT */
            ))
          ],
          2
          /* CLASS */
        )
      ]),
      _: 2
      /* DYNAMIC */
    }, [
      It(e.elementSlots, (o, s) => ({
        name: s,
        fn: Qe(() => [
          Me(e.$slots, s, { el$: e.el$ }, () => [
            (U(), Ae(ze(o), { el$: e.el$ }, null, 8, ["el$"]))
          ])
        ])
      }))
    ]),
    1536
    /* NEED_PATCH, DYNAMIC_SLOTS */
  );
}
eR.render = G5e;
eR.__file = "themes/blank/templates/elements/CheckboxElement.vue";
var dp = {
  name: "CheckboxgroupElement",
  data() {
    return {
      merge: !0,
      defaultClasses: {
        container: "",
        wrapper: ""
      }
    };
  }
};
const Y5e = ["aria-labelledby"];
function H5e(e, t, n, r, i, a) {
  const o = Bt("CheckboxgroupCheckbox");
  return U(), Ae(
    ze(e.elementLayout),
    { ref: "container" },
    nr({
      element: Qe(() => [
        de("div", {
          class: re(e.classes.wrapper),
          "aria-labelledby": e.labelId,
          role: "group"
        }, [
          (U(!0), ee(
            gt,
            null,
            It(e.resolvedOptions, (s, l, u) => (U(), Ae(o, {
              items: e.resolvedOptions,
              index: l,
              item: s,
              value: s.value,
              key: u,
              attrs: e.aria
            }, {
              default: Qe((c) => [
                Me(e.$slots, "checkbox", $e(c, { el$: e.el$ }), () => [
                  (U(), Ae(ze(e.fieldSlots.checkbox), $e(c, { el$: e.el$ }), null, 16, ["el$"]))
                ])
              ]),
              _: 2
              /* DYNAMIC */
            }, 1032, ["items", "index", "item", "value", "attrs"]))),
            128
            /* KEYED_FRAGMENT */
          ))
        ], 10, Y5e)
      ]),
      _: 2
      /* DYNAMIC */
    }, [
      It(e.elementSlots, (s, l) => ({
        name: l,
        fn: Qe(() => [
          Me(e.$slots, l, { el$: e.el$ }, () => [
            (U(), Ae(ze(s), { el$: e.el$ }, null, 8, ["el$"]))
          ])
        ])
      }))
    ]),
    1536
    /* NEED_PATCH, DYNAMIC_SLOTS */
  );
}
dp.render = H5e;
dp.__file = "themes/blank/templates/elements/CheckboxgroupElement.vue";
var Jp = {
  name: "DateElement",
  data() {
    return {
      merge: !0,
      defaultClasses: {
        container: "",
        inputContainer: "",
        inputWrapper: "",
        input: ""
      }
    };
  }
};
function z5e(e, t, n, r, i, a) {
  const o = Bt("ElementAddon"), s = Bt("ElementLabelFloating"), l = Bt("DatepickerWrapper");
  return U(), Ae(
    ze(e.elementLayout),
    { ref: "container" },
    nr({
      element: Qe(() => [
        de(
          "div",
          {
            class: re(e.classes.inputContainer)
          },
          [
            e.hasAddonBefore ? (U(), Ae(o, {
              key: 0,
              type: "before"
            }, {
              default: Qe(() => [
                Me(e.$slots, "addon-before", {}, () => [
                  (U(), Ae(ze(e.fieldSlots["addon-before"]), { el$: e.el$ }, null, 8, ["el$"]))
                ])
              ]),
              _: 3
              /* FORWARDED */
            })) : se("v-if", !0),
            e.hasAddonAfter ? (U(), Ae(o, {
              key: 1,
              type: "after"
            }, {
              default: Qe(() => [
                Me(e.$slots, "addon-after", {}, () => [
                  (U(), Ae(ze(e.fieldSlots["addon-after"]), { el$: e.el$ }, null, 8, ["el$"]))
                ])
              ]),
              _: 3
              /* FORWARDED */
            })) : se("v-if", !0),
            e.hasFloating && !e.empty ? (U(), Ae(s, {
              key: 2,
              visible: !e.empty
            }, null, 8, ["visible"])) : se("v-if", !0),
            de(
              "div",
              {
                class: re(e.classes.inputWrapper)
              },
              [
                rn(l, {
                  value: e.model,
                  options: e.fieldOptions,
                  id: e.fieldId,
                  class: re(e.classes.input),
                  placeholder: e.Placeholder,
                  disabled: e.isDisabled,
                  readonly: e.readonly,
                  attrs: e.aria,
                  onChange: e.handleChange,
                  ref: "input"
                }, null, 8, ["value", "options", "id", "class", "placeholder", "disabled", "readonly", "attrs", "onChange"])
              ],
              2
              /* CLASS */
            )
          ],
          2
          /* CLASS */
        )
      ]),
      _: 2
      /* DYNAMIC */
    }, [
      It(e.elementSlots, (u, c) => ({
        name: c,
        fn: Qe(() => [
          Me(e.$slots, c, { el$: e.el$ }, () => [
            (U(), Ae(ze(u), { el$: e.el$ }, null, 8, ["el$"]))
          ])
        ])
      }))
    ]),
    1536
    /* NEED_PATCH, DYNAMIC_SLOTS */
  );
}
Jp.render = z5e;
Jp.__file = "themes/blank/templates/elements/DateElement.vue";
var n9 = {
  name: "DatesElement",
  render: Jp.render,
  staticRenderFns: Jp.staticRenderFns,
  data() {
    return {
      merge: !0,
      defaultClasses: {
        container: "",
        inputContainer: "",
        input: ""
      }
    };
  }
};
n9.__file = "themes/blank/templates/elements/DatesElement.vue";
var tR = {
  name: "FileElement",
  data() {
    return {
      merge: !0,
      defaultClasses: {
        container: "",
        button: ""
      }
    };
  }
};
const V5e = ["aria-labelledby", "aria-placeholder"], W5e = ["id", "accept"];
function K5e(e, t, n, r, i, a) {
  const o = Bt("DragAndDrop"), s = Bt("FilePreview");
  return U(), Ae(
    ze(e.elementLayout),
    { ref: "container" },
    nr({
      element: Qe(() => [
        se(" Drag n drop "),
        e.drop && e.canDrop && e.canSelect ? (U(), Ae(o, {
          key: 0,
          title: e.form$.translations.vueform.elements[e.type].dndTitle,
          description: e.form$.translations.vueform.elements[e.type].dndDescription,
          disabled: e.isDisabled,
          onClick: e.handleClick,
          onDrop: e.handleDrop
        }, null, 8, ["title", "description", "disabled", "onClick", "onDrop"])) : e.canSelect ? (U(), ee(
          gt,
          { key: 1 },
          [
            se(" Upload button "),
            de("div", $e(e.aria, {
              class: e.classes.button,
              "aria-labelledby": e.labelId,
              "aria-placeholder": e.form$.translations.vueform.elements[e.type].select,
              onClick: t[0] || (t[0] = An((...l) => e.handleClick && e.handleClick(...l), ["prevent"])),
              onKeypress: t[1] || (t[1] = Zr((...l) => e.handleClick && e.handleClick(...l), ["enter", "space"])),
              role: "button",
              tabindex: "0"
            }), zt(e.form$.translations.vueform.elements[e.type].select), 17, V5e)
          ],
          2112
          /* STABLE_FRAGMENT, DEV_ROOT_FRAGMENT */
        )) : se("v-if", !0),
        se(" Hidden file input "),
        e.canSelect && !e.isDisabled && !e.preparing ? Gn((U(), ee("input", {
          key: 2,
          id: e.fieldId,
          type: "file",
          accept: e.accept,
          onChange: t[2] || (t[2] = (...l) => e.handleChange && e.handleChange(...l)),
          ref: "input"
        }, null, 40, W5e)), [
          [Wi, !1]
        ]) : se("v-if", !0),
        se(" Preview "),
        Me(e.$slots, "preview", {}, () => [
          (U(), Ae(s, {
            key: e.view,
            attrs: e.aria
          }, null, 8, ["attrs"]))
        ])
      ]),
      _: 2
      /* DYNAMIC */
    }, [
      It(e.elementSlots, (l, u) => ({
        name: u,
        fn: Qe(() => [
          Me(e.$slots, u, { el$: e.el$ }, () => [
            (U(), Ae(ze(l), { el$: e.el$ }, null, 8, ["el$"]))
          ])
        ])
      }))
    ]),
    1536
    /* NEED_PATCH, DYNAMIC_SLOTS */
  );
}
tR.render = K5e;
tR.__file = "themes/blank/templates/elements/FileElement.vue";
var nR = {
  name: "GroupElement",
  data() {
    return {
      merge: !0,
      defaultClasses: {
        container: "",
        wrapper: ""
      }
    };
  }
};
const j5e = ["aria-labelledby"];
function Q5e(e, t, n, r, i, a) {
  return U(), Ae(
    ze(e.elementLayout),
    {
      multiple: !0,
      ref: "container"
    },
    nr({
      element: Qe(() => [
        de("div", {
          class: re(e.classes.wrapper),
          role: "group",
          "aria-labelledby": e.labelId
        }, [
          Me(e.$slots, "default", {}, () => [
            (U(!0), ee(
              gt,
              null,
              It(e.children, (o, s) => (U(), Ae(ze(e.component(o)), $e(o, {
                name: s,
                key: s
              }), null, 16, ["name"]))),
              128
              /* KEYED_FRAGMENT */
            ))
          ])
        ], 10, j5e)
      ]),
      _: 2
      /* DYNAMIC */
    }, [
      It(e.elementSlots, (o, s) => ({
        name: s,
        fn: Qe(() => [
          Me(e.$slots, s, { el$: e.el$ }, () => [
            (U(), Ae(ze(o), { el$: e.el$ }, null, 8, ["el$"]))
          ])
        ])
      }))
    ]),
    1536
    /* NEED_PATCH, DYNAMIC_SLOTS */
  );
}
nR.render = Q5e;
nR.__file = "themes/blank/templates/elements/GroupElement.vue";
var rR = {
  name: "HiddenElement",
  data() {
    return {
      merge: !0,
      defaultClasses: {}
    };
  }
};
const X5e = {
  key: 0,
  ref: "container"
}, Z5e = ["name", "id"];
function J5e(e, t, n, r, i, a) {
  return e.meta ? se("v-if", !0) : (U(), ee(
    "span",
    X5e,
    [
      Gn(de("input", {
        "onUpdate:modelValue": t[0] || (t[0] = (o) => e.value = o),
        type: "hidden",
        name: e.name,
        id: e.fieldId,
        ref: "input"
      }, null, 8, Z5e), [
        [sF, e.value]
      ])
    ],
    512
    /* NEED_PATCH */
  ));
}
rR.render = J5e;
rR.__file = "themes/blank/templates/elements/HiddenElement.vue";
var iR = {
  name: "ListElement",
  data() {
    return {
      merge: !0,
      defaultClasses: {
        container: "",
        list: "",
        listItem: "",
        handle: "",
        handleIcon: "",
        remove: "",
        removeIcon: "",
        add: ""
      }
    };
  }
};
const eqe = ["aria-labelledby"], tqe = ["data-id"], nqe = ["aria-roledescription", "id", "onClick", "onKeypress"], rqe = ["id", "innerHTML"];
function iqe(e, t, n, r, i, a) {
  return U(), Ae(
    ze(e.elementLayout),
    { ref: "container" },
    nr({
      element: Qe(() => [
        se(" Sorting container "),
        de("div", {
          class: re(e.classes.list),
          role: "list",
          "aria-labelledby": e.labelId,
          ref: "list"
        }, [
          (U(!0), ee(
            gt,
            null,
            It(e.value, (o, s) => (U(), ee("div", {
              key: s,
              class: re(e.classes.listItem),
              role: "listitem",
              "data-id": `${e.path}-${s}`
            }, [
              Me(e.$slots, "default", { index: s }, () => [
                e.prototype.type ? (U(), Ae(ze(e.component(e.prototype)), $e({ key: 0 }, e.prototype, {
                  name: s,
                  key: s
                }), null, 16, ["name"])) : se("v-if", !0)
              ]),
              se(" Sort handle "),
              e.hasSort ? (U(), ee(
                "span",
                {
                  key: 0,
                  class: re(e.classes.handle),
                  "data-handle": ""
                },
                [
                  de(
                    "span",
                    {
                      class: re(e.classes.handleIcon)
                    },
                    null,
                    2
                    /* CLASS */
                  )
                ],
                2
                /* CLASS */
              )) : se("v-if", !0),
              se(" Remove button "),
              e.hasRemove ? (U(), ee("div", {
                key: 1,
                "aria-roledescription": e.form$.translations.vueform.a11y.list.remove,
                class: re(e.classes.remove),
                id: `${e.path}-${s}-remove-button`,
                onClick: An((l) => e.handleRemove(s), ["prevent"]),
                onKeypress: Zr((l) => e.handleRemove(s), ["space", "enter"]),
                role: "button",
                tabindex: "0"
              }, [
                de(
                  "span",
                  {
                    class: re(e.classes.removeIcon)
                  },
                  null,
                  2
                  /* CLASS */
                )
              ], 42, nqe)) : se("v-if", !0)
            ], 10, tqe))),
            128
            /* KEYED_FRAGMENT */
          ))
        ], 10, eqe),
        se(" Add button "),
        e.hasAdd ? (U(), ee("div", {
          key: 0,
          class: re(e.classes.add),
          id: `${e.fieldId}-add-button`,
          onClick: t[0] || (t[0] = An((...o) => e.handleAdd && e.handleAdd(...o), ["prevent"])),
          onKeypress: t[1] || (t[1] = Zr((...o) => e.handleAdd && e.handleAdd(...o), ["enter", "space"])),
          innerHTML: e.addLabel,
          role: "button",
          tabindex: "0"
        }, null, 42, rqe)) : se("v-if", !0)
      ]),
      _: 2
      /* DYNAMIC */
    }, [
      It(e.elementSlots, (o, s) => ({
        name: s,
        fn: Qe(() => [
          Me(e.$slots, s, { el$: e.el$ }, () => [
            (U(), Ae(ze(o), { el$: e.el$ }, null, 8, ["el$"]))
          ])
        ])
      }))
    ]),
    1536
    /* NEED_PATCH, DYNAMIC_SLOTS */
  );
}
iR.render = iqe;
iR.__file = "themes/blank/templates/elements/ListElement.vue";
var x_ = {
  name: "LocationElement",
  data() {
    return {
      merge: !0,
      defaultClasses: {
        container: "",
        inputContainer: "",
        input: ""
      }
    };
  }
};
const aqe = ["name", "id", "placeholder", "disabled", "readonly", "aria-labelledby"];
function oqe(e, t, n, r, i, a) {
  const o = Bt("ElementAddon"), s = Bt("ElementLabelFloating");
  return U(), Ae(
    ze(e.elementLayout),
    { ref: "container" },
    nr({
      element: Qe(() => [
        de(
          "div",
          {
            class: re(e.classes.inputContainer)
          },
          [
            e.hasAddonBefore ? (U(), Ae(o, {
              key: 0,
              type: "before"
            }, {
              default: Qe(() => [
                Me(e.$slots, "addon-before", {}, () => [
                  (U(), Ae(ze(e.fieldSlots["addon-before"]), { el$: e.el$ }, null, 8, ["el$"]))
                ])
              ]),
              _: 3
              /* FORWARDED */
            })) : se("v-if", !0),
            e.hasAddonAfter ? (U(), Ae(o, {
              key: 1,
              type: "after"
            }, {
              default: Qe(() => [
                Me(e.$slots, "addon-after", {}, () => [
                  (U(), Ae(ze(e.fieldSlots["addon-after"]), { el$: e.el$ }, null, 8, ["el$"]))
                ])
              ]),
              _: 3
              /* FORWARDED */
            })) : se("v-if", !0),
            e.hasFloating && !e.empty ? (U(), Ae(s, {
              key: 2,
              visible: !e.empty
            }, null, 8, ["visible"])) : se("v-if", !0),
            de("input", $e({
              type: "search",
              name: e.name,
              id: e.fieldId,
              class: e.classes.input,
              placeholder: e.Placeholder,
              disabled: e.isDisabled,
              readonly: e.readonly,
              "aria-labelledby": e.labelId,
              autocomplete: "off"
            }, e.attrs, {
              ref: "input",
              onBlur: t[0] || (t[0] = (...l) => e.handleLocationBlur && e.handleLocationBlur(...l))
            }), null, 16, aqe)
          ],
          2
          /* CLASS */
        )
      ]),
      _: 2
      /* DYNAMIC */
    }, [
      It(e.elementSlots, (l, u) => ({
        name: u,
        fn: Qe(() => [
          Me(e.$slots, u, { el$: e.el$ }, () => [
            (U(), Ae(ze(l), { el$: e.el$ }, null, 8, ["el$"]))
          ])
        ])
      }))
    ]),
    1536
    /* NEED_PATCH, DYNAMIC_SLOTS */
  );
}
x_.render = oqe;
x_.__file = "themes/blank/templates/elements/LocationElement.vue";
var r9 = {
  name: "LocationElement",
  render: x_.render,
  data: x_.data
};
function aR(e, t) {
  t === void 0 && (t = {});
  var n = t.insertAt;
  if (!(!e || typeof document > "u")) {
    var r = document.head || document.getElementsByTagName("head")[0], i = document.createElement("style");
    i.type = "text/css", n === "top" && r.firstChild ? r.insertBefore(i, r.firstChild) : r.appendChild(i), i.styleSheet ? i.styleSheet.cssText = e : i.appendChild(document.createTextNode(e));
  }
}
var sqe = `/* Google */

.pac-container {
  border-color: var(--vf-border-color-input);
  background: var(--vf-bg-input);
}

.pac-item {
  display: flex;
  align-items: center;
  padding: 0.375rem 0.75rem;
  border-color: var(--vf-border-color-input);
  background: var(--vf-bg-input);
  color: var(--vf-color-input);
  cursor: pointer;
}

.pac-item > span:last-of-type {
  font-size: 0.75rem;
  color: var(--vf-color-muted);
}

.pac-item:hover, .pac-item.pac-item-selected {
  background: var(--vf-bg-selected);
}

.pac-item-query {
  font-size: 0.875rem;
  line-height: 1;
  margin-right: 0.25rem;
  padding-right: 0.25rem;
  color: var(--vf-color-input);
}

.pac-icon-marker {
  mask-repeat: no-repeat;
  -webkit-mask-repeat: no-repeat;
  mask-position: center center;
  -webkit-mask-position: center center;
  mask-size: contain;
  -webkit-mask-size: contain;
  mask-image: url("data:image/svg+xml,%3csvg viewBox='0 0 384 512' fill='currentColor' xmlns='http://www.w3.org/2000/svg'%3e%3cpath d='M172.268 501.67C26.97 291.031 0 269.413 0 192 0 85.961 85.961 0 192 0s192 85.961 192 192c0 77.413-26.97 99.031-172.268 309.67-9.535 13.774-29.93 13.773-39.464 0zM192 272c44.183 0 80-35.817 80-80s-35.817-80-80-80-80 35.817-80 80 35.817 80 80 80z'%3e%3c/path%3e%3c/svg%3e");
  -webkit-mask-image: url("data:image/svg+xml,%3csvg viewBox='0 0 384 512' fill='currentColor' xmlns='http://www.w3.org/2000/svg'%3e%3cpath d='M172.268 501.67C26.97 291.031 0 269.413 0 192 0 85.961 85.961 0 192 0s192 85.961 192 192c0 77.413-26.97 99.031-172.268 309.67-9.535 13.774-29.93 13.773-39.464 0zM192 272c44.183 0 80-35.817 80-80s-35.817-80-80-80-80 35.817-80 80 35.817 80 80 80z'%3e%3c/path%3e%3c/svg%3e");
  background: var(--vf-bg-icon);
  width: 0.875rem;
  width: 0.875rem;
  margin-right: 0.75rem;
  margin-top: 0;
  padding-top: 1px;
  padding-bottom: 1px;
  box-sizing: content-box;
  flex-shrink: 0;
}

.pac-logo:after {
  margin-left: 0.625rem;
  margin-right: 0.625rem;
  margin-bottom: 0.625rem;
}

.pac-icon, .hdpi .pac-icon {
  background-image: none;
}`;
aR(sqe);
r9.__file = "themes/tailwind/templates/elements/LocationElement.vue";
var oR = {
  name: "MultifileElement",
  data() {
    return {
      merge: !0,
      defaultClasses: {
        container: "",
        list: "",
        listItem: "",
        handle: "",
        handleIcon: "",
        dnd: "",
        button: ""
      }
    };
  }
};
const lqe = ["aria-labelledby", "aria-placeholder"], uqe = ["id", "accept", "disabled"];
function cqe(e, t, n, r, i, a) {
  const o = Bt("DragAndDrop");
  return U(), Ae(
    ze(e.elementLayout),
    {
      multiple: !0,
      ref: "container"
    },
    nr({
      element: Qe(() => [
        se(" Drag n drop "),
        e.drop && e.canDrop && e.hasAdd ? (U(), Ae(o, {
          key: 0,
          title: e.form$.translations.vueform.elements[e.type].dndTitle,
          description: e.form$.translations.vueform.elements[e.type].dndDescription,
          disabled: e.isDisabled,
          class: re(e.classes.dnd),
          onClick: e.handleClick,
          onDrop: e.handleDrop
        }, null, 8, ["title", "description", "disabled", "class", "onClick", "onDrop"])) : e.hasAdd ? (U(), ee(
          gt,
          { key: 1 },
          [
            se(" Upload button "),
            de("div", $e(e.aria, {
              class: e.classes.button,
              "aria-labelledby": e.labelId,
              "aria-placeholder": e.form$.translations.vueform.elements.multifile.uploadButton,
              onClick: t[0] || (t[0] = An((...s) => e.handleClick && e.handleClick(...s), ["prevent"])),
              onKeypress: t[1] || (t[1] = Zr((...s) => e.handleClick && e.handleClick(...s), ["enter", "space"])),
              role: "button",
              tabindex: "0"
            }), zt(e.form$.translations.vueform.elements.multifile.uploadButton), 17, lqe)
          ],
          2112
          /* STABLE_FRAGMENT, DEV_ROOT_FRAGMENT */
        )) : se("v-if", !0),
        se(" Actual input field "),
        Gn(de("input", {
          multiple: "",
          id: e.fieldId,
          type: "file",
          onChange: t[2] || (t[2] = (...s) => e.handleChange && e.handleChange(...s)),
          accept: e.accept,
          disabled: e.isDisabled,
          ref: "input"
        }, null, 40, uqe), [
          [Wi, !1]
        ]),
        Gn((U(), ee(
          "div",
          {
            class: re(e.classes.list),
            key: `${e.fieldId}-${e.length}`,
            ref: "list"
          },
          [
            (U(!0), ee(
              gt,
              null,
              It(e.value, (s, l) => (U(), ee(
                "div",
                {
                  key: l,
                  class: re(e.classes.listItem)
                },
                [
                  e.prototype.type ? (U(), Ae(ze(e.component(e.prototype)), $e({ key: 0 }, e.prototype, {
                    disabled: !e.hasRemove,
                    embed: !0,
                    name: l,
                    onRemove: (u) => e.remove(l)
                  }), null, 16, ["disabled", "name", "onRemove"])) : se("v-if", !0),
                  se(" Sort handle "),
                  e.hasSort ? (U(), ee(
                    "span",
                    {
                      key: 1,
                      class: re(e.classes.handle),
                      "data-handle": ""
                    },
                    [
                      de(
                        "span",
                        {
                          class: re(e.classes.handleIcon)
                        },
                        null,
                        2
                        /* CLASS */
                      )
                    ],
                    2
                    /* CLASS */
                  )) : se("v-if", !0)
                ],
                2
                /* CLASS */
              ))),
              128
              /* KEYED_FRAGMENT */
            ))
          ],
          2
          /* CLASS */
        )), [
          [Wi, !e.empty]
        ])
      ]),
      _: 2
      /* DYNAMIC */
    }, [
      It(e.elementSlots, (s, l) => ({
        name: l,
        fn: Qe(() => [
          Me(e.$slots, l, { el$: e.el$ }, () => [
            (U(), Ae(ze(s), { el$: e.el$ }, null, 8, ["el$"]))
          ])
        ])
      }))
    ]),
    1536
    /* NEED_PATCH, DYNAMIC_SLOTS */
  );
}
oR.render = cqe;
oR.__file = "themes/blank/templates/elements/MultifileElement.vue";
function Fo(e) {
  return [null, void 0].indexOf(e) !== -1;
}
function dqe(e, t, n) {
  const { object: r, valueProp: i, mode: a } = De(e), o = fi().proxy, s = n.iv, l = (d, f = !0) => {
    s.value = c(d);
    const h = u(d);
    t.emit("change", h, o), f && (t.emit("input", h), t.emit("update:modelValue", h));
  }, u = (d) => r.value || Fo(d) ? d : Array.isArray(d) ? d.map((f) => f[i.value]) : d[i.value], c = (d) => Fo(d) ? a.value === "single" ? {} : [] : d;
  return {
    update: l
  };
}
function fqe(e, t) {
  const { value: n, modelValue: r, mode: i, valueProp: a } = De(e), o = he(i.value !== "single" ? [] : {}), s = N(() => r && r.value !== void 0 ? r.value : n.value), l = N(() => i.value === "single" ? o.value[a.value] : o.value.map((c) => c[a.value])), u = N(() => i.value !== "single" ? o.value.map((c) => c[a.value]).join(",") : o.value[a.value]);
  return {
    iv: o,
    internalValue: o,
    ev: s,
    externalValue: s,
    textValue: u,
    plainValue: l
  };
}
function pqe(e, t, n) {
  const { regex: r } = De(e), i = fi().proxy, a = n.isOpen, o = n.open, s = he(null), l = () => {
    s.value = "";
  }, u = (f) => {
    s.value = f.target.value;
  }, c = (f) => {
    if (r && r.value) {
      let h = r.value;
      typeof h == "string" && (h = new RegExp(h)), f.key.match(h) || f.preventDefault();
    }
  }, d = (f) => {
    if (r && r.value) {
      let m = (f.clipboardData || /* istanbul ignore next */
      window.clipboardData).getData("Text"), v = r.value;
      typeof v == "string" && (v = new RegExp(v)), m.split("").every((b) => !!b.match(v)) || f.preventDefault();
    }
    t.emit("paste", f, i);
  };
  return et(s, (f) => {
    !a.value && f && o(), t.emit("search-change", f, i);
  }), {
    search: s,
    clearSearch: l,
    handleSearchInput: u,
    handleKeypress: c,
    handlePaste: d
  };
}
function mqe(e, t, n) {
  const { groupSelect: r, mode: i, groups: a, disabledProp: o } = De(e), s = he(null), l = (c) => {
    c === void 0 || c !== null && c[o.value] || a.value && c && c.group && (i.value === "single" || !r.value) || (s.value = c);
  };
  return {
    pointer: s,
    setPointer: l,
    clearPointer: () => {
      l(null);
    }
  };
}
function zT(e, t = !0) {
  return t ? String(e).toLowerCase().trim() : String(e).toLowerCase().normalize("NFD").trim().replace(new RegExp(/æ/g), "ae").replace(new RegExp(/œ/g), "oe").replace(new RegExp(/ø/g), "o").replace(new RegExp("\\p{Diacritic}", "gu"), "");
}
function hqe(e) {
  return Object.prototype.toString.call(e) === "[object Object]";
}
function gqe(e, t) {
  const n = t.slice().sort();
  return e.length === t.length && e.slice().sort().every(function(r, i) {
    return r === n[i];
  });
}
function _qe(e, t, n) {
  const {
    options: r,
    mode: i,
    trackBy: a,
    limit: o,
    hideSelected: s,
    createTag: l,
    createOption: u,
    label: c,
    appendNewTag: d,
    appendNewOption: f,
    multipleLabel: h,
    object: m,
    loading: v,
    delay: b,
    resolveOnLoad: y,
    minChars: g,
    filterResults: E,
    clearOnSearch: S,
    clearOnSelect: C,
    valueProp: T,
    allowAbsent: O,
    groupLabel: R,
    canDeselect: D,
    max: q,
    strict: $,
    closeOnSelect: P,
    closeOnDeselect: Y,
    groups: L,
    reverse: x,
    infinite: I,
    groupOptions: k,
    groupHideEmpty: B,
    groupSelect: W,
    onCreate: Z,
    disabledProp: V,
    searchStart: K,
    searchFilter: ne
  } = De(e), Ee = fi().proxy, oe = n.iv, ae = n.ev, pe = n.search, Se = n.clearSearch, Re = n.update, Ye = n.pointer, nt = n.setPointer, ut = n.clearPointer, Tt = n.focus, Ot = n.deactivate, Xt = n.close, We = n.localize, st = he([]), Pt = he([]), Ke = he(!1), Je = he(null), Be = he(I.value && o.value === -1 ? 10 : o.value), pt = N(() => l.value || u.value || !1), ft = N(() => d.value !== void 0 ? d.value : f.value !== void 0 ? f.value : !0), Ze = N(() => {
    if (L.value) {
      let Q = we.value || /* istanbul ignore next */
      [], ye = [];
      return Q.forEach((ct) => {
        pi(ct[k.value]).forEach((en) => {
          ye.push(Object.assign({}, en, ct[V.value] ? { [V.value]: !0 } : {}));
        });
      }), ye;
    } else {
      let Q = pi(Pt.value || /* istanbul ignore next */
      []);
      return st.value.length && (Q = Q.concat(st.value)), Q;
    }
  }), _t = N(() => {
    let Q = Ze.value;
    return x.value && (Q = Q.reverse()), tt.value.length && (Q = tt.value.concat(Q)), Un(Q);
  }), St = N(() => {
    let Q = _t.value;
    return Be.value > 0 && (Q = Q.slice(0, Be.value)), Q;
  }), we = N(() => {
    if (!L.value)
      return [];
    let Q = [], ye = Pt.value || /* istanbul ignore next */
    [];
    return st.value.length && Q.push({
      [R.value]: " ",
      [k.value]: [...st.value],
      __CREATE__: !0
    }), Q.concat(ye);
  }), je = N(() => {
    let Q = [...we.value].map((ye) => ({ ...ye }));
    return tt.value.length && (Q[0] && Q[0].__CREATE__ ? Q[0][k.value] = [...tt.value, ...Q[0][k.value]] : Q = [{
      [R.value]: " ",
      [k.value]: [...tt.value],
      __CREATE__: !0
    }].concat(Q)), Q;
  }), yt = N(() => {
    if (!L.value)
      return [];
    let Q = je.value;
    return xr((Q || /* istanbul ignore next */
    []).map((ye, ct) => {
      const en = pi(ye[k.value]);
      return {
        ...ye,
        index: ct,
        group: !0,
        [k.value]: Un(en, !1).map((Rn) => Object.assign({}, Rn, ye[V.value] ? { [V.value]: !0 } : {})),
        __VISIBLE__: Un(en).map((Rn) => Object.assign({}, Rn, ye[V.value] ? { [V.value]: !0 } : {}))
      };
    }));
  }), Rt = N(() => {
    switch (i.value) {
      case "single":
        return !Fo(oe.value[T.value]);
      case "multiple":
      case "tags":
        return !Fo(oe.value) && oe.value.length > 0;
    }
  }), sn = N(() => h !== void 0 && h.value !== void 0 ? h.value(oe.value, Ee) : oe.value && oe.value.length > 1 ? `${oe.value.length} options selected` : "1 option selected"), me = N(() => !Ze.value.length && !Ke.value && !tt.value.length), He = N(() => Ze.value.length > 0 && St.value.length == 0 && (pe.value && L.value || !L.value)), tt = N(() => pt.value === !1 || !pe.value ? [] : Mt(pe.value) !== -1 ? [] : [{
    [T.value]: pe.value,
    [ot.value[0]]: pe.value,
    [c.value]: pe.value,
    __CREATE__: !0
  }]), ot = N(() => a.value ? Array.isArray(a.value) ? a.value : [a.value] : [c.value]), xn = N(() => {
    switch (i.value) {
      case "single":
        return null;
      case "multiple":
      case "tags":
        return [];
    }
  }), kt = N(() => v.value || Ke.value), Dn = (Q) => {
    switch (typeof Q != "object" && (Q = xe(Q)), i.value) {
      case "single":
        Re(Q);
        break;
      case "multiple":
      case "tags":
        Re(oe.value.concat(Q));
        break;
    }
    t.emit("select", Vn(Q), Q, Ee);
  }, gn = (Q) => {
    switch (typeof Q != "object" && (Q = xe(Q)), i.value) {
      case "single":
        _e();
        break;
      case "tags":
      case "multiple":
        Re(Array.isArray(Q) ? oe.value.filter((ye) => Q.map((ct) => ct[T.value]).indexOf(ye[T.value]) === -1) : oe.value.filter((ye) => ye[T.value] != Q[T.value]));
        break;
    }
    t.emit("deselect", Vn(Q), Q, Ee);
  }, Vn = (Q) => m.value ? Q : Q[T.value], X = (Q) => {
    gn(Q);
  }, te = (Q, ye) => {
    if (ye.button !== 0) {
      ye.preventDefault();
      return;
    }
    X(Q);
  }, _e = () => {
    Re(xn.value), t.emit("clear", Ee);
  }, M = (Q) => {
    if (Q.group !== void 0)
      return i.value === "single" ? !1 : Pe(Q[k.value]) && Q[k.value].length;
    switch (i.value) {
      case "single":
        return !Fo(oe.value) && oe.value[T.value] == Q[T.value];
      case "tags":
      case "multiple":
        return !Fo(oe.value) && oe.value.map((ye) => ye[T.value]).indexOf(Q[T.value]) !== -1;
    }
  }, G = (Q) => Q[V.value] === !0, j = () => q === void 0 || q.value === -1 || !Rt.value && q.value > 0 ? !1 : oe.value.length >= q.value, ce = (Q) => {
    if (!G(Q)) {
      if (Z && Z.value && !M(Q) && Q.__CREATE__ && (Q = { ...Q }, delete Q.__CREATE__, Q = Z.value(Q, Ee), Q instanceof Promise)) {
        Ke.value = !0, Q.then((ye) => {
          Ke.value = !1, be(ye);
        });
        return;
      }
      be(Q);
    }
  }, be = (Q) => {
    switch (Q.__CREATE__ && (Q = { ...Q }, delete Q.__CREATE__), i.value) {
      case "single":
        if (Q && M(Q)) {
          D.value && gn(Q), Y.value && (ut(), Xt());
          return;
        }
        Q && Ue(Q), C.value && Se(), P.value && (ut(), Xt()), Q && Dn(Q);
        break;
      case "multiple":
        if (Q && M(Q)) {
          gn(Q), Y.value && (ut(), Xt());
          return;
        }
        if (j()) {
          t.emit("max", Ee);
          return;
        }
        Q && (Ue(Q), Dn(Q)), C.value && Se(), s.value && ut(), P.value && Xt();
        break;
      case "tags":
        if (Q && M(Q)) {
          gn(Q), Y.value && (ut(), Xt());
          return;
        }
        if (j()) {
          t.emit("max", Ee);
          return;
        }
        Q && Ue(Q), C.value && Se(), Q && Dn(Q), s.value && ut(), P.value && Xt();
        break;
    }
    P.value || Tt();
  }, Ie = (Q) => {
    if (!(G(Q) || i.value === "single" || !W.value)) {
      switch (i.value) {
        case "multiple":
        case "tags":
          dt(Q[k.value]) ? gn(Q[k.value]) : Dn(
            Q[k.value].filter((ye) => oe.value.map((ct) => ct[T.value]).indexOf(ye[T.value]) === -1).filter((ye) => !ye[V.value]).filter((ye, ct) => oe.value.length + 1 + ct <= q.value || q.value === -1)
          ), s.value && Ye.value && nt(yt.value.filter((ye) => !ye[V.value])[Ye.value.index]);
          break;
      }
      P.value && Ot();
    }
  }, Ue = (Q) => {
    xe(Q[T.value]) === void 0 && pt.value && (t.emit("tag", Q[T.value], Ee), t.emit("option", Q[T.value], Ee), t.emit("create", Q[T.value], Ee), ft.value && Jt(Q), Se());
  }, Ve = () => {
    i.value !== "single" && Dn(St.value.filter((Q) => !Q.disabled && !M(Q)));
  }, dt = (Q) => Q.find((ye) => !M(ye) && !ye[V.value]) === void 0, Pe = (Q) => Q.find((ye) => !M(ye)) === void 0, xe = (Q) => Ze.value[Ze.value.map((ye) => String(ye[T.value])).indexOf(String(Q))], Mt = (Q) => Ze.value.findIndex((ye) => ot.value.some((ct) => (parseInt(ye[ct]) == ye[ct] ? parseInt(ye[ct]) : ye[ct]) === (parseInt(Q) == Q ? parseInt(Q) : Q))), Zt = (Q) => ["tags", "multiple"].indexOf(i.value) !== -1 && s.value && M(Q), Jt = (Q) => {
    st.value.push(Q);
  }, xr = (Q) => B.value ? Q.filter(
    (ye) => pe.value ? ye.__VISIBLE__.length : ye[k.value].length
  ) : Q.filter((ye) => pe.value ? ye.__VISIBLE__.length : !0), Un = (Q, ye = !0) => {
    let ct = Q;
    if (pe.value && E.value) {
      let en = ne.value;
      en || (en = (Rn, Nr, mi) => ot.value.some((ha) => {
        let Er = zT(We(Rn[ha]), $.value);
        return K.value ? Er.startsWith(zT(Nr, $.value)) : Er.indexOf(zT(Nr, $.value)) !== -1;
      })), ct = ct.filter((Rn) => en(Rn, pe.value, Ee));
    }
    return s.value && ye && (ct = ct.filter((en) => !Zt(en))), ct;
  }, pi = (Q) => {
    let ye = Q;
    return hqe(ye) && (ye = Object.keys(ye).map((ct) => {
      let en = ye[ct];
      return { [T.value]: ct, [ot.value[0]]: en, [c.value]: en };
    })), ye = ye.map((ct) => typeof ct == "object" ? ct : { [T.value]: ct, [ot.value[0]]: ct, [c.value]: ct }), ye;
  }, Cr = () => {
    Fo(ae.value) || (oe.value = vt(ae.value));
  }, ti = (Q) => (Ke.value = !0, new Promise((ye, ct) => {
    r.value(pe.value, Ee).then((en) => {
      Pt.value = en || [], typeof Q == "function" && Q(en), Ke.value = !1;
    }).catch((en) => {
      console.error(en), Pt.value = [], Ke.value = !1;
    }).finally(() => {
      ye();
    });
  })), Si = () => {
    if (Rt.value)
      if (i.value === "single") {
        let Q = xe(oe.value[T.value]);
        if (Q !== void 0) {
          let ye = Q[c.value];
          oe.value[c.value] = ye, m.value && (ae.value[c.value] = ye);
        }
      } else
        oe.value.forEach((Q, ye) => {
          let ct = xe(oe.value[ye][T.value]);
          if (ct !== void 0) {
            let en = ct[c.value];
            oe.value[ye][c.value] = en, m.value && (ae.value[ye][c.value] = en);
          }
        });
  }, yi = (Q) => {
    ti(Q);
  }, vt = (Q) => Fo(Q) ? i.value === "single" ? {} : [] : m.value ? Q : i.value === "single" ? xe(Q) || (O.value ? {
    [c.value]: Q,
    [T.value]: Q,
    [ot.value[0]]: Q
  } : {}) : Q.filter((ye) => !!xe(ye) || O.value).map((ye) => xe(ye) || {
    [c.value]: ye,
    [T.value]: ye,
    [ot.value[0]]: ye
  }), ue = () => {
    Je.value = et(pe, (Q) => {
      Q.length < g.value || !Q && g.value !== 0 || (Ke.value = !0, S.value && (Pt.value = []), setTimeout(() => {
        Q == pe.value && r.value(pe.value, Ee).then((ye) => {
          (Q == pe.value || !pe.value) && (Pt.value = ye, Ye.value = St.value.filter((ct) => ct[V.value] !== !0)[0] || null, Ke.value = !1);
        }).catch(
          /* istanbul ignore next */
          (ye) => {
            console.error(ye);
          }
        );
      }, b.value));
    }, { flush: "sync" });
  };
  if (i.value !== "single" && !Fo(ae.value) && !Array.isArray(ae.value))
    throw new Error(`v-model must be an array when using "${i.value}" mode`);
  return r && typeof r.value == "function" ? y.value ? ti(Cr) : m.value == !0 && Cr() : (Pt.value = r.value, Cr()), b.value > -1 && ue(), et(b, (Q, ye) => {
    Je.value && Je.value(), Q >= 0 && ue();
  }), et(ae, (Q) => {
    if (Fo(Q)) {
      Re(vt(Q), !1);
      return;
    }
    switch (i.value) {
      case "single":
        (m.value ? Q[T.value] != oe.value[T.value] : Q != oe.value[T.value]) && Re(vt(Q), !1);
        break;
      case "multiple":
      case "tags":
        gqe(m.value ? Q.map((ye) => ye[T.value]) : Q, oe.value.map((ye) => ye[T.value])) || Re(vt(Q), !1);
        break;
    }
  }, { deep: !0 }), et(r, (Q, ye) => {
    typeof e.options == "function" ? y.value && (!ye || Q && Q.toString() !== ye.toString()) && ti() : (Pt.value = e.options, Object.keys(oe.value).length || Cr(), Si());
  }), et(c, Si), et(o, (Q, ye) => {
    Be.value = I.value && Q === -1 ? 10 : Q;
  }), {
    pfo: _t,
    fo: St,
    filteredOptions: St,
    hasSelected: Rt,
    multipleLabelText: sn,
    eo: Ze,
    extendedOptions: Ze,
    eg: we,
    extendedGroups: we,
    fg: yt,
    filteredGroups: yt,
    noOptions: me,
    noResults: He,
    resolving: Ke,
    busy: kt,
    offset: Be,
    select: Dn,
    deselect: gn,
    remove: X,
    selectAll: Ve,
    clear: _e,
    isSelected: M,
    isDisabled: G,
    isMax: j,
    getOption: xe,
    handleOptionClick: ce,
    handleGroupClick: Ie,
    handleTagRemove: te,
    refreshOptions: yi,
    resolveOptions: ti,
    refreshLabels: Si
  };
}
function vqe(e, t, n) {
  const {
    valueProp: r,
    showOptions: i,
    searchable: a,
    groupLabel: o,
    groups: s,
    mode: l,
    groupSelect: u,
    disabledProp: c,
    groupOptions: d
  } = De(e), f = n.fo, h = n.fg, m = n.handleOptionClick, v = n.handleGroupClick, b = n.search, y = n.pointer, g = n.setPointer, E = n.clearPointer, S = n.multiselect, C = n.isOpen, T = N(() => f.value.filter((ae) => !ae[c.value])), O = N(() => h.value.filter((ae) => !ae[c.value])), R = N(() => l.value !== "single" && u.value), D = N(() => y.value && y.value.group), q = N(() => Ee(y.value)), $ = N(() => {
    const ae = D.value ? y.value : (
      /* istanbul ignore next */
      Ee(y.value)
    ), pe = O.value.map((Re) => Re[o.value]).indexOf(ae[o.value]);
    let Se = O.value[pe - 1];
    return Se === void 0 && (Se = Y.value), Se;
  }), P = N(() => {
    let ae = O.value.map((pe) => pe.label).indexOf(D.value ? y.value[o.value] : Ee(y.value)[o.value]) + 1;
    return O.value.length <= ae && (ae = 0), O.value[ae];
  }), Y = N(() => [...O.value].slice(-1)[0]), L = N(() => y.value.__VISIBLE__.filter((ae) => !ae[c.value])[0]), x = N(() => {
    const ae = q.value.__VISIBLE__.filter((pe) => !pe[c.value]);
    return ae[ae.map((pe) => pe[r.value]).indexOf(y.value[r.value]) - 1];
  }), I = N(() => {
    const ae = Ee(y.value).__VISIBLE__.filter((pe) => !pe[c.value]);
    return ae[ae.map((pe) => pe[r.value]).indexOf(y.value[r.value]) + 1];
  }), k = N(() => [...$.value.__VISIBLE__.filter((ae) => !ae[c.value])].slice(-1)[0]), B = N(() => [...Y.value.__VISIBLE__.filter((ae) => !ae[c.value])].slice(-1)[0]), W = (ae) => y.value && (!ae.group && y.value[r.value] === ae[r.value] || ae.group !== void 0 && y.value[o.value] === ae[o.value]) ? !0 : void 0, Z = () => {
    g(T.value[0] || null);
  }, V = () => {
    !y.value || y.value[c.value] === !0 || (D.value ? v(y.value) : m(y.value));
  }, K = () => {
    if (y.value === null)
      g((s.value && R.value ? O.value[0].__CREATE__ ? T.value[0] : O.value[0] : T.value[0]) || null);
    else if (s.value && R.value) {
      let ae = D.value ? L.value : I.value;
      ae === void 0 && (ae = P.value, ae.__CREATE__ && (ae = ae[d.value][0])), g(ae || /* istanbul ignore next */
      null);
    } else {
      let ae = T.value.map((pe) => pe[r.value]).indexOf(y.value[r.value]) + 1;
      T.value.length <= ae && (ae = 0), g(T.value[ae] || null);
    }
    Ut(() => {
      oe();
    });
  }, ne = () => {
    if (y.value === null) {
      let ae = T.value[T.value.length - 1];
      s.value && R.value && (ae = B.value, ae === void 0 && (ae = Y.value)), g(ae || null);
    } else if (s.value && R.value) {
      let ae = D.value ? k.value : x.value;
      ae === void 0 && (ae = D.value ? $.value : q.value, ae.__CREATE__ && (ae = k.value, ae === void 0 && (ae = $.value))), g(ae || /* istanbul ignore next */
      null);
    } else {
      let ae = T.value.map((pe) => pe[r.value]).indexOf(y.value[r.value]) - 1;
      ae < 0 && (ae = T.value.length - 1), g(T.value[ae] || null);
    }
    Ut(() => {
      oe();
    });
  }, Ee = (ae) => O.value.find((pe) => pe.__VISIBLE__.map((Se) => Se[r.value]).indexOf(ae[r.value]) !== -1), oe = () => {
    let ae = S.value.querySelector("[data-pointed]");
    if (!ae)
      return;
    let pe = ae.parentElement.parentElement;
    s.value && (pe = D.value ? ae.parentElement.parentElement.parentElement : ae.parentElement.parentElement.parentElement.parentElement), ae.offsetTop + ae.offsetHeight > pe.clientHeight + pe.scrollTop && (pe.scrollTop = ae.offsetTop + ae.offsetHeight - pe.clientHeight), ae.offsetTop < pe.scrollTop && (pe.scrollTop = ae.offsetTop);
  };
  return et(b, (ae) => {
    a.value && (ae.length && i.value ? Z() : E());
  }), et(C, (ae) => {
    if (ae) {
      let pe = S.value.querySelectorAll("[data-selected]")[0];
      if (!pe)
        return;
      let Se = pe.parentElement.parentElement;
      Ut(() => {
        Se.scrollTop > 0 || (Se.scrollTop = pe.offsetTop);
      });
    }
  }), {
    pointer: y,
    canPointGroups: R,
    isPointed: W,
    setPointerFirst: Z,
    selectPointer: V,
    forwardPointer: K,
    backwardPointer: ne
  };
}
function La(e) {
  if (e == null)
    return window;
  if (e.toString() !== "[object Window]") {
    var t = e.ownerDocument;
    return t && t.defaultView || window;
  }
  return e;
}
function ju(e) {
  var t = La(e).Element;
  return e instanceof t || e instanceof Element;
}
function Xa(e) {
  var t = La(e).HTMLElement;
  return e instanceof t || e instanceof HTMLElement;
}
function sR(e) {
  if (typeof ShadowRoot > "u")
    return !1;
  var t = La(e).ShadowRoot;
  return e instanceof t || e instanceof ShadowRoot;
}
var qu = Math.max, N_ = Math.min, bd = Math.round;
function i1() {
  var e = navigator.userAgentData;
  return e != null && e.brands && Array.isArray(e.brands) ? e.brands.map(function(t) {
    return t.brand + "/" + t.version;
  }).join(" ") : navigator.userAgent;
}
function i9() {
  return !/^((?!chrome|android).)*safari/i.test(i1());
}
function Ed(e, t, n) {
  t === void 0 && (t = !1), n === void 0 && (n = !1);
  var r = e.getBoundingClientRect(), i = 1, a = 1;
  t && Xa(e) && (i = e.offsetWidth > 0 && bd(r.width) / e.offsetWidth || 1, a = e.offsetHeight > 0 && bd(r.height) / e.offsetHeight || 1);
  var o = ju(e) ? La(e) : window, s = o.visualViewport, l = !i9() && n, u = (r.left + (l && s ? s.offsetLeft : 0)) / i, c = (r.top + (l && s ? s.offsetTop : 0)) / a, d = r.width / i, f = r.height / a;
  return {
    width: d,
    height: f,
    top: c,
    right: u + d,
    bottom: c + f,
    left: u,
    x: u,
    y: c
  };
}
function lR(e) {
  var t = La(e), n = t.pageXOffset, r = t.pageYOffset;
  return {
    scrollLeft: n,
    scrollTop: r
  };
}
function bqe(e) {
  return {
    scrollLeft: e.scrollLeft,
    scrollTop: e.scrollTop
  };
}
function Eqe(e) {
  return e === La(e) || !Xa(e) ? lR(e) : bqe(e);
}
function Zo(e) {
  return e ? (e.nodeName || "").toLowerCase() : null;
}
function Wl(e) {
  return ((ju(e) ? e.ownerDocument : (
    // $FlowFixMe[prop-missing]
    e.document
  )) || window.document).documentElement;
}
function uR(e) {
  return Ed(Wl(e)).left + lR(e).scrollLeft;
}
function zs(e) {
  return La(e).getComputedStyle(e);
}
function cR(e) {
  var t = zs(e), n = t.overflow, r = t.overflowX, i = t.overflowY;
  return /auto|scroll|overlay|hidden/.test(n + i + r);
}
function Sqe(e) {
  var t = e.getBoundingClientRect(), n = bd(t.width) / e.offsetWidth || 1, r = bd(t.height) / e.offsetHeight || 1;
  return n !== 1 || r !== 1;
}
function yqe(e, t, n) {
  n === void 0 && (n = !1);
  var r = Xa(t), i = Xa(t) && Sqe(t), a = Wl(t), o = Ed(e, i, n), s = {
    scrollLeft: 0,
    scrollTop: 0
  }, l = {
    x: 0,
    y: 0
  };
  return (r || !r && !n) && ((Zo(t) !== "body" || // https://github.com/popperjs/popper-core/issues/1078
  cR(a)) && (s = Eqe(t)), Xa(t) ? (l = Ed(t, !0), l.x += t.clientLeft, l.y += t.clientTop) : a && (l.x = uR(a))), {
    x: o.left + s.scrollLeft - l.x,
    y: o.top + s.scrollTop - l.y,
    width: o.width,
    height: o.height
  };
}
function a9(e) {
  var t = Ed(e), n = e.offsetWidth, r = e.offsetHeight;
  return Math.abs(t.width - n) <= 1 && (n = t.width), Math.abs(t.height - r) <= 1 && (r = t.height), {
    x: e.offsetLeft,
    y: e.offsetTop,
    width: n,
    height: r
  };
}
function Kv(e) {
  return Zo(e) === "html" ? e : (
    // this is a quicker (but less type safe) way to save quite some bytes from the bundle
    // $FlowFixMe[incompatible-return]
    // $FlowFixMe[prop-missing]
    e.assignedSlot || // step into the shadow DOM of the parent of a slotted node
    e.parentNode || // DOM Element detected
    (sR(e) ? e.host : null) || // ShadowRoot detected
    // $FlowFixMe[incompatible-call]: HTMLElement is a Node
    Wl(e)
  );
}
function o9(e) {
  return ["html", "body", "#document"].indexOf(Zo(e)) >= 0 ? e.ownerDocument.body : Xa(e) && cR(e) ? e : o9(Kv(e));
}
function fp(e, t) {
  var n;
  t === void 0 && (t = []);
  var r = o9(e), i = r === ((n = e.ownerDocument) == null ? void 0 : n.body), a = La(r), o = i ? [a].concat(a.visualViewport || [], cR(r) ? r : []) : r, s = t.concat(o);
  return i ? s : (
    // $FlowFixMe[incompatible-call]: isBody tells us target will be an HTMLElement here
    s.concat(fp(Kv(o)))
  );
}
function Tqe(e) {
  return ["table", "td", "th"].indexOf(Zo(e)) >= 0;
}
function BP(e) {
  return !Xa(e) || // https://github.com/popperjs/popper-core/issues/837
  zs(e).position === "fixed" ? null : e.offsetParent;
}
function Cqe(e) {
  var t = /firefox/i.test(i1()), n = /Trident/i.test(i1());
  if (n && Xa(e)) {
    var r = zs(e);
    if (r.position === "fixed")
      return null;
  }
  var i = Kv(e);
  for (sR(i) && (i = i.host); Xa(i) && ["html", "body"].indexOf(Zo(i)) < 0; ) {
    var a = zs(i);
    if (a.transform !== "none" || a.perspective !== "none" || a.contain === "paint" || ["transform", "perspective"].indexOf(a.willChange) !== -1 || t && a.willChange === "filter" || t && a.filter && a.filter !== "none")
      return i;
    i = i.parentNode;
  }
  return null;
}
function jv(e) {
  for (var t = La(e), n = BP(e); n && Tqe(n) && zs(n).position === "static"; )
    n = BP(n);
  return n && (Zo(n) === "html" || Zo(n) === "body" && zs(n).position === "static") ? t : n || Cqe(e) || t;
}
var So = "top", Jo = "bottom", Yl = "right", $s = "left", dR = "auto", Qv = [So, Jo, Yl, $s], Sd = "start", em = "end", Aqe = "clippingParents", s9 = "viewport", Pf = "popper", Oqe = "reference", $P = /* @__PURE__ */ Qv.reduce(function(e, t) {
  return e.concat([t + "-" + Sd, t + "-" + em]);
}, []), Rqe = /* @__PURE__ */ [].concat(Qv, [dR]).reduce(function(e, t) {
  return e.concat([t, t + "-" + Sd, t + "-" + em]);
}, []), wqe = "beforeRead", xqe = "read", Nqe = "afterRead", Dqe = "beforeMain", Iqe = "main", Lqe = "afterMain", kqe = "beforeWrite", Mqe = "write", Pqe = "afterWrite", Fqe = [wqe, xqe, Nqe, Dqe, Iqe, Lqe, kqe, Mqe, Pqe];
function Bqe(e) {
  var t = /* @__PURE__ */ new Map(), n = /* @__PURE__ */ new Set(), r = [];
  e.forEach(function(a) {
    t.set(a.name, a);
  });
  function i(a) {
    n.add(a.name);
    var o = [].concat(a.requires || [], a.requiresIfExists || []);
    o.forEach(function(s) {
      if (!n.has(s)) {
        var l = t.get(s);
        l && i(l);
      }
    }), r.push(a);
  }
  return e.forEach(function(a) {
    n.has(a.name) || i(a);
  }), r;
}
function $qe(e) {
  var t = Bqe(e);
  return Fqe.reduce(function(n, r) {
    return n.concat(t.filter(function(i) {
      return i.phase === r;
    }));
  }, []);
}
function Uqe(e) {
  var t;
  return function() {
    return t || (t = new Promise(function(n) {
      Promise.resolve().then(function() {
        t = void 0, n(e());
      });
    })), t;
  };
}
function qqe(e) {
  var t = e.reduce(function(n, r) {
    var i = n[r.name];
    return n[r.name] = i ? Object.assign({}, i, r, {
      options: Object.assign({}, i.options, r.options),
      data: Object.assign({}, i.data, r.data)
    }) : r, n;
  }, {});
  return Object.keys(t).map(function(n) {
    return t[n];
  });
}
function Gqe(e, t) {
  var n = La(e), r = Wl(e), i = n.visualViewport, a = r.clientWidth, o = r.clientHeight, s = 0, l = 0;
  if (i) {
    a = i.width, o = i.height;
    var u = i9();
    (u || !u && t === "fixed") && (s = i.offsetLeft, l = i.offsetTop);
  }
  return {
    width: a,
    height: o,
    x: s + uR(e),
    y: l
  };
}
function Yqe(e) {
  var t, n = Wl(e), r = lR(e), i = (t = e.ownerDocument) == null ? void 0 : t.body, a = qu(n.scrollWidth, n.clientWidth, i ? i.scrollWidth : 0, i ? i.clientWidth : 0), o = qu(n.scrollHeight, n.clientHeight, i ? i.scrollHeight : 0, i ? i.clientHeight : 0), s = -r.scrollLeft + uR(e), l = -r.scrollTop;
  return zs(i || n).direction === "rtl" && (s += qu(n.clientWidth, i ? i.clientWidth : 0) - a), {
    width: a,
    height: o,
    x: s,
    y: l
  };
}
function Hqe(e, t) {
  var n = t.getRootNode && t.getRootNode();
  if (e.contains(t))
    return !0;
  if (n && sR(n)) {
    var r = t;
    do {
      if (r && e.isSameNode(r))
        return !0;
      r = r.parentNode || r.host;
    } while (r);
  }
  return !1;
}
function a1(e) {
  return Object.assign({}, e, {
    left: e.x,
    top: e.y,
    right: e.x + e.width,
    bottom: e.y + e.height
  });
}
function zqe(e, t) {
  var n = Ed(e, !1, t === "fixed");
  return n.top = n.top + e.clientTop, n.left = n.left + e.clientLeft, n.bottom = n.top + e.clientHeight, n.right = n.left + e.clientWidth, n.width = e.clientWidth, n.height = e.clientHeight, n.x = n.left, n.y = n.top, n;
}
function UP(e, t, n) {
  return t === s9 ? a1(Gqe(e, n)) : ju(t) ? zqe(t, n) : a1(Yqe(Wl(e)));
}
function Vqe(e) {
  var t = fp(Kv(e)), n = ["absolute", "fixed"].indexOf(zs(e).position) >= 0, r = n && Xa(e) ? jv(e) : e;
  return ju(r) ? t.filter(function(i) {
    return ju(i) && Hqe(i, r) && Zo(i) !== "body";
  }) : [];
}
function Wqe(e, t, n, r) {
  var i = t === "clippingParents" ? Vqe(e) : [].concat(t), a = [].concat(i, [n]), o = a[0], s = a.reduce(function(l, u) {
    var c = UP(e, u, r);
    return l.top = qu(c.top, l.top), l.right = N_(c.right, l.right), l.bottom = N_(c.bottom, l.bottom), l.left = qu(c.left, l.left), l;
  }, UP(e, o, r));
  return s.width = s.right - s.left, s.height = s.bottom - s.top, s.x = s.left, s.y = s.top, s;
}
function Fl(e) {
  return e.split("-")[0];
}
function yd(e) {
  return e.split("-")[1];
}
function l9(e) {
  return ["top", "bottom"].indexOf(e) >= 0 ? "x" : "y";
}
function u9(e) {
  var t = e.reference, n = e.element, r = e.placement, i = r ? Fl(r) : null, a = r ? yd(r) : null, o = t.x + t.width / 2 - n.width / 2, s = t.y + t.height / 2 - n.height / 2, l;
  switch (i) {
    case So:
      l = {
        x: o,
        y: t.y - n.height
      };
      break;
    case Jo:
      l = {
        x: o,
        y: t.y + t.height
      };
      break;
    case Yl:
      l = {
        x: t.x + t.width,
        y: s
      };
      break;
    case $s:
      l = {
        x: t.x - n.width,
        y: s
      };
      break;
    default:
      l = {
        x: t.x,
        y: t.y
      };
  }
  var u = i ? l9(i) : null;
  if (u != null) {
    var c = u === "y" ? "height" : "width";
    switch (a) {
      case Sd:
        l[u] = l[u] - (t[c] / 2 - n[c] / 2);
        break;
      case em:
        l[u] = l[u] + (t[c] / 2 - n[c] / 2);
        break;
    }
  }
  return l;
}
function c9() {
  return {
    top: 0,
    right: 0,
    bottom: 0,
    left: 0
  };
}
function Kqe(e) {
  return Object.assign({}, c9(), e);
}
function jqe(e, t) {
  return t.reduce(function(n, r) {
    return n[r] = e, n;
  }, {});
}
function fR(e, t) {
  t === void 0 && (t = {});
  var n = t, r = n.placement, i = r === void 0 ? e.placement : r, a = n.strategy, o = a === void 0 ? e.strategy : a, s = n.boundary, l = s === void 0 ? Aqe : s, u = n.rootBoundary, c = u === void 0 ? s9 : u, d = n.elementContext, f = d === void 0 ? Pf : d, h = n.altBoundary, m = h === void 0 ? !1 : h, v = n.padding, b = v === void 0 ? 0 : v, y = Kqe(typeof b != "number" ? b : jqe(b, Qv)), g = f === Pf ? Oqe : Pf, E = e.rects.popper, S = e.elements[m ? g : f], C = Wqe(ju(S) ? S : S.contextElement || Wl(e.elements.popper), l, c, o), T = Ed(e.elements.reference), O = u9({
    reference: T,
    element: E,
    strategy: "absolute",
    placement: i
  }), R = a1(Object.assign({}, E, O)), D = f === Pf ? R : T, q = {
    top: C.top - D.top + y.top,
    bottom: D.bottom - C.bottom + y.bottom,
    left: C.left - D.left + y.left,
    right: D.right - C.right + y.right
  }, $ = e.modifiersData.offset;
  if (f === Pf && $) {
    var P = $[i];
    Object.keys(q).forEach(function(Y) {
      var L = [Yl, Jo].indexOf(Y) >= 0 ? 1 : -1, x = [So, Jo].indexOf(Y) >= 0 ? "y" : "x";
      q[Y] += P[x] * L;
    });
  }
  return q;
}
var qP = {
  placement: "bottom",
  modifiers: [],
  strategy: "absolute"
};
function GP() {
  for (var e = arguments.length, t = new Array(e), n = 0; n < e; n++)
    t[n] = arguments[n];
  return !t.some(function(r) {
    return !(r && typeof r.getBoundingClientRect == "function");
  });
}
function Qqe(e) {
  e === void 0 && (e = {});
  var t = e, n = t.defaultModifiers, r = n === void 0 ? [] : n, i = t.defaultOptions, a = i === void 0 ? qP : i;
  return function(s, l, u) {
    u === void 0 && (u = a);
    var c = {
      placement: "bottom",
      orderedModifiers: [],
      options: Object.assign({}, qP, a),
      modifiersData: {},
      elements: {
        reference: s,
        popper: l
      },
      attributes: {},
      styles: {}
    }, d = [], f = !1, h = {
      state: c,
      setOptions: function(y) {
        var g = typeof y == "function" ? y(c.options) : y;
        v(), c.options = Object.assign({}, a, c.options, g), c.scrollParents = {
          reference: ju(s) ? fp(s) : s.contextElement ? fp(s.contextElement) : [],
          popper: fp(l)
        };
        var E = $qe(qqe([].concat(r, c.options.modifiers)));
        return c.orderedModifiers = E.filter(function(S) {
          return S.enabled;
        }), m(), h.update();
      },
      // Sync update – it will always be executed, even if not necessary. This
      // is useful for low frequency updates where sync behavior simplifies the
      // logic.
      // For high frequency updates (e.g. `resize` and `scroll` events), always
      // prefer the async Popper#update method
      forceUpdate: function() {
        if (!f) {
          var y = c.elements, g = y.reference, E = y.popper;
          if (GP(g, E)) {
            c.rects = {
              reference: yqe(g, jv(E), c.options.strategy === "fixed"),
              popper: a9(E)
            }, c.reset = !1, c.placement = c.options.placement, c.orderedModifiers.forEach(function(q) {
              return c.modifiersData[q.name] = Object.assign({}, q.data);
            });
            for (var S = 0; S < c.orderedModifiers.length; S++) {
              if (c.reset === !0) {
                c.reset = !1, S = -1;
                continue;
              }
              var C = c.orderedModifiers[S], T = C.fn, O = C.options, R = O === void 0 ? {} : O, D = C.name;
              typeof T == "function" && (c = T({
                state: c,
                options: R,
                name: D,
                instance: h
              }) || c);
            }
          }
        }
      },
      // Async and optimistically optimized update – it will not be executed if
      // not necessary (debounced to run at most once-per-tick)
      update: Uqe(function() {
        return new Promise(function(b) {
          h.forceUpdate(), b(c);
        });
      }),
      destroy: function() {
        v(), f = !0;
      }
    };
    if (!GP(s, l))
      return h;
    h.setOptions(u).then(function(b) {
      !f && u.onFirstUpdate && u.onFirstUpdate(b);
    });
    function m() {
      c.orderedModifiers.forEach(function(b) {
        var y = b.name, g = b.options, E = g === void 0 ? {} : g, S = b.effect;
        if (typeof S == "function") {
          var C = S({
            state: c,
            name: y,
            instance: h,
            options: E
          }), T = function() {
          };
          d.push(C || T);
        }
      });
    }
    function v() {
      d.forEach(function(b) {
        return b();
      }), d = [];
    }
    return h;
  };
}
var ig = {
  passive: !0
};
function Xqe(e) {
  var t = e.state, n = e.instance, r = e.options, i = r.scroll, a = i === void 0 ? !0 : i, o = r.resize, s = o === void 0 ? !0 : o, l = La(t.elements.popper), u = [].concat(t.scrollParents.reference, t.scrollParents.popper);
  return a && u.forEach(function(c) {
    c.addEventListener("scroll", n.update, ig);
  }), s && l.addEventListener("resize", n.update, ig), function() {
    a && u.forEach(function(c) {
      c.removeEventListener("scroll", n.update, ig);
    }), s && l.removeEventListener("resize", n.update, ig);
  };
}
var Zqe = {
  name: "eventListeners",
  enabled: !0,
  phase: "write",
  fn: function() {
  },
  effect: Xqe,
  data: {}
};
function Jqe(e) {
  var t = e.state, n = e.name;
  t.modifiersData[n] = u9({
    reference: t.rects.reference,
    element: t.rects.popper,
    strategy: "absolute",
    placement: t.placement
  });
}
var e9e = {
  name: "popperOffsets",
  enabled: !0,
  phase: "read",
  fn: Jqe,
  data: {}
}, t9e = {
  top: "auto",
  right: "auto",
  bottom: "auto",
  left: "auto"
};
function n9e(e, t) {
  var n = e.x, r = e.y, i = t.devicePixelRatio || 1;
  return {
    x: bd(n * i) / i || 0,
    y: bd(r * i) / i || 0
  };
}
function YP(e) {
  var t, n = e.popper, r = e.popperRect, i = e.placement, a = e.variation, o = e.offsets, s = e.position, l = e.gpuAcceleration, u = e.adaptive, c = e.roundOffsets, d = e.isFixed, f = o.x, h = f === void 0 ? 0 : f, m = o.y, v = m === void 0 ? 0 : m, b = typeof c == "function" ? c({
    x: h,
    y: v
  }) : {
    x: h,
    y: v
  };
  h = b.x, v = b.y;
  var y = o.hasOwnProperty("x"), g = o.hasOwnProperty("y"), E = $s, S = So, C = window;
  if (u) {
    var T = jv(n), O = "clientHeight", R = "clientWidth";
    if (T === La(n) && (T = Wl(n), zs(T).position !== "static" && s === "absolute" && (O = "scrollHeight", R = "scrollWidth")), T = T, i === So || (i === $s || i === Yl) && a === em) {
      S = Jo;
      var D = d && T === C && C.visualViewport ? C.visualViewport.height : (
        // $FlowFixMe[prop-missing]
        T[O]
      );
      v -= D - r.height, v *= l ? 1 : -1;
    }
    if (i === $s || (i === So || i === Jo) && a === em) {
      E = Yl;
      var q = d && T === C && C.visualViewport ? C.visualViewport.width : (
        // $FlowFixMe[prop-missing]
        T[R]
      );
      h -= q - r.width, h *= l ? 1 : -1;
    }
  }
  var $ = Object.assign({
    position: s
  }, u && t9e), P = c === !0 ? n9e({
    x: h,
    y: v
  }, La(n)) : {
    x: h,
    y: v
  };
  if (h = P.x, v = P.y, l) {
    var Y;
    return Object.assign({}, $, (Y = {}, Y[S] = g ? "0" : "", Y[E] = y ? "0" : "", Y.transform = (C.devicePixelRatio || 1) <= 1 ? "translate(" + h + "px, " + v + "px)" : "translate3d(" + h + "px, " + v + "px, 0)", Y));
  }
  return Object.assign({}, $, (t = {}, t[S] = g ? v + "px" : "", t[E] = y ? h + "px" : "", t.transform = "", t));
}
function r9e(e) {
  var t = e.state, n = e.options, r = n.gpuAcceleration, i = r === void 0 ? !0 : r, a = n.adaptive, o = a === void 0 ? !0 : a, s = n.roundOffsets, l = s === void 0 ? !0 : s, u = {
    placement: Fl(t.placement),
    variation: yd(t.placement),
    popper: t.elements.popper,
    popperRect: t.rects.popper,
    gpuAcceleration: i,
    isFixed: t.options.strategy === "fixed"
  };
  t.modifiersData.popperOffsets != null && (t.styles.popper = Object.assign({}, t.styles.popper, YP(Object.assign({}, u, {
    offsets: t.modifiersData.popperOffsets,
    position: t.options.strategy,
    adaptive: o,
    roundOffsets: l
  })))), t.modifiersData.arrow != null && (t.styles.arrow = Object.assign({}, t.styles.arrow, YP(Object.assign({}, u, {
    offsets: t.modifiersData.arrow,
    position: "absolute",
    adaptive: !1,
    roundOffsets: l
  })))), t.attributes.popper = Object.assign({}, t.attributes.popper, {
    "data-popper-placement": t.placement
  });
}
var i9e = {
  name: "computeStyles",
  enabled: !0,
  phase: "beforeWrite",
  fn: r9e,
  data: {}
};
function a9e(e) {
  var t = e.state;
  Object.keys(t.elements).forEach(function(n) {
    var r = t.styles[n] || {}, i = t.attributes[n] || {}, a = t.elements[n];
    !Xa(a) || !Zo(a) || (Object.assign(a.style, r), Object.keys(i).forEach(function(o) {
      var s = i[o];
      s === !1 ? a.removeAttribute(o) : a.setAttribute(o, s === !0 ? "" : s);
    }));
  });
}
function o9e(e) {
  var t = e.state, n = {
    popper: {
      position: t.options.strategy,
      left: "0",
      top: "0",
      margin: "0"
    },
    arrow: {
      position: "absolute"
    },
    reference: {}
  };
  return Object.assign(t.elements.popper.style, n.popper), t.styles = n, t.elements.arrow && Object.assign(t.elements.arrow.style, n.arrow), function() {
    Object.keys(t.elements).forEach(function(r) {
      var i = t.elements[r], a = t.attributes[r] || {}, o = Object.keys(t.styles.hasOwnProperty(r) ? t.styles[r] : n[r]), s = o.reduce(function(l, u) {
        return l[u] = "", l;
      }, {});
      !Xa(i) || !Zo(i) || (Object.assign(i.style, s), Object.keys(a).forEach(function(l) {
        i.removeAttribute(l);
      }));
    });
  };
}
var s9e = {
  name: "applyStyles",
  enabled: !0,
  phase: "write",
  fn: a9e,
  effect: o9e,
  requires: ["computeStyles"]
}, l9e = [Zqe, e9e, i9e, s9e], u9e = /* @__PURE__ */ Qqe({
  defaultModifiers: l9e
});
function c9e(e) {
  return e === "x" ? "y" : "x";
}
function wg(e, t, n) {
  return qu(e, N_(t, n));
}
function d9e(e, t, n) {
  var r = wg(e, t, n);
  return r > n ? n : r;
}
function f9e(e) {
  var t = e.state, n = e.options, r = e.name, i = n.mainAxis, a = i === void 0 ? !0 : i, o = n.altAxis, s = o === void 0 ? !1 : o, l = n.boundary, u = n.rootBoundary, c = n.altBoundary, d = n.padding, f = n.tether, h = f === void 0 ? !0 : f, m = n.tetherOffset, v = m === void 0 ? 0 : m, b = fR(t, {
    boundary: l,
    rootBoundary: u,
    padding: d,
    altBoundary: c
  }), y = Fl(t.placement), g = yd(t.placement), E = !g, S = l9(y), C = c9e(S), T = t.modifiersData.popperOffsets, O = t.rects.reference, R = t.rects.popper, D = typeof v == "function" ? v(Object.assign({}, t.rects, {
    placement: t.placement
  })) : v, q = typeof D == "number" ? {
    mainAxis: D,
    altAxis: D
  } : Object.assign({
    mainAxis: 0,
    altAxis: 0
  }, D), $ = t.modifiersData.offset ? t.modifiersData.offset[t.placement] : null, P = {
    x: 0,
    y: 0
  };
  if (T) {
    if (a) {
      var Y, L = S === "y" ? So : $s, x = S === "y" ? Jo : Yl, I = S === "y" ? "height" : "width", k = T[S], B = k + b[L], W = k - b[x], Z = h ? -R[I] / 2 : 0, V = g === Sd ? O[I] : R[I], K = g === Sd ? -R[I] : -O[I], ne = t.elements.arrow, Ee = h && ne ? a9(ne) : {
        width: 0,
        height: 0
      }, oe = t.modifiersData["arrow#persistent"] ? t.modifiersData["arrow#persistent"].padding : c9(), ae = oe[L], pe = oe[x], Se = wg(0, O[I], Ee[I]), Re = E ? O[I] / 2 - Z - Se - ae - q.mainAxis : V - Se - ae - q.mainAxis, Ye = E ? -O[I] / 2 + Z + Se + pe + q.mainAxis : K + Se + pe + q.mainAxis, nt = t.elements.arrow && jv(t.elements.arrow), ut = nt ? S === "y" ? nt.clientTop || 0 : nt.clientLeft || 0 : 0, Tt = (Y = $ == null ? void 0 : $[S]) != null ? Y : 0, Ot = k + Re - Tt - ut, Xt = k + Ye - Tt, We = wg(h ? N_(B, Ot) : B, k, h ? qu(W, Xt) : W);
      T[S] = We, P[S] = We - k;
    }
    if (s) {
      var st, Pt = S === "x" ? So : $s, Ke = S === "x" ? Jo : Yl, Je = T[C], Be = C === "y" ? "height" : "width", pt = Je + b[Pt], ft = Je - b[Ke], Ze = [So, $s].indexOf(y) !== -1, _t = (st = $ == null ? void 0 : $[C]) != null ? st : 0, St = Ze ? pt : Je - O[Be] - R[Be] - _t + q.altAxis, we = Ze ? Je + O[Be] + R[Be] - _t - q.altAxis : ft, je = h && Ze ? d9e(St, Je, we) : wg(h ? St : pt, Je, h ? we : ft);
      T[C] = je, P[C] = je - Je;
    }
    t.modifiersData[r] = P;
  }
}
var p9e = {
  name: "preventOverflow",
  enabled: !0,
  phase: "main",
  fn: f9e,
  requiresIfExists: ["offset"]
}, m9e = {
  left: "right",
  right: "left",
  bottom: "top",
  top: "bottom"
};
function xg(e) {
  return e.replace(/left|right|bottom|top/g, function(t) {
    return m9e[t];
  });
}
var h9e = {
  start: "end",
  end: "start"
};
function HP(e) {
  return e.replace(/start|end/g, function(t) {
    return h9e[t];
  });
}
function g9e(e, t) {
  t === void 0 && (t = {});
  var n = t, r = n.placement, i = n.boundary, a = n.rootBoundary, o = n.padding, s = n.flipVariations, l = n.allowedAutoPlacements, u = l === void 0 ? Rqe : l, c = yd(r), d = c ? s ? $P : $P.filter(function(m) {
    return yd(m) === c;
  }) : Qv, f = d.filter(function(m) {
    return u.indexOf(m) >= 0;
  });
  f.length === 0 && (f = d);
  var h = f.reduce(function(m, v) {
    return m[v] = fR(e, {
      placement: v,
      boundary: i,
      rootBoundary: a,
      padding: o
    })[Fl(v)], m;
  }, {});
  return Object.keys(h).sort(function(m, v) {
    return h[m] - h[v];
  });
}
function _9e(e) {
  if (Fl(e) === dR)
    return [];
  var t = xg(e);
  return [HP(e), t, HP(t)];
}
function v9e(e) {
  var t = e.state, n = e.options, r = e.name;
  if (!t.modifiersData[r]._skip) {
    for (var i = n.mainAxis, a = i === void 0 ? !0 : i, o = n.altAxis, s = o === void 0 ? !0 : o, l = n.fallbackPlacements, u = n.padding, c = n.boundary, d = n.rootBoundary, f = n.altBoundary, h = n.flipVariations, m = h === void 0 ? !0 : h, v = n.allowedAutoPlacements, b = t.options.placement, y = Fl(b), g = y === b, E = l || (g || !m ? [xg(b)] : _9e(b)), S = [b].concat(E).reduce(function(Ee, oe) {
      return Ee.concat(Fl(oe) === dR ? g9e(t, {
        placement: oe,
        boundary: c,
        rootBoundary: d,
        padding: u,
        flipVariations: m,
        allowedAutoPlacements: v
      }) : oe);
    }, []), C = t.rects.reference, T = t.rects.popper, O = /* @__PURE__ */ new Map(), R = !0, D = S[0], q = 0; q < S.length; q++) {
      var $ = S[q], P = Fl($), Y = yd($) === Sd, L = [So, Jo].indexOf(P) >= 0, x = L ? "width" : "height", I = fR(t, {
        placement: $,
        boundary: c,
        rootBoundary: d,
        altBoundary: f,
        padding: u
      }), k = L ? Y ? Yl : $s : Y ? Jo : So;
      C[x] > T[x] && (k = xg(k));
      var B = xg(k), W = [];
      if (a && W.push(I[P] <= 0), s && W.push(I[k] <= 0, I[B] <= 0), W.every(function(Ee) {
        return Ee;
      })) {
        D = $, R = !1;
        break;
      }
      O.set($, W);
    }
    if (R)
      for (var Z = m ? 3 : 1, V = function(oe) {
        var ae = S.find(function(pe) {
          var Se = O.get(pe);
          if (Se)
            return Se.slice(0, oe).every(function(Re) {
              return Re;
            });
        });
        if (ae)
          return D = ae, "break";
      }, K = Z; K > 0; K--) {
        var ne = V(K);
        if (ne === "break") break;
      }
    t.placement !== D && (t.modifiersData[r]._skip = !0, t.placement = D, t.reset = !0);
  }
}
var b9e = {
  name: "flip",
  enabled: !0,
  phase: "main",
  fn: v9e,
  requiresIfExists: ["offset"],
  data: {
    _skip: !1
  }
};
function E9e(e, t, n) {
  const { disabled: r, appendTo: i, appendToBody: a, openDirection: o } = De(e), s = fi().proxy, l = n.multiselect, u = n.dropdown, c = he(!1), d = he(null), f = he(null), h = N(() => i.value || a.value), m = N(() => o.value === "top" && f.value === "bottom" || o.value === "bottom" && f.value !== "top" ? "bottom" : "top"), v = () => {
    c.value || r.value || (c.value = !0, t.emit("open", s), h.value && Ut(() => {
      y();
    }));
  }, b = () => {
    c.value && (c.value = !1, t.emit("close", s));
  }, y = () => {
    if (!d.value)
      return;
    let E = parseInt(window.getComputedStyle(u.value).borderTopWidth.replace("px", "")), S = parseInt(window.getComputedStyle(u.value).borderBottomWidth.replace("px", ""));
    d.value.setOptions((C) => ({
      ...C,
      modifiers: [
        ...C.modifiers,
        {
          name: "offset",
          options: {
            offset: [0, (m.value === "top" ? E : S) * -1]
          }
        }
      ]
    })), d.value.update();
  }, g = (E) => {
    for (; E && E !== document.body; ) {
      if (getComputedStyle(E).position === "fixed")
        return !0;
      E = E.parentElement;
    }
    return !1;
  };
  return On(() => {
    h.value && (d.value = u9e(l.value, u.value, {
      strategy: g(l.value) ? (
        /* istanbul ignore next: UI feature */
        "fixed"
      ) : void 0,
      placement: o.value,
      modifiers: [
        p9e,
        b9e,
        {
          name: "sameWidth",
          enabled: !0,
          phase: "beforeWrite",
          requires: ["computeStyles"],
          fn: ({ state: E }) => {
            E.styles.popper.width = `${E.rects.reference.width}px`;
          },
          effect: ({ state: E }) => {
            E.elements.popper.style.width = `${E.elements.reference.offsetWidth}px`;
          }
        },
        {
          name: "toggleClass",
          enabled: !0,
          phase: "write",
          fn({ state: E }) {
            f.value = E.placement;
          }
        }
      ]
    }));
  }), pa(() => {
    !h.value || !d.value || (d.value.destroy(), d.value = null);
  }), {
    popper: d,
    isOpen: c,
    open: v,
    close: b,
    placement: m,
    updatePopper: y
  };
}
function S9e(e, t, n) {
  const { searchable: r, disabled: i, clearOnBlur: a } = De(e), o = n.input, s = n.open, l = n.close, u = n.clearSearch, c = n.isOpen, d = n.wrapper, f = n.tags, h = he(!1), m = he(!1), v = N(() => r.value || i.value ? -1 : 0), b = () => {
    r.value && o.value.blur(), d.value.blur();
  }, y = () => {
    r.value && !i.value && o.value.focus();
  }, g = (R = !0) => {
    i.value || (h.value = !0, R && s());
  }, E = () => {
    h.value = !1, setTimeout(() => {
      h.value || (l(), a.value && u());
    }, 1);
  };
  return {
    tabindex: v,
    isActive: h,
    mouseClicked: m,
    blur: b,
    focus: y,
    activate: g,
    deactivate: E,
    handleFocusIn: (R) => {
      R.target.closest("[data-tags]") && R.target.nodeName !== "INPUT" || R.target.closest("[data-clear]") || g(m.value);
    },
    handleFocusOut: () => {
      E();
    },
    handleCaretClick: () => {
      E(), b();
    },
    handleMousedown: (R) => {
      m.value = !0, c.value && (R.target.isEqualNode(d.value) || R.target.isEqualNode(f.value)) ? setTimeout(() => {
        E();
      }, 0) : !c.value && (document.activeElement.isEqualNode(d.value) || document.activeElement.isEqualNode(o.value)) && g(), setTimeout(() => {
        m.value = !1;
      }, 0);
    }
  };
}
function y9e(e, t, n) {
  const {
    mode: r,
    addTagOn: i,
    openDirection: a,
    searchable: o,
    showOptions: s,
    valueProp: l,
    groups: u,
    addOptionOn: c,
    createTag: d,
    createOption: f,
    reverse: h
  } = De(e), m = fi().proxy, v = n.iv, b = n.update, y = n.deselect, g = n.search, E = n.setPointer, S = n.selectPointer, C = n.backwardPointer, T = n.forwardPointer, O = n.multiselect, R = n.wrapper, D = n.tags, q = n.isOpen, $ = n.open, P = n.blur, Y = n.fo, L = N(() => d.value || f.value || !1), x = N(() => i.value !== void 0 ? i.value : c.value !== void 0 ? c.value : ["enter"]), I = () => {
    r.value === "tags" && !s.value && L.value && o.value && !u.value && E(Y.value[Y.value.map((W) => W[l.value]).indexOf(g.value)]);
  };
  return {
    handleKeydown: (W) => {
      t.emit("keydown", W, m);
      let Z, V;
      switch (["ArrowLeft", "ArrowRight", "Enter"].indexOf(W.key) !== -1 && r.value === "tags" && (Z = [...O.value.querySelectorAll("[data-tags] > *")].filter((K) => K !== D.value), V = Z.findIndex((K) => K === document.activeElement)), W.key) {
        case "Backspace":
          if (r.value === "single" || o.value && [null, ""].indexOf(g.value) === -1 || v.value.length === 0)
            return;
          let K = v.value.filter((ne) => !ne.disabled && ne.remove !== !1);
          K.length && y(K[K.length - 1]);
          break;
        case "Enter":
          if (W.preventDefault(), W.keyCode === 229)
            return;
          if (V !== -1 && V !== void 0) {
            b([...v.value].filter((ne, Ee) => Ee !== V)), V === Z.length - 1 && (Z.length - 1 ? Z[Z.length - 2].focus() : o.value ? D.value.querySelector("input").focus() : R.value.focus());
            return;
          }
          if (x.value.indexOf("enter") === -1 && L.value)
            return;
          I(), S();
          break;
        case " ":
          if (!L.value && !o.value) {
            W.preventDefault(), I(), S();
            return;
          }
          if (!L.value)
            return !1;
          if (x.value.indexOf("space") === -1 && L.value)
            return;
          W.preventDefault(), I(), S();
          break;
        case "Tab":
        case ";":
        case ",":
          if (x.value.indexOf(W.key.toLowerCase()) === -1 || !L.value)
            return;
          I(), S(), W.preventDefault();
          break;
        case "Escape":
          P();
          break;
        case "ArrowUp":
          if (W.preventDefault(), !s.value)
            return;
          q.value || $(), C();
          break;
        case "ArrowDown":
          if (W.preventDefault(), !s.value)
            return;
          q.value || $(), T();
          break;
        case "ArrowLeft":
          if (o.value && D.value && D.value.querySelector("input").selectionStart || W.shiftKey || r.value !== "tags" || !v.value || !v.value.length)
            return;
          W.preventDefault(), V === -1 ? Z[Z.length - 1].focus() : V > 0 && Z[V - 1].focus();
          break;
        case "ArrowRight":
          if (V === -1 || W.shiftKey || r.value !== "tags" || !v.value || !v.value.length)
            return;
          W.preventDefault(), Z.length > V + 1 ? Z[V + 1].focus() : o.value ? D.value.querySelector("input").focus() : o.value || R.value.focus();
          break;
      }
    },
    handleKeyup: (W) => {
      t.emit("keyup", W, m);
    },
    preparePointer: I
  };
}
function T9e(e, t, n) {
  const {
    classes: r,
    disabled: i,
    showOptions: a,
    breakTags: o
  } = De(e), s = n.isOpen, l = n.isPointed, u = n.isSelected, c = n.isDisabled, d = n.isActive, f = n.canPointGroups, h = n.resolving, m = n.fo, v = n.placement, b = N(() => ({
    container: "multiselect",
    containerDisabled: "is-disabled",
    containerOpen: "is-open",
    containerOpenTop: "is-open-top",
    containerActive: "is-active",
    wrapper: "multiselect-wrapper",
    singleLabel: "multiselect-single-label",
    singleLabelText: "multiselect-single-label-text",
    multipleLabel: "multiselect-multiple-label",
    search: "multiselect-search",
    tags: "multiselect-tags",
    tag: "multiselect-tag",
    tagWrapper: "multiselect-tag-wrapper",
    tagWrapperBreak: "multiselect-tag-wrapper-break",
    tagDisabled: "is-disabled",
    tagRemove: "multiselect-tag-remove",
    tagRemoveIcon: "multiselect-tag-remove-icon",
    tagsSearchWrapper: "multiselect-tags-search-wrapper",
    tagsSearch: "multiselect-tags-search",
    tagsSearchCopy: "multiselect-tags-search-copy",
    placeholder: "multiselect-placeholder",
    caret: "multiselect-caret",
    caretOpen: "is-open",
    clear: "multiselect-clear",
    clearIcon: "multiselect-clear-icon",
    spinner: "multiselect-spinner",
    inifinite: "multiselect-inifite",
    inifiniteSpinner: "multiselect-inifite-spinner",
    dropdown: "multiselect-dropdown",
    dropdownTop: "is-top",
    dropdownHidden: "is-hidden",
    options: "multiselect-options",
    optionsTop: "is-top",
    group: "multiselect-group",
    groupLabel: "multiselect-group-label",
    groupLabelPointable: "is-pointable",
    groupLabelPointed: "is-pointed",
    groupLabelSelected: "is-selected",
    groupLabelDisabled: "is-disabled",
    groupLabelSelectedPointed: "is-selected is-pointed",
    groupLabelSelectedDisabled: "is-selected is-disabled",
    groupOptions: "multiselect-group-options",
    option: "multiselect-option",
    optionPointed: "is-pointed",
    optionSelected: "is-selected",
    optionDisabled: "is-disabled",
    optionSelectedPointed: "is-selected is-pointed",
    optionSelectedDisabled: "is-selected is-disabled",
    noOptions: "multiselect-no-options",
    noResults: "multiselect-no-results",
    fakeInput: "multiselect-fake-input",
    assist: "multiselect-assistive-text",
    spacer: "multiselect-spacer",
    ...r.value
  })), y = N(() => !!(s.value && a.value && (!h.value || h.value && m.value.length)));
  return {
    classList: N(() => {
      const E = b.value;
      return {
        container: [E.container].concat(i.value ? E.containerDisabled : []).concat(y.value && v.value === "top" ? E.containerOpenTop : []).concat(y.value && v.value !== "top" ? E.containerOpen : []).concat(d.value ? E.containerActive : []),
        wrapper: E.wrapper,
        spacer: E.spacer,
        singleLabel: E.singleLabel,
        singleLabelText: E.singleLabelText,
        multipleLabel: E.multipleLabel,
        search: E.search,
        tags: E.tags,
        tag: [E.tag].concat(i.value ? E.tagDisabled : []),
        tagWrapper: [E.tagWrapper, o.value ? E.tagWrapperBreak : null],
        tagDisabled: E.tagDisabled,
        tagRemove: E.tagRemove,
        tagRemoveIcon: E.tagRemoveIcon,
        tagsSearchWrapper: E.tagsSearchWrapper,
        tagsSearch: E.tagsSearch,
        tagsSearchCopy: E.tagsSearchCopy,
        placeholder: E.placeholder,
        caret: [E.caret].concat(s.value ? E.caretOpen : []),
        clear: E.clear,
        clearIcon: E.clearIcon,
        spinner: E.spinner,
        inifinite: E.inifinite,
        inifiniteSpinner: E.inifiniteSpinner,
        dropdown: [E.dropdown].concat(v.value === "top" ? E.dropdownTop : []).concat(!s.value || !a.value || !y.value ? E.dropdownHidden : []),
        options: [E.options].concat(v.value === "top" ? E.optionsTop : []),
        group: E.group,
        groupLabel: (S) => {
          let C = [E.groupLabel];
          return l(S) ? C.push(u(S) ? E.groupLabelSelectedPointed : E.groupLabelPointed) : u(S) && f.value ? C.push(c(S) ? E.groupLabelSelectedDisabled : E.groupLabelSelected) : c(S) && C.push(E.groupLabelDisabled), f.value && C.push(E.groupLabelPointable), C;
        },
        groupOptions: E.groupOptions,
        option: (S, C) => {
          let T = [E.option];
          return l(S) ? T.push(u(S) ? E.optionSelectedPointed : E.optionPointed) : u(S) ? T.push(c(S) ? E.optionSelectedDisabled : E.optionSelected) : (c(S) || C && c(C)) && T.push(E.optionDisabled), T;
        },
        noOptions: E.noOptions,
        noResults: E.noResults,
        assist: E.assist,
        fakeInput: E.fakeInput
      };
    }),
    showDropdown: y
  };
}
function C9e(e, t, n) {
  const {
    limit: r,
    infinite: i
  } = De(e), a = n.isOpen, o = n.offset, s = n.search, l = n.pfo, u = n.eo, c = he(null), d = he(null), f = N(() => o.value < l.value.length), h = (v) => {
    const { isIntersecting: b, target: y } = v[0];
    if (b) {
      const g = y.offsetParent, E = g.scrollTop;
      o.value += r.value == -1 ? 10 : r.value, Ut(() => {
        g.scrollTop = E;
      });
    }
  }, m = () => {
    a.value && o.value < l.value.length ? c.value.observe(d.value) : !a.value && c.value && c.value.disconnect();
  };
  return et(a, () => {
    i.value && m();
  }), et(s, () => {
    i.value && (o.value = r.value, m());
  }, { flush: "post" }), et(u, () => {
    i.value && m();
  }, { immediate: !1, flush: "post" }), On(() => {
    window && window.IntersectionObserver && (c.value = new IntersectionObserver(h));
  }), {
    hasMore: f,
    infiniteLoader: d
  };
}
function A9e(e, t, n) {
  const {
    placeholder: r,
    id: i,
    valueProp: a,
    label: o,
    mode: s,
    groupLabel: l,
    aria: u,
    searchable: c
  } = De(e), d = n.pointer, f = n.iv, h = n.hasSelected, m = n.multipleLabelText, v = he(null), b = N(() => {
    let P = [];
    return i && i.value && P.push(i.value), P.push("assist"), P.join("-");
  }), y = N(() => {
    let P = [];
    return i && i.value && P.push(i.value), P.push("multiselect-options"), P.join("-");
  }), g = N(() => {
    let P = [];
    if (i && i.value && P.push(i.value), d.value)
      return P.push(d.value.group ? "multiselect-group" : "multiselect-option"), P.push(d.value.group ? d.value.index : d.value[a.value]), P.join("-");
  }), E = N(() => r.value), S = N(() => s.value !== "single"), C = N(() => {
    let P = "";
    return s.value === "single" && h.value && (P += f.value[o.value]), s.value === "multiple" && h.value && (P += m.value), s.value === "tags" && h.value && (P += f.value.map((Y) => Y[o.value]).join(", ")), P;
  }), T = N(() => {
    let P = { ...u.value };
    return c.value && (P["aria-labelledby"] = P["aria-labelledby"] ? `${b.value} ${P["aria-labelledby"]}` : b.value, C.value && P["aria-label"] && (P["aria-label"] = `${C.value}, ${P["aria-label"]}`)), P;
  }), O = (P) => {
    let Y = [];
    return i && i.value && Y.push(i.value), Y.push("multiselect-option"), Y.push(P[a.value]), Y.join("-");
  }, R = (P) => {
    let Y = [];
    return i && i.value && Y.push(i.value), Y.push("multiselect-group"), Y.push(P.index), Y.join("-");
  }, D = (P) => {
    let Y = [];
    return Y.push(P), Y.join(" ");
  }, q = (P) => {
    let Y = [];
    return Y.push(P), Y.join(" ");
  }, $ = (P) => `${P} ❎`;
  return On(() => {
    if (i && i.value && document && document.querySelector) {
      let P = document.querySelector(`[for="${i.value}"]`);
      v.value = P ? P.innerText : null;
    }
  }), {
    arias: T,
    ariaLabel: C,
    ariaAssist: b,
    ariaControls: y,
    ariaPlaceholder: E,
    ariaMultiselectable: S,
    ariaActiveDescendant: g,
    ariaOptionId: O,
    ariaOptionLabel: D,
    ariaGroupId: R,
    ariaGroupLabel: q,
    ariaTagLabel: $
  };
}
function O9e(e, t, n) {
  const {
    locale: r,
    fallbackLocale: i
  } = De(e);
  return {
    localize: (o) => !o || typeof o != "object" ? o : o && o[r.value] ? o[r.value] : o && r.value && o[r.value.toUpperCase()] ? o[r.value.toUpperCase()] : o && o[i.value] ? o[i.value] : o && i.value && o[i.value.toUpperCase()] ? o[i.value.toUpperCase()] : o && Object.keys(o)[0] ? o[Object.keys(o)[0]] : ""
  };
}
function R9e(e, t, n) {
  const r = he(null), i = he(null), a = he(null), o = he(null), s = he(null);
  return {
    multiselect: r,
    wrapper: i,
    tags: a,
    input: o,
    dropdown: s
  };
}
function w9e(e, t, n, r = {}) {
  return n.forEach((i) => {
    i && (r = {
      ...r,
      ...i(e, t, r)
    });
  }), r;
}
var Gm = {
  name: "Multiselect",
  emits: [
    "paste",
    "open",
    "close",
    "select",
    "deselect",
    "input",
    "search-change",
    "tag",
    "option",
    "update:modelValue",
    "change",
    "clear",
    "keydown",
    "keyup",
    "max",
    "create"
  ],
  props: {
    value: {
      required: !1
    },
    modelValue: {
      required: !1
    },
    options: {
      type: [Array, Object, Function],
      required: !1,
      default: () => []
    },
    id: {
      type: [String, Number],
      required: !1
    },
    name: {
      type: [String, Number],
      required: !1,
      default: "multiselect"
    },
    disabled: {
      type: Boolean,
      required: !1,
      default: !1
    },
    label: {
      type: String,
      required: !1,
      default: "label"
    },
    trackBy: {
      type: [String, Array],
      required: !1,
      default: void 0
    },
    valueProp: {
      type: String,
      required: !1,
      default: "value"
    },
    placeholder: {
      type: String,
      required: !1,
      default: null
    },
    mode: {
      type: String,
      required: !1,
      default: "single"
      // single|multiple|tags
    },
    searchable: {
      type: Boolean,
      required: !1,
      default: !1
    },
    limit: {
      type: Number,
      required: !1,
      default: -1
    },
    hideSelected: {
      type: Boolean,
      required: !1,
      default: !0
    },
    createTag: {
      type: Boolean,
      required: !1,
      default: void 0
    },
    createOption: {
      type: Boolean,
      required: !1,
      default: void 0
    },
    appendNewTag: {
      type: Boolean,
      required: !1,
      default: void 0
    },
    appendNewOption: {
      type: Boolean,
      required: !1,
      default: void 0
    },
    addTagOn: {
      type: Array,
      required: !1,
      default: void 0
    },
    addOptionOn: {
      type: Array,
      required: !1,
      default: void 0
    },
    caret: {
      type: Boolean,
      required: !1,
      default: !0
    },
    loading: {
      type: Boolean,
      required: !1,
      default: !1
    },
    noOptionsText: {
      type: [String, Object],
      required: !1,
      default: "The list is empty"
    },
    noResultsText: {
      type: [String, Object],
      required: !1,
      default: "No results found"
    },
    multipleLabel: {
      type: Function,
      required: !1
    },
    object: {
      type: Boolean,
      required: !1,
      default: !1
    },
    delay: {
      type: Number,
      required: !1,
      default: -1
    },
    minChars: {
      type: Number,
      required: !1,
      default: 0
    },
    resolveOnLoad: {
      type: Boolean,
      required: !1,
      default: !0
    },
    filterResults: {
      type: Boolean,
      required: !1,
      default: !0
    },
    clearOnSearch: {
      type: Boolean,
      required: !1,
      default: !1
    },
    clearOnSelect: {
      type: Boolean,
      required: !1,
      default: !0
    },
    canDeselect: {
      type: Boolean,
      required: !1,
      default: !0
    },
    canClear: {
      type: Boolean,
      required: !1,
      default: !0
    },
    max: {
      type: Number,
      required: !1,
      default: -1
    },
    showOptions: {
      type: Boolean,
      required: !1,
      default: !0
    },
    required: {
      type: Boolean,
      required: !1,
      default: !1
    },
    openDirection: {
      type: String,
      required: !1,
      default: "bottom"
    },
    nativeSupport: {
      type: Boolean,
      required: !1,
      default: !1
    },
    classes: {
      type: Object,
      required: !1,
      default: () => ({})
    },
    strict: {
      type: Boolean,
      required: !1,
      default: !0
    },
    closeOnSelect: {
      type: Boolean,
      required: !1,
      default: !0
    },
    closeOnDeselect: {
      type: Boolean,
      required: !1,
      default: !1
    },
    autocomplete: {
      type: String,
      required: !1
    },
    groups: {
      type: Boolean,
      required: !1,
      default: !1
    },
    groupLabel: {
      type: String,
      required: !1,
      default: "label"
    },
    groupOptions: {
      type: String,
      required: !1,
      default: "options"
    },
    groupHideEmpty: {
      type: Boolean,
      required: !1,
      default: !1
    },
    groupSelect: {
      type: Boolean,
      required: !1,
      default: !0
    },
    inputType: {
      type: String,
      required: !1,
      default: "text"
    },
    attrs: {
      required: !1,
      type: Object,
      default: () => ({})
    },
    onCreate: {
      required: !1,
      type: Function
    },
    disabledProp: {
      type: String,
      required: !1,
      default: "disabled"
    },
    searchStart: {
      type: Boolean,
      required: !1,
      default: !1
    },
    reverse: {
      type: Boolean,
      required: !1,
      default: !1
    },
    regex: {
      type: [Object, String, RegExp],
      required: !1,
      default: void 0
    },
    rtl: {
      type: Boolean,
      required: !1,
      default: !1
    },
    infinite: {
      type: Boolean,
      required: !1,
      default: !1
    },
    aria: {
      required: !1,
      type: Object,
      default: () => ({})
    },
    clearOnBlur: {
      required: !1,
      type: Boolean,
      default: !0
    },
    locale: {
      required: !1,
      type: String,
      default: null
    },
    fallbackLocale: {
      required: !1,
      type: String,
      default: "en"
    },
    searchFilter: {
      required: !1,
      type: Function,
      default: null
    },
    allowAbsent: {
      required: !1,
      type: Boolean,
      default: !1
    },
    appendToBody: {
      required: !1,
      type: Boolean,
      default: !1
    },
    closeOnScroll: {
      required: !1,
      type: Boolean,
      default: !1
    },
    breakTags: {
      required: !1,
      type: Boolean,
      default: !1
    },
    appendTo: {
      required: !1,
      type: String
    }
  },
  setup(e, t) {
    return w9e(e, t, [
      R9e,
      O9e,
      fqe,
      mqe,
      E9e,
      pqe,
      dqe,
      S9e,
      _qe,
      C9e,
      vqe,
      y9e,
      T9e,
      A9e
    ]);
  },
  beforeMount() {
    var e, t;
    ((t = (e = this.$root.constructor) == null ? void 0 : e.version) != null && t.match(/^2\./) || this.vueVersionMs === 2) && (this.$options.components.Teleport || (this.$options.components.Teleport = {
      render() {
        return this.$slots.default ? this.$slots.default[0] : null;
      }
    }));
  }
};
const x9e = ["id", "dir"], N9e = ["tabindex", "aria-controls", "aria-placeholder", "aria-expanded", "aria-activedescendant", "aria-multiselectable", "role"], D9e = ["type", "modelValue", "value", "autocomplete", "id", "aria-controls", "aria-placeholder", "aria-expanded", "aria-activedescendant", "aria-multiselectable"], I9e = ["onKeyup", "aria-label"], L9e = ["onClick"], k9e = ["type", "modelValue", "value", "id", "autocomplete", "aria-controls", "aria-placeholder", "aria-expanded", "aria-activedescendant", "aria-multiselectable"], M9e = ["innerHTML"], P9e = ["id"], F9e = ["id"], B9e = ["id", "aria-label", "aria-selected"], $9e = ["data-pointed", "onMouseenter", "onMousedown"], U9e = ["innerHTML"], q9e = ["aria-label"], G9e = ["data-pointed", "data-selected", "onMouseenter", "onMousedown", "id", "aria-selected", "aria-label"], Y9e = ["data-pointed", "data-selected", "onMouseenter", "onMousedown", "id", "aria-selected", "aria-label"], H9e = ["innerHTML"], z9e = ["innerHTML"], V9e = ["value"], W9e = ["name", "value"], K9e = ["name", "value"], j9e = ["id"];
function Q9e(e, t, n, r, i, a) {
  return U(), ee("div", {
    ref: "multiselect",
    class: re(e.classList.container),
    id: n.searchable ? void 0 : n.id,
    dir: n.rtl ? "rtl" : void 0,
    onFocusin: t[10] || (t[10] = (...o) => e.handleFocusIn && e.handleFocusIn(...o)),
    onFocusout: t[11] || (t[11] = (...o) => e.handleFocusOut && e.handleFocusOut(...o)),
    onKeyup: t[12] || (t[12] = (...o) => e.handleKeyup && e.handleKeyup(...o)),
    onKeydown: t[13] || (t[13] = (...o) => e.handleKeydown && e.handleKeydown(...o))
  }, [
    de("div", $e({
      class: e.classList.wrapper,
      onMousedown: t[9] || (t[9] = (...o) => e.handleMousedown && e.handleMousedown(...o)),
      ref: "wrapper",
      tabindex: e.tabindex,
      "aria-controls": n.searchable ? void 0 : e.ariaControls,
      "aria-placeholder": n.searchable ? void 0 : e.ariaPlaceholder,
      "aria-expanded": n.searchable ? void 0 : e.isOpen,
      "aria-activedescendant": n.searchable ? void 0 : e.ariaActiveDescendant,
      "aria-multiselectable": n.searchable ? void 0 : e.ariaMultiselectable,
      role: n.searchable ? void 0 : "combobox"
    }, n.searchable ? {} : e.arias), [
      se(" Search "),
      n.mode !== "tags" && n.searchable && !n.disabled ? (U(), ee("input", $e({
        key: 0,
        type: n.inputType,
        modelValue: e.search,
        value: e.search,
        class: e.classList.search,
        autocomplete: n.autocomplete,
        id: n.searchable ? n.id : void 0,
        onInput: t[0] || (t[0] = (...o) => e.handleSearchInput && e.handleSearchInput(...o)),
        onKeypress: t[1] || (t[1] = (...o) => e.handleKeypress && e.handleKeypress(...o)),
        onPaste: t[2] || (t[2] = An((...o) => e.handlePaste && e.handlePaste(...o), ["stop"])),
        ref: "input",
        "aria-controls": e.ariaControls,
        "aria-placeholder": e.ariaPlaceholder,
        "aria-expanded": e.isOpen,
        "aria-activedescendant": e.ariaActiveDescendant,
        "aria-multiselectable": e.ariaMultiselectable,
        role: "combobox"
      }, {
        ...n.attrs,
        ...e.arias
      }), null, 16, D9e)) : se("v-if", !0),
      se(" Tags (with search) "),
      n.mode == "tags" ? (U(), ee(
        "div",
        {
          key: 1,
          class: re(e.classList.tags),
          "data-tags": ""
        },
        [
          (U(!0), ee(
            gt,
            null,
            It(e.iv, (o, s, l) => Me(e.$slots, "tag", {
              option: o,
              handleTagRemove: e.handleTagRemove,
              disabled: n.disabled
            }, () => [
              (U(), ee("span", {
                class: re([
                  e.classList.tag,
                  o.disabled ? e.classList.tagDisabled : null
                ]),
                tabindex: "-1",
                onKeyup: Zr((u) => e.handleTagRemove(o, u), ["enter"]),
                key: l,
                "aria-label": e.ariaTagLabel(e.localize(o[n.label]))
              }, [
                de(
                  "span",
                  {
                    class: re(e.classList.tagWrapper)
                  },
                  zt(e.localize(o[n.label])),
                  3
                  /* TEXT, CLASS */
                ),
                !n.disabled && !o.disabled ? (U(), ee("span", {
                  key: 0,
                  class: re(e.classList.tagRemove),
                  onClick: An((u) => e.handleTagRemove(o, u), ["stop"])
                }, [
                  de(
                    "span",
                    {
                      class: re(e.classList.tagRemoveIcon)
                    },
                    null,
                    2
                    /* CLASS */
                  )
                ], 10, L9e)) : se("v-if", !0)
              ], 42, I9e))
            ])),
            256
            /* UNKEYED_FRAGMENT */
          )),
          de(
            "div",
            {
              class: re(e.classList.tagsSearchWrapper),
              ref: "tags"
            },
            [
              se(" Used for measuring search width "),
              de(
                "span",
                {
                  class: re(e.classList.tagsSearchCopy)
                },
                zt(e.search),
                3
                /* TEXT, CLASS */
              ),
              se(" Actual search input "),
              n.searchable && !n.disabled ? (U(), ee("input", $e({
                key: 0,
                type: n.inputType,
                modelValue: e.search,
                value: e.search,
                class: e.classList.tagsSearch,
                id: n.searchable ? n.id : void 0,
                autocomplete: n.autocomplete,
                onInput: t[3] || (t[3] = (...o) => e.handleSearchInput && e.handleSearchInput(...o)),
                onKeypress: t[4] || (t[4] = (...o) => e.handleKeypress && e.handleKeypress(...o)),
                onPaste: t[5] || (t[5] = An((...o) => e.handlePaste && e.handlePaste(...o), ["stop"])),
                ref: "input",
                "aria-controls": e.ariaControls,
                "aria-placeholder": e.ariaPlaceholder,
                "aria-expanded": e.isOpen,
                "aria-activedescendant": e.ariaActiveDescendant,
                "aria-multiselectable": e.ariaMultiselectable,
                role: "combobox"
              }, {
                ...n.attrs,
                ...e.arias
              }), null, 16, k9e)) : se("v-if", !0)
            ],
            2
            /* CLASS */
          )
        ],
        2
        /* CLASS */
      )) : se("v-if", !0),
      se(" Single label "),
      n.mode == "single" && e.hasSelected && !e.search && e.iv ? Me(e.$slots, "singlelabel", {
        key: 2,
        value: e.iv
      }, () => [
        de(
          "div",
          {
            class: re(e.classList.singleLabel)
          },
          [
            de(
              "span",
              {
                class: re(e.classList.singleLabelText)
              },
              zt(e.localize(e.iv[n.label])),
              3
              /* TEXT, CLASS */
            )
          ],
          2
          /* CLASS */
        )
      ]) : se("v-if", !0),
      se(" Multiple label "),
      n.mode == "multiple" && e.hasSelected && !e.search ? Me(e.$slots, "multiplelabel", {
        key: 3,
        values: e.iv
      }, () => [
        de("div", {
          class: re(e.classList.multipleLabel),
          innerHTML: e.multipleLabelText
        }, null, 10, M9e)
      ]) : se("v-if", !0),
      se(" Placeholder "),
      n.placeholder && !e.hasSelected && !e.search ? Me(e.$slots, "placeholder", { key: 4 }, () => [
        de(
          "div",
          {
            class: re(e.classList.placeholder),
            "aria-hidden": "true"
          },
          zt(n.placeholder),
          3
          /* TEXT, CLASS */
        )
      ]) : se("v-if", !0),
      se(" Spinner "),
      n.loading || e.resolving ? Me(e.$slots, "spinner", { key: 5 }, () => [
        de(
          "span",
          {
            class: re(e.classList.spinner),
            "aria-hidden": "true"
          },
          null,
          2
          /* CLASS */
        )
      ]) : se("v-if", !0),
      se(" Clear "),
      e.hasSelected && !n.disabled && n.canClear && !e.busy ? Me(e.$slots, "clear", {
        key: 6,
        clear: e.clear
      }, () => [
        de(
          "span",
          {
            "aria-hidden": "true",
            tabindex: "0",
            role: "button",
            "data-clear": "",
            "aria-roledescription": "❎",
            class: re(e.classList.clear),
            onClick: t[6] || (t[6] = (...o) => e.clear && e.clear(...o)),
            onKeyup: t[7] || (t[7] = Zr((...o) => e.clear && e.clear(...o), ["enter"]))
          },
          [
            de(
              "span",
              {
                class: re(e.classList.clearIcon)
              },
              null,
              2
              /* CLASS */
            )
          ],
          34
          /* CLASS, NEED_HYDRATION */
        )
      ]) : se("v-if", !0),
      se(" Caret "),
      n.caret && n.showOptions ? Me(e.$slots, "caret", {
        key: 7,
        handleCaretClick: e.handleCaretClick,
        isOpen: e.isOpen
      }, () => [
        de(
          "span",
          {
            class: re(e.classList.caret),
            onClick: t[8] || (t[8] = (...o) => e.handleCaretClick && e.handleCaretClick(...o)),
            "aria-hidden": "true"
          },
          null,
          2
          /* CLASS */
        )
      ]) : se("v-if", !0)
    ], 16, N9e),
    se(" Options "),
    (U(), Ae(rW, {
      to: n.appendTo || "body",
      disabled: !n.appendToBody && !n.appendTo
    }, [
      de("div", {
        id: `${n.id}-dropdown`,
        class: re(e.classList.dropdown),
        tabindex: "-1",
        ref: "dropdown"
      }, [
        Me(e.$slots, "beforelist", { options: e.fo }),
        de("ul", {
          class: re(e.classList.options),
          id: e.ariaControls,
          role: "listbox"
        }, [
          n.groups ? (U(!0), ee(
            gt,
            { key: 0 },
            It(e.fg, (o, s, l) => (U(), ee("li", {
              class: re(e.classList.group),
              key: l,
              id: e.ariaGroupId(o),
              "aria-label": e.ariaGroupLabel(e.localize(o[n.groupLabel])),
              "aria-selected": e.isSelected(o),
              role: "option"
            }, [
              o.__CREATE__ ? se("v-if", !0) : (U(), ee("div", {
                key: 0,
                class: re(e.classList.groupLabel(o)),
                "data-pointed": e.isPointed(o),
                onMouseenter: (u) => e.setPointer(o, s),
                onMousedown: An((u) => e.handleGroupClick(o), ["prevent"])
              }, [
                Me(e.$slots, "grouplabel", {
                  group: o,
                  isSelected: e.isSelected,
                  isPointed: e.isPointed
                }, () => [
                  de("span", {
                    innerHTML: e.localize(o[n.groupLabel])
                  }, null, 8, U9e)
                ])
              ], 42, $9e)),
              de("ul", {
                class: re(e.classList.groupOptions),
                "aria-label": e.ariaGroupLabel(e.localize(o[n.groupLabel])),
                role: "group"
              }, [
                (U(!0), ee(
                  gt,
                  null,
                  It(o.__VISIBLE__, (u, c, d) => (U(), ee("li", {
                    class: re(e.classList.option(u, o)),
                    "data-pointed": e.isPointed(u),
                    "data-selected": e.isSelected(u) || void 0,
                    key: d,
                    onMouseenter: (f) => e.setPointer(u),
                    onMousedown: An((f) => e.handleOptionClick(u), ["prevent"]),
                    id: e.ariaOptionId(u),
                    "aria-selected": e.isSelected(u),
                    "aria-label": e.ariaOptionLabel(e.localize(u[n.label])),
                    role: "option"
                  }, [
                    Me(e.$slots, "option", {
                      option: u,
                      isSelected: e.isSelected,
                      isPointed: e.isPointed,
                      search: e.search
                    }, () => [
                      de(
                        "span",
                        null,
                        zt(e.localize(u[n.label])),
                        1
                        /* TEXT */
                      )
                    ])
                  ], 42, G9e))),
                  128
                  /* KEYED_FRAGMENT */
                ))
              ], 10, q9e)
            ], 10, B9e))),
            128
            /* KEYED_FRAGMENT */
          )) : (U(!0), ee(
            gt,
            { key: 1 },
            It(e.fo, (o, s, l) => (U(), ee("li", {
              class: re(e.classList.option(o)),
              "data-pointed": e.isPointed(o),
              "data-selected": e.isSelected(o) || void 0,
              key: l,
              onMouseenter: (u) => e.setPointer(o),
              onMousedown: An((u) => e.handleOptionClick(o), ["prevent"]),
              id: e.ariaOptionId(o),
              "aria-selected": e.isSelected(o),
              "aria-label": e.ariaOptionLabel(e.localize(o[n.label])),
              role: "option"
            }, [
              Me(e.$slots, "option", {
                option: o,
                isSelected: e.isSelected,
                isPointed: e.isPointed,
                search: e.search
              }, () => [
                de(
                  "span",
                  null,
                  zt(e.localize(o[n.label])),
                  1
                  /* TEXT */
                )
              ])
            ], 42, Y9e))),
            128
            /* KEYED_FRAGMENT */
          ))
        ], 10, F9e),
        e.noOptions ? Me(e.$slots, "nooptions", { key: 0 }, () => [
          de("div", {
            class: re(e.classList.noOptions),
            innerHTML: e.localize(n.noOptionsText)
          }, null, 10, H9e)
        ]) : se("v-if", !0),
        e.noResults ? Me(e.$slots, "noresults", { key: 1 }, () => [
          de("div", {
            class: re(e.classList.noResults),
            innerHTML: e.localize(n.noResultsText)
          }, null, 10, z9e)
        ]) : se("v-if", !0),
        n.infinite && e.hasMore ? (U(), ee(
          "div",
          {
            key: 2,
            class: re(e.classList.inifinite),
            ref: "infiniteLoader"
          },
          [
            Me(e.$slots, "infinite", {}, () => [
              de(
                "span",
                {
                  class: re(e.classList.inifiniteSpinner)
                },
                null,
                2
                /* CLASS */
              )
            ])
          ],
          2
          /* CLASS */
        )) : se("v-if", !0),
        Me(e.$slots, "afterlist", { options: e.fo })
      ], 10, P9e)
    ], 8, ["to", "disabled"])),
    se(" Hacky input element to show HTML5 required warning "),
    n.required ? (U(), ee("input", {
      key: 0,
      class: re(e.classList.fakeInput),
      tabindex: "-1",
      value: e.textValue,
      required: ""
    }, null, 10, V9e)) : se("v-if", !0),
    se(" Native input support "),
    n.nativeSupport ? (U(), ee(
      gt,
      { key: 1 },
      [
        n.mode == "single" ? (U(), ee("input", {
          key: 0,
          type: "hidden",
          name: n.name,
          value: e.plainValue !== void 0 ? e.plainValue : ""
        }, null, 8, W9e)) : (U(!0), ee(
          gt,
          { key: 1 },
          It(e.plainValue, (o, s) => (U(), ee("input", {
            type: "hidden",
            name: `${n.name}[]`,
            value: o,
            key: s
          }, null, 8, K9e))),
          128
          /* KEYED_FRAGMENT */
        ))
      ],
      64
      /* STABLE_FRAGMENT */
    )) : se("v-if", !0),
    se(" Screen reader assistive text "),
    n.searchable && e.hasSelected ? (U(), ee("div", {
      key: 2,
      class: re(e.classList.assist),
      id: e.ariaAssist,
      "aria-hidden": "true"
    }, zt(e.ariaLabel), 11, j9e)) : se("v-if", !0),
    se(" Create height for empty input "),
    de(
      "div",
      {
        class: re(e.classList.spacer)
      },
      null,
      2
      /* CLASS */
    )
  ], 42, x9e);
}
Gm.render = Q9e;
Gm.__file = "node_modules/@vueform/multiselect/src/Multiselect.vue";
var pR = {
  name: "MultiselectElement",
  components: {
    Multiselect: Gm
  },
  data() {
    return {
      merge: !0,
      defaultClasses: {
        container: "",
        input: "",
        inputWrapper: "",
        select: {
          container: "",
          containerDisabled: "",
          containerOpen: "",
          containerOpenTop: "",
          containerActive: "",
          multipleLabel: "",
          search: "",
          placeholder: "",
          caret: "",
          caretOpen: "",
          clear: "",
          clearIcon: "",
          spinner: "",
          dropdown: "",
          dropdownTop: "",
          dropdownHidden: "",
          options: "",
          optionsTop: "",
          group: "",
          groupLabel: "",
          groupLabelPointable: "",
          groupLabelPointed: "",
          groupLabelSelected: "",
          groupLabelDisabled: "",
          groupLabelSelectedPointed: "",
          groupLabelSelectedDisabled: "",
          groupOptions: "",
          option: "",
          optionPointed: "",
          optionSelected: "",
          optionDisabled: "",
          optionSelectedPointed: "",
          optionSelectedDisabled: "",
          noOptions: "",
          noResults: "",
          fakeInput: "",
          spacer: ""
        }
      }
    };
  }
};
const X9e = ["name", "id", "disabled"], Z9e = ["value"];
function J9e(e, t, n, r, i, a) {
  const o = Bt("ElementLabelFloating"), s = Bt("Multiselect");
  return U(), Ae(
    ze(e.elementLayout),
    { ref: "container" },
    nr({
      element: Qe(() => [
        e.hasFloating && !e.empty ? (U(), Ae(o, {
          key: 0,
          visible: !e.empty
        }, null, 8, ["visible"])) : se("v-if", !0),
        se(" Native select "),
        e.isNative ? (U(), ee(
          "div",
          {
            key: 1,
            class: re(e.classes.inputWrapper)
          },
          [
            Gn(de("select", $e({
              "onUpdate:modelValue": t[0] || (t[0] = (l) => e.value = l),
              class: e.classes.input,
              name: e.name,
              id: e.fieldId,
              multiple: !0,
              disabled: e.isDisabled
            }, {
              ...e.attrs,
              ...e.aria
            }, { ref: "input" }), [
              (U(!0), ee(
                gt,
                null,
                It(e.resolvedOptions, (l, u) => (U(), ee("option", {
                  value: l.value,
                  key: u
                }, zt(l.label), 9, Z9e))),
                128
                /* KEYED_FRAGMENT */
              ))
            ], 16, X9e), [
              [dF, e.value]
            ]),
            e.placeholder && e.empty && !e.isDisabled && e.type == "select" ? (U(), ee(
              "span",
              {
                key: 0,
                class: re(e.classes.inputPlaceholder)
              },
              zt(e.placeholder),
              3
              /* TEXT, CLASS */
            )) : se("v-if", !0)
          ],
          2
          /* CLASS */
        )) : (U(), ee(
          gt,
          { key: 2 },
          [
            se(" @vueform/multiselect copmonent "),
            rn(s, $e(e.fieldOptions, {
              modelValue: e.value,
              "onUpdate:modelValue": t[1] || (t[1] = (l) => e.value = l),
              classes: e.classes.select,
              id: e.fieldId,
              name: e.name,
              options: e.resolvedOptions,
              disabled: e.isDisabled,
              placeholder: e.Placeholder,
              attrs: e.attrs,
              aria: e.aria,
              locale: e.form$.locale$,
              onSelect: e.handleSelect,
              onDeselect: e.handleDeselect,
              onSearchChange: e.handleSearchChange,
              onTag: e.handleTag,
              onOpen: e.handleOpen,
              onClose: e.handleClose,
              onClear: e.handleClear,
              onPaste: e.handlePaste,
              ref: "input"
            }), nr({
              _: 2
              /* DYNAMIC */
            }, [
              It({
                option: "option",
                noresults: "no-results",
                nooptions: "no-options",
                afterlist: "after-list",
                beforelist: "before-list",
                placeholder: "placeholder",
                grouplabel: "group-label",
                caret: "caret",
                clear: "clear",
                spinner: "spinner",
                default: "default"
              }, (l, u) => ({
                name: u,
                fn: Qe((c) => [
                  Me(e.$slots, l, $e(c, { el$: e.el$ }), () => [
                    (U(), Ae(ze(e.fieldSlots[l]), $e(c, { el$: e.el$ }), null, 16, ["el$"]))
                  ])
                ])
              })),
              e.fieldOptions.mode == "multiple" ? {
                name: "multiplelabel",
                fn: Qe(({ values: l }) => [
                  Me(e.$slots, "multiple-label", {
                    values: l,
                    el$: e.el$
                  }, () => [
                    (U(), Ae(ze(e.fieldSlots["multiple-label"]), {
                      values: l,
                      el$: e.el$
                    }, null, 8, ["values", "el$"]))
                  ])
                ]),
                key: "0"
              } : void 0
            ]), 1040, ["modelValue", "classes", "id", "name", "options", "disabled", "placeholder", "attrs", "aria", "locale", "onSelect", "onDeselect", "onSearchChange", "onTag", "onOpen", "onClose", "onClear", "onPaste"])
          ],
          2112
          /* STABLE_FRAGMENT, DEV_ROOT_FRAGMENT */
        ))
      ]),
      _: 2
      /* DYNAMIC */
    }, [
      It(e.elementSlots, (l, u) => ({
        name: u,
        fn: Qe(() => [
          Me(e.$slots, u, { el$: e.el$ }, () => [
            (U(), Ae(ze(l), { el$: e.el$ }, null, 8, ["el$"]))
          ])
        ])
      }))
    ]),
    1536
    /* NEED_PATCH, DYNAMIC_SLOTS */
  );
}
pR.render = J9e;
pR.__file = "themes/blank/templates/elements/MultiselectElement.vue";
var mR = {
  name: "ObjectElement",
  data() {
    return {
      merge: !0,
      defaultClasses: {
        container: "",
        wrapper: ""
      }
    };
  }
};
const eGe = ["aria-labelledby"];
function tGe(e, t, n, r, i, a) {
  return U(), Ae(
    ze(e.elementLayout),
    {
      multiple: !0,
      ref: "container"
    },
    nr({
      element: Qe(() => [
        de("div", {
          class: re(e.classes.wrapper),
          role: "group",
          "aria-labelledby": e.labelId
        }, [
          Me(e.$slots, "default", {}, () => [
            (U(!0), ee(
              gt,
              null,
              It(e.children, (o, s) => (U(), Ae(ze(e.component(o)), $e(o, {
                embed: e.embed,
                name: s,
                key: s,
                onRemove: t[0] || (t[0] = (l) => e.$emit("remove", l))
              }), null, 16, ["embed", "name"]))),
              128
              /* KEYED_FRAGMENT */
            ))
          ])
        ], 10, eGe)
      ]),
      _: 2
      /* DYNAMIC */
    }, [
      It(e.elementSlots, (o, s) => ({
        name: s,
        fn: Qe(() => [
          Me(e.$slots, s, { el$: e.el$ }, () => [
            (U(), Ae(ze(o), { el$: e.el$ }, null, 8, ["el$"]))
          ])
        ])
      }))
    ]),
    1536
    /* NEED_PATCH, DYNAMIC_SLOTS */
  );
}
mR.render = tGe;
mR.__file = "themes/blank/templates/elements/ObjectElement.vue";
var hR = {
  name: "RadioElement",
  data() {
    return {
      merge: !0,
      defaultClasses: {
        container: "",
        wrapper: "",
        input: "",
        text: ""
      }
    };
  }
};
const nGe = ["value", "name", "id", "disabled"], rGe = ["innerHTML"];
function iGe(e, t, n, r, i, a) {
  return U(), Ae(
    ze(e.elementLayout),
    { ref: "container" },
    nr({
      element: Qe(() => [
        de(
          "label",
          {
            class: re(e.classes.wrapper)
          },
          [
            Gn(de("input", $e({
              type: "radio",
              "onUpdate:modelValue": t[0] || (t[0] = (o) => e.value = o)
            }, e.aria, {
              value: e.radioValue,
              class: e.classes.input,
              name: e.inputName,
              id: e.fieldId,
              disabled: e.isDisabled,
              ref: "input"
            }), null, 16, nGe), [
              [P_, e.value]
            ]),
            se(" If label is HTML "),
            e.Text ? (U(), ee("span", {
              key: 0,
              class: re(e.classes.text),
              innerHTML: e.Text
            }, null, 10, rGe)) : (U(), ee(
              gt,
              { key: 1 },
              [
                se(" If label is slot "),
                de(
                  "span",
                  {
                    class: re(e.classes.text)
                  },
                  [
                    Me(e.$slots, "default", { el$: e.el$ }, () => [
                      (U(), Ae(ze(e.fieldSlots.default), { el$: e.el$ }, null, 8, ["el$"]))
                    ])
                  ],
                  2
                  /* CLASS */
                )
              ],
              2112
              /* STABLE_FRAGMENT, DEV_ROOT_FRAGMENT */
            ))
          ],
          2
          /* CLASS */
        )
      ]),
      _: 2
      /* DYNAMIC */
    }, [
      It(e.elementSlots, (o, s) => ({
        name: s,
        fn: Qe(() => [
          Me(e.$slots, s, { el$: e.el$ }, () => [
            (U(), Ae(ze(o), { el$: e.el$ }, null, 8, ["el$"]))
          ])
        ])
      }))
    ]),
    1536
    /* NEED_PATCH, DYNAMIC_SLOTS */
  );
}
hR.render = iGe;
hR.__file = "themes/blank/templates/elements/RadioElement.vue";
var pp = {
  name: "RadiogroupElement",
  data() {
    return {
      merge: !0,
      defaultClasses: {
        container: "",
        wrapper: ""
      }
    };
  }
};
const aGe = ["aria-labelledby"];
function oGe(e, t, n, r, i, a) {
  const o = Bt("RadiogroupRadio");
  return U(), Ae(
    ze(e.elementLayout),
    { ref: "container" },
    nr({
      element: Qe(() => [
        de("div", {
          class: re(e.classes.wrapper),
          "aria-labelledby": e.labelId,
          role: "radiogroup"
        }, [
          (U(!0), ee(
            gt,
            null,
            It(e.resolvedOptions, (s, l, u) => (U(), Ae(o, {
              items: e.resolvedOptions,
              index: l,
              item: s,
              value: s.value,
              key: u,
              attrs: e.aria
            }, {
              default: Qe((c) => [
                Me(e.$slots, "radio", $e(c, { el$: e.el$ }), () => [
                  (U(), Ae(ze(e.fieldSlots.radio), $e(c, { el$: e.el$ }), null, 16, ["el$"]))
                ])
              ]),
              _: 2
              /* DYNAMIC */
            }, 1032, ["items", "index", "item", "value", "attrs"]))),
            128
            /* KEYED_FRAGMENT */
          ))
        ], 10, aGe)
      ]),
      _: 2
      /* DYNAMIC */
    }, [
      It(e.elementSlots, (s, l) => ({
        name: l,
        fn: Qe(() => [
          Me(e.$slots, l, { el$: e.el$ }, () => [
            (U(), Ae(ze(s), { el$: e.el$ }, null, 8, ["el$"]))
          ])
        ])
      }))
    ]),
    1536
    /* NEED_PATCH, DYNAMIC_SLOTS */
  );
}
pp.render = oGe;
pp.__file = "themes/blank/templates/elements/RadiogroupElement.vue";
var gR = {
  name: "SelectElement",
  components: {
    Multiselect: Gm
  },
  data() {
    return {
      merge: !0,
      defaultClasses: {
        container: "",
        input: "",
        inputWrapper: "",
        inputPlaceholder: "",
        inputCaret: "",
        select: {
          container: "",
          containerDisabled: "",
          containerOpen: "",
          containerOpenTop: "",
          containerActive: "",
          singleLabel: "",
          singleLabelText: "",
          search: "",
          placeholder: "",
          caret: "",
          caretOpen: "",
          clear: "",
          clearIcon: "",
          spinner: "",
          dropdown: "",
          dropdownTop: "",
          dropdownHidden: "",
          options: "",
          optionsTop: "",
          group: "",
          groupLabel: "",
          groupLabelPointable: "",
          groupLabelPointed: "",
          groupLabelSelected: "",
          groupLabelDisabled: "",
          groupLabelSelectedPointed: "",
          groupLabelSelectedDisabled: "",
          groupOptions: "",
          option: "",
          optionPointed: "",
          optionSelected: "",
          optionDisabled: "",
          optionSelectedPointed: "",
          optionSelectedDisabled: "",
          noOptions: "",
          noResults: "",
          fakeInput: "",
          spacer: ""
        }
      }
    };
  }
};
const sGe = ["name", "id", "disabled"], lGe = ["value"];
function uGe(e, t, n, r, i, a) {
  const o = Bt("ElementLabelFloating"), s = Bt("Multiselect");
  return U(), Ae(
    ze(e.elementLayout),
    { ref: "container" },
    nr({
      element: Qe(() => [
        e.hasFloating && !e.empty ? (U(), Ae(o, {
          key: 0,
          visible: !e.empty
        }, null, 8, ["visible"])) : se("v-if", !0),
        se(" Native select "),
        e.isNative ? (U(), ee(
          "div",
          {
            key: 1,
            class: re(e.classes.inputWrapper)
          },
          [
            Gn(de("select", $e({
              "onUpdate:modelValue": t[0] || (t[0] = (l) => e.value = l),
              class: e.classes.input,
              name: e.name,
              id: e.fieldId,
              disabled: e.isDisabled
            }, {
              ...e.attrs,
              ...e.aria
            }, { ref: "input" }), [
              (U(!0), ee(
                gt,
                null,
                It(e.resolvedOptions, (l, u) => (U(), ee("option", {
                  value: l.value,
                  key: u
                }, zt(l.label), 9, lGe))),
                128
                /* KEYED_FRAGMENT */
              ))
            ], 16, sGe), [
              [dF, e.value]
            ]),
            e.placeholder && e.empty && !e.isDisabled && e.type == "select" ? (U(), ee(
              "span",
              {
                key: 0,
                class: re(e.classes.inputPlaceholder)
              },
              zt(e.placeholder),
              3
              /* TEXT, CLASS */
            )) : se("v-if", !0),
            de(
              "span",
              {
                class: re(e.classes.inputCaret)
              },
              null,
              2
              /* CLASS */
            )
          ],
          2
          /* CLASS */
        )) : (U(), ee(
          gt,
          { key: 2 },
          [
            se(" @vueform/multiselect copmonent "),
            rn(s, $e(e.fieldOptions, {
              modelValue: e.value,
              "onUpdate:modelValue": t[1] || (t[1] = (l) => e.value = l),
              classes: e.classes.select,
              id: e.fieldId,
              name: e.name,
              options: e.resolvedOptions,
              disabled: e.isDisabled,
              placeholder: e.Placeholder,
              attrs: e.attrs,
              aria: e.aria,
              locale: e.form$.locale$,
              onSelect: e.handleSelect,
              onDeselect: e.handleDeselect,
              onSearchChange: e.handleSearchChange,
              onTag: e.handleTag,
              onOpen: e.handleOpen,
              onClose: e.handleClose,
              onClear: e.handleClear,
              onPaste: e.handlePaste,
              ref: "input"
            }), nr({
              _: 2
              /* DYNAMIC */
            }, [
              It({
                option: "option",
                noresults: "no-results",
                nooptions: "no-options",
                afterlist: "after-list",
                beforelist: "before-list",
                placeholder: "placeholder",
                grouplabel: "group-label",
                caret: "caret",
                clear: "clear",
                spinner: "spinner",
                default: "default"
              }, (l, u) => ({
                name: u,
                fn: Qe((c) => [
                  Me(e.$slots, l, $e(c, { el$: e.el$ }), () => [
                    (U(), Ae(ze(e.fieldSlots[l]), $e(c, { el$: e.el$ }), null, 16, ["el$"]))
                  ])
                ])
              })),
              e.fieldOptions.mode == "single" ? {
                name: "singlelabel",
                fn: Qe(({ value: l }) => [
                  Me(e.$slots, "single-label", {
                    value: l,
                    el$: e.el$
                  }, () => [
                    (U(), Ae(ze(e.fieldSlots["single-label"]), {
                      value: l,
                      el$: e.el$
                    }, null, 8, ["value", "el$"]))
                  ])
                ]),
                key: "0"
              } : void 0
            ]), 1040, ["modelValue", "classes", "id", "name", "options", "disabled", "placeholder", "attrs", "aria", "locale", "onSelect", "onDeselect", "onSearchChange", "onTag", "onOpen", "onClose", "onClear", "onPaste"])
          ],
          2112
          /* STABLE_FRAGMENT, DEV_ROOT_FRAGMENT */
        ))
      ]),
      _: 2
      /* DYNAMIC */
    }, [
      It(e.elementSlots, (l, u) => ({
        name: u,
        fn: Qe(() => [
          Me(e.$slots, u, { el$: e.el$ }, () => [
            (U(), Ae(ze(l), { el$: e.el$ }, null, 8, ["el$"]))
          ])
        ])
      }))
    ]),
    1536
    /* NEED_PATCH, DYNAMIC_SLOTS */
  );
}
gR.render = uGe;
gR.__file = "themes/blank/templates/elements/SelectElement.vue";
function Ng(e) {
  return [null, void 0, !1].indexOf(e) !== -1;
}
function cGe(e, t, n) {
  const { value: r, modelValue: i, min: a } = De(e);
  let o = i && i.value !== void 0 ? i : r;
  const s = he(o.value);
  if (Ng(o.value) && (o = he(a.value)), Array.isArray(o.value) && o.value.length == 0)
    throw new Error("Slider v-model must not be an empty array");
  return {
    value: o,
    initialValue: s
  };
}
function dGe(e, t, n) {
  const {
    classes: r,
    showTooltip: i,
    tooltipPosition: a,
    orientation: o
  } = De(e), s = N(() => ({
    target: "slider-target",
    focused: "slider-focused",
    tooltipFocus: "slider-tooltip-focus",
    tooltipDrag: "slider-tooltip-drag",
    ltr: "slider-ltr",
    rtl: "slider-rtl",
    horizontal: "slider-horizontal",
    vertical: "slider-vertical",
    textDirectionRtl: "slider-txt-dir-rtl",
    textDirectionLtr: "slider-txt-dir-ltr",
    base: "slider-base",
    connects: "slider-connects",
    connect: "slider-connect",
    origin: "slider-origin",
    handle: "slider-handle",
    handleLower: "slider-handle-lower",
    handleUpper: "slider-handle-upper",
    touchArea: "slider-touch-area",
    tooltip: "slider-tooltip",
    tooltipTop: "slider-tooltip-top",
    tooltipBottom: "slider-tooltip-bottom",
    tooltipLeft: "slider-tooltip-left",
    tooltipRight: "slider-tooltip-right",
    tooltipHidden: "slider-tooltip-hidden",
    active: "slider-active",
    draggable: "slider-draggable",
    tap: "slider-state-tap",
    drag: "slider-state-drag",
    // Unimplemented
    pips: "slider-pips",
    pipsHorizontal: "slider-pips-horizontal",
    pipsVertical: "slider-pips-vertical",
    marker: "slider-marker",
    markerHorizontal: "slider-marker-horizontal",
    markerVertical: "slider-marker-vertical",
    markerNormal: "slider-marker-normal",
    markerLarge: "slider-marker-large",
    markerSub: "slider-marker-sub",
    value: "slider-value",
    valueHorizontal: "slider-value-horizontal",
    valueVertical: "slider-value-vertical",
    valueNormal: "slider-value-normal",
    valueLarge: "slider-value-large",
    valueSub: "slider-value-sub",
    ...r.value
  }));
  return {
    classList: N(() => {
      const u = { ...s.value };
      return Object.keys(u).forEach((c) => {
        u[c] = Array.isArray(u[c]) ? u[c].filter((d) => d !== null).join(" ") : u[c];
      }), i.value !== "always" && (u.target += ` ${i.value === "drag" ? u.tooltipDrag : u.tooltipFocus}`), o.value === "horizontal" && (u.tooltip += a.value === "bottom" ? ` ${u.tooltipBottom}` : ` ${u.tooltipTop}`), o.value === "vertical" && (u.tooltip += a.value === "right" ? ` ${u.tooltipRight}` : ` ${u.tooltipLeft}`), u;
    })
  };
}
var Mc = typeof globalThis < "u" ? globalThis : typeof window < "u" ? window : typeof global < "u" ? global : typeof self < "u" ? self : {}, d9 = { exports: {} };
(function(e, t) {
  (function(n) {
    e.exports = n();
  })(function() {
    var n = [
      "decimals",
      "thousand",
      "mark",
      "prefix",
      "suffix",
      "encoder",
      "decoder",
      "negativeBefore",
      "negative",
      "edit",
      "undo"
    ];
    function r(m) {
      return m.split("").reverse().join("");
    }
    function i(m, v) {
      return m.substring(0, v.length) === v;
    }
    function a(m, v) {
      return m.slice(-1 * v.length) === v;
    }
    function o(m, v, b) {
      if ((m[v] || m[b]) && m[v] === m[b])
        throw new Error(v);
    }
    function s(m) {
      return typeof m == "number" && isFinite(m);
    }
    function l(m, v) {
      return m = m.toString().split("e"), m = Math.round(+(m[0] + "e" + (m[1] ? +m[1] + v : v))), m = m.toString().split("e"), (+(m[0] + "e" + (m[1] ? +m[1] - v : -v))).toFixed(v);
    }
    function u(m, v, b, y, g, E, S, C, T, O, R, D) {
      var q = D, $, P, Y, L = "", x = "";
      return E && (D = E(D)), s(D) ? (m !== !1 && parseFloat(D.toFixed(m)) === 0 && (D = 0), D < 0 && ($ = !0, D = Math.abs(D)), m !== !1 && (D = l(D, m)), D = D.toString(), D.indexOf(".") !== -1 ? (P = D.split("."), Y = P[0], b && (L = b + P[1])) : Y = D, v && (Y = r(Y).match(/.{1,3}/g), Y = r(Y.join(r(v)))), $ && C && (x += C), y && (x += y), $ && T && (x += T), x += Y, x += L, g && (x += g), O && (x = O(x, q)), x) : !1;
    }
    function c(m, v, b, y, g, E, S, C, T, O, R, D) {
      var q, $ = "";
      return R && (D = R(D)), !D || typeof D != "string" || (C && i(D, C) && (D = D.replace(C, ""), q = !0), y && i(D, y) && (D = D.replace(y, "")), T && i(D, T) && (D = D.replace(T, ""), q = !0), g && a(D, g) && (D = D.slice(0, -1 * g.length)), v && (D = D.split(v).join("")), b && (D = D.replace(b, ".")), q && ($ += "-"), $ += D, $ = $.replace(/[^0-9\.\-.]/g, ""), $ === "") || ($ = Number($), S && ($ = S($)), !s($)) ? !1 : $;
    }
    function d(m) {
      var v, b, y, g = {};
      for (m.suffix === void 0 && (m.suffix = m.postfix), v = 0; v < n.length; v += 1)
        if (b = n[v], y = m[b], y === void 0)
          b === "negative" && !g.negativeBefore ? g[b] = "-" : b === "mark" && g.thousand !== "." ? g[b] = "." : g[b] = !1;
        else if (b === "decimals")
          if (y >= 0 && y < 8)
            g[b] = y;
          else
            throw new Error(b);
        else if (b === "encoder" || b === "decoder" || b === "edit" || b === "undo")
          if (typeof y == "function")
            g[b] = y;
          else
            throw new Error(b);
        else if (typeof y == "string")
          g[b] = y;
        else
          throw new Error(b);
      return o(g, "mark", "thousand"), o(g, "prefix", "negative"), o(g, "prefix", "negativeBefore"), g;
    }
    function f(m, v, b) {
      var y, g = [];
      for (y = 0; y < n.length; y += 1)
        g.push(m[n[y]]);
      return g.push(b), v.apply("", g);
    }
    function h(m) {
      if (!(this instanceof h))
        return new h(m);
      typeof m == "object" && (m = d(m), this.to = function(v) {
        return f(m, u, v);
      }, this.from = function(v) {
        return f(m, c, v);
      });
    }
    return h;
  });
})(d9);
var zP = d9.exports;
function fGe(e, t, n) {
  const { format: r, step: i } = De(e), a = n.value, o = n.classList, s = N(() => !r || !r.value ? zP({ decimals: i.value >= 0 ? 0 : 2 }) : typeof r.value == "function" ? { to: r.value } : zP({ ...r.value })), l = N(() => Array.isArray(a.value) ? a.value.map((c) => s.value) : s.value);
  return {
    tooltipFormat: s,
    tooltipsFormat: l,
    tooltipsMerge: (c, d, f) => {
      var h = getComputedStyle(c).direction === "rtl", m = c.noUiSlider.options.direction === "rtl", v = c.noUiSlider.options.orientation === "vertical", b = c.noUiSlider.getTooltips(), y = c.noUiSlider.getOrigins();
      b.forEach(function(g, E) {
        g && y[E].appendChild(g);
      }), c.noUiSlider.on("update", function(g, E, S, C, T) {
        var O = [[]], R = [[]], D = [[]], q = 0;
        b[0] && (O[0][0] = 0, R[0][0] = T[0], D[0][0] = s.value.to(parseFloat(g[0])));
        for (var $ = 1; $ < g.length; $++)
          (!b[$] || g[$] - g[$ - 1] > d) && (q++, O[q] = [], D[q] = [], R[q] = []), b[$] && (O[q].push($), D[q].push(s.value.to(parseFloat(g[$]))), R[q].push(T[$]));
        O.forEach(function(P, Y) {
          for (var L = P.length, x = 0; x < L; x++) {
            var I = P[x];
            if (x === L - 1) {
              var k = 0;
              R[Y].forEach(function(V) {
                k += 1e3 - V;
              });
              var B = v ? "bottom" : "right", W = m ? 0 : L - 1, Z = 1e3 - R[Y][W];
              k = (h && !v ? 100 : 0) + k / L - Z, b[I].innerHTML = D[Y].join(f), b[I].style.display = "block", b[I].style[B] = k + "%", o.value.tooltipHidden.split(" ").forEach((V) => {
                b[I].classList.contains(V) && b[I].classList.remove(V);
              });
            } else
              b[I].style.display = "none", o.value.tooltipHidden.split(" ").forEach((V) => {
                b[I].classList.add(V);
              });
          }
        });
      });
    }
  };
}
var Cl;
(function(e) {
  e.Range = "range", e.Steps = "steps", e.Positions = "positions", e.Count = "count", e.Values = "values";
})(Cl || (Cl = {}));
var Yi;
(function(e) {
  e[e.None = -1] = "None", e[e.NoValue = 0] = "NoValue", e[e.LargeValue = 1] = "LargeValue", e[e.SmallValue = 2] = "SmallValue";
})(Yi || (Yi = {}));
function pGe(e) {
  return D_(e) && typeof e.from == "function";
}
function D_(e) {
  return typeof e == "object" && typeof e.to == "function";
}
function VP(e) {
  e.parentElement.removeChild(e);
}
function o1(e) {
  return e != null;
}
function WP(e) {
  e.preventDefault();
}
function mGe(e) {
  return e.filter(function(t) {
    return this[t] ? !1 : this[t] = !0;
  }, {});
}
function hGe(e, t) {
  return Math.round(e / t) * t;
}
function gGe(e, t) {
  var n = e.getBoundingClientRect(), r = e.ownerDocument, i = r.documentElement, a = f9(r);
  return /webkit.*Chrome.*Mobile/i.test(navigator.userAgent) && (a.x = 0), t ? n.top + a.y - i.clientTop : n.left + a.x - i.clientLeft;
}
function yo(e) {
  return typeof e == "number" && !isNaN(e) && isFinite(e);
}
function KP(e, t, n) {
  n > 0 && (wi(e, t), setTimeout(function() {
    Dg(e, t);
  }, n));
}
function jP(e) {
  return Math.max(Math.min(e, 100), 0);
}
function Xv(e) {
  return Array.isArray(e) ? e : [e];
}
function _Ge(e) {
  e = String(e);
  var t = e.split(".");
  return t.length > 1 ? t[1].length : 0;
}
function wi(e, t) {
  e.classList && !/\s/.test(t) ? e.classList.add(t) : e.className += " " + t;
}
function Dg(e, t) {
  e.classList && !/\s/.test(t) ? e.classList.remove(t) : e.className = e.className.replace(new RegExp("(^|\\b)" + t.split(" ").join("|") + "(\\b|$)", "gi"), " ");
}
function vGe(e, t) {
  return e.classList ? e.classList.contains(t) : new RegExp("\\b" + t + "\\b").test(e.className);
}
function f9(e) {
  var t = window.pageXOffset !== void 0, n = (e.compatMode || "") === "CSS1Compat", r = t ? window.pageXOffset : n ? e.documentElement.scrollLeft : e.body.scrollLeft, i = t ? window.pageYOffset : n ? e.documentElement.scrollTop : e.body.scrollTop;
  return {
    x: r,
    y: i
  };
}
function bGe() {
  return window.navigator.pointerEnabled ? {
    start: "pointerdown",
    move: "pointermove",
    end: "pointerup"
  } : window.navigator.msPointerEnabled ? {
    start: "MSPointerDown",
    move: "MSPointerMove",
    end: "MSPointerUp"
  } : {
    start: "mousedown touchstart",
    move: "mousemove touchmove",
    end: "mouseup touchend"
  };
}
function EGe() {
  var e = !1;
  try {
    var t = Object.defineProperty({}, "passive", {
      get: function() {
        e = !0;
      }
    });
    window.addEventListener("test", null, t);
  } catch {
  }
  return e;
}
function SGe() {
  return window.CSS && CSS.supports && CSS.supports("touch-action", "none");
}
function _R(e, t) {
  return 100 / (t - e);
}
function s1(e, t, n) {
  return t * 100 / (e[n + 1] - e[n]);
}
function yGe(e, t) {
  return s1(e, e[0] < 0 ? t + Math.abs(e[0]) : t - e[0], 0);
}
function TGe(e, t) {
  return t * (e[1] - e[0]) / 100 + e[0];
}
function tm(e, t) {
  for (var n = 1; e >= t[n]; )
    n += 1;
  return n;
}
function CGe(e, t, n) {
  if (n >= e.slice(-1)[0])
    return 100;
  var r = tm(n, e), i = e[r - 1], a = e[r], o = t[r - 1], s = t[r];
  return o + yGe([i, a], n) / _R(o, s);
}
function AGe(e, t, n) {
  if (n >= 100)
    return e.slice(-1)[0];
  var r = tm(n, t), i = e[r - 1], a = e[r], o = t[r - 1], s = t[r];
  return TGe([i, a], (n - o) * _R(o, s));
}
function OGe(e, t, n, r) {
  if (r === 100)
    return r;
  var i = tm(r, e), a = e[i - 1], o = e[i];
  return n ? r - a > (o - a) / 2 ? o : a : t[i - 1] ? e[i - 1] + hGe(r - e[i - 1], t[i - 1]) : r;
}
var p9 = (
  /** @class */
  function() {
    function e(t, n, r) {
      this.xPct = [], this.xVal = [], this.xSteps = [], this.xNumSteps = [], this.xHighestCompleteStep = [], this.xSteps = [r || !1], this.xNumSteps = [!1], this.snap = n;
      var i, a = [];
      for (Object.keys(t).forEach(function(o) {
        a.push([Xv(t[o]), o]);
      }), a.sort(function(o, s) {
        return o[0][0] - s[0][0];
      }), i = 0; i < a.length; i++)
        this.handleEntryPoint(a[i][1], a[i][0]);
      for (this.xNumSteps = this.xSteps.slice(0), i = 0; i < this.xNumSteps.length; i++)
        this.handleStepPoint(i, this.xNumSteps[i]);
    }
    return e.prototype.getDistance = function(t) {
      for (var n = [], r = 0; r < this.xNumSteps.length - 1; r++)
        n[r] = s1(this.xVal, t, r);
      return n;
    }, e.prototype.getAbsoluteDistance = function(t, n, r) {
      var i = 0;
      if (t < this.xPct[this.xPct.length - 1])
        for (; t > this.xPct[i + 1]; )
          i++;
      else t === this.xPct[this.xPct.length - 1] && (i = this.xPct.length - 2);
      !r && t === this.xPct[i + 1] && i++, n === null && (n = []);
      var a, o = 1, s = n[i], l = 0, u = 0, c = 0, d = 0;
      for (r ? a = (t - this.xPct[i]) / (this.xPct[i + 1] - this.xPct[i]) : a = (this.xPct[i + 1] - t) / (this.xPct[i + 1] - this.xPct[i]); s > 0; )
        l = this.xPct[i + 1 + d] - this.xPct[i + d], n[i + d] * o + 100 - a * 100 > 100 ? (u = l * a, o = (s - 100 * a) / n[i + d], a = 1) : (u = n[i + d] * l / 100 * o, o = 0), r ? (c = c - u, this.xPct.length + d >= 1 && d--) : (c = c + u, this.xPct.length - d >= 1 && d++), s = n[i + d] * o;
      return t + c;
    }, e.prototype.toStepping = function(t) {
      return t = CGe(this.xVal, this.xPct, t), t;
    }, e.prototype.fromStepping = function(t) {
      return AGe(this.xVal, this.xPct, t);
    }, e.prototype.getStep = function(t) {
      return t = OGe(this.xPct, this.xSteps, this.snap, t), t;
    }, e.prototype.getDefaultStep = function(t, n, r) {
      var i = tm(t, this.xPct);
      return (t === 100 || n && t === this.xPct[i - 1]) && (i = Math.max(i - 1, 1)), (this.xVal[i] - this.xVal[i - 1]) / r;
    }, e.prototype.getNearbySteps = function(t) {
      var n = tm(t, this.xPct);
      return {
        stepBefore: {
          startValue: this.xVal[n - 2],
          step: this.xNumSteps[n - 2],
          highestStep: this.xHighestCompleteStep[n - 2]
        },
        thisStep: {
          startValue: this.xVal[n - 1],
          step: this.xNumSteps[n - 1],
          highestStep: this.xHighestCompleteStep[n - 1]
        },
        stepAfter: {
          startValue: this.xVal[n],
          step: this.xNumSteps[n],
          highestStep: this.xHighestCompleteStep[n]
        }
      };
    }, e.prototype.countStepDecimals = function() {
      var t = this.xNumSteps.map(_Ge);
      return Math.max.apply(null, t);
    }, e.prototype.hasNoSize = function() {
      return this.xVal[0] === this.xVal[this.xVal.length - 1];
    }, e.prototype.convert = function(t) {
      return this.getStep(this.toStepping(t));
    }, e.prototype.handleEntryPoint = function(t, n) {
      var r;
      if (t === "min" ? r = 0 : t === "max" ? r = 100 : r = parseFloat(t), !yo(r) || !yo(n[0]))
        throw new Error("noUiSlider: 'range' value isn't numeric.");
      this.xPct.push(r), this.xVal.push(n[0]);
      var i = Number(n[1]);
      r ? this.xSteps.push(isNaN(i) ? !1 : i) : isNaN(i) || (this.xSteps[0] = i), this.xHighestCompleteStep.push(0);
    }, e.prototype.handleStepPoint = function(t, n) {
      if (n) {
        if (this.xVal[t] === this.xVal[t + 1]) {
          this.xSteps[t] = this.xHighestCompleteStep[t] = this.xVal[t];
          return;
        }
        this.xSteps[t] = s1([this.xVal[t], this.xVal[t + 1]], n, 0) / _R(this.xPct[t], this.xPct[t + 1]);
        var r = (this.xVal[t + 1] - this.xVal[t]) / this.xNumSteps[t], i = Math.ceil(Number(r.toFixed(3)) - 1), a = this.xVal[t] + this.xNumSteps[t] * i;
        this.xHighestCompleteStep[t] = a;
      }
    }, e;
  }()
), QP = {
  to: function(e) {
    return e === void 0 ? "" : e.toFixed(2);
  },
  from: Number
}, m9 = {
  target: "target",
  base: "base",
  origin: "origin",
  handle: "handle",
  handleLower: "handle-lower",
  handleUpper: "handle-upper",
  touchArea: "touch-area",
  horizontal: "horizontal",
  vertical: "vertical",
  background: "background",
  connect: "connect",
  connects: "connects",
  ltr: "ltr",
  rtl: "rtl",
  textDirectionLtr: "txt-dir-ltr",
  textDirectionRtl: "txt-dir-rtl",
  draggable: "draggable",
  drag: "state-drag",
  tap: "state-tap",
  active: "active",
  tooltip: "tooltip",
  pips: "pips",
  pipsHorizontal: "pips-horizontal",
  pipsVertical: "pips-vertical",
  marker: "marker",
  markerHorizontal: "marker-horizontal",
  markerVertical: "marker-vertical",
  markerNormal: "marker-normal",
  markerLarge: "marker-large",
  markerSub: "marker-sub",
  value: "value",
  valueHorizontal: "value-horizontal",
  valueVertical: "value-vertical",
  valueNormal: "value-normal",
  valueLarge: "value-large",
  valueSub: "value-sub"
}, vl = {
  tooltips: ".__tooltips",
  aria: ".__aria"
};
function RGe(e, t) {
  if (!yo(t))
    throw new Error("noUiSlider: 'step' is not numeric.");
  e.singleStep = t;
}
function wGe(e, t) {
  if (!yo(t))
    throw new Error("noUiSlider: 'keyboardPageMultiplier' is not numeric.");
  e.keyboardPageMultiplier = t;
}
function xGe(e, t) {
  if (!yo(t))
    throw new Error("noUiSlider: 'keyboardMultiplier' is not numeric.");
  e.keyboardMultiplier = t;
}
function NGe(e, t) {
  if (!yo(t))
    throw new Error("noUiSlider: 'keyboardDefaultStep' is not numeric.");
  e.keyboardDefaultStep = t;
}
function DGe(e, t) {
  if (typeof t != "object" || Array.isArray(t))
    throw new Error("noUiSlider: 'range' is not an object.");
  if (t.min === void 0 || t.max === void 0)
    throw new Error("noUiSlider: Missing 'min' or 'max' in 'range'.");
  e.spectrum = new p9(t, e.snap || !1, e.singleStep);
}
function IGe(e, t) {
  if (t = Xv(t), !Array.isArray(t) || !t.length)
    throw new Error("noUiSlider: 'start' option is incorrect.");
  e.handles = t.length, e.start = t;
}
function LGe(e, t) {
  if (typeof t != "boolean")
    throw new Error("noUiSlider: 'snap' option must be a boolean.");
  e.snap = t;
}
function kGe(e, t) {
  if (typeof t != "boolean")
    throw new Error("noUiSlider: 'animate' option must be a boolean.");
  e.animate = t;
}
function MGe(e, t) {
  if (typeof t != "number")
    throw new Error("noUiSlider: 'animationDuration' option must be a number.");
  e.animationDuration = t;
}
function PGe(e, t) {
  var n = [!1], r;
  if (t === "lower" ? t = [!0, !1] : t === "upper" && (t = [!1, !0]), t === !0 || t === !1) {
    for (r = 1; r < e.handles; r++)
      n.push(t);
    n.push(!1);
  } else {
    if (!Array.isArray(t) || !t.length || t.length !== e.handles + 1)
      throw new Error("noUiSlider: 'connect' option doesn't match handle count.");
    n = t;
  }
  e.connect = n;
}
function FGe(e, t) {
  switch (t) {
    case "horizontal":
      e.ort = 0;
      break;
    case "vertical":
      e.ort = 1;
      break;
    default:
      throw new Error("noUiSlider: 'orientation' option is invalid.");
  }
}
function h9(e, t) {
  if (!yo(t))
    throw new Error("noUiSlider: 'margin' option must be numeric.");
  t !== 0 && (e.margin = e.spectrum.getDistance(t));
}
function BGe(e, t) {
  if (!yo(t))
    throw new Error("noUiSlider: 'limit' option must be numeric.");
  if (e.limit = e.spectrum.getDistance(t), !e.limit || e.handles < 2)
    throw new Error("noUiSlider: 'limit' option is only supported on linear sliders with 2 or more handles.");
}
function $Ge(e, t) {
  var n;
  if (!yo(t) && !Array.isArray(t))
    throw new Error("noUiSlider: 'padding' option must be numeric or array of exactly 2 numbers.");
  if (Array.isArray(t) && !(t.length === 2 || yo(t[0]) || yo(t[1])))
    throw new Error("noUiSlider: 'padding' option must be numeric or array of exactly 2 numbers.");
  if (t !== 0) {
    for (Array.isArray(t) || (t = [t, t]), e.padding = [e.spectrum.getDistance(t[0]), e.spectrum.getDistance(t[1])], n = 0; n < e.spectrum.xNumSteps.length - 1; n++)
      if (e.padding[0][n] < 0 || e.padding[1][n] < 0)
        throw new Error("noUiSlider: 'padding' option must be a positive number(s).");
    var r = t[0] + t[1], i = e.spectrum.xVal[0], a = e.spectrum.xVal[e.spectrum.xVal.length - 1];
    if (r / (a - i) > 1)
      throw new Error("noUiSlider: 'padding' option must not exceed 100% of the range.");
  }
}
function UGe(e, t) {
  switch (t) {
    case "ltr":
      e.dir = 0;
      break;
    case "rtl":
      e.dir = 1;
      break;
    default:
      throw new Error("noUiSlider: 'direction' option was not recognized.");
  }
}
function qGe(e, t) {
  if (typeof t != "string")
    throw new Error("noUiSlider: 'behaviour' must be a string containing options.");
  var n = t.indexOf("tap") >= 0, r = t.indexOf("drag") >= 0, i = t.indexOf("fixed") >= 0, a = t.indexOf("snap") >= 0, o = t.indexOf("hover") >= 0, s = t.indexOf("unconstrained") >= 0, l = t.indexOf("drag-all") >= 0, u = t.indexOf("smooth-steps") >= 0;
  if (i) {
    if (e.handles !== 2)
      throw new Error("noUiSlider: 'fixed' behaviour must be used with 2 handles");
    h9(e, e.start[1] - e.start[0]);
  }
  if (s && (e.margin || e.limit))
    throw new Error("noUiSlider: 'unconstrained' behaviour cannot be used with margin or limit");
  e.events = {
    tap: n || a,
    drag: r,
    dragAll: l,
    smoothSteps: u,
    fixed: i,
    snap: a,
    hover: o,
    unconstrained: s
  };
}
function GGe(e, t) {
  if (t !== !1)
    if (t === !0 || D_(t)) {
      e.tooltips = [];
      for (var n = 0; n < e.handles; n++)
        e.tooltips.push(t);
    } else {
      if (t = Xv(t), t.length !== e.handles)
        throw new Error("noUiSlider: must pass a formatter for all handles.");
      t.forEach(function(r) {
        if (typeof r != "boolean" && !D_(r))
          throw new Error("noUiSlider: 'tooltips' must be passed a formatter or 'false'.");
      }), e.tooltips = t;
    }
}
function YGe(e, t) {
  if (t.length !== e.handles)
    throw new Error("noUiSlider: must pass a attributes for all handles.");
  e.handleAttributes = t;
}
function HGe(e, t) {
  if (!D_(t))
    throw new Error("noUiSlider: 'ariaFormat' requires 'to' method.");
  e.ariaFormat = t;
}
function zGe(e, t) {
  if (!pGe(t))
    throw new Error("noUiSlider: 'format' requires 'to' and 'from' methods.");
  e.format = t;
}
function VGe(e, t) {
  if (typeof t != "boolean")
    throw new Error("noUiSlider: 'keyboardSupport' option must be a boolean.");
  e.keyboardSupport = t;
}
function WGe(e, t) {
  e.documentElement = t;
}
function KGe(e, t) {
  if (typeof t != "string" && t !== !1)
    throw new Error("noUiSlider: 'cssPrefix' must be a string or `false`.");
  e.cssPrefix = t;
}
function jGe(e, t) {
  if (typeof t != "object")
    throw new Error("noUiSlider: 'cssClasses' must be an object.");
  typeof e.cssPrefix == "string" ? (e.cssClasses = {}, Object.keys(t).forEach(function(n) {
    e.cssClasses[n] = e.cssPrefix + t[n];
  })) : e.cssClasses = t;
}
function g9(e) {
  var t = {
    margin: null,
    limit: null,
    padding: null,
    animate: !0,
    animationDuration: 300,
    ariaFormat: QP,
    format: QP
  }, n = {
    step: { r: !1, t: RGe },
    keyboardPageMultiplier: { r: !1, t: wGe },
    keyboardMultiplier: { r: !1, t: xGe },
    keyboardDefaultStep: { r: !1, t: NGe },
    start: { r: !0, t: IGe },
    connect: { r: !0, t: PGe },
    direction: { r: !0, t: UGe },
    snap: { r: !1, t: LGe },
    animate: { r: !1, t: kGe },
    animationDuration: { r: !1, t: MGe },
    range: { r: !0, t: DGe },
    orientation: { r: !1, t: FGe },
    margin: { r: !1, t: h9 },
    limit: { r: !1, t: BGe },
    padding: { r: !1, t: $Ge },
    behaviour: { r: !0, t: qGe },
    ariaFormat: { r: !1, t: HGe },
    format: { r: !1, t: zGe },
    tooltips: { r: !1, t: GGe },
    keyboardSupport: { r: !0, t: VGe },
    documentElement: { r: !1, t: WGe },
    cssPrefix: { r: !0, t: KGe },
    cssClasses: { r: !0, t: jGe },
    handleAttributes: { r: !1, t: YGe }
  }, r = {
    connect: !1,
    direction: "ltr",
    behaviour: "tap",
    orientation: "horizontal",
    keyboardSupport: !0,
    cssPrefix: "noUi-",
    cssClasses: m9,
    keyboardPageMultiplier: 5,
    keyboardMultiplier: 1,
    keyboardDefaultStep: 10
  };
  e.format && !e.ariaFormat && (e.ariaFormat = e.format), Object.keys(n).forEach(function(l) {
    if (!o1(e[l]) && r[l] === void 0) {
      if (n[l].r)
        throw new Error("noUiSlider: '" + l + "' is required.");
      return;
    }
    n[l].t(t, o1(e[l]) ? e[l] : r[l]);
  }), t.pips = e.pips;
  var i = document.createElement("div"), a = i.style.msTransform !== void 0, o = i.style.transform !== void 0;
  t.transformRule = o ? "transform" : a ? "msTransform" : "webkitTransform";
  var s = [
    ["left", "top"],
    ["right", "bottom"]
  ];
  return t.style = s[t.dir][t.ort], t;
}
function QGe(e, t, n) {
  var r = bGe(), i = SGe(), a = i && EGe(), o = e, s, l, u, c, d, f = t.spectrum, h = [], m = [], v = [], b = 0, y = {}, g = e.ownerDocument, E = t.documentElement || g.documentElement, S = g.body, C = g.dir === "rtl" || t.ort === 1 ? 0 : 100;
  function T(X, te) {
    var _e = g.createElement("div");
    return te && wi(_e, te), X.appendChild(_e), _e;
  }
  function O(X, te) {
    var _e = T(X, t.cssClasses.origin), M = T(_e, t.cssClasses.handle);
    if (T(M, t.cssClasses.touchArea), M.setAttribute("data-handle", String(te)), t.keyboardSupport && (M.setAttribute("tabindex", "0"), M.addEventListener("keydown", function(j) {
      return We(j, te);
    })), t.handleAttributes !== void 0) {
      var G = t.handleAttributes[te];
      Object.keys(G).forEach(function(j) {
        M.setAttribute(j, G[j]);
      });
    }
    return M.setAttribute("role", "slider"), M.setAttribute("aria-orientation", t.ort ? "vertical" : "horizontal"), te === 0 ? wi(M, t.cssClasses.handleLower) : te === t.handles - 1 && wi(M, t.cssClasses.handleUpper), _e.handle = M, _e;
  }
  function R(X, te) {
    return te ? T(X, t.cssClasses.connect) : !1;
  }
  function D(X, te) {
    var _e = T(te, t.cssClasses.connects);
    l = [], u = [], u.push(R(_e, X[0]));
    for (var M = 0; M < t.handles; M++)
      l.push(O(te, M)), v[M] = M, u.push(R(_e, X[M + 1]));
  }
  function q(X) {
    wi(X, t.cssClasses.target), t.dir === 0 ? wi(X, t.cssClasses.ltr) : wi(X, t.cssClasses.rtl), t.ort === 0 ? wi(X, t.cssClasses.horizontal) : wi(X, t.cssClasses.vertical);
    var te = getComputedStyle(X).direction;
    return te === "rtl" ? wi(X, t.cssClasses.textDirectionRtl) : wi(X, t.cssClasses.textDirectionLtr), T(X, t.cssClasses.base);
  }
  function $(X, te) {
    return !t.tooltips || !t.tooltips[te] ? !1 : T(X.firstChild, t.cssClasses.tooltip);
  }
  function P() {
    return o.hasAttribute("disabled");
  }
  function Y(X) {
    var te = l[X];
    return te.hasAttribute("disabled");
  }
  function L(X) {
    X != null ? (l[X].setAttribute("disabled", ""), l[X].handle.removeAttribute("tabindex")) : (o.setAttribute("disabled", ""), l.forEach(function(te) {
      te.handle.removeAttribute("tabindex");
    }));
  }
  function x(X) {
    X != null ? (l[X].removeAttribute("disabled"), l[X].handle.setAttribute("tabindex", "0")) : (o.removeAttribute("disabled"), l.forEach(function(te) {
      te.removeAttribute("disabled"), te.handle.setAttribute("tabindex", "0");
    }));
  }
  function I() {
    d && (Je("update" + vl.tooltips), d.forEach(function(X) {
      X && VP(X);
    }), d = null);
  }
  function k() {
    I(), d = l.map($), Pt("update" + vl.tooltips, function(X, te, _e) {
      if (!(!d || !t.tooltips) && d[te] !== !1) {
        var M = X[te];
        t.tooltips[te] !== !0 && (M = t.tooltips[te].to(_e[te])), d[te].innerHTML = M;
      }
    });
  }
  function B() {
    Je("update" + vl.aria), Pt("update" + vl.aria, function(X, te, _e, M, G) {
      v.forEach(function(j) {
        var ce = l[j], be = pt(m, j, 0, !0, !0, !0), Ie = pt(m, j, 100, !0, !0, !0), Ue = G[j], Ve = String(t.ariaFormat.to(_e[j]));
        be = f.fromStepping(be).toFixed(1), Ie = f.fromStepping(Ie).toFixed(1), Ue = f.fromStepping(Ue).toFixed(1), ce.children[0].setAttribute("aria-valuemin", be), ce.children[0].setAttribute("aria-valuemax", Ie), ce.children[0].setAttribute("aria-valuenow", Ue), ce.children[0].setAttribute("aria-valuetext", Ve);
      });
    });
  }
  function W(X) {
    if (X.mode === Cl.Range || X.mode === Cl.Steps)
      return f.xVal;
    if (X.mode === Cl.Count) {
      if (X.values < 2)
        throw new Error("noUiSlider: 'values' (>= 2) required for mode 'count'.");
      for (var te = X.values - 1, _e = 100 / te, M = []; te--; )
        M[te] = te * _e;
      return M.push(100), Z(M, X.stepped);
    }
    return X.mode === Cl.Positions ? Z(X.values, X.stepped) : X.mode === Cl.Values ? X.stepped ? X.values.map(function(G) {
      return f.fromStepping(f.getStep(f.toStepping(G)));
    }) : X.values : [];
  }
  function Z(X, te) {
    return X.map(function(_e) {
      return f.fromStepping(te ? f.getStep(_e) : _e);
    });
  }
  function V(X) {
    function te(Ue, Ve) {
      return Number((Ue + Ve).toFixed(7));
    }
    var _e = W(X), M = {}, G = f.xVal[0], j = f.xVal[f.xVal.length - 1], ce = !1, be = !1, Ie = 0;
    return _e = mGe(_e.slice().sort(function(Ue, Ve) {
      return Ue - Ve;
    })), _e[0] !== G && (_e.unshift(G), ce = !0), _e[_e.length - 1] !== j && (_e.push(j), be = !0), _e.forEach(function(Ue, Ve) {
      var dt, Pe, xe, Mt = Ue, Zt = _e[Ve + 1], Jt, xr, Un, pi, Cr, ti, Si, yi = X.mode === Cl.Steps;
      for (yi && (dt = f.xNumSteps[Ve]), dt || (dt = Zt - Mt), Zt === void 0 && (Zt = Mt), dt = Math.max(dt, 1e-7), Pe = Mt; Pe <= Zt; Pe = te(Pe, dt)) {
        for (Jt = f.toStepping(Pe), xr = Jt - Ie, Cr = xr / (X.density || 1), ti = Math.round(Cr), Si = xr / ti, xe = 1; xe <= ti; xe += 1)
          Un = Ie + xe * Si, M[Un.toFixed(5)] = [f.fromStepping(Un), 0];
        pi = _e.indexOf(Pe) > -1 ? Yi.LargeValue : yi ? Yi.SmallValue : Yi.NoValue, !Ve && ce && Pe !== Zt && (pi = 0), Pe === Zt && be || (M[Jt.toFixed(5)] = [Pe, pi]), Ie = Jt;
      }
    }), M;
  }
  function K(X, te, _e) {
    var M, G, j = g.createElement("div"), ce = (M = {}, M[Yi.None] = "", M[Yi.NoValue] = t.cssClasses.valueNormal, M[Yi.LargeValue] = t.cssClasses.valueLarge, M[Yi.SmallValue] = t.cssClasses.valueSub, M), be = (G = {}, G[Yi.None] = "", G[Yi.NoValue] = t.cssClasses.markerNormal, G[Yi.LargeValue] = t.cssClasses.markerLarge, G[Yi.SmallValue] = t.cssClasses.markerSub, G), Ie = [t.cssClasses.valueHorizontal, t.cssClasses.valueVertical], Ue = [t.cssClasses.markerHorizontal, t.cssClasses.markerVertical];
    wi(j, t.cssClasses.pips), wi(j, t.ort === 0 ? t.cssClasses.pipsHorizontal : t.cssClasses.pipsVertical);
    function Ve(Pe, xe) {
      var Mt = xe === t.cssClasses.value, Zt = Mt ? Ie : Ue, Jt = Mt ? ce : be;
      return xe + " " + Zt[t.ort] + " " + Jt[Pe];
    }
    function dt(Pe, xe, Mt) {
      if (Mt = te ? te(xe, Mt) : Mt, Mt !== Yi.None) {
        var Zt = T(j, !1);
        Zt.className = Ve(Mt, t.cssClasses.marker), Zt.style[t.style] = Pe + "%", Mt > Yi.NoValue && (Zt = T(j, !1), Zt.className = Ve(Mt, t.cssClasses.value), Zt.setAttribute("data-value", String(xe)), Zt.style[t.style] = Pe + "%", Zt.innerHTML = String(_e.to(xe)));
      }
    }
    return Object.keys(X).forEach(function(Pe) {
      dt(Pe, X[Pe][0], X[Pe][1]);
    }), j;
  }
  function ne() {
    c && (VP(c), c = null);
  }
  function Ee(X) {
    ne();
    var te = V(X), _e = X.filter, M = X.format || {
      to: function(G) {
        return String(Math.round(G));
      }
    };
    return c = o.appendChild(K(te, _e, M)), c;
  }
  function oe() {
    var X = s.getBoundingClientRect(), te = "offset" + ["Width", "Height"][t.ort];
    return t.ort === 0 ? X.width || s[te] : X.height || s[te];
  }
  function ae(X, te, _e, M) {
    var G = function(ce) {
      var be = pe(ce, M.pageOffset, M.target || te);
      if (!be || P() && !M.doNotReject || vGe(o, t.cssClasses.tap) && !M.doNotReject || X === r.start && be.buttons !== void 0 && be.buttons > 1 || M.hover && be.buttons)
        return !1;
      a || be.preventDefault(), be.calcPoint = be.points[t.ort], _e(be, M);
    }, j = [];
    return X.split(" ").forEach(function(ce) {
      te.addEventListener(ce, G, a ? { passive: !0 } : !1), j.push([ce, G]);
    }), j;
  }
  function pe(X, te, _e) {
    var M = X.type.indexOf("touch") === 0, G = X.type.indexOf("mouse") === 0, j = X.type.indexOf("pointer") === 0, ce = 0, be = 0;
    if (X.type.indexOf("MSPointer") === 0 && (j = !0), X.type === "mousedown" && !X.buttons && !X.touches)
      return !1;
    if (M) {
      var Ie = function(dt) {
        var Pe = dt.target;
        return Pe === _e || _e.contains(Pe) || X.composed && X.composedPath().shift() === _e;
      };
      if (X.type === "touchstart") {
        var Ue = Array.prototype.filter.call(X.touches, Ie);
        if (Ue.length > 1)
          return !1;
        ce = Ue[0].pageX, be = Ue[0].pageY;
      } else {
        var Ve = Array.prototype.find.call(X.changedTouches, Ie);
        if (!Ve)
          return !1;
        ce = Ve.pageX, be = Ve.pageY;
      }
    }
    return te = te || f9(g), (G || j) && (ce = X.clientX + te.x, be = X.clientY + te.y), X.pageOffset = te, X.points = [ce, be], X.cursor = G || j, X;
  }
  function Se(X) {
    var te = X - gGe(s, t.ort), _e = te * 100 / oe();
    return _e = jP(_e), t.dir ? 100 - _e : _e;
  }
  function Re(X) {
    var te = 100, _e = !1;
    return l.forEach(function(M, G) {
      if (!Y(G)) {
        var j = m[G], ce = Math.abs(j - X), be = ce === 100 && te === 100, Ie = ce < te, Ue = ce <= te && X > j;
        (Ie || Ue || be) && (_e = G, te = ce);
      }
    }), _e;
  }
  function Ye(X, te) {
    X.type === "mouseout" && X.target.nodeName === "HTML" && X.relatedTarget === null && ut(X, te);
  }
  function nt(X, te) {
    if (navigator.appVersion.indexOf("MSIE 9") === -1 && X.buttons === 0 && te.buttonsProperty !== 0)
      return ut(X, te);
    var _e = (t.dir ? -1 : 1) * (X.calcPoint - te.startCalcPoint), M = _e * 100 / te.baseSize;
    Ze(_e > 0, M, te.locations, te.handleNumbers, te.connect);
  }
  function ut(X, te) {
    te.handle && (Dg(te.handle, t.cssClasses.active), b -= 1), te.listeners.forEach(function(_e) {
      E.removeEventListener(_e[0], _e[1]);
    }), b === 0 && (Dg(o, t.cssClasses.drag), we(), X.cursor && (S.style.cursor = "", S.removeEventListener("selectstart", WP))), t.events.smoothSteps && (te.handleNumbers.forEach(function(_e) {
      je(_e, m[_e], !0, !0, !1, !1);
    }), te.handleNumbers.forEach(function(_e) {
      Be("update", _e);
    })), te.handleNumbers.forEach(function(_e) {
      Be("change", _e), Be("set", _e), Be("end", _e);
    });
  }
  function Tt(X, te) {
    if (!te.handleNumbers.some(Y)) {
      var _e;
      if (te.handleNumbers.length === 1) {
        var M = l[te.handleNumbers[0]];
        _e = M.children[0], b += 1, wi(_e, t.cssClasses.active);
      }
      X.stopPropagation();
      var G = [], j = ae(r.move, E, nt, {
        // The event target has changed so we need to propagate the original one so that we keep
        // relying on it to extract target touches.
        target: X.target,
        handle: _e,
        connect: te.connect,
        listeners: G,
        startCalcPoint: X.calcPoint,
        baseSize: oe(),
        pageOffset: X.pageOffset,
        handleNumbers: te.handleNumbers,
        buttonsProperty: X.buttons,
        locations: m.slice()
      }), ce = ae(r.end, E, ut, {
        target: X.target,
        handle: _e,
        listeners: G,
        doNotReject: !0,
        handleNumbers: te.handleNumbers
      }), be = ae("mouseout", E, Ye, {
        target: X.target,
        handle: _e,
        listeners: G,
        doNotReject: !0,
        handleNumbers: te.handleNumbers
      });
      G.push.apply(G, j.concat(ce, be)), X.cursor && (S.style.cursor = getComputedStyle(X.target).cursor, l.length > 1 && wi(o, t.cssClasses.drag), S.addEventListener("selectstart", WP, !1)), te.handleNumbers.forEach(function(Ie) {
        Be("start", Ie);
      });
    }
  }
  function Ot(X) {
    X.stopPropagation();
    var te = Se(X.calcPoint), _e = Re(te);
    _e !== !1 && (t.events.snap || KP(o, t.cssClasses.tap, t.animationDuration), je(_e, te, !0, !0), we(), Be("slide", _e, !0), Be("update", _e, !0), t.events.snap ? Tt(X, { handleNumbers: [_e] }) : (Be("change", _e, !0), Be("set", _e, !0)));
  }
  function Xt(X) {
    var te = Se(X.calcPoint), _e = f.getStep(te), M = f.fromStepping(_e);
    Object.keys(y).forEach(function(G) {
      G.split(".")[0] === "hover" && y[G].forEach(function(j) {
        j.call(Vn, M);
      });
    });
  }
  function We(X, te) {
    if (P() || Y(te))
      return !1;
    var _e = ["Left", "Right"], M = ["Down", "Up"], G = ["PageDown", "PageUp"], j = ["Home", "End"];
    t.dir && !t.ort ? _e.reverse() : t.ort && !t.dir && (M.reverse(), G.reverse());
    var ce = X.key.replace("Arrow", ""), be = ce === G[0], Ie = ce === G[1], Ue = ce === M[0] || ce === _e[0] || be, Ve = ce === M[1] || ce === _e[1] || Ie, dt = ce === j[0], Pe = ce === j[1];
    if (!Ue && !Ve && !dt && !Pe)
      return !0;
    X.preventDefault();
    var xe;
    if (Ve || Ue) {
      var Mt = Ue ? 0 : 1, Zt = xn(te), Jt = Zt[Mt];
      if (Jt === null)
        return !1;
      Jt === !1 && (Jt = f.getDefaultStep(m[te], Ue, t.keyboardDefaultStep)), Ie || be ? Jt *= t.keyboardPageMultiplier : Jt *= t.keyboardMultiplier, Jt = Math.max(Jt, 1e-7), Jt = (Ue ? -1 : 1) * Jt, xe = h[te] + Jt;
    } else Pe ? xe = t.spectrum.xVal[t.spectrum.xVal.length - 1] : xe = t.spectrum.xVal[0];
    return je(te, f.toStepping(xe), !0, !0), Be("slide", te), Be("update", te), Be("change", te), Be("set", te), !1;
  }
  function st(X) {
    X.fixed || l.forEach(function(te, _e) {
      ae(r.start, te.children[0], Tt, {
        handleNumbers: [_e]
      });
    }), X.tap && ae(r.start, s, Ot, {}), X.hover && ae(r.move, s, Xt, {
      hover: !0
    }), X.drag && u.forEach(function(te, _e) {
      if (!(te === !1 || _e === 0 || _e === u.length - 1)) {
        var M = l[_e - 1], G = l[_e], j = [te], ce = [M, G], be = [_e - 1, _e];
        wi(te, t.cssClasses.draggable), X.fixed && (j.push(M.children[0]), j.push(G.children[0])), X.dragAll && (ce = l, be = v), j.forEach(function(Ie) {
          ae(r.start, Ie, Tt, {
            handles: ce,
            handleNumbers: be,
            connect: te
          });
        });
      }
    });
  }
  function Pt(X, te) {
    y[X] = y[X] || [], y[X].push(te), X.split(".")[0] === "update" && l.forEach(function(_e, M) {
      Be("update", M);
    });
  }
  function Ke(X) {
    return X === vl.aria || X === vl.tooltips;
  }
  function Je(X) {
    var te = X && X.split(".")[0], _e = te ? X.substring(te.length) : X;
    Object.keys(y).forEach(function(M) {
      var G = M.split(".")[0], j = M.substring(G.length);
      (!te || te === G) && (!_e || _e === j) && (!Ke(j) || _e === j) && delete y[M];
    });
  }
  function Be(X, te, _e) {
    Object.keys(y).forEach(function(M) {
      var G = M.split(".")[0];
      X === G && y[M].forEach(function(j) {
        j.call(
          // Use the slider public API as the scope ('this')
          Vn,
          // Return values as array, so arg_1[arg_2] is always valid.
          h.map(t.format.to),
          // Handle index, 0 or 1
          te,
          // Un-formatted slider values
          h.slice(),
          // Event is fired by tap, true or false
          _e || !1,
          // Left offset of the handle, in relation to the slider
          m.slice(),
          // add the slider public API to an accessible parameter when this is unavailable
          Vn
        );
      });
    });
  }
  function pt(X, te, _e, M, G, j, ce) {
    var be;
    return l.length > 1 && !t.events.unconstrained && (M && te > 0 && (be = f.getAbsoluteDistance(X[te - 1], t.margin, !1), _e = Math.max(_e, be)), G && te < l.length - 1 && (be = f.getAbsoluteDistance(X[te + 1], t.margin, !0), _e = Math.min(_e, be))), l.length > 1 && t.limit && (M && te > 0 && (be = f.getAbsoluteDistance(X[te - 1], t.limit, !1), _e = Math.min(_e, be)), G && te < l.length - 1 && (be = f.getAbsoluteDistance(X[te + 1], t.limit, !0), _e = Math.max(_e, be))), t.padding && (te === 0 && (be = f.getAbsoluteDistance(0, t.padding[0], !1), _e = Math.max(_e, be)), te === l.length - 1 && (be = f.getAbsoluteDistance(100, t.padding[1], !0), _e = Math.min(_e, be))), ce || (_e = f.getStep(_e)), _e = jP(_e), _e === X[te] && !j ? !1 : _e;
  }
  function ft(X, te) {
    var _e = t.ort;
    return (_e ? te : X) + ", " + (_e ? X : te);
  }
  function Ze(X, te, _e, M, G) {
    var j = _e.slice(), ce = M[0], be = t.events.smoothSteps, Ie = [!X, X], Ue = [X, !X];
    M = M.slice(), X && M.reverse(), M.length > 1 ? M.forEach(function(dt, Pe) {
      var xe = pt(j, dt, j[dt] + te, Ie[Pe], Ue[Pe], !1, be);
      xe === !1 ? te = 0 : (te = xe - j[dt], j[dt] = xe);
    }) : Ie = Ue = [!0];
    var Ve = !1;
    M.forEach(function(dt, Pe) {
      Ve = je(dt, _e[dt] + te, Ie[Pe], Ue[Pe], !1, be) || Ve;
    }), Ve && (M.forEach(function(dt) {
      Be("update", dt), Be("slide", dt);
    }), G != null && Be("drag", ce));
  }
  function _t(X, te) {
    return t.dir ? 100 - X - te : X;
  }
  function St(X, te) {
    m[X] = te, h[X] = f.fromStepping(te);
    var _e = _t(te, 0) - C, M = "translate(" + ft(_e + "%", "0") + ")";
    l[X].style[t.transformRule] = M, yt(X), yt(X + 1);
  }
  function we() {
    v.forEach(function(X) {
      var te = m[X] > 50 ? -1 : 1, _e = 3 + (l.length + te * X);
      l[X].style.zIndex = String(_e);
    });
  }
  function je(X, te, _e, M, G, j) {
    return G || (te = pt(m, X, te, _e, M, !1, j)), te === !1 ? !1 : (St(X, te), !0);
  }
  function yt(X) {
    if (u[X]) {
      var te = 0, _e = 100;
      X !== 0 && (te = m[X - 1]), X !== u.length - 1 && (_e = m[X]);
      var M = _e - te, G = "translate(" + ft(_t(te, M) + "%", "0") + ")", j = "scale(" + ft(M / 100, "1") + ")";
      u[X].style[t.transformRule] = G + " " + j;
    }
  }
  function Rt(X, te) {
    return X === null || X === !1 || X === void 0 || (typeof X == "number" && (X = String(X)), X = t.format.from(X), X !== !1 && (X = f.toStepping(X)), X === !1 || isNaN(X)) ? m[te] : X;
  }
  function sn(X, te, _e) {
    var M = Xv(X), G = m[0] === void 0;
    te = te === void 0 ? !0 : te, t.animate && !G && KP(o, t.cssClasses.tap, t.animationDuration), v.forEach(function(be) {
      je(be, Rt(M[be], be), !0, !1, _e);
    });
    var j = v.length === 1 ? 0 : 1;
    if (G && f.hasNoSize() && (_e = !0, m[0] = 0, v.length > 1)) {
      var ce = 100 / (v.length - 1);
      v.forEach(function(be) {
        m[be] = be * ce;
      });
    }
    for (; j < v.length; ++j)
      v.forEach(function(be) {
        je(be, m[be], !0, !0, _e);
      });
    we(), v.forEach(function(be) {
      Be("update", be), M[be] !== null && te && Be("set", be);
    });
  }
  function me(X) {
    sn(t.start, X);
  }
  function He(X, te, _e, M) {
    if (X = Number(X), !(X >= 0 && X < v.length))
      throw new Error("noUiSlider: invalid handle number, got: " + X);
    je(X, Rt(te, X), !0, !0, M), Be("update", X), _e && Be("set", X);
  }
  function tt(X) {
    if (X === void 0 && (X = !1), X)
      return h.length === 1 ? h[0] : h.slice(0);
    var te = h.map(t.format.to);
    return te.length === 1 ? te[0] : te;
  }
  function ot() {
    for (Je(vl.aria), Je(vl.tooltips), Object.keys(t.cssClasses).forEach(function(X) {
      Dg(o, t.cssClasses[X]);
    }); o.firstChild; )
      o.removeChild(o.firstChild);
    delete o.noUiSlider;
  }
  function xn(X) {
    var te = m[X], _e = f.getNearbySteps(te), M = h[X], G = _e.thisStep.step, j = null;
    if (t.snap)
      return [
        M - _e.stepBefore.startValue || null,
        _e.stepAfter.startValue - M || null
      ];
    G !== !1 && M + G > _e.stepAfter.startValue && (G = _e.stepAfter.startValue - M), M > _e.thisStep.startValue ? j = _e.thisStep.step : _e.stepBefore.step === !1 ? j = !1 : j = M - _e.stepBefore.highestStep, te === 100 ? G = null : te === 0 && (j = null);
    var ce = f.countStepDecimals();
    return G !== null && G !== !1 && (G = Number(G.toFixed(ce))), j !== null && j !== !1 && (j = Number(j.toFixed(ce))), [j, G];
  }
  function kt() {
    return v.map(xn);
  }
  function Dn(X, te) {
    var _e = tt(), M = [
      "margin",
      "limit",
      "padding",
      "range",
      "animate",
      "snap",
      "step",
      "format",
      "pips",
      "tooltips"
    ];
    M.forEach(function(j) {
      X[j] !== void 0 && (n[j] = X[j]);
    });
    var G = g9(n);
    M.forEach(function(j) {
      X[j] !== void 0 && (t[j] = G[j]);
    }), f = G.spectrum, t.margin = G.margin, t.limit = G.limit, t.padding = G.padding, t.pips ? Ee(t.pips) : ne(), t.tooltips ? k() : I(), m = [], sn(o1(X.start) ? X.start : _e, te);
  }
  function gn() {
    s = q(o), D(t.connect, s), st(t.events), sn(t.start), t.pips && Ee(t.pips), t.tooltips && k(), B();
  }
  gn();
  var Vn = {
    destroy: ot,
    steps: kt,
    on: Pt,
    off: Je,
    get: tt,
    set: sn,
    setHandle: He,
    reset: me,
    disable: L,
    enable: x,
    // Exposed for unit testing, don't use this in your application.
    __moveHandles: function(X, te, _e) {
      Ze(X, te, m, _e);
    },
    options: n,
    updateOptions: Dn,
    target: o,
    removePips: ne,
    removeTooltips: I,
    getPositions: function() {
      return m.slice();
    },
    getTooltips: function() {
      return d;
    },
    getOrigins: function() {
      return l;
    },
    pips: Ee
    // Issue #594
  };
  return Vn;
}
function XGe(e, t) {
  if (!e || !e.nodeName)
    throw new Error("noUiSlider: create requires a single element, got: " + e);
  if (e.noUiSlider)
    throw new Error("noUiSlider: Slider was already initialized.");
  var n = g9(t), r = QGe(e, n, t);
  return e.noUiSlider = r, r;
}
var ZGe = {
  // Exposed for unit testing, don't use this in your application.
  __spectrum: p9,
  // A reference to the default classes, allows global changes.
  // Use the cssClasses option for changes to one slider.
  cssClasses: m9,
  create: XGe
};
function XP(e, t) {
  if (!Array.isArray(e) || !Array.isArray(t))
    return !1;
  const n = t.slice().sort();
  return e.length === t.length && e.slice().sort().every(function(r, i) {
    return r === n[i];
  });
}
function JGe(e, t, n) {
  const {
    orientation: r,
    direction: i,
    tooltips: a,
    step: o,
    min: s,
    max: l,
    merge: u,
    id: c,
    disabled: d,
    options: f,
    classes: h,
    format: m,
    lazy: v,
    ariaLabelledby: b,
    aria: y
  } = De(e), g = n.value, E = n.initialValue, S = n.tooltipsFormat, C = n.tooltipsMerge, T = n.tooltipFormat, O = n.classList, R = he(null), D = he(null), q = he(!1), $ = N(() => {
    let V = {
      cssPrefix: "",
      cssClasses: O.value,
      orientation: r.value,
      direction: i.value,
      tooltips: a.value ? S.value : !1,
      connect: "lower",
      start: Ng(g.value) ? s.value : g.value,
      range: {
        min: s.value,
        max: l.value
      }
    };
    if (o.value > 0 && (V.step = o.value), Array.isArray(g.value) && (V.connect = !0), b && b.value || y && Object.keys(y.value).length) {
      let K = Array.isArray(g.value) ? g.value : [g.value];
      V.handleAttributes = K.map((ne) => Object.assign({}, y.value, b && b.value ? {
        "aria-labelledby": b.value
      } : {}));
    }
    return m.value && (V.ariaFormat = T.value), V;
  }), P = N(() => {
    let V = {
      id: c && c.value ? c.value : void 0
    };
    return d.value && (V.disabled = !0), V;
  }), Y = N(() => Array.isArray(g.value)), L = () => {
    k(E.value);
  }, x = () => {
    let V = D.value.get();
    return Array.isArray(V) ? V.map((K) => parseFloat(K)) : parseFloat(V);
  }, I = (V, K = !0) => {
    D.value.set(V, K);
  }, k = (V) => {
    t.emit("input", V), t.emit("update:modelValue", V), t.emit("update", V);
  }, B = () => {
    D.value = ZGe.create(R.value, Object.assign({}, $.value, f.value)), a.value && Y.value && u.value >= 0 && C(R.value, u.value, " - "), D.value.on("set", () => {
      const V = x();
      t.emit("change", V), t.emit("set", V), v.value && k(V);
    }), D.value.on("update", () => {
      if (!q.value)
        return;
      const V = x();
      if (Y.value && XP(g.value, V) || !Y.value && g.value == V) {
        t.emit("update", V);
        return;
      }
      v.value || k(V);
    }), D.value.on("start", () => {
      t.emit("start", x());
    }), D.value.on("end", () => {
      t.emit("end", x());
    }), D.value.on("slide", () => {
      t.emit("slide", x());
    }), D.value.on("drag", () => {
      t.emit("drag", x());
    }), R.value.querySelectorAll("[data-handle]").forEach((V) => {
      V.onblur = () => {
        R.value && O.value.focused.split(" ").forEach((K) => {
          R.value.classList.remove(K);
        });
      }, V.onfocus = () => {
        O.value.focused.split(" ").forEach((K) => {
          R.value.classList.add(K);
        });
      };
    }), q.value = !0;
  }, W = () => {
    D.value.off(), D.value.destroy(), D.value = null;
  }, Z = (V, K) => {
    q.value = !1, W(), B();
  };
  return On(B), l1(W), et(Y, Z, { immediate: !1 }), et(s, Z, { immediate: !1 }), et(l, Z, { immediate: !1 }), et(o, Z, { immediate: !1 }), et(r, Z, { immediate: !1 }), et(i, Z, { immediate: !1 }), et(a, Z, { immediate: !1 }), et(u, Z, { immediate: !1 }), et(m, Z, { immediate: !1, deep: !0 }), et(f, Z, { immediate: !1, deep: !0 }), et(h, Z, { immediate: !1, deep: !0 }), et(g, (V, K) => {
    K && // If both old and new has multiple handles
    // and the number of handles decreased
    (typeof K == "object" && typeof V == "object" && V && Object.keys(K) > Object.keys(V) || // If the old had multiple handles but
    // if it decreased to single
    typeof K == "object" && typeof V != "object" || // Or has no value at all
    Ng(V)) && Z();
  }, { immediate: !1 }), et(g, (V) => {
    if (Ng(V)) {
      I(s.value, !1);
      return;
    }
    let K = x();
    Y.value && !Array.isArray(K) && (K = [K]), (Y.value && !XP(V, K) || !Y.value && V != K) && I(V, !1);
  }, { deep: !0 }), {
    slider: R,
    slider$: D,
    isRange: Y,
    sliderProps: P,
    init: B,
    destroy: W,
    refresh: Z,
    update: I,
    reset: L
  };
}
const eYe = {
  value: {
    validator: function(e) {
      return (t) => typeof t == "number" || t instanceof Array || t === null || t === void 0 || t === !1;
    },
    required: !1
  },
  modelValue: {
    validator: function(e) {
      return (t) => typeof t == "number" || t instanceof Array || t === null || t === void 0 || t === !1;
    },
    required: !1
  }
};
var vR = {
  name: "Slider",
  emits: [
    "input",
    "update:modelValue",
    "start",
    "slide",
    "drag",
    "update",
    "change",
    "set",
    "end"
  ],
  props: {
    ...eYe,
    id: {
      type: [String, Number],
      required: !1
    },
    disabled: {
      type: Boolean,
      required: !1,
      default: !1
    },
    min: {
      type: Number,
      required: !1,
      default: 0
    },
    max: {
      type: Number,
      required: !1,
      default: 100
    },
    step: {
      type: Number,
      required: !1,
      default: 1
    },
    orientation: {
      type: String,
      required: !1,
      default: "horizontal"
    },
    direction: {
      type: String,
      required: !1,
      default: "ltr"
    },
    tooltips: {
      type: Boolean,
      required: !1,
      default: !0
    },
    options: {
      type: Object,
      required: !1,
      default: () => ({})
    },
    merge: {
      type: Number,
      required: !1,
      default: -1
    },
    format: {
      type: [Object, Function, Boolean],
      required: !1,
      default: null
    },
    classes: {
      type: Object,
      required: !1,
      default: () => ({})
    },
    showTooltip: {
      type: String,
      required: !1,
      default: "always"
    },
    tooltipPosition: {
      type: String,
      required: !1,
      default: null
    },
    lazy: {
      type: Boolean,
      required: !1,
      default: !0
    },
    ariaLabelledby: {
      type: String,
      required: !1,
      default: void 0
    },
    aria: {
      required: !1,
      type: Object,
      default: () => ({})
    }
  },
  setup(e, t) {
    const n = cGe(e), r = dGe(e), i = fGe(e, t, {
      value: n.value,
      classList: r.classList
    }), a = JGe(e, t, {
      value: n.value,
      initialValue: n.initialValue,
      tooltipFormat: i.tooltipFormat,
      tooltipsFormat: i.tooltipsFormat,
      tooltipsMerge: i.tooltipsMerge,
      classList: r.classList
    });
    return {
      ...r,
      ...i,
      ...a
    };
  }
};
function tYe(e, t, n, r, i, a) {
  return U(), ee(
    "div",
    $e(e.sliderProps, { ref: "slider" }),
    null,
    16
    /* FULL_PROPS */
  );
}
vR.render = tYe;
vR.__file = "node_modules/@vueform/slider/src/Slider.vue";
var bR = {
  name: "SliderElement",
  components: {
    Slider: vR
  },
  data() {
    return {
      merge: !0,
      defaultClasses: {
        container: "",
        wrapper: "",
        slider: {
          target: "",
          focused: "",
          tooltipFocus: "",
          tooltipDrag: "",
          ltr: "",
          rtl: "",
          horizontal: "",
          vertical: "",
          textDirectionRtl: "",
          textDirectionLtr: "",
          base: "",
          connects: "",
          connect: "",
          origin: "",
          handle: "",
          touchArea: "",
          tooltip: "",
          tooltipTop: "",
          tooltipBottom: "",
          tooltipLeft: "",
          tooltipRight: "",
          tooltipHidden: "",
          active: "",
          draggable: "",
          tap: "",
          drag: ""
        }
      }
    };
  }
};
function nYe(e, t, n, r, i, a) {
  const o = Bt("Slider");
  return U(), Ae(
    ze(e.elementLayout),
    { ref: "container" },
    nr({
      element: Qe(() => [
        de(
          "div",
          {
            class: re(e.classes.wrapper)
          },
          [
            se(" @vueform/slider component "),
            rn(o, $e({
              value: e.value,
              modelValue: e.value
            }, e.fieldOptions, {
              aria: e.aria,
              classes: e.classes.slider,
              id: e.fieldId,
              ref: "input",
              onUpdate: e.handleUpdate,
              onChange: e.handleChange
            }), null, 16, ["value", "modelValue", "aria", "classes", "id", "onUpdate", "onChange"])
          ],
          2
          /* CLASS */
        )
      ]),
      _: 2
      /* DYNAMIC */
    }, [
      It(e.elementSlots, (s, l) => ({
        name: l,
        fn: Qe(() => [
          Me(e.$slots, l, { el$: e.el$ }, () => [
            (U(), Ae(ze(s), { el$: e.el$ }, null, 8, ["el$"]))
          ])
        ])
      }))
    ]),
    1536
    /* NEED_PATCH, DYNAMIC_SLOTS */
  );
}
bR.render = nYe;
bR.__file = "themes/blank/templates/elements/SliderElement.vue";
var ER = {
  name: "StaticElement",
  data() {
    return {
      merge: !0,
      defaultClasses: {
        container: "",
        content: "",
        tag: ""
      }
    };
  }
};
const rYe = ["innerHTML"], iYe = ["innerHTML"], aYe = ["innerHTML"], oYe = ["innerHTML"], sYe = ["innerHTML"], lYe = ["innerHTML"], uYe = ["innerHTML"], cYe = ["href", "target", "innerHTML"], dYe = ["href", "target"], fYe = ["href", "target"], pYe = ["src", "alt", "title", "width", "height"], mYe = ["src", "alt", "title", "width", "height"], hYe = ["innerHTML"];
function gYe(e, t, n, r, i, a) {
  return e.wrap ? (U(), Ae(
    ze(e.elementLayout),
    {
      key: 0,
      ref: "container"
    },
    nr({
      element: Qe(() => [
        se(" If content is HTML "),
        e.isHtml && (e.content || ["img", "hr"].indexOf(e.tag) !== -1) ? (U(), ee(
          gt,
          { key: 0 },
          [
            !e.tag && e.allowHtml ? (U(), ee("div", $e({
              key: 0,
              class: e.classes.content,
              innerHTML: e.content
            }, e.attrs), null, 16, rYe)) : se("v-if", !0),
            !e.tag && !e.allowHtml ? (U(), ee(
              "div",
              $e({
                key: 1,
                class: e.classes.content
              }, e.attrs),
              zt(e.content),
              17
              /* TEXT, FULL_PROPS */
            )) : se("v-if", !0),
            e.tag === "p" ? (U(), ee(
              "div",
              {
                key: 2,
                class: re(e.classes.tag)
              },
              [
                e.allowHtml ? (U(), ee("p", $e({
                  key: 0,
                  innerHTML: e.content
                }, e.attrs), null, 16, iYe)) : (U(), ee(
                  "p",
                  bl($e({ key: 1 }, e.attrs)),
                  zt(e.content),
                  17
                  /* TEXT, FULL_PROPS */
                ))
              ],
              2
              /* CLASS */
            )) : se("v-if", !0),
            e.tag === "h1" ? (U(), ee(
              "div",
              {
                key: 3,
                class: re(e.classes.tag)
              },
              [
                e.allowHtml ? (U(), ee("h1", $e({
                  key: 0,
                  innerHTML: e.content
                }, e.attrs), null, 16, aYe)) : (U(), ee(
                  "h1",
                  bl($e({ key: 1 }, e.attrs)),
                  zt(e.content),
                  17
                  /* TEXT, FULL_PROPS */
                ))
              ],
              2
              /* CLASS */
            )) : se("v-if", !0),
            e.tag === "h2" ? (U(), ee(
              "div",
              {
                key: 4,
                class: re(e.classes.tag)
              },
              [
                e.allowHtml ? (U(), ee("h2", $e({
                  key: 0,
                  innerHTML: e.content
                }, e.attrs), null, 16, oYe)) : (U(), ee(
                  "h2",
                  bl($e({ key: 1 }, e.attrs)),
                  zt(e.content),
                  17
                  /* TEXT, FULL_PROPS */
                ))
              ],
              2
              /* CLASS */
            )) : se("v-if", !0),
            e.tag === "h3" ? (U(), ee(
              "div",
              {
                key: 5,
                class: re(e.classes.tag)
              },
              [
                e.allowHtml ? (U(), ee("h3", $e({
                  key: 0,
                  innerHTML: e.content
                }, e.attrs), null, 16, sYe)) : (U(), ee(
                  "h3",
                  bl($e({ key: 1 }, e.attrs)),
                  zt(e.content),
                  17
                  /* TEXT, FULL_PROPS */
                ))
              ],
              2
              /* CLASS */
            )) : se("v-if", !0),
            e.tag === "h4" ? (U(), ee(
              "div",
              {
                key: 6,
                class: re(e.classes.tag)
              },
              [
                e.allowHtml ? (U(), ee("h4", $e({
                  key: 0,
                  innerHTML: e.content
                }, e.attrs), null, 16, lYe)) : (U(), ee(
                  "h4",
                  bl($e({ key: 1 }, e.attrs)),
                  zt(e.content),
                  17
                  /* TEXT, FULL_PROPS */
                ))
              ],
              2
              /* CLASS */
            )) : se("v-if", !0),
            e.tag === "blockquote" ? (U(), ee(
              "div",
              {
                key: 7,
                class: re(e.classes.tag)
              },
              [
                e.allowHtml ? (U(), ee("blockquote", $e({
                  key: 0,
                  innerHTML: e.content
                }, e.attrs), null, 16, uYe)) : (U(), ee(
                  "blockquote",
                  bl($e({ key: 1 }, e.attrs)),
                  zt(e.content),
                  17
                  /* TEXT, FULL_PROPS */
                ))
              ],
              2
              /* CLASS */
            )) : se("v-if", !0),
            e.tag === "a" ? (U(), ee(
              "div",
              {
                key: 8,
                class: re(e.classes.tag)
              },
              [
                e.allowHtml ? (U(), ee("a", $e({
                  key: 0,
                  href: e.href,
                  target: e.target
                }, e.attrs, { innerHTML: e.content }), null, 16, cYe)) : (U(), ee("a", $e({
                  key: 1,
                  href: e.href,
                  target: e.target
                }, e.attrs), zt(e.content), 17, dYe))
              ],
              2
              /* CLASS */
            )) : se("v-if", !0),
            e.tag === "hr" ? (U(), ee(
              "div",
              {
                key: 9,
                class: re(e.classes.tag)
              },
              [
                de(
                  "hr",
                  bl(cF(e.attrs)),
                  null,
                  16
                  /* FULL_PROPS */
                )
              ],
              2
              /* CLASS */
            )) : se("v-if", !0),
            e.tag === "img" ? (U(), ee(
              "div",
              {
                key: 10,
                class: re(e.classes.tag)
              },
              [
                e.href ? (U(), ee("a", {
                  key: 0,
                  href: e.href,
                  target: e.target
                }, [
                  de("img", $e({
                    src: e.src,
                    alt: e.alt,
                    title: e.title,
                    width: e.width,
                    height: e.height
                  }, e.attrs), null, 16, pYe)
                ], 8, fYe)) : (U(), ee("img", $e({
                  key: 1,
                  src: e.src,
                  alt: e.alt,
                  title: e.title,
                  width: e.width,
                  height: e.height
                }, e.attrs), null, 16, mYe))
              ],
              2
              /* CLASS */
            )) : se("v-if", !0)
          ],
          64
          /* STABLE_FRAGMENT */
        )) : e.content ? (U(), ee(
          gt,
          { key: 1 },
          [
            se(" If content is component "),
            (U(), Ae(ze(e.componentContent), { el$: e.el$ }, null, 8, ["el$"]))
          ],
          2112
          /* STABLE_FRAGMENT, DEV_ROOT_FRAGMENT */
        )) : (U(), ee(
          gt,
          { key: 2 },
          [
            se(" If content is a slot "),
            Me(e.$slots, "default", { el$: e.el$ }, () => [
              (U(), Ae(ze(e.slotContent), { el$: e.el$ }, null, 8, ["el$"]))
            ])
          ],
          2112
          /* STABLE_FRAGMENT, DEV_ROOT_FRAGMENT */
        ))
      ]),
      _: 2
      /* DYNAMIC */
    }, [
      It(e.elementSlots, (o, s) => ({
        name: s,
        fn: Qe(() => [
          Me(e.$slots, s, { el$: e.el$ }, () => [
            (U(), Ae(ze(o), { el$: e.el$ }, null, 8, ["el$"]))
          ])
        ])
      }))
    ]),
    1536
    /* NEED_PATCH, DYNAMIC_SLOTS */
  )) : e.content && e.isHtml ? (U(), ee("div", {
    key: 1,
    class: re(e.classes.content),
    innerHTML: e.content
  }, null, 10, hYe)) : e.content ? (U(), Ae(
    ze(e.componentContent),
    {
      key: 2,
      ref: "container"
    },
    null,
    512
    /* NEED_PATCH */
  )) : (U(), ee(
    "div",
    {
      key: 3,
      class: re(e.classes.container),
      ref: "container"
    },
    [
      Me(e.$slots, "default", { el$: e.el$ }, () => [
        (U(), Ae(ze(e.slotContent), { el$: e.el$ }, null, 8, ["el$"]))
      ])
    ],
    2
    /* CLASS */
  ));
}
ER.render = gYe;
ER.__file = "themes/blank/templates/elements/StaticElement.vue";
var SR = {
  name: "TagsElement",
  components: {
    Multiselect: Gm
  },
  data() {
    return {
      merge: !0,
      defaultClasses: {
        container: "",
        select: {
          container: "",
          containerDisabled: "",
          containerOpen: "",
          containerOpenTop: "",
          containerActive: "",
          search: "",
          tags: "",
          tag: "",
          tagDisabled: "",
          tagRemove: "",
          tagRemoveIcon: "",
          tagsSearchWrapper: "",
          tagsSearch: "",
          tagsSearchCopy: "",
          placeholder: "",
          caret: "",
          caretOpen: "",
          clear: "",
          clearIcon: "",
          spinner: "",
          dropdown: "",
          dropdownTop: "",
          dropdownHidden: "",
          options: "",
          optionsTop: "",
          group: "",
          groupLabel: "",
          groupLabelPointable: "",
          groupLabelPointed: "",
          groupLabelSelected: "",
          groupLabelDisabled: "",
          groupLabelSelectedPointed: "",
          groupLabelSelectedDisabled: "",
          groupOptions: "",
          option: "",
          optionPointed: "",
          optionSelected: "",
          optionDisabled: "",
          optionSelectedPointed: "",
          optionSelectedDisabled: "",
          noOptions: "",
          noResults: "",
          fakeInput: "",
          spacer: ""
        }
      }
    };
  }
};
function _Ye(e, t, n, r, i, a) {
  const o = Bt("ElementLabelFloating"), s = Bt("Multiselect");
  return U(), Ae(
    ze(e.elementLayout),
    { ref: "container" },
    nr({
      element: Qe(() => [
        e.hasFloating && !e.empty ? (U(), Ae(o, {
          key: 0,
          visible: !e.empty
        }, null, 8, ["visible"])) : se("v-if", !0),
        se(" @vueform/multiselect copmonent "),
        rn(s, $e(e.fieldOptions, {
          modelValue: e.value,
          "onUpdate:modelValue": t[0] || (t[0] = (l) => e.value = l),
          classes: e.classes.select,
          id: e.fieldId,
          name: e.name,
          options: e.resolvedOptions,
          disabled: e.isDisabled,
          placeholder: e.Placeholder,
          attrs: e.attrs,
          aria: e.aria,
          locale: e.form$.locale$,
          onSelect: e.handleSelect,
          onDeselect: e.handleDeselect,
          onSearchChange: e.handleSearchChange,
          onTag: e.handleTag,
          onOpen: e.handleOpen,
          onClose: e.handleClose,
          onClear: e.handleClear,
          onPaste: e.handlePaste,
          ref: "input"
        }), nr({
          _: 2
          /* DYNAMIC */
        }, [
          It({
            option: "option",
            noresults: "no-results",
            nooptions: "no-options",
            afterlist: "after-list",
            beforelist: "before-list",
            placeholder: "placeholder",
            grouplabel: "group-label",
            caret: "caret",
            clear: "clear",
            spinner: "spinner",
            default: "default"
          }, (l, u) => ({
            name: u,
            fn: Qe((c) => [
              Me(e.$slots, l, $e(c, { el$: e.el$ }), () => [
                (U(), Ae(ze(e.fieldSlots[l]), $e(c, { el$: e.el$ }), null, 16, ["el$"]))
              ])
            ])
          })),
          e.fieldOptions.mode == "tags" ? {
            name: "tag",
            fn: Qe(({ option: l, handleTagRemove: u, disabled: c }) => [
              Me(e.$slots, "tag", {
                option: l,
                handleTagRemove: u,
                disabled: c,
                el$: e.el$
              }, () => [
                (U(), Ae(ze(e.fieldSlots.tag), {
                  option: l,
                  handleTagRemove: u,
                  disabled: c,
                  el$: e.el$
                }, null, 8, ["option", "handleTagRemove", "disabled", "el$"]))
              ])
            ]),
            key: "0"
          } : void 0
        ]), 1040, ["modelValue", "classes", "id", "name", "options", "disabled", "placeholder", "attrs", "aria", "locale", "onSelect", "onDeselect", "onSearchChange", "onTag", "onOpen", "onClose", "onClear", "onPaste"])
      ]),
      _: 2
      /* DYNAMIC */
    }, [
      It(e.elementSlots, (l, u) => ({
        name: u,
        fn: Qe(() => [
          Me(e.$slots, u, { el$: e.el$ }, () => [
            (U(), Ae(ze(l), { el$: e.el$ }, null, 8, ["el$"]))
          ])
        ])
      }))
    ]),
    1536
    /* NEED_PATCH, DYNAMIC_SLOTS */
  );
}
SR.render = _Ye;
SR.__file = "themes/blank/templates/elements/TagsElement.vue";
var nm = {
  name: "TextareaElement",
  data() {
    return {
      merge: !0,
      defaultClasses: {
        container: "",
        inputContainer: "",
        input: ""
      }
    };
  }
};
const vYe = ["value", "name", "id", "placeholder", "disabled", "readonly", "rows", "data-autogrow"];
function bYe(e, t, n, r, i, a) {
  const o = Bt("ElementAddon"), s = Bt("ElementLabelFloating"), l = Bt("ElementLoader");
  return U(), Ae(
    ze(e.elementLayout),
    { ref: "container" },
    nr({
      element: Qe(() => [
        de(
          "div",
          {
            class: re(e.classes.inputContainer)
          },
          [
            e.hasAddonBefore ? (U(), Ae(o, {
              key: 0,
              type: "before"
            }, {
              default: Qe(() => [
                Me(e.$slots, "addon-before", {}, () => [
                  (U(), Ae(ze(e.fieldSlots["addon-before"]), { el$: e.el$ }, null, 8, ["el$"]))
                ])
              ]),
              _: 3
              /* FORWARDED */
            })) : se("v-if", !0),
            e.hasAddonAfter ? (U(), Ae(o, {
              key: 1,
              type: "after"
            }, {
              default: Qe(() => [
                Me(e.$slots, "addon-after", {}, () => [
                  (U(), Ae(ze(e.fieldSlots["addon-after"]), { el$: e.el$ }, null, 8, ["el$"]))
                ])
              ]),
              _: 3
              /* FORWARDED */
            })) : se("v-if", !0),
            e.hasFloating && !e.empty ? (U(), Ae(s, {
              key: 2,
              visible: !e.empty
            }, null, 8, ["visible"])) : se("v-if", !0),
            Gn(rn(
              l,
              null,
              null,
              512
              /* NEED_PATCH */
            ), [
              [Wi, e.pending]
            ]),
            de("textarea", $e({
              value: e.model,
              name: e.name,
              id: e.fieldId,
              class: e.classes.input,
              placeholder: e.Placeholder,
              disabled: e.isDisabled,
              readonly: e.readonly,
              rows: e.rows
            }, {
              ...e.attrs,
              ...e.aria
            }, {
              "data-autogrow": e.autogrow || void 0,
              onKeydown: t[0] || (t[0] = (...u) => e.handleKeydown && e.handleKeydown(...u)),
              onKeyup: t[1] || (t[1] = (...u) => e.handleKeyup && e.handleKeyup(...u)),
              onKeypress: t[2] || (t[2] = (...u) => e.handleKeypress && e.handleKeypress(...u)),
              onInput: t[3] || (t[3] = (...u) => e.handleInput && e.handleInput(...u)),
              onBlur: t[4] || (t[4] = (...u) => e.handleBlur && e.handleBlur(...u)),
              ref: "input"
            }), null, 16, vYe)
          ],
          2
          /* CLASS */
        )
      ]),
      _: 2
      /* DYNAMIC */
    }, [
      It(e.elementSlots, (u, c) => ({
        name: c,
        fn: Qe(() => [
          Me(e.$slots, c, { el$: e.el$ }, () => [
            (U(), Ae(ze(u), { el$: e.el$ }, null, 8, ["el$"]))
          ])
        ])
      }))
    ]),
    1536
    /* NEED_PATCH, DYNAMIC_SLOTS */
  );
}
nm.render = bYe;
nm.__file = "themes/blank/templates/elements/TextareaElement.vue";
var rm = {
  name: "TextElement",
  data() {
    return {
      merge: !0,
      defaultClasses: {
        container: "",
        inputContainer: "",
        input: ""
      }
    };
  }
};
const EYe = ["value", "type", "name", "id", "placeholder", "autocomplete", "disabled", "readonly"];
function SYe(e, t, n, r, i, a) {
  const o = Bt("ElementAddon"), s = Bt("ElementLabelFloating"), l = Bt("ElementLoader");
  return U(), Ae(
    ze(e.elementLayout),
    { ref: "container" },
    nr({
      element: Qe(() => [
        de(
          "div",
          {
            class: re(e.classes.inputContainer)
          },
          [
            e.hasAddonBefore ? (U(), Ae(o, {
              key: 0,
              type: "before"
            }, {
              default: Qe(() => [
                Me(e.$slots, "addon-before", {}, () => [
                  (U(), Ae(ze(e.fieldSlots["addon-before"]), { el$: e.el$ }, null, 8, ["el$"]))
                ])
              ]),
              _: 3
              /* FORWARDED */
            })) : se("v-if", !0),
            e.hasAddonAfter ? (U(), Ae(o, {
              key: 1,
              type: "after"
            }, {
              default: Qe(() => [
                Me(e.$slots, "addon-after", {}, () => [
                  (U(), Ae(ze(e.fieldSlots["addon-after"]), { el$: e.el$ }, null, 8, ["el$"]))
                ])
              ]),
              _: 3
              /* FORWARDED */
            })) : se("v-if", !0),
            e.hasFloating && !e.empty ? (U(), Ae(s, {
              key: 2,
              visible: !e.empty
            }, null, 8, ["visible"])) : se("v-if", !0),
            e.isLoading ? (U(), Ae(l, { key: 3 })) : se("v-if", !0),
            de("input", $e({
              value: e.model,
              type: e.inputType,
              name: e.name,
              id: e.fieldId,
              class: e.classes.input,
              placeholder: e.Placeholder,
              autocomplete: e.autocomplete,
              disabled: e.isDisabled,
              readonly: e.readonly
            }, {
              ...e.attrs,
              ...e.aria
            }, {
              onKeydown: t[0] || (t[0] = (...u) => e.handleKeydown && e.handleKeydown(...u)),
              onKeyup: t[1] || (t[1] = (...u) => e.handleKeyup && e.handleKeyup(...u)),
              onKeypress: t[2] || (t[2] = (...u) => e.handleKeypress && e.handleKeypress(...u)),
              onInput: t[3] || (t[3] = (...u) => e.handleInput && e.handleInput(...u)),
              onSelect: t[4] || (t[4] = (...u) => e.handleInput && e.handleInput(...u)),
              onBlur: t[5] || (t[5] = (...u) => e.handleBlur && e.handleBlur(...u)),
              ref: "input"
            }), null, 16, EYe)
          ],
          2
          /* CLASS */
        )
      ]),
      _: 2
      /* DYNAMIC */
    }, [
      It(e.elementSlots, (u, c) => ({
        name: c,
        fn: Qe(() => [
          Me(e.$slots, c, { el$: e.el$ }, () => [
            (U(), Ae(ze(u), { el$: e.el$ }, null, 8, ["el$"]))
          ])
        ])
      }))
    ]),
    1536
    /* NEED_PATCH, DYNAMIC_SLOTS */
  );
}
rm.render = SYe;
rm.__file = "themes/blank/templates/elements/TextElement.vue";
function yYe(e, t, n) {
  const { value: r, modelValue: i, falseValue: a, trueValue: o, disabled: s } = De(e), l = i && i.value !== void 0 ? i : r, u = N(() => l.value === o.value), c = (v) => {
    t.emit("input", v), t.emit("update:modelValue", v), t.emit("change", v);
  }, d = () => {
    c(o.value);
  }, f = () => {
    c(a.value);
  }, h = (v) => {
    c(v.target.checked ? o.value : a.value);
  }, m = () => {
    s.value || (u.value ? f() : d());
  };
  return [null, void 0, !1, 0, "0", "off"].indexOf(l.value) !== -1 && [a.value, o.value].indexOf(l.value) === -1 && f(), [!0, 1, "1", "on"].indexOf(l.value) !== -1 && [a.value, o.value].indexOf(l.value) === -1 && d(), {
    externalValue: l,
    checked: u,
    update: c,
    check: d,
    uncheck: f,
    handleInput: h,
    handleClick: m
  };
}
function TYe(e, t, n) {
  const { trueValue: r, falseValue: i, onLabel: a, offLabel: o } = De(e), s = n.checked, l = n.update;
  return {
    label: N(() => {
      let h = s.value ? a.value : o.value;
      return h || (h = "&nbsp;"), h;
    }),
    toggle: () => {
      l(s.value ? i.value : r.value);
    },
    on: () => {
      l(r.value);
    },
    off: () => {
      l(i.value);
    }
  };
}
function CYe(e, t, n) {
  const r = De(e), i = r.disabled, a = n.checked, o = N(() => ({
    container: "toggle-container",
    toggle: "toggle",
    toggleOn: "toggle-on",
    toggleOff: "toggle-off",
    toggleOnDisabled: "toggle-on-disabled",
    toggleOffDisabled: "toggle-off-disabled",
    handle: "toggle-handle",
    handleOn: "toggle-handle-on",
    handleOff: "toggle-handle-off",
    handleOnDisabled: "toggle-handle-on-disabled",
    handleOffDisabled: "toggle-handle-off-disabled",
    label: "toggle-label",
    ...r.classes.value
  }));
  return {
    classList: N(() => ({
      container: o.value.container,
      toggle: [
        o.value.toggle,
        i.value ? a.value ? o.value.toggleOnDisabled : o.value.toggleOffDisabled : a.value ? o.value.toggleOn : o.value.toggleOff
      ],
      handle: [
        o.value.handle,
        i.value ? a.value ? o.value.handleOnDisabled : o.value.handleOffDisabled : a.value ? o.value.handleOn : o.value.handleOff
      ],
      label: o.value.label
    }))
  };
}
function AYe(e, t, n) {
  const { disabled: r } = De(e), i = n.check, a = n.uncheck, o = n.checked;
  return {
    handleSpace: () => {
      r.value || (o.value ? a() : i());
    }
  };
}
const OYe = {
  value: {
    validator: function(e) {
      return (t) => ["number", "string", "boolean"].indexOf(typeof t) !== -1 || t === null || t === void 0;
    },
    required: !1
  },
  modelValue: {
    validator: function(e) {
      return (t) => ["number", "string", "boolean"].indexOf(typeof t) !== -1 || t === null || t === void 0;
    },
    required: !1
  }
};
var yR = {
  name: "Toggle",
  emits: [
    "input",
    "update:modelValue",
    "change"
  ],
  props: {
    ...OYe,
    id: {
      type: [String, Number],
      required: !1,
      default: "toggle"
    },
    name: {
      type: [String, Number],
      required: !1,
      default: "toggle"
    },
    disabled: {
      type: Boolean,
      required: !1,
      default: !1
    },
    required: {
      type: Boolean,
      required: !1,
      default: !1
    },
    falseValue: {
      type: [String, Number, Boolean],
      required: !1,
      default: !1
    },
    trueValue: {
      type: [String, Number, Boolean],
      required: !1,
      default: !0
    },
    onLabel: {
      type: [String, Object],
      required: !1,
      default: ""
    },
    offLabel: {
      type: [String, Object],
      required: !1,
      default: ""
    },
    classes: {
      type: Object,
      required: !1,
      default: () => ({})
    },
    labelledby: {
      type: String,
      required: !1
    },
    describedby: {
      type: String,
      required: !1
    },
    aria: {
      required: !1,
      type: Object,
      default: () => ({})
    }
  },
  setup(e, t) {
    const n = yYe(e, t), r = TYe(e, t, {
      checked: n.checked,
      update: n.update
    }), i = CYe(e, t, {
      checked: n.checked
    }), a = AYe(e, t, {
      check: n.check,
      uncheck: n.uncheck,
      checked: n.checked
    });
    return {
      ...n,
      ...i,
      ...r,
      ...a
    };
  }
};
const RYe = ["tabindex", "aria-checked", "aria-describedby", "aria-labelledby"], wYe = ["id", "name", "value", "checked", "disabled"], xYe = ["innerHTML"], NYe = ["checked"];
function DYe(e, t, n, r, i, a) {
  return U(), ee("div", $e({
    class: e.classList.container,
    tabindex: n.disabled ? void 0 : 0,
    "aria-checked": e.checked,
    "aria-describedby": n.describedby,
    "aria-labelledby": n.labelledby,
    role: "switch"
  }, n.aria, {
    onKeypress: t[1] || (t[1] = Zr(An((...o) => e.handleSpace && e.handleSpace(...o), ["prevent"]), ["space"]))
  }), [
    Gn(de("input", {
      type: "checkbox",
      id: n.id,
      name: n.name,
      value: n.trueValue,
      checked: e.checked,
      disabled: n.disabled
    }, null, 8, wYe), [
      [Wi, !1]
    ]),
    de(
      "div",
      {
        class: re(e.classList.toggle),
        onClick: t[0] || (t[0] = (...o) => e.handleClick && e.handleClick(...o))
      },
      [
        de(
          "span",
          {
            class: re(e.classList.handle)
          },
          null,
          2
          /* CLASS */
        ),
        Me(e.$slots, "label", {
          checked: e.checked,
          classList: e.classList
        }, () => [
          de("span", {
            class: re(e.classList.label),
            innerHTML: e.label
          }, null, 10, xYe)
        ]),
        n.required ? (U(), ee("input", {
          key: 0,
          type: "checkbox",
          style: {
            appearance: "none",
            height: "1px",
            margin: "0",
            padding: "0",
            fontSize: "0",
            background: "transparent",
            position: "absolute",
            width: "100%",
            bottom: "0",
            outline: "none"
          },
          checked: e.checked,
          "aria-hidden": "true",
          tabindex: "-1",
          required: ""
        }, null, 8, NYe)) : se("v-if", !0)
      ],
      2
      /* CLASS */
    )
  ], 16, RYe);
}
yR.render = DYe;
yR.__file = "node_modules/@vueform/toggle/src/Toggle.vue";
var TR = {
  name: "ToggleElement",
  components: {
    Toggle: yR
  },
  data() {
    return {
      merge: !0,
      defaultClasses: {
        container: "",
        wrapper: "",
        toggle: {
          container: "",
          toggle: "",
          toggleOn: "",
          toggleOff: "",
          toggleOnDisabled: "",
          toggleOffDisabled: "",
          handle: "",
          handleOn: "",
          handleOff: "",
          handleOnDisabled: "",
          handleOffDisabled: "",
          label: ""
        },
        text: ""
      }
    };
  }
};
const IYe = ["innerHTML"];
function LYe(e, t, n, r, i, a) {
  const o = Bt("Toggle");
  return U(), Ae(
    ze(e.elementLayout),
    { ref: "container" },
    nr({
      element: Qe(() => [
        de(
          "div",
          {
            class: re(e.classes.wrapper)
          },
          [
            se(" @vueform/toggle component "),
            rn(o, $e({
              value: e.value,
              modelValue: e.value
            }, e.fieldOptions, {
              classes: e.classes.toggle,
              name: e.name,
              id: e.fieldId,
              aria: e.aria,
              onInput: e.handleChange,
              ref: "input"
            }), null, 16, ["value", "modelValue", "classes", "name", "id", "aria", "onInput"]),
            e.Text ? (U(), ee("span", {
              key: 0,
              class: re(e.classes.text),
              innerHTML: e.Text
            }, null, 10, IYe)) : (U(), ee(
              "span",
              {
                key: 1,
                class: re(e.classes.text)
              },
              [
                Me(e.$slots, "default", { el$: e.el$ }, () => [
                  (U(), Ae(ze(e.fieldSlots.default), { el$: e.el$ }, null, 8, ["el$"]))
                ])
              ],
              2
              /* CLASS */
            ))
          ],
          2
          /* CLASS */
        )
      ]),
      _: 2
      /* DYNAMIC */
    }, [
      It(e.elementSlots, (s, l) => ({
        name: l,
        fn: Qe(() => [
          Me(e.$slots, l, { el$: e.el$ }, () => [
            (U(), Ae(ze(s), { el$: e.el$ }, null, 8, ["el$"]))
          ])
        ])
      }))
    ]),
    1536
    /* NEED_PATCH, DYNAMIC_SLOTS */
  );
}
TR.render = LYe;
TR.__file = "themes/blank/templates/elements/ToggleElement.vue";
var im = {
  name: "EditorElement",
  data() {
    return {
      merge: !0,
      defaultClasses: {
        container: "",
        input: ""
      }
    };
  }
};
function kYe(e, t, n, r, i, a) {
  const o = Bt("EditorWrapper");
  return U(), Ae(
    ze(e.elementLayout),
    { ref: "container" },
    nr({
      element: Qe(() => [
        rn(o, {
          value: e.model,
          placeholder: e.Placeholder,
          id: e.fieldId,
          accept: e.accept,
          "accept-mimes": e.acceptMimes,
          endpoint: e.editorEndpoint,
          method: e.editorMethod,
          disabled: e.isDisabled,
          "hide-tools": e.hideTools,
          class: re(e.classes.input),
          attrs: e.aria,
          onInput: e.handleInput,
          onAlert: e.handleAlert,
          onError: e.handleError,
          onBlur: e.handleBlur,
          ref: "input"
        }, null, 8, ["value", "placeholder", "id", "accept", "accept-mimes", "endpoint", "method", "disabled", "hide-tools", "class", "attrs", "onInput", "onAlert", "onError", "onBlur"])
      ]),
      _: 2
      /* DYNAMIC */
    }, [
      It(e.elementSlots, (s, l) => ({
        name: l,
        fn: Qe(() => [
          Me(e.$slots, l, { el$: e.el$ }, () => [
            (U(), Ae(ze(s), { el$: e.el$ }, null, 8, ["el$"]))
          ])
        ])
      }))
    ]),
    1536
    /* NEED_PATCH, DYNAMIC_SLOTS */
  );
}
im.render = kYe;
im.__file = "themes/blank/templates/elements/EditorElement.vue";
var _9 = {
  name: "TTextareaElement",
  render: nm.render,
  staticRenderFns: nm.staticRenderFns,
  data() {
    return {
      merge: !0,
      defaultClasses: {
        container: "",
        inputContainer: "",
        input: ""
      }
    };
  }
};
_9.__file = "themes/blank/templates/elements/TTextareaElement.vue";
var v9 = {
  name: "TTextElement",
  render: rm.render,
  staticRenderFns: rm.staticRenderFns,
  data() {
    return {
      merge: !0,
      defaultClasses: {
        container: "",
        inputContainer: "",
        input: ""
      }
    };
  }
};
v9.__file = "themes/blank/templates/elements/TTextElement.vue";
var b9 = {
  name: "TEditorElement",
  render: im.render,
  staticRenderFns: im.staticRenderFns,
  data() {
    return {
      merge: !0,
      defaultClasses: {
        container: "",
        input: ""
      }
    };
  }
};
b9.__file = "themes/blank/templates/elements/TEditorElement.vue";
var CR = {
  name: "CheckboxgroupCheckbox",
  data() {
    return {
      merge: !0,
      defaultClasses: {
        container: "",
        input: "",
        text: ""
      }
    };
  }
};
const MYe = ["value", "name", "id", "disabled", "aria-label"], PYe = ["innerHTML"];
function FYe(e, t, n, r, i, a) {
  return U(), ee(
    "label",
    {
      class: re(e.classes.container)
    },
    [
      Me(e.$slots, "default", $e({ name: e.name }, {
        classes: e.classes,
        isDisabled: e.isDisabled,
        id: e.id,
        item: e.item,
        value: e.value,
        items: e.items,
        index: e.index
      }), () => [
        Gn(de("input", $e({
          type: "checkbox",
          "onUpdate:modelValue": t[0] || (t[0] = (o) => e.el$.model = o)
        }, e.attrs, {
          value: e.value,
          class: e.classes.input,
          name: e.name,
          id: e.id,
          disabled: e.isDisabled,
          "aria-label": e.item.label
        }), null, 16, MYe), [
          [M_, e.el$.model]
        ]),
        de("span", {
          class: re(e.classes.text),
          innerHTML: e.item.label
        }, null, 10, PYe)
      ])
    ],
    2
    /* CLASS */
  );
}
CR.render = FYe;
CR.__file = "themes/blank/templates/elements/partials/CheckboxgroupCheckbox.vue";
var AR = {
  name: "CheckboxgroupCheckbox_tabs",
  data() {
    return {
      merge: !0,
      defaultClasses: {
        container: "",
        wrapper: "",
        input: "",
        text: ""
      }
    };
  }
};
const BYe = ["aria-checked"], $Ye = ["value", "id", "name", "disabled"], UYe = ["innerHTML"];
function qYe(e, t, n, r, i, a) {
  return U(), ee("label", $e(e.attrs, {
    class: e.classes.container,
    tabindex: "0",
    role: "checkbox",
    "aria-checked": e.checked,
    onKeypress: t[1] || (t[1] = Zr(An((o) => e.el$.toggle(e.value), ["prevent"]), ["space"])),
    onKeydown: t[2] || (t[2] = (...o) => e.handleKeydown && e.handleKeydown(...o))
  }), [
    Me(e.$slots, "default", $e({ name: e.name }, {
      classes: e.classes,
      isDisabled: e.isDisabled,
      id: e.id,
      item: e.item,
      value: e.value,
      items: e.items,
      index: e.index
    }), () => [
      de(
        "div",
        {
          class: re(e.classes.wrapper)
        },
        [
          Gn(de("input", {
            type: "checkbox",
            "onUpdate:modelValue": t[0] || (t[0] = (o) => e.el$.model = o),
            value: e.value,
            id: e.id,
            class: re(e.classes.input),
            name: e.name,
            disabled: e.isDisabled
          }, null, 10, $Ye), [
            [M_, e.el$.model]
          ]),
          de("span", {
            class: re(e.classes.text),
            innerHTML: `${e.item.label}`
          }, null, 10, UYe)
        ],
        2
        /* CLASS */
      )
    ])
  ], 16, BYe);
}
AR.render = qYe;
AR.__file = "themes/blank/templates/elements/partials/CheckboxgroupCheckbox_tabs.vue";
var OR = {
  name: "CheckboxgroupCheckbox_tabs",
  data() {
    return {
      merge: !0,
      defaultClasses: {
        container: "",
        wrapper: "",
        input: "",
        text_wrapper: "",
        text: "",
        description: ""
      }
    };
  }
};
const GYe = ["value", "name", "id", "disabled"], YYe = ["innerHTML"], HYe = ["innerHTML"];
function zYe(e, t, n, r, i, a) {
  return U(), ee(
    "label",
    {
      class: re(e.classes.container)
    },
    [
      Me(e.$slots, "default", $e({ name: e.name }, {
        classes: e.classes,
        isDisabled: e.isDisabled,
        id: e.id,
        item: e.item,
        value: e.value,
        items: e.items,
        index: e.index
      }), () => [
        de(
          "div",
          {
            class: re(e.classes.wrapper)
          },
          [
            Gn(de("input", $e({
              type: "checkbox",
              "onUpdate:modelValue": t[0] || (t[0] = (o) => e.el$.model = o)
            }, e.attrs, {
              value: e.value,
              class: e.classes.input,
              name: e.name,
              id: e.id,
              disabled: e.isDisabled
            }), null, 16, GYe), [
              [M_, e.el$.model]
            ]),
            de(
              "div",
              {
                class: re(e.classes.text_wrapper)
              },
              [
                de("div", {
                  class: re(e.classes.text),
                  innerHTML: e.item.label
                }, null, 10, YYe),
                de("div", {
                  class: re(e.classes.description),
                  innerHTML: e.item.description
                }, null, 10, HYe)
              ],
              2
              /* CLASS */
            )
          ],
          2
          /* CLASS */
        )
      ])
    ],
    2
    /* CLASS */
  );
}
OR.render = zYe;
OR.__file = "themes/blank/templates/elements/partials/CheckboxgroupCheckbox_blocks.vue";
var RR = {
  name: "DragAndDrop",
  data() {
    return {
      merge: !0,
      defaultClasses: {
        container: "",
        icon: "",
        title: "",
        description: ""
      }
    };
  }
};
function VYe(e, t, n, r, i, a) {
  return U(), ee(
    "div",
    {
      class: re(e.classes.container),
      onClick: t[0] || (t[0] = An((...o) => e.handleClick && e.handleClick(...o), ["prevent"])),
      ref: "area"
    },
    [
      de(
        "span",
        {
          class: re(e.classes.icon)
        },
        null,
        2
        /* CLASS */
      ),
      e.title ? (U(), ee(
        "span",
        {
          key: 0,
          class: re(e.classes.title)
        },
        zt(e.title),
        3
        /* TEXT, CLASS */
      )) : se("v-if", !0),
      e.description ? (U(), ee(
        "span",
        {
          key: 1,
          class: re(e.classes.description)
        },
        zt(e.description),
        3
        /* TEXT, CLASS */
      )) : se("v-if", !0)
    ],
    2
    /* CLASS */
  );
}
RR.render = VYe;
RR.__file = "themes/blank/templates/elements/partials/DragAndDrop.vue";
var wR = {
  name: "FilePreview",
  data() {
    return {
      merge: !0,
      defaultClasses: {
        container: "",
        wrapper: "",
        file: "",
        filenameLink: "",
        filenameStatic: "",
        actions: "",
        percent: "",
        upload: "",
        progressBar: "",
        progress: "",
        warning: "",
        warningIcon: "",
        uploaded: "",
        uploadedIcon: "",
        remove: "",
        removeIcon: "",
        assistiveText: ""
      }
    };
  }
};
const WYe = ["aria-labelledby", "aria-placeholder", "aria-describedby"], KYe = ["id"], jYe = ["href"];
function QYe(e, t, n, r, i, a) {
  return Gn((U(), ee("div", $e({
    class: e.classes.container
  }, e.attrs, {
    tabindex: "0",
    role: "button",
    "aria-labelledby": e.ariaLabelledby,
    "aria-placeholder": e.ariaPlaceholder,
    "aria-describedby": `${e.el$.fieldId}-file-description`,
    onKeyup: t[3] || (t[3] = (...o) => e.handleKeyup && e.handleKeyup(...o))
  }), [
    de("span", {
      id: `${e.el$.fieldId}-file-description`,
      class: re(e.classes.assistiveText),
      "aria-hidden": ""
    }, zt(e.form$.translations.vueform.a11y.file.description), 11, KYe),
    de(
      "div",
      {
        class: re(e.classes.wrapper)
      },
      [
        de(
          "div",
          {
            class: re(e.classes.file)
          },
          [
            se(" Filename "),
            e.hasLink && e.clickable ? (U(), ee("a", {
              key: 0,
              href: e.link,
              class: re(e.classes.filenameLink),
              target: "_blank",
              rel: "nofollow noopener"
            }, zt(e.filename), 11, jYe)) : (U(), ee(
              "span",
              {
                key: 1,
                class: re(e.classes.filenameStatic)
              },
              zt(e.filename),
              3
              /* TEXT, CLASS */
            ))
          ],
          2
          /* CLASS */
        ),
        de(
          "div",
          {
            class: re(e.classes.actions)
          },
          [
            se(" Remove "),
            e.canRemove ? (U(), ee(
              "div",
              {
                key: 0,
                class: re(e.classes.remove),
                onClick: t[0] || (t[0] = An((...o) => e.remove && e.remove(...o), ["prevent"])),
                onKeypress: t[1] || (t[1] = Zr((...o) => e.remove && e.remove(...o), ["enter", "space"])),
                "aria-roledescription": "❎",
                role: "button",
                tabindex: "0"
              },
              [
                de(
                  "span",
                  {
                    class: re(e.classes.removeIcon)
                  },
                  null,
                  2
                  /* CLASS */
                )
              ],
              34
              /* CLASS, NEED_HYDRATION */
            )) : se("v-if", !0),
            se(" Progress "),
            e.uploading ? (U(), ee(
              "div",
              {
                key: 1,
                class: re(e.classes.percent)
              },
              zt(e.progress) + "%",
              3
              /* TEXT, CLASS */
            )) : se("v-if", !0),
            se(" Error "),
            e.hasError ? (U(), ee(
              "span",
              {
                key: 2,
                class: re(e.classes.warning)
              },
              [
                de(
                  "span",
                  {
                    class: re(e.classes.warningIcon)
                  },
                  null,
                  2
                  /* CLASS */
                )
              ],
              2
              /* CLASS */
            )) : se("v-if", !0),
            se(" Upload button "),
            e.canUploadTemp ? (U(), ee(
              "div",
              {
                key: 3,
                class: re(e.classes.upload),
                onClick: t[2] || (t[2] = An((...o) => e.upload && e.upload(...o), ["prevent"])),
                tabindex: "-1"
              },
              zt(e.uploadText),
              3
              /* TEXT, CLASS */
            )) : e.el$.stage > 1 ? (U(), ee(
              gt,
              { key: 4 },
              [
                se(" Success "),
                de(
                  "span",
                  {
                    class: re(e.classes.uploaded)
                  },
                  [
                    de(
                      "span",
                      {
                        class: re(e.classes.uploadedIcon)
                      },
                      null,
                      2
                      /* CLASS */
                    )
                  ],
                  2
                  /* CLASS */
                )
              ],
              2112
              /* STABLE_FRAGMENT, DEV_ROOT_FRAGMENT */
            )) : se("v-if", !0)
          ],
          2
          /* CLASS */
        )
      ],
      2
      /* CLASS */
    ),
    e.uploading ? (U(), ee(
      "div",
      {
        key: 0,
        class: re(e.classes.progressBar)
      },
      [
        de(
          "div",
          {
            class: re(e.classes.progress),
            style: am({ width: e.progress + "%" })
          },
          null,
          6
          /* CLASS, STYLE */
        )
      ],
      2
      /* CLASS */
    )) : se("v-if", !0)
  ], 16, WYe)), [
    [Wi, e.visible]
  ]);
}
wR.render = QYe;
wR.__file = "themes/blank/templates/elements/partials/FilePreview.vue";
var xR = {
  name: "FilePreview_image",
  data() {
    return {
      merge: !0,
      defaultClasses: {
        container: "",
        wrapper: "",
        image: "",
        img: "",
        file: "",
        filenameLink: "",
        filenameStatic: "",
        actions: "",
        percent: "",
        upload: "",
        progressBar: "",
        progress: "",
        warning: "",
        warningIcon: "",
        uploaded: "",
        uploadedIcon: "",
        remove: "",
        removeIcon: ""
      }
    };
  }
};
const XYe = ["aria-labelledby", "aria-placeholder", "aria-describedby"], ZYe = ["id"], JYe = ["href"], eHe = ["src", "alt", "title"], tHe = ["src", "alt", "title"], nHe = ["href"];
function rHe(e, t, n, r, i, a) {
  return Gn((U(), ee("div", $e({
    class: e.classes.container,
    tabindex: "0",
    role: "button"
  }, e.attrs, {
    "aria-labelledby": e.ariaLabelledby,
    "aria-placeholder": e.ariaPlaceholder,
    "aria-describedby": `${e.el$.fieldId}-file-description`,
    onKeyup: t[4] || (t[4] = (...o) => e.handleKeyup && e.handleKeyup(...o))
  }), [
    de("span", {
      id: `${e.el$.fieldId}-file-description`,
      class: re(e.classes.assistiveText),
      "aria-hidden": ""
    }, zt(e.form$.translations.vueform.a11y.file.description), 11, ZYe),
    de(
      "div",
      {
        class: re(e.classes.wrapper)
      },
      [
        se(" Image "),
        e.uploaded && e.hasLink && e.clickable ? (U(), ee("a", {
          key: 0,
          href: e.link,
          class: re(e.classes.image),
          target: "_blank",
          rel: "nofollow noopener"
        }, [
          de("img", {
            class: re(e.classes.img),
            src: e.preview,
            alt: e.filename,
            title: e.filename,
            "aria-hidden": "true"
          }, null, 10, eHe)
        ], 10, JYe)) : (U(), ee(
          "span",
          {
            key: 1,
            class: re(e.classes.image)
          },
          [
            de("img", {
              class: re(e.classes.img),
              src: e.preview,
              alt: e.filename,
              title: e.filename,
              "aria-hidden": "true"
            }, null, 10, tHe)
          ],
          2
          /* CLASS */
        )),
        de(
          "div",
          {
            class: re(e.classes.file)
          },
          [
            se(" Filename "),
            e.hasLink && e.clickable ? (U(), ee("a", {
              key: 0,
              href: e.link,
              class: re(e.classes.filenameLink),
              target: "_blank",
              rel: "nofollow noopener"
            }, zt(e.filename), 11, nHe)) : (U(), ee(
              "span",
              {
                key: 1,
                class: re(e.classes.filenameStatic)
              },
              zt(e.filename),
              3
              /* TEXT, CLASS */
            ))
          ],
          2
          /* CLASS */
        ),
        de(
          "div",
          {
            class: re(e.classes.actions)
          },
          [
            se(" Remove "),
            e.canRemove ? (U(), ee(
              "div",
              {
                key: 0,
                class: re(e.classes.remove),
                onClick: t[0] || (t[0] = An((...o) => e.remove && e.remove(...o), ["prevent"])),
                onKeypress: t[1] || (t[1] = Zr((...o) => e.remove && e.remove(...o), ["enter", "space"])),
                "aria-roledescription": "❎",
                role: "button",
                tabindex: "0"
              },
              [
                de(
                  "span",
                  {
                    class: re(e.classes.removeIcon)
                  },
                  null,
                  2
                  /* CLASS */
                )
              ],
              34
              /* CLASS, NEED_HYDRATION */
            )) : se("v-if", !0),
            se(" Progress "),
            e.uploading ? (U(), ee(
              "div",
              {
                key: 1,
                class: re(e.classes.percent)
              },
              zt(e.progress) + "%",
              3
              /* TEXT, CLASS */
            )) : se("v-if", !0),
            se(" Error "),
            e.hasError ? (U(), ee(
              "span",
              {
                key: 2,
                class: re(e.classes.warning)
              },
              [
                de(
                  "span",
                  {
                    class: re(e.classes.warningIcon)
                  },
                  null,
                  2
                  /* CLASS */
                )
              ],
              2
              /* CLASS */
            )) : se("v-if", !0),
            se(" Upload button "),
            e.canUploadTemp ? (U(), ee(
              "div",
              {
                key: 3,
                class: re(e.classes.upload),
                onClick: t[2] || (t[2] = An((...o) => e.upload && e.upload(...o), ["prevent"])),
                onKeypress: t[3] || (t[3] = Zr((...o) => e.upload && e.upload(...o), ["enter", "space"])),
                tabindex: "-1",
                role: "button"
              },
              zt(e.uploadText),
              35
              /* TEXT, CLASS, NEED_HYDRATION */
            )) : e.el$.stage > 1 ? (U(), ee(
              gt,
              { key: 4 },
              [
                se(" Success "),
                de(
                  "span",
                  {
                    class: re(e.classes.uploaded)
                  },
                  [
                    de(
                      "span",
                      {
                        class: re(e.classes.uploadedIcon)
                      },
                      null,
                      2
                      /* CLASS */
                    )
                  ],
                  2
                  /* CLASS */
                )
              ],
              2112
              /* STABLE_FRAGMENT, DEV_ROOT_FRAGMENT */
            )) : se("v-if", !0)
          ],
          2
          /* CLASS */
        )
      ],
      2
      /* CLASS */
    ),
    e.uploading ? (U(), ee(
      "div",
      {
        key: 0,
        class: re(e.classes.progressBar)
      },
      [
        de(
          "div",
          {
            class: re(e.classes.progress),
            style: am({ width: e.progress + "%" })
          },
          null,
          6
          /* CLASS, STYLE */
        )
      ],
      2
      /* CLASS */
    )) : se("v-if", !0)
  ], 16, XYe)), [
    [Wi, e.visible]
  ]);
}
xR.render = rHe;
xR.__file = "themes/blank/templates/elements/partials/FilePreview_image.vue";
var NR = {
  name: "FilePreview_gallery",
  data() {
    return {
      merge: !0,
      defaultClasses: {
        container: "",
        image: "",
        img: "",
        overlay: "",
        upload: "",
        progressBar: "",
        progress: "",
        warning: "",
        warningIcon: "",
        uploaded: "",
        uploadedIcon: "",
        remove: "",
        removeIcon: ""
      }
    };
  }
};
const iHe = ["aria-labelledby", "aria-placeholder", "aria-role", "aria-describedby"], aHe = ["id"], oHe = ["href"], sHe = ["src", "alt", "title"], lHe = ["src", "alt", "title"];
function uHe(e, t, n, r, i, a) {
  return Gn((U(), ee("div", $e({
    class: e.classes.container,
    tabindex: "0",
    role: "button"
  }, e.attrs, {
    "aria-labelledby": e.ariaLabelledby,
    "aria-placeholder": e.ariaPlaceholder,
    "aria-role": e.ariaRoledescription,
    "aria-describedby": `${e.el$.fieldId}-file-description`,
    onKeyup: t[4] || (t[4] = (...o) => e.handleKeyup && e.handleKeyup(...o))
  }), [
    de("span", {
      id: `${e.el$.fieldId}-file-description`,
      class: re(e.classes.assistiveText),
      "aria-hidden": ""
    }, zt(e.form$.translations.vueform.a11y.file.description), 11, aHe),
    se(" Image  "),
    e.uploaded && e.hasLink && e.clickable ? (U(), ee("a", {
      key: 0,
      class: re(e.classes.image),
      href: e.link,
      target: "_blank",
      rel: "nofollow noopener"
    }, [
      de("img", {
        src: e.preview,
        class: re(e.classes.img),
        alt: e.filename,
        title: e.filename,
        "aria-hidden": "true"
      }, null, 10, sHe)
    ], 10, oHe)) : (U(), ee(
      "div",
      {
        key: 1,
        class: re(e.classes.image)
      },
      [
        de("img", {
          class: re(e.classes.img),
          src: e.preview,
          alt: e.filename,
          title: e.filename,
          "aria-hidden": "true"
        }, null, 10, lHe)
      ],
      2
      /* CLASS */
    )),
    se(" Overlay "),
    !e.uploaded && !e.uploading ? (U(), ee(
      "div",
      {
        key: 2,
        class: re(e.classes.overlay)
      },
      [
        e.canUploadTemp ? (U(), ee(
          "div",
          {
            key: 0,
            class: re(e.classes.upload),
            onClick: t[0] || (t[0] = An((...o) => e.upload && e.upload(...o), ["prevent"])),
            onKeypress: t[1] || (t[1] = Zr((...o) => e.upload && e.upload(...o), ["enter", "space"])),
            tabindex: "-1",
            role: "button"
          },
          zt(e.uploadText),
          35
          /* TEXT, CLASS, NEED_HYDRATION */
        )) : se("v-if", !0)
      ],
      2
      /* CLASS */
    )) : se("v-if", !0),
    se(" Error "),
    e.hasError ? (U(), ee(
      "span",
      {
        key: 3,
        class: re(e.classes.warning)
      },
      [
        de(
          "span",
          {
            class: re(e.classes.warningIcon)
          },
          null,
          2
          /* CLASS */
        )
      ],
      2
      /* CLASS */
    )) : e.el$.stage > 1 ? (U(), ee(
      gt,
      { key: 4 },
      [
        se(" Success "),
        de(
          "span",
          {
            class: re(e.classes.uploaded)
          },
          [
            de(
              "span",
              {
                class: re(e.classes.uploadedIcon)
              },
              null,
              2
              /* CLASS */
            )
          ],
          2
          /* CLASS */
        )
      ],
      2112
      /* STABLE_FRAGMENT, DEV_ROOT_FRAGMENT */
    )) : se("v-if", !0),
    se(" Remove "),
    e.canRemove ? (U(), ee(
      "div",
      {
        key: 5,
        class: re(e.classes.remove),
        onClick: t[2] || (t[2] = An((...o) => e.remove && e.remove(...o), ["prevent"])),
        onKeypress: t[3] || (t[3] = Zr((...o) => e.remove && e.remove(...o), ["enter", "space"])),
        "aria-roledescription": "❎",
        role: "button",
        tabindex: "0"
      },
      [
        de(
          "span",
          {
            class: re(e.classes.removeIcon)
          },
          null,
          2
          /* CLASS */
        )
      ],
      34
      /* CLASS, NEED_HYDRATION */
    )) : se("v-if", !0),
    se(" Progress "),
    e.uploading ? (U(), ee(
      "div",
      {
        key: 6,
        class: re(e.classes.progressBar)
      },
      [
        de(
          "div",
          {
            class: re(e.classes.progress),
            style: am({ width: e.progress + "%" })
          },
          null,
          6
          /* CLASS, STYLE */
        )
      ],
      2
      /* CLASS */
    )) : se("v-if", !0)
  ], 16, iHe)), [
    [Wi, e.visible]
  ]);
}
NR.render = uHe;
NR.__file = "themes/blank/templates/elements/partials/FilePreview_gallery.vue";
var DR = {
  name: "RadiogroupRadio",
  data() {
    return {
      merge: !0,
      defaultClasses: {
        container: "",
        input: "",
        text: ""
      }
    };
  }
};
const cHe = ["value", "name", "id", "disabled", "aria-label"], dHe = ["innerHTML"];
function fHe(e, t, n, r, i, a) {
  return U(), ee(
    "label",
    {
      class: re(e.classes.container)
    },
    [
      Me(e.$slots, "default", $e({ name: e.name }, {
        classes: e.classes,
        isDisabled: e.isDisabled,
        id: e.id,
        item: e.item,
        value: e.value,
        items: e.items,
        index: e.index
      }), () => [
        Gn(de("input", $e({
          type: "radio",
          "onUpdate:modelValue": t[0] || (t[0] = (o) => e.el$.value = o)
        }, e.attrs, {
          value: e.value,
          class: e.classes.input,
          name: e.name,
          id: e.id,
          disabled: e.isDisabled,
          "aria-label": e.item.label
        }), null, 16, cHe), [
          [P_, e.el$.value]
        ]),
        de("span", {
          class: re(e.classes.text),
          innerHTML: e.item.label
        }, null, 10, dHe)
      ])
    ],
    2
    /* CLASS */
  );
}
DR.render = fHe;
DR.__file = "themes/blank/templates/elements/partials/RadiogroupRadio.vue";
var IR = {
  name: "CheckboxgroupCheckbox_tabs",
  data() {
    return {
      merge: !0,
      defaultClasses: {
        container: "",
        wrapper: "",
        input: "",
        text: ""
      }
    };
  }
};
const pHe = ["aria-checked"], mHe = ["value", "name", "id", "disabled"], hHe = ["innerHTML"];
function gHe(e, t, n, r, i, a) {
  return U(), ee("label", $e(e.attrs, {
    class: e.classes.container,
    tabindex: "0",
    role: "radio",
    "aria-checked": e.checked,
    onKeypress: t[1] || (t[1] = Zr(An((o) => e.el$.update(e.value), ["prevent"]), ["space"])),
    onKeydown: t[2] || (t[2] = (...o) => e.handleKeydown && e.handleKeydown(...o))
  }), [
    Me(e.$slots, "default", $e({ name: e.name }, {
      classes: e.classes,
      isDisabled: e.isDisabled,
      id: e.id,
      item: e.item,
      value: e.value,
      items: e.items,
      index: e.index
    }), () => [
      de(
        "div",
        {
          class: re(e.classes.wrapper)
        },
        [
          Gn(de("input", {
            type: "radio",
            "onUpdate:modelValue": t[0] || (t[0] = (o) => e.el$.model = o),
            value: e.value,
            class: re(e.classes.input),
            name: e.name,
            id: e.id,
            disabled: e.isDisabled
          }, null, 10, mHe), [
            [P_, e.el$.model]
          ]),
          de("span", {
            class: re(e.classes.text),
            innerHTML: `${e.item.label}`
          }, null, 10, hHe)
        ],
        2
        /* CLASS */
      )
    ])
  ], 16, pHe);
}
IR.render = gHe;
IR.__file = "themes/blank/templates/elements/partials/RadiogroupRadio_tabs.vue";
var LR = {
  name: "CheckboxgroupCheckbox_tabs",
  data() {
    return {
      merge: !0,
      defaultClasses: {
        container: "",
        wrapper: "",
        input: "",
        text_wrapper: "",
        text: "",
        description: ""
      }
    };
  }
};
const _He = ["value", "name", "id", "disabled"], vHe = ["innerHTML"], bHe = ["innerHTML"];
function EHe(e, t, n, r, i, a) {
  return U(), ee(
    "label",
    {
      class: re(e.classes.container)
    },
    [
      Me(e.$slots, "default", $e({ name: e.name }, {
        classes: e.classes,
        isDisabled: e.isDisabled,
        id: e.id,
        item: e.item,
        value: e.value,
        items: e.items,
        index: e.index
      }), () => [
        de(
          "div",
          {
            class: re(e.classes.wrapper)
          },
          [
            Gn(de("input", $e({
              type: "radio",
              "onUpdate:modelValue": t[0] || (t[0] = (o) => e.el$.model = o)
            }, e.attrs, {
              value: e.value,
              class: e.classes.input,
              name: e.name,
              id: e.id,
              disabled: e.isDisabled
            }), null, 16, _He), [
              [P_, e.el$.model]
            ]),
            de(
              "div",
              {
                class: re(e.classes.text_wrapper)
              },
              [
                de("div", {
                  class: re(e.classes.text),
                  innerHTML: e.item.label
                }, null, 10, vHe),
                de("div", {
                  class: re(e.classes.description),
                  innerHTML: e.item.description
                }, null, 10, bHe)
              ],
              2
              /* CLASS */
            )
          ],
          2
          /* CLASS */
        )
      ])
    ],
    2
    /* CLASS */
  );
}
LR.render = EHe;
LR.__file = "themes/blank/templates/elements/partials/RadiogroupRadio_blocks.vue";
var I_ = {
  name: "DatepickerWrapper",
  data() {
    return {
      merge: !0,
      defaultClasses: {
        datepicker: "",
        calendarContainer: ""
      }
    };
  }
};
const SHe = ["id", "placeholder"];
function yHe(e, t, n, r, i, a) {
  return U(), ee("input", $e({
    type: "text",
    class: e.classes.datepicker,
    id: e.id,
    placeholder: e.placeholder
  }, e.attrs, { ref: "input" }), null, 16, SHe);
}
I_.render = yHe;
I_.__file = "themes/blank/templates/wrappers/DatepickerWrapper.vue";
var E9 = {
  name: "DatepickerWrapper",
  render: I_.render,
  data: I_.data
}, THe = `.flatpickr-calendar {
  background: transparent;
  opacity: 0;
  display: none;
  text-align: center;
  visibility: hidden;
  padding: 0;
  animation: none;
  direction: ltr;
  border: 0;
  font-size: 14px;
  line-height: 24px;
  border-radius: 5px;
  position: absolute;
  width: 307.875px;
  box-sizing: border-box;
  touch-action: manipulation;
  box-shadow: 0 3px 13px rgba(0, 0, 0, 0.08);
  color: var(--vf-color-input);
}

.flatpickr-calendar.open,
.flatpickr-calendar.inline {
  opacity: 1;
  max-height: 640px;
  visibility: visible;
}

.flatpickr-calendar.open {
  display: inline-block;
  z-index: 999;
}

.flatpickr-calendar.animate.open {
  animation: fpFadeInDown 300ms cubic-bezier(0.23, 1, 0.32, 1);
}

.flatpickr-calendar.inline {
  display: block;
  position: relative;
  top: 2px;
}

.flatpickr-calendar.rightMost {
  left: auto;
  right: 0;
}

.flatpickr-calendar.static {
  position: absolute;
  top: calc(100% + 2px);
}

.flatpickr-calendar.static.open {
  z-index: 999;
  display: block;
}

.flatpickr-calendar.multiMonth .flatpickr-days .dayContainer:nth-child(n+1) .flatpickr-day.inRange:nth-child(7n+7) {
  box-shadow: none !important;
}

.flatpickr-calendar.multiMonth .flatpickr-days .dayContainer:nth-child(n+2) .flatpickr-day.inRange:nth-child(7n+1) {
  box-shadow: -2px 0 0 var(--vf-bg-selected), 5px 0 0 var(--vf-bg-selected);
}

.flatpickr-calendar .hasWeeks .dayContainer,
.flatpickr-calendar .hasTime .dayContainer {
  border-bottom: 0;
  border-bottom-right-radius: 0;
  border-bottom-left-radius: 0;
}

.flatpickr-calendar .hasWeeks .dayContainer {
  border-left: 0;
}

.flatpickr-calendar.hasTime .flatpickr-time {
  height: 40px;
  border-top: 1px solid var(--vf-border-color-input);
}

.flatpickr-calendar.hasTime .flatpickr-innerContainer {
  border-bottom: 0;
}

.flatpickr-calendar.noCalendar.hasTime .flatpickr-time {
  height: auto;
}

.flatpickr-calendar:before,
.flatpickr-calendar:after {
  position: absolute;
  display: block;
  pointer-events: none;
  border: solid transparent;
  content: "";
  height: 0;
  width: 0;
  left: 22px;
}

.flatpickr-calendar.rightMost:before,
.flatpickr-calendar.arrowRight:before,
.flatpickr-calendar.rightMost:after,
.flatpickr-calendar.arrowRight:after {
  left: auto;
  right: 22px;
}

.flatpickr-calendar.arrowCenter:before,
.flatpickr-calendar.arrowCenter:after {
  left: 50%;
  right: 50%;
}

.flatpickr-calendar:before {
  border-width: 5px;
  margin: 0 -5px;
  box-sizing: border-box;
}

.flatpickr-calendar:after {
  border-width: 4px;
  margin: 0 -4px;
  box-sizing: border-box;
}

.flatpickr-calendar.arrowTop:before,
.flatpickr-calendar.arrowTop:after {
  bottom: 100%;
}

.flatpickr-calendar.arrowTop:before {
  border-bottom-color: var(--vf-bg-date-head);
  box-sizing: border-box;
}

.flatpickr-calendar.arrowTop:after {
  border-bottom-color: var(--vf-bg-date-head);
  box-sizing: border-box;
}

.flatpickr-calendar.arrowBottom:before,
.flatpickr-calendar.arrowBottom:after {
  top: 100%;
}

.flatpickr-calendar.arrowBottom:before {
  border-top-color: var(--vf-bg-date-head);
}

.flatpickr-calendar.arrowBottom:after {
  border-top-color: var(--vf-bg-date-head);
}

.flatpickr-calendar:focus {
  outline: 0;
}

.flatpickr-wrapper {
  position: relative;
  display: flex;
  width: 100%;
  height: 100%;
}

.flatpickr-months {
  display: flex;
}

.flatpickr-months .flatpickr-month {
  border-radius: 5px 5px 0 0;
  background: var(--vf-bg-date-head);
  color: var(--vf-color-date-head);
  fill: var(--vf-color-date-head);
  height: 34px;
  line-height: 1;
  text-align: center;
  position: relative;
  -webkit-user-select: none;
  -moz-user-select: none;
  user-select: none;
  overflow: hidden;
  flex: 1;
}

.flatpickr-months .flatpickr-prev-month,
.flatpickr-months .flatpickr-next-month {
  text-decoration: none;
  cursor: pointer;
  position: absolute;
  top: 0;
  height: 34px;
  padding: 10px;
  z-index: 1;
  color: var(--vf-color-date-head);
  fill: var(--vf-color-date-head);
}

.flatpickr-months .flatpickr-prev-month.flatpickr-disabled,
.flatpickr-months .flatpickr-next-month.flatpickr-disabled {
  display: none;
}

.flatpickr-months .flatpickr-prev-month i,
.flatpickr-months .flatpickr-next-month i {
  position: relative;
}

.flatpickr-months .flatpickr-prev-month.flatpickr-prev-month,
.flatpickr-months .flatpickr-next-month.flatpickr-prev-month {
  left: 0;
}

.flatpickr-months .flatpickr-prev-month.flatpickr-next-month,
.flatpickr-months .flatpickr-next-month.flatpickr-next-month {
  right: 0;
}

.flatpickr-months .flatpickr-prev-month:hover,
.flatpickr-months .flatpickr-next-month:hover {
  color: var(--vf-color-date-head);
}

.flatpickr-months .flatpickr-prev-month:hover svg,
.flatpickr-months .flatpickr-next-month:hover svg {
  opacity: 1;
}

.flatpickr-months .flatpickr-prev-month svg,
.flatpickr-months .flatpickr-next-month svg {
  width: 14px;
  height: 14px;
  opacity: 0.7;
  display: block;
}

.flatpickr-months .flatpickr-prev-month svg path,
.flatpickr-months .flatpickr-next-month svg path {
  transition: fill 0.1s;
  fill: inherit;
}

.numInputWrapper {
  position: relative;
  height: auto;
}

.numInputWrapper input,
.numInputWrapper span {
  display: inline-block;
}

.numInputWrapper input {
  width: 100%;
}

.numInputWrapper input::-ms-clear {
  display: none;
}

.numInputWrapper input::-webkit-outer-spin-button,
.numInputWrapper input::-webkit-inner-spin-button {
  margin: 0;
  -webkit-appearance: none;
}

.numInputWrapper span {
  position: absolute;
  right: 0;
  width: 14px;
  padding: 0 4px 0 2px;
  height: 50%;
  line-height: 50%;
  opacity: 0;
  cursor: pointer;
  border: 1px solid var(--vf-border-color-input);
  box-sizing: border-box;
}

.numInputWrapper span:hover {
  background: var(--vf-bg-selected);
}

.numInputWrapper span:active {
  background: var(--vf-bg-selected);
}

.numInputWrapper span:after {
  display: block;
  content: "";
  position: absolute;
}

.numInputWrapper span.arrowUp {
  top: 0;
  border-bottom: 0;
}

.numInputWrapper span.arrowUp:after {
  border-left: 4px solid transparent;
  border-right: 4px solid transparent;
  border-bottom: 4px solid var(--vf-color-input);
  top: 26%;
  box-sizing: border-box;
}

.numInputWrapper span.arrowDown {
  top: 50%;
}

.numInputWrapper span.arrowDown:after {
  border-left: 4px solid transparent;
  border-right: 4px solid transparent;
  border-top: 4px solid var(--vf-color-input);
  top: 40%;
  box-sizing: border-box;
}

.numInputWrapper span svg {
  width: inherit;
  height: auto;
}

.numInputWrapper span svg path {
  fill: var(--vf-color-input);
}

.numInputWrapper:hover {
  background: rgba(0, 0, 0, 0.05);
}

.numInputWrapper:hover span {
  opacity: 1;
}

.flatpickr-current-month {
  font-size: 135%;
  line-height: inherit;
  font-weight: 300;
  color: inherit;
  position: absolute;
  width: 75%;
  left: 12.5%;
  padding: 7.48px 0 0 0;
  line-height: 1;
  height: 34px;
  display: inline-block;
  text-align: center;
  transform: translate3d(0px, 0px, 0px);
}

.flatpickr-current-month span.cur-month {
  font-family: inherit;
  font-weight: 700;
  color: inherit;
  display: inline-block;
  margin-left: 0.5ch;
  padding: 0;
}

.flatpickr-current-month span.cur-month:hover {
  background: rgba(0, 0, 0, 0.05);
}

.flatpickr-current-month .numInputWrapper {
  width: 6ch;
  width: 7ch\\0 ;
  display: inline-block;
}

.flatpickr-current-month .numInputWrapper span.arrowUp:after {
  border-bottom-color: var(--vf-color-date-head);
}

.flatpickr-current-month .numInputWrapper span.arrowDown:after {
  border-top-color: var(--vf-color-date-head);
}

.flatpickr-current-month input.cur-year {
  background: transparent;
  box-sizing: border-box;
  color: inherit;
  cursor: text;
  padding: 0 0 0 0.5ch;
  margin: 0;
  display: inline-block;
  font-size: inherit;
  font-family: inherit;
  font-weight: 300;
  line-height: inherit;
  height: auto;
  border: 0;
  border-radius: 0;
  vertical-align: initial;
  -webkit-appearance: textfield;
  -moz-appearance: textfield;
  appearance: textfield;
}

.flatpickr-current-month input.cur-year:focus {
  outline: 0;
}

.flatpickr-current-month input.cur-year[disabled],
.flatpickr-current-month input.cur-year[disabled]:hover {
  font-size: 100%;
  color: var(--vf-gray-300);
  background: transparent;
  pointer-events: none;
}

.flatpickr-current-month .flatpickr-monthDropdown-months {
  appearance: menulist;
  background: var(--vf-bg-date-head);
  border: none;
  border-radius: 0;
  box-sizing: border-box;
  color: inherit;
  cursor: pointer;
  font-size: inherit;
  font-family: inherit;
  font-weight: 300;
  height: auto;
  line-height: inherit;
  margin: -1px 0 0 0;
  outline: none;
  padding: 0 0 0 0.5ch;
  position: relative;
  vertical-align: initial;
  -webkit-box-sizing: border-box;
  -webkit-appearance: menulist;
  -moz-appearance: menulist;
  width: auto;
}

.flatpickr-current-month .flatpickr-monthDropdown-months:focus,
.flatpickr-current-month .flatpickr-monthDropdown-months:active {
  outline: none;
}

.flatpickr-current-month .flatpickr-monthDropdown-months:hover {
  background: rgba(0, 0, 0, 0.1);
}

.flatpickr-current-month .flatpickr-monthDropdown-months .flatpickr-monthDropdown-month {
  background-color: var(--vf-bg-date-head);
  outline: none;
  padding: 0;
}

.flatpickr-weekdays {
  background: var(--vf-bg-date-head);
  text-align: center;
  overflow: hidden;
  width: 100%;
  display: flex;
  align-items: center;
  height: 28px;
}

.flatpickr-weekdays .flatpickr-weekdaycontainer {
  display: flex;
  flex: 1;
}

span.flatpickr-weekday {
  cursor: default;
  font-size: 90%;
  background: var(--vf-bg-date-head);
  color: var(--vf-color-date-head);
  line-height: 1;
  margin: 0;
  text-align: center;
  display: block;
  flex: 1;
  font-weight: bolder;
}

.dayContainer,
.flatpickr-weeks {
  padding: 1px 0 0 0;
}

.flatpickr-days {
  position: relative;
  overflow: hidden;
  display: flex;
  align-items: flex-start;
  width: 307.875px;
  background-color: var(--vf-bg-input);
}

.flatpickr-days:focus {
  outline: 0;
}

.dayContainer {
  padding: 0;
  outline: 0;
  text-align: left;
  width: 307.875px;
  min-width: 307.875px;
  max-width: 307.875px;
  box-sizing: border-box;
  display: inline-block;
  display: flex;
  flex-wrap: wrap;
  -ms-flex-wrap: wrap;
  justify-content: space-around;
  transform: translate3d(0px, 0px, 0px);
  opacity: 1;
}

.dayContainer + .dayContainer {
  box-shadow: -1px 0 0 var(--vf-gray-200);
}

.flatpickr-day {
  background: none;
  border: 1px solid transparent;
  border-radius: 150px;
  box-sizing: border-box;
  cursor: pointer;
  font-weight: 400;
  width: 14.2857143%;
  flex-basis: 14.2857143%;
  max-width: 39px;
  height: 39px;
  line-height: 38px;
  margin: 0;
  display: inline-block;
  position: relative;
  justify-content: center;
  text-align: center;
}

.flatpickr-day.inRange,
.flatpickr-day.prevMonthDay.inRange,
.flatpickr-day.nextMonthDay.inRange,
.flatpickr-day.today.inRange,
.flatpickr-day.prevMonthDay.today.inRange,
.flatpickr-day.nextMonthDay.today.inRange,
.flatpickr-day:hover,
.flatpickr-day.prevMonthDay:hover,
.flatpickr-day.nextMonthDay:hover,
.flatpickr-day:focus,
.flatpickr-day.prevMonthDay:focus,
.flatpickr-day.nextMonthDay:focus {
  cursor: pointer;
  outline: 0;
  background: var(--vf-bg-selected);
  border-color: var(--vf-bg-selected);
}

.flatpickr-day.today {
  border-color: var(--vf-bg-selected);
}

.flatpickr-day.today:hover,
.flatpickr-day.today:focus {
  border-color: var(--vf-bg-selected);
  background: var(--vf-bg-selected);
}

.flatpickr-day.selected,
.flatpickr-day.startRange,
.flatpickr-day.endRange,
.flatpickr-day.selected.inRange,
.flatpickr-day.startRange.inRange,
.flatpickr-day.endRange.inRange,
.flatpickr-day.selected:focus,
.flatpickr-day.startRange:focus,
.flatpickr-day.endRange:focus,
.flatpickr-day.selected:hover,
.flatpickr-day.startRange:hover,
.flatpickr-day.endRange:hover,
.flatpickr-day.selected.prevMonthDay,
.flatpickr-day.startRange.prevMonthDay,
.flatpickr-day.endRange.prevMonthDay,
.flatpickr-day.selected.nextMonthDay,
.flatpickr-day.startRange.nextMonthDay,
.flatpickr-day.endRange.nextMonthDay {
  background: var(--vf-primary);
  box-shadow: none;
  color: #fff;
  border-color: var(--vf-primary);
}

.flatpickr-day.selected.startRange,
.flatpickr-day.startRange.startRange,
.flatpickr-day.endRange.startRange {
  border-radius: 50px 0 0 50px;
}

.flatpickr-day.selected.endRange,
.flatpickr-day.startRange.endRange,
.flatpickr-day.endRange.endRange {
  border-radius: 0 50px 50px 0;
}

.flatpickr-day.selected.startRange + .endRange:not(:nth-child(7n+1)),
.flatpickr-day.startRange.startRange + .endRange:not(:nth-child(7n+1)),
.flatpickr-day.endRange.startRange + .endRange:not(:nth-child(7n+1)) {
  box-shadow: -10px 0 0 var(--vf-primary);
}

.flatpickr-day.selected.startRange.endRange,
.flatpickr-day.startRange.startRange.endRange,
.flatpickr-day.endRange.startRange.endRange {
  border-radius: 50px;
}

.flatpickr-day.inRange {
  border-radius: 0;
  box-shadow: -5px 0 0 var(--vf-bg-selected), 5px 0 0 var(--vf-bg-selected);
}

.flatpickr-day.flatpickr-disabled,
.flatpickr-day.flatpickr-disabled:hover,
.flatpickr-day.prevMonthDay,
.flatpickr-day.nextMonthDay,
.flatpickr-day.notAllowed,
.flatpickr-day.notAllowed.prevMonthDay,
.flatpickr-day.notAllowed.nextMonthDay {
  color: var(--vf-color-disabled);
  background: transparent;
  border-color: transparent;
  cursor: default;
}

.flatpickr-day.flatpickr-disabled,
.flatpickr-day.flatpickr-disabled:hover {
  cursor: not-allowed;
  color: var(--vf-color-disabled);
}

.flatpickr-day.week.selected {
  border-radius: 0;
  box-shadow: -5px 0 0 var(--vf-primary), 5px 0 0 var(--vf-primary);
}

.flatpickr-day.hidden {
  visibility: hidden;
}

.rangeMode .flatpickr-day {
  margin-top: 1px;
}

.flatpickr-weekwrapper {
  float: left;
}

.flatpickr-weekwrapper .flatpickr-weeks {
  padding: 0 12px;
}

.flatpickr-weekwrapper .flatpickr-weekday {
  float: none;
  width: 100%;
  line-height: 28px;
}

.flatpickr-weekwrapper span.flatpickr-day,
.flatpickr-weekwrapper span.flatpickr-day:hover {
  display: block;
  width: 100%;
  max-width: none;
  color: var(--vf-gray-300);
  background: transparent;
  cursor: default;
  border: none;
}

.flatpickr-innerContainer {
  display: block;
  display: flex;
  box-sizing: border-box;
  overflow: hidden;
  background: var(--vf-bg-input);
}

.flatpickr-rContainer {
  display: inline-block;
  padding: 0;
  box-sizing: border-box;
}

.flatpickr-time {
  text-align: center;
  outline: 0;
  display: block;
  height: 0;
  line-height: 40px;
  max-height: 40px;
  box-sizing: border-box;
  overflow: hidden;
  display: flex;
  background: var(--vf-bg-input);
  border-radius: 0 0 5px 5px;
  color: var(--vf-color-input);
}

.flatpickr-time:after {
  content: "";
  display: table;
  clear: both;
}

.flatpickr-time .numInputWrapper {
  flex: 1;
  width: 40%;
  height: 40px;
  float: left;
}

.flatpickr-time .numInputWrapper span.arrowUp:after {
  border-bottom-color: var(--vf-color-input);
  box-sizing: border-box;
}

.flatpickr-time .numInputWrapper span.arrowDown:after {
  border-top-color: var(--vf-color-input);
  box-sizing: border-box;
}

.flatpickr-time.hasSeconds .numInputWrapper {
  width: 26%;
}

.flatpickr-time.time24hr .numInputWrapper {
  width: 49%;
}

.flatpickr-time input {
  background: transparent;
  box-shadow: none;
  border: 0;
  border-radius: 0;
  text-align: center;
  margin: 0;
  padding: 0;
  height: inherit;
  line-height: inherit;
  font-size: 14px;
  position: relative;
  box-sizing: border-box;
  -webkit-appearance: textfield;
  -moz-appearance: textfield;
  appearance: textfield;
  color: var(--vf-color-input);
  background: var(--vf-bg-input);
}

.flatpickr-time input.flatpickr-hour {
  font-weight: bold;
}

.flatpickr-time input.flatpickr-minute,
.flatpickr-time input.flatpickr-second {
  font-weight: 400;
}

.flatpickr-time input:focus {
  outline: 0;
  border: 0;
}

.flatpickr-time .flatpickr-time-separator,
.flatpickr-time .flatpickr-am-pm {
  height: inherit;
  float: left;
  line-height: inherit;
  font-weight: bold;
  width: 2%;
  -webkit-user-select: none;
  -moz-user-select: none;
  user-select: none;
  align-self: center;
  background: var(--vf-bg-input);
}

.flatpickr-time .flatpickr-am-pm {
  outline: 0;
  width: 18%;
  cursor: pointer;
  text-align: center;
  font-weight: 400;
}

.flatpickr-time input:hover,
.flatpickr-time .flatpickr-am-pm:hover,
.flatpickr-time input:focus,
.flatpickr-time .flatpickr-am-pm:focus {
  background: var(--vf-bg-selected);
}

.flatpickr-input[readonly] {
  cursor: pointer;
}

@keyframes fpFadeInDown {
  from {
    opacity: 0;
    transform: translate3d(0, -20px, 0);
  }

  to {
    opacity: 1;
    transform: translate3d(0, 0, 0);
  }
}

span.flatpickr-day.selected {
  font-weight: bold;
}`;
aR(THe);
E9.__file = "themes/tailwind/templates/wrappers/DatepickerWrapper.vue";
var CHe = { exports: {} };
(function(e) {
  (function() {
  }).call(Mc), (function() {
    window.Set == null && (window.Set = function() {
      function t() {
        this.clear();
      }
      return t.prototype.clear = function() {
        return this.values = [];
      }, t.prototype.has = function(n) {
        return this.values.indexOf(n) !== -1;
      }, t.prototype.add = function(n) {
        return this.has(n) || this.values.push(n), this;
      }, t.prototype.delete = function(n) {
        var r;
        return (r = this.values.indexOf(n)) === -1 ? !1 : (this.values.splice(r, 1), !0);
      }, t.prototype.forEach = function() {
        var n;
        return (n = this.values).forEach.apply(n, arguments);
      }, t;
    }());
  }).call(Mc), function(t) {
    function n() {
    }
    function r(m, v) {
      return function() {
        m.apply(v, arguments);
      };
    }
    function i(m) {
      if (typeof this != "object") throw new TypeError("Promises must be constructed via new");
      if (typeof m != "function") throw new TypeError("not a function");
      this._state = 0, this._handled = !1, this._value = void 0, this._deferreds = [], c(m, this);
    }
    function a(m, v) {
      for (; m._state === 3; ) m = m._value;
      return m._state === 0 ? void m._deferreds.push(v) : (m._handled = !0, void f(function() {
        var b = m._state === 1 ? v.onFulfilled : v.onRejected;
        if (b === null) return void (m._state === 1 ? o : s)(v.promise, m._value);
        var y;
        try {
          y = b(m._value);
        } catch (g) {
          return void s(v.promise, g);
        }
        o(v.promise, y);
      }));
    }
    function o(m, v) {
      try {
        if (v === m) throw new TypeError("A promise cannot be resolved with itself.");
        if (v && (typeof v == "object" || typeof v == "function")) {
          var b = v.then;
          if (v instanceof i) return m._state = 3, m._value = v, void l(m);
          if (typeof b == "function") return void c(r(b, v), m);
        }
        m._state = 1, m._value = v, l(m);
      } catch (y) {
        s(m, y);
      }
    }
    function s(m, v) {
      m._state = 2, m._value = v, l(m);
    }
    function l(m) {
      m._state === 2 && m._deferreds.length === 0 && setTimeout(function() {
        m._handled || h(m._value);
      }, 1);
      for (var v = 0, b = m._deferreds.length; b > v; v++) a(m, m._deferreds[v]);
      m._deferreds = null;
    }
    function u(m, v, b) {
      this.onFulfilled = typeof m == "function" ? m : null, this.onRejected = typeof v == "function" ? v : null, this.promise = b;
    }
    function c(m, v) {
      var b = !1;
      try {
        m(function(y) {
          b || (b = !0, o(v, y));
        }, function(y) {
          b || (b = !0, s(v, y));
        });
      } catch (y) {
        if (b) return;
        b = !0, s(v, y);
      }
    }
    var d = setTimeout, f = typeof setImmediate == "function" && setImmediate || function(m) {
      d(m, 1);
    }, h = function(m) {
      typeof console < "u" && console && console.warn("Possible Unhandled Promise Rejection:", m);
    };
    i.prototype.catch = function(m) {
      return this.then(null, m);
    }, i.prototype.then = function(m, v) {
      var b = new i(n);
      return a(this, new u(m, v, b)), b;
    }, i.all = function(m) {
      var v = Array.prototype.slice.call(m);
      return new i(function(b, y) {
        function g(C, T) {
          try {
            if (T && (typeof T == "object" || typeof T == "function")) {
              var O = T.then;
              if (typeof O == "function") return void O.call(T, function(R) {
                g(C, R);
              }, y);
            }
            v[C] = T, --E === 0 && b(v);
          } catch (R) {
            y(R);
          }
        }
        if (v.length === 0) return b([]);
        for (var E = v.length, S = 0; S < v.length; S++) g(S, v[S]);
      });
    }, i.resolve = function(m) {
      return m && typeof m == "object" && m.constructor === i ? m : new i(function(v) {
        v(m);
      });
    }, i.reject = function(m) {
      return new i(function(v, b) {
        b(m);
      });
    }, i.race = function(m) {
      return new i(function(v, b) {
        for (var y = 0, g = m.length; g > y; y++) m[y].then(v, b);
      });
    }, i._setImmediateFn = function(m) {
      f = m;
    }, i._setUnhandledRejectionFn = function(m) {
      h = m;
    }, e.exports ? e.exports = i : t.Promise || (t.Promise = i);
  }(Mc), (function() {
    var t = typeof window.customElements == "object", n = typeof document.registerElement == "function", r = t || n;
    r || /**
    * @license
    * Copyright (c) 2014 The Polymer Project Authors. All rights reserved.
    * This code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt
    * The complete set of authors may be found at http://polymer.github.io/AUTHORS.txt
    * The complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt
    * Code distributed by Google as part of the polymer project is also
    * subject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt
    */
    (typeof WeakMap > "u" && function() {
      var i = Object.defineProperty, a = Date.now() % 1e9, o = function() {
        this.name = "__st" + (1e9 * Math.random() >>> 0) + (a++ + "__");
      };
      o.prototype = { set: function(s, l) {
        var u = s[this.name];
        return u && u[0] === s ? u[1] = l : i(s, this.name, { value: [s, l], writable: !0 }), this;
      }, get: function(s) {
        var l;
        return (l = s[this.name]) && l[0] === s ? l[1] : void 0;
      }, delete: function(s) {
        var l = s[this.name];
        return l && l[0] === s ? (l[0] = l[1] = void 0, !0) : !1;
      }, has: function(s) {
        var l = s[this.name];
        return l ? l[0] === s : !1;
      } }, window.WeakMap = o;
    }(), function(i) {
      function a(P) {
        R.push(P), O || (O = !0, E(s));
      }
      function o(P) {
        return window.ShadowDOMPolyfill && window.ShadowDOMPolyfill.wrapIfNeeded(P) || P;
      }
      function s() {
        O = !1;
        var P = R;
        R = [], P.sort(function(L, x) {
          return L.uid_ - x.uid_;
        });
        var Y = !1;
        P.forEach(function(L) {
          var x = L.takeRecords();
          l(L), x.length && (L.callback_(x, L), Y = !0);
        }), Y && s();
      }
      function l(P) {
        P.nodes_.forEach(function(Y) {
          var L = S.get(Y);
          L && L.forEach(function(x) {
            x.observer === P && x.removeTransientObservers();
          });
        });
      }
      function u(P, Y) {
        for (var L = P; L; L = L.parentNode) {
          var x = S.get(L);
          if (x) for (var I = 0; I < x.length; I++) {
            var k = x[I], B = k.options;
            if (L === P || B.subtree) {
              var W = Y(B);
              W && k.enqueue(W);
            }
          }
        }
      }
      function c(P) {
        this.callback_ = P, this.nodes_ = [], this.records_ = [], this.uid_ = ++D;
      }
      function d(P, Y) {
        this.type = P, this.target = Y, this.addedNodes = [], this.removedNodes = [], this.previousSibling = null, this.nextSibling = null, this.attributeName = null, this.attributeNamespace = null, this.oldValue = null;
      }
      function f(P) {
        var Y = new d(P.type, P.target);
        return Y.addedNodes = P.addedNodes.slice(), Y.removedNodes = P.removedNodes.slice(), Y.previousSibling = P.previousSibling, Y.nextSibling = P.nextSibling, Y.attributeName = P.attributeName, Y.attributeNamespace = P.attributeNamespace, Y.oldValue = P.oldValue, Y;
      }
      function h(P, Y) {
        return q = new d(P, Y);
      }
      function m(P) {
        return $ || ($ = f(q), $.oldValue = P, $);
      }
      function v() {
        q = $ = void 0;
      }
      function b(P) {
        return P === $ || P === q;
      }
      function y(P, Y) {
        return P === Y ? P : $ && b(P) ? $ : null;
      }
      function g(P, Y, L) {
        this.observer = P, this.target = Y, this.options = L, this.transientObservedNodes = [];
      }
      if (!i.JsMutationObserver) {
        var E, S = /* @__PURE__ */ new WeakMap();
        if (/Trident|Edge/.test(navigator.userAgent)) E = setTimeout;
        else if (window.setImmediate) E = window.setImmediate;
        else {
          var C = [], T = String(Math.random());
          window.addEventListener("message", function(P) {
            if (P.data === T) {
              var Y = C;
              C = [], Y.forEach(function(L) {
                L();
              });
            }
          }), E = function(P) {
            C.push(P), window.postMessage(T, "*");
          };
        }
        var O = !1, R = [], D = 0;
        c.prototype = { observe: function(P, Y) {
          if (P = o(P), !Y.childList && !Y.attributes && !Y.characterData || Y.attributeOldValue && !Y.attributes || Y.attributeFilter && Y.attributeFilter.length && !Y.attributes || Y.characterDataOldValue && !Y.characterData) throw new SyntaxError();
          var L = S.get(P);
          L || S.set(P, L = []);
          for (var x, I = 0; I < L.length; I++) if (L[I].observer === this) {
            x = L[I], x.removeListeners(), x.options = Y;
            break;
          }
          x || (x = new g(this, P, Y), L.push(x), this.nodes_.push(P)), x.addListeners();
        }, disconnect: function() {
          this.nodes_.forEach(function(P) {
            for (var Y = S.get(P), L = 0; L < Y.length; L++) {
              var x = Y[L];
              if (x.observer === this) {
                x.removeListeners(), Y.splice(L, 1);
                break;
              }
            }
          }, this), this.records_ = [];
        }, takeRecords: function() {
          var P = this.records_;
          return this.records_ = [], P;
        } };
        var q, $;
        g.prototype = { enqueue: function(P) {
          var Y = this.observer.records_, L = Y.length;
          if (Y.length > 0) {
            var x = Y[L - 1], I = y(x, P);
            if (I) return void (Y[L - 1] = I);
          } else a(this.observer);
          Y[L] = P;
        }, addListeners: function() {
          this.addListeners_(this.target);
        }, addListeners_: function(P) {
          var Y = this.options;
          Y.attributes && P.addEventListener("DOMAttrModified", this, !0), Y.characterData && P.addEventListener("DOMCharacterDataModified", this, !0), Y.childList && P.addEventListener("DOMNodeInserted", this, !0), (Y.childList || Y.subtree) && P.addEventListener("DOMNodeRemoved", this, !0);
        }, removeListeners: function() {
          this.removeListeners_(this.target);
        }, removeListeners_: function(P) {
          var Y = this.options;
          Y.attributes && P.removeEventListener("DOMAttrModified", this, !0), Y.characterData && P.removeEventListener("DOMCharacterDataModified", this, !0), Y.childList && P.removeEventListener("DOMNodeInserted", this, !0), (Y.childList || Y.subtree) && P.removeEventListener("DOMNodeRemoved", this, !0);
        }, addTransientObserver: function(P) {
          if (P !== this.target) {
            this.addListeners_(P), this.transientObservedNodes.push(P);
            var Y = S.get(P);
            Y || S.set(P, Y = []), Y.push(this);
          }
        }, removeTransientObservers: function() {
          var P = this.transientObservedNodes;
          this.transientObservedNodes = [], P.forEach(function(Y) {
            this.removeListeners_(Y);
            for (var L = S.get(Y), x = 0; x < L.length; x++) if (L[x] === this) {
              L.splice(x, 1);
              break;
            }
          }, this);
        }, handleEvent: function(P) {
          switch (P.stopImmediatePropagation(), P.type) {
            case "DOMAttrModified":
              var Y = P.attrName, L = P.relatedNode.namespaceURI, x = P.target, K = new h("attributes", x);
              K.attributeName = Y, K.attributeNamespace = L;
              var I = P.attrChange === MutationEvent.ADDITION ? null : P.prevValue;
              u(x, function(ne) {
                return !ne.attributes || ne.attributeFilter && ne.attributeFilter.length && ne.attributeFilter.indexOf(Y) === -1 && ne.attributeFilter.indexOf(L) === -1 ? void 0 : ne.attributeOldValue ? m(I) : K;
              });
              break;
            case "DOMCharacterDataModified":
              var x = P.target, K = h("characterData", x), I = P.prevValue;
              u(x, function(ne) {
                return ne.characterData ? ne.characterDataOldValue ? m(I) : K : void 0;
              });
              break;
            case "DOMNodeRemoved":
              this.addTransientObserver(P.target);
            case "DOMNodeInserted":
              var k, B, W = P.target;
              P.type === "DOMNodeInserted" ? (k = [W], B = []) : (k = [], B = [W]);
              var Z = W.previousSibling, V = W.nextSibling, K = h("childList", P.target.parentNode);
              K.addedNodes = k, K.removedNodes = B, K.previousSibling = Z, K.nextSibling = V, u(P.relatedNode, function(ne) {
                return ne.childList ? K : void 0;
              });
          }
          v();
        } }, i.JsMutationObserver = c, i.MutationObserver || (i.MutationObserver = c, c._isPolyfilled = !0);
      }
    }(self), function() {
      if (!window.performance || !window.performance.now) {
        var i = Date.now();
        window.performance = { now: function() {
          return Date.now() - i;
        } };
      }
      window.requestAnimationFrame || (window.requestAnimationFrame = function() {
        var u = window.webkitRequestAnimationFrame || window.mozRequestAnimationFrame;
        return u ? function(c) {
          return u(function() {
            c(performance.now());
          });
        } : function(c) {
          return window.setTimeout(c, 1e3 / 60);
        };
      }()), window.cancelAnimationFrame || (window.cancelAnimationFrame = function() {
        return window.webkitCancelAnimationFrame || window.mozCancelAnimationFrame || function(u) {
          clearTimeout(u);
        };
      }());
      var a = function() {
        var u = document.createEvent("Event");
        return u.initEvent("foo", !0, !0), u.preventDefault(), u.defaultPrevented;
      }();
      if (!a) {
        var o = Event.prototype.preventDefault;
        Event.prototype.preventDefault = function() {
          this.cancelable && (o.call(this), Object.defineProperty(this, "defaultPrevented", { get: function() {
            return !0;
          }, configurable: !0 }));
        };
      }
      var s = /Trident/.test(navigator.userAgent);
      if ((!window.CustomEvent || s && typeof window.CustomEvent != "function") && (window.CustomEvent = function(u, c) {
        c = c || {};
        var d = document.createEvent("CustomEvent");
        return d.initCustomEvent(u, !!c.bubbles, !!c.cancelable, c.detail), d;
      }, window.CustomEvent.prototype = window.Event.prototype), !window.Event || s && typeof window.Event != "function") {
        var l = window.Event;
        window.Event = function(u, c) {
          c = c || {};
          var d = document.createEvent("Event");
          return d.initEvent(u, !!c.bubbles, !!c.cancelable), d;
        }, window.Event.prototype = l.prototype;
      }
    }(), window.CustomElements = window.CustomElements || { flags: {} }, function(i) {
      var a = i.flags, o = [], s = function(u) {
        o.push(u);
      }, l = function() {
        o.forEach(function(u) {
          u(i);
        });
      };
      i.addModule = s, i.initializeModules = l, i.hasNative = !!document.registerElement, i.isIE = /Trident/.test(navigator.userAgent), i.useNative = !a.register && i.hasNative && !window.ShadowDOMPolyfill && (!window.HTMLImports || window.HTMLImports.useNative);
    }(window.CustomElements), window.CustomElements.addModule(function(i) {
      function a(d, f) {
        o(d, function(h) {
          return f(h) ? !0 : void s(h, f);
        }), s(d, f);
      }
      function o(d, f, h) {
        var m = d.firstElementChild;
        if (!m) for (m = d.firstChild; m && m.nodeType !== Node.ELEMENT_NODE; ) m = m.nextSibling;
        for (; m; ) f(m, h) !== !0 && o(m, f, h), m = m.nextElementSibling;
        return null;
      }
      function s(d, f) {
        for (var h = d.shadowRoot; h; ) a(h, f), h = h.olderShadowRoot;
      }
      function l(d, f) {
        u(d, f, []);
      }
      function u(d, f, h) {
        if (d = window.wrap(d), !(h.indexOf(d) >= 0)) {
          h.push(d);
          for (var m, v = d.querySelectorAll("link[rel=" + c + "]"), b = 0, y = v.length; y > b && (m = v[b]); b++) m.import && u(m.import, f, h);
          f(d);
        }
      }
      var c = window.HTMLImports ? window.HTMLImports.IMPORT_LINK_TYPE : "none";
      i.forDocumentTree = l, i.forSubtree = a;
    }), window.CustomElements.addModule(function(i) {
      function a(L, x) {
        return o(L, x) || s(L, x);
      }
      function o(L, x) {
        return i.upgrade(L, x) ? !0 : void (x && c(L));
      }
      function s(L, x) {
        O(L, function(I) {
          return o(I, x) ? !0 : void 0;
        });
      }
      function l(L) {
        $.push(L), q || (q = !0, setTimeout(u));
      }
      function u() {
        q = !1;
        for (var L, x = $, I = 0, k = x.length; k > I && (L = x[I]); I++) L();
        $ = [];
      }
      function c(L) {
        D ? l(function() {
          d(L);
        }) : d(L);
      }
      function d(L) {
        L.__upgraded__ && !L.__attached && (L.__attached = !0, L.attachedCallback && L.attachedCallback());
      }
      function f(L) {
        h(L), O(L, function(x) {
          h(x);
        });
      }
      function h(L) {
        D ? l(function() {
          m(L);
        }) : m(L);
      }
      function m(L) {
        L.__upgraded__ && L.__attached && (L.__attached = !1, L.detachedCallback && L.detachedCallback());
      }
      function v(L) {
        for (var x = L, I = window.wrap(document); x; ) {
          if (x == I) return !0;
          x = x.parentNode || x.nodeType === Node.DOCUMENT_FRAGMENT_NODE && x.host;
        }
      }
      function b(L) {
        if (L.shadowRoot && !L.shadowRoot.__watched) {
          T.dom && console.log("watching shadow-root for: ", L.localName);
          for (var x = L.shadowRoot; x; ) E(x), x = x.olderShadowRoot;
        }
      }
      function y(L, x) {
        if (T.dom) {
          var I = x[0];
          if (I && I.type === "childList" && I.addedNodes && I.addedNodes) {
            for (var k = I.addedNodes[0]; k && k !== document && !k.host; ) k = k.parentNode;
            var B = k && (k.URL || k._URL || k.host && k.host.localName) || "";
            B = B.split("/?").shift().split("/").pop();
          }
          console.group("mutations (%d) [%s]", x.length, B || "");
        }
        var W = v(L);
        x.forEach(function(Z) {
          Z.type === "childList" && (P(Z.addedNodes, function(V) {
            V.localName && a(V, W);
          }), P(Z.removedNodes, function(V) {
            V.localName && f(V);
          }));
        }), T.dom && console.groupEnd();
      }
      function g(L) {
        for (L = window.wrap(L), L || (L = window.wrap(document)); L.parentNode; ) L = L.parentNode;
        var x = L.__observer;
        x && (y(L, x.takeRecords()), u());
      }
      function E(L) {
        if (!L.__observer) {
          var x = new MutationObserver(y.bind(this, L));
          x.observe(L, { childList: !0, subtree: !0 }), L.__observer = x;
        }
      }
      function S(L) {
        L = window.wrap(L), T.dom && console.group("upgradeDocument: ", L.baseURI.split("/").pop());
        var x = L === window.wrap(document);
        a(L, x), E(L), T.dom && console.groupEnd();
      }
      function C(L) {
        R(L, S);
      }
      var T = i.flags, O = i.forSubtree, R = i.forDocumentTree, D = window.MutationObserver._isPolyfilled && T["throttle-attached"];
      i.hasPolyfillMutations = D, i.hasThrottledAttached = D;
      var q = !1, $ = [], P = Array.prototype.forEach.call.bind(Array.prototype.forEach), Y = Element.prototype.createShadowRoot;
      Y && (Element.prototype.createShadowRoot = function() {
        var L = Y.call(this);
        return window.CustomElements.watchShadow(this), L;
      }), i.watchShadow = b, i.upgradeDocumentTree = C, i.upgradeDocument = S, i.upgradeSubtree = s, i.upgradeAll = a, i.attached = c, i.takeRecords = g;
    }), window.CustomElements.addModule(function(i) {
      function a(d, f) {
        if (d.localName === "template" && window.HTMLTemplateElement && HTMLTemplateElement.decorate && HTMLTemplateElement.decorate(d), !d.__upgraded__ && d.nodeType === Node.ELEMENT_NODE) {
          var h = d.getAttribute("is"), m = i.getRegisteredDefinition(d.localName) || i.getRegisteredDefinition(h);
          if (m && (h && m.tag == d.localName || !h && !m.extends)) return o(d, m, f);
        }
      }
      function o(d, f, h) {
        return c.upgrade && console.group("upgrade:", d.localName), f.is && d.setAttribute("is", f.is), s(d, f), d.__upgraded__ = !0, u(d), h && i.attached(d), i.upgradeSubtree(d, h), c.upgrade && console.groupEnd(), d;
      }
      function s(d, f) {
        Object.__proto__ || l(d, f.prototype, f.native), d.__proto__ = f.prototype;
      }
      function l(d, f, h) {
        for (var m = {}, v = f; v !== h && v !== HTMLElement.prototype; ) {
          for (var b, y = Object.getOwnPropertyNames(v), g = 0; b = y[g]; g++) m[b] || (Object.defineProperty(d, b, Object.getOwnPropertyDescriptor(v, b)), m[b] = 1);
          v = Object.getPrototypeOf(v);
        }
      }
      function u(d) {
        d.createdCallback && d.createdCallback();
      }
      var c = i.flags;
      i.upgrade = a, i.upgradeWithDefinition = o, i.implementPrototype = s;
    }), window.CustomElements.addModule(function(i) {
      function a(L, x) {
        var I = x || {};
        if (!L) throw new Error("document.registerElement: first argument `name` must not be empty");
        if (L.indexOf("-") < 0) throw new Error("document.registerElement: first argument ('name') must contain a dash ('-'). Argument provided was '" + String(L) + "'.");
        if (l(L)) throw new Error("Failed to execute 'registerElement' on 'Document': Registration failed for type '" + String(L) + "'. The type name is invalid.");
        if (h(L)) throw new Error("DuplicateDefinitionError: a type with name '" + String(L) + "' is already registered");
        return I.prototype || (I.prototype = Object.create(HTMLElement.prototype)), I.__name = L.toLowerCase(), I.extends && (I.extends = I.extends.toLowerCase()), I.lifecycle = I.lifecycle || {}, I.ancestry = u(I.extends), c(I), d(I), o(I.prototype), m(I.__name, I), I.ctor = v(I), I.ctor.prototype = I.prototype, I.prototype.constructor = I.ctor, i.ready && S(document), I.ctor;
      }
      function o(L) {
        if (!L.setAttribute._polyfilled) {
          var x = L.setAttribute;
          L.setAttribute = function(k, B) {
            s.call(this, k, B, x);
          };
          var I = L.removeAttribute;
          L.removeAttribute = function(k) {
            s.call(this, k, null, I);
          }, L.setAttribute._polyfilled = !0;
        }
      }
      function s(L, x, I) {
        L = L.toLowerCase();
        var k = this.getAttribute(L);
        I.apply(this, arguments);
        var B = this.getAttribute(L);
        this.attributeChangedCallback && B !== k && this.attributeChangedCallback(L, k, B);
      }
      function l(L) {
        for (var x = 0; x < D.length; x++) if (L === D[x]) return !0;
      }
      function u(L) {
        var x = h(L);
        return x ? u(x.extends).concat([x]) : [];
      }
      function c(L) {
        for (var x, I = L.extends, k = 0; x = L.ancestry[k]; k++) I = x.is && x.tag;
        L.tag = I || L.__name, I && (L.is = L.__name);
      }
      function d(L) {
        if (!Object.__proto__) {
          var x = HTMLElement.prototype;
          if (L.is) {
            var I = document.createElement(L.tag);
            x = Object.getPrototypeOf(I);
          }
          for (var k, B = L.prototype, W = !1; B; ) B == x && (W = !0), k = Object.getPrototypeOf(B), k && (B.__proto__ = k), B = k;
          W || console.warn(L.tag + " prototype not found in prototype chain for " + L.is), L.native = x;
        }
      }
      function f(L) {
        return T(P(L.tag), L);
      }
      function h(L) {
        return L ? q[L.toLowerCase()] : void 0;
      }
      function m(L, x) {
        q[L] = x;
      }
      function v(L) {
        return function() {
          return f(L);
        };
      }
      function b(L, x, I) {
        return L === $ ? y(x, I) : Y(L, x);
      }
      function y(L, x) {
        L && (L = L.toLowerCase()), x && (x = x.toLowerCase());
        var I = h(x || L);
        if (I) {
          if (L == I.tag && x == I.is) return new I.ctor();
          if (!x && !I.is) return new I.ctor();
        }
        var k;
        return x ? (k = y(L), k.setAttribute("is", x), k) : (k = P(L), L.indexOf("-") >= 0 && O(k, HTMLElement), k);
      }
      function g(L, x) {
        var I = L[x];
        L[x] = function() {
          var k = I.apply(this, arguments);
          return C(k), k;
        };
      }
      var E, S = (i.isIE, i.upgradeDocumentTree), C = i.upgradeAll, T = i.upgradeWithDefinition, O = i.implementPrototype, R = i.useNative, D = ["annotation-xml", "color-profile", "font-face", "font-face-src", "font-face-uri", "font-face-format", "font-face-name", "missing-glyph"], q = {}, $ = "http://www.w3.org/1999/xhtml", P = document.createElement.bind(document), Y = document.createElementNS.bind(document);
      E = Object.__proto__ || R ? function(L, x) {
        return L instanceof x;
      } : function(L, x) {
        if (L instanceof x) return !0;
        for (var I = L; I; ) {
          if (I === x.prototype) return !0;
          I = I.__proto__;
        }
        return !1;
      }, g(Node.prototype, "cloneNode"), g(document, "importNode"), document.registerElement = a, document.createElement = y, document.createElementNS = b, i.registry = q, i.instanceof = E, i.reservedTagList = D, i.getRegisteredDefinition = h, document.register = document.registerElement;
    }), function(i) {
      function a() {
        u(window.wrap(document)), window.CustomElements.ready = !0;
        var f = window.requestAnimationFrame || function(h) {
          setTimeout(h, 16);
        };
        f(function() {
          setTimeout(function() {
            window.CustomElements.readyTime = Date.now(), window.HTMLImports && (window.CustomElements.elapsed = window.CustomElements.readyTime - window.HTMLImports.readyTime), document.dispatchEvent(new CustomEvent("WebComponentsReady", { bubbles: !0 }));
          });
        });
      }
      var o = i.useNative, s = i.initializeModules;
      if (i.isIE, o) {
        var l = function() {
        };
        i.watchShadow = l, i.upgrade = l, i.upgradeAll = l, i.upgradeDocumentTree = l, i.upgradeSubtree = l, i.takeRecords = l, i.instanceof = function(f, h) {
          return f instanceof h;
        };
      } else s();
      var u = i.upgradeDocumentTree, c = i.upgradeDocument;
      if (window.wrap || (window.ShadowDOMPolyfill ? (window.wrap = window.ShadowDOMPolyfill.wrapIfNeeded, window.unwrap = window.ShadowDOMPolyfill.unwrapIfNeeded) : window.wrap = window.unwrap = function(f) {
        return f;
      }), window.HTMLImports && (window.HTMLImports.__importsParsingHook = function(f) {
        f.import && c(wrap(f.import));
      }), document.readyState === "complete" || i.flags.eager) a();
      else if (document.readyState !== "interactive" || window.attachEvent || window.HTMLImports && !window.HTMLImports.ready) {
        var d = window.HTMLImports && !window.HTMLImports.ready ? "HTMLImportsLoaded" : "DOMContentLoaded";
        window.addEventListener(d, a);
      } else a();
    }(window.CustomElements));
  }).call(Mc), (function() {
  }).call(Mc), (function() {
    var t = this;
    (function() {
      (function() {
        this.Trix = { VERSION: "1.3.1", ZERO_WIDTH_SPACE: "\uFEFF", NON_BREAKING_SPACE: " ", OBJECT_REPLACEMENT_CHARACTER: "￼", browser: { composesExistingText: /Android.*Chrome/.test(navigator.userAgent), forcesObjectResizing: /Trident.*rv:11/.test(navigator.userAgent), supportsInputEvents: function() {
          var r, i, a, o;
          if (typeof InputEvent > "u") return !1;
          for (o = ["data", "getTargetRanges", "inputType"], r = 0, i = o.length; i > r; r++) if (a = o[r], !(a in InputEvent.prototype)) return !1;
          return !0;
        }() }, config: {} };
      }).call(this);
    }).call(t);
    var n = t.Trix;
    (function() {
      (function() {
        n.BasicObject = function() {
          function r() {
          }
          var i, a, o;
          return r.proxyMethod = function(s) {
            var l, u, c, d, f;
            return c = a(s), l = c.name, d = c.toMethod, f = c.toProperty, u = c.optional, this.prototype[l] = function() {
              var h, m;
              return h = d != null ? u ? typeof this[d] == "function" ? this[d]() : void 0 : this[d]() : f != null ? this[f] : void 0, u ? (m = h != null ? h[l] : void 0, m != null ? i.call(m, h, arguments) : void 0) : (m = h[l], i.call(m, h, arguments));
            };
          }, a = function(s) {
            var l, u;
            if (!(u = s.match(o))) throw new Error("can't parse @proxyMethod expression: " + s);
            return l = { name: u[4] }, u[2] != null ? l.toMethod = u[1] : l.toProperty = u[1], u[3] != null && (l.optional = !0), l;
          }, i = Function.prototype.apply, o = /^(.+?)(\(\))?(\?)?\.(.+?)$/, r;
        }();
      }).call(this), (function() {
        var r = function(a, o) {
          function s() {
            this.constructor = a;
          }
          for (var l in o) i.call(o, l) && (a[l] = o[l]);
          return s.prototype = o.prototype, a.prototype = new s(), a.__super__ = o.prototype, a;
        }, i = {}.hasOwnProperty;
        n.Object = function(a) {
          function o() {
            this.id = ++s;
          }
          var s;
          return r(o, a), s = 0, o.fromJSONString = function(l) {
            return this.fromJSON(JSON.parse(l));
          }, o.prototype.hasSameConstructorAs = function(l) {
            return this.constructor === (l != null ? l.constructor : void 0);
          }, o.prototype.isEqualTo = function(l) {
            return this === l;
          }, o.prototype.inspect = function() {
            var l, u, c;
            return l = (function() {
              var d, f, h;
              f = (d = this.contentsForInspection()) != null ? d : {}, h = [];
              for (u in f) c = f[u], h.push(u + "=" + c);
              return h;
            }).call(this), "#<" + this.constructor.name + ":" + this.id + (l.length ? " " + l.join(", ") : "") + ">";
          }, o.prototype.contentsForInspection = function() {
          }, o.prototype.toJSONString = function() {
            return JSON.stringify(this);
          }, o.prototype.toUTF16String = function() {
            return n.UTF16String.box(this);
          }, o.prototype.getCacheKey = function() {
            return this.id.toString();
          }, o;
        }(n.BasicObject);
      }).call(this), (function() {
        n.extend = function(r) {
          var i, a;
          for (i in r) a = r[i], this[i] = a;
          return this;
        };
      }).call(this), (function() {
        n.extend({ defer: function(r) {
          return setTimeout(r, 1);
        } });
      }).call(this), (function() {
        var r, i;
        n.extend({ normalizeSpaces: function(a) {
          return a.replace(RegExp("" + n.ZERO_WIDTH_SPACE, "g"), "").replace(RegExp("" + n.NON_BREAKING_SPACE, "g"), " ");
        }, normalizeNewlines: function(a) {
          return a.replace(/\r\n/g, `
`);
        }, breakableWhitespacePattern: RegExp("[^\\S" + n.NON_BREAKING_SPACE + "]"), squishBreakableWhitespace: function(a) {
          return a.replace(RegExp("" + n.breakableWhitespacePattern.source, "g"), " ").replace(/\ {2,}/g, " ");
        }, summarizeStringChange: function(a, o) {
          var s, l, u, c;
          return a = n.UTF16String.box(a), o = n.UTF16String.box(o), o.length < a.length ? (l = i(a, o), c = l[0], s = l[1]) : (u = i(o, a), s = u[0], c = u[1]), { added: s, removed: c };
        } }), i = function(a, o) {
          var s, l, u, c, d;
          return a.isEqualTo(o) ? ["", ""] : (l = r(a, o), c = l.utf16String.length, u = c ? (d = l.offset, s = a.codepoints.slice(0, d).concat(a.codepoints.slice(d + c)), r(o, n.UTF16String.fromCodepoints(s))) : r(o, a), [l.utf16String.toString(), u.utf16String.toString()]);
        }, r = function(a, o) {
          var s, l, u;
          for (s = 0, l = a.length, u = o.length; l > s && a.charAt(s).isEqualTo(o.charAt(s)); ) s++;
          for (; l > s + 1 && a.charAt(l - 1).isEqualTo(o.charAt(u - 1)); ) l--, u--;
          return { utf16String: a.slice(s, l), offset: s };
        };
      }).call(this), (function() {
        n.extend({ copyObject: function(r) {
          var i, a, o;
          r == null && (r = {}), a = {};
          for (i in r) o = r[i], a[i] = o;
          return a;
        }, objectsAreEqual: function(r, i) {
          var a, o;
          if (r == null && (r = {}), i == null && (i = {}), Object.keys(r).length !== Object.keys(i).length) return !1;
          for (a in r) if (o = r[a], o !== i[a]) return !1;
          return !0;
        } });
      }).call(this), (function() {
        var r = [].slice;
        n.extend({ arraysAreEqual: function(i, a) {
          var o, s, l, u;
          if (i == null && (i = []), a == null && (a = []), i.length !== a.length) return !1;
          for (s = o = 0, l = i.length; l > o; s = ++o) if (u = i[s], u !== a[s]) return !1;
          return !0;
        }, arrayStartsWith: function(i, a) {
          return i == null && (i = []), a == null && (a = []), n.arraysAreEqual(i.slice(0, a.length), a);
        }, spliceArray: function() {
          var i, a, o;
          return a = arguments[0], i = 2 <= arguments.length ? r.call(arguments, 1) : [], o = a.slice(0), o.splice.apply(o, i), o;
        }, summarizeArrayChange: function(i, a) {
          var o, s, l, u, c, d, f, h, m, v, b;
          for (i == null && (i = []), a == null && (a = []), o = [], v = [], l = /* @__PURE__ */ new Set(), u = 0, f = i.length; f > u; u++) b = i[u], l.add(b);
          for (s = /* @__PURE__ */ new Set(), c = 0, h = a.length; h > c; c++) b = a[c], s.add(b), l.has(b) || o.push(b);
          for (d = 0, m = i.length; m > d; d++) b = i[d], s.has(b) || v.push(b);
          return { added: o, removed: v };
        } });
      }).call(this), (function() {
        var r, i, a, o;
        r = null, i = null, o = null, a = null, n.extend({ getAllAttributeNames: function() {
          return r ?? (r = n.getTextAttributeNames().concat(n.getBlockAttributeNames()));
        }, getBlockConfig: function(s) {
          return n.config.blockAttributes[s];
        }, getBlockAttributeNames: function() {
          return i ?? (i = Object.keys(n.config.blockAttributes));
        }, getTextConfig: function(s) {
          return n.config.textAttributes[s];
        }, getTextAttributeNames: function() {
          return o ?? (o = Object.keys(n.config.textAttributes));
        }, getListAttributeNames: function() {
          var s, l;
          return a ?? (a = function() {
            var u, c;
            u = n.config.blockAttributes, c = [];
            for (s in u) l = u[s].listAttribute, l != null && c.push(l);
            return c;
          }());
        } });
      }).call(this), (function() {
        var r, i, a, o, s, l = [].indexOf || function(u) {
          for (var c = 0, d = this.length; d > c; c++) if (c in this && this[c] === u) return c;
          return -1;
        };
        r = document.documentElement, i = (a = (o = (s = r.matchesSelector) != null ? s : r.webkitMatchesSelector) != null ? o : r.msMatchesSelector) != null ? a : r.mozMatchesSelector, n.extend({ handleEvent: function(u, c) {
          var d, f, h, m, v, b, y, g, E, S, C;
          return y = c ?? {}, v = y.onElement, m = y.matchingSelector, C = y.withCallback, h = y.inPhase, b = y.preventDefault, E = y.times, d = v ?? r, g = m, S = h === "capturing", f = function(T) {
            var O;
            return E != null && --E === 0 && f.destroy(), O = n.findClosestElementFromNode(T.target, { matchingSelector: g }), O != null && (C != null && C.call(O, T, O), b) ? T.preventDefault() : void 0;
          }, f.destroy = function() {
            return d.removeEventListener(u, f, S);
          }, d.addEventListener(u, f, S), f;
        }, handleEventOnce: function(u, c) {
          return c == null && (c = {}), c.times = 1, n.handleEvent(u, c);
        }, triggerEvent: function(u, c) {
          var d, f, h, m, v, b, y;
          return y = c ?? {}, b = y.onElement, f = y.bubbles, h = y.cancelable, d = y.attributes, m = b ?? r, f = f !== !1, h = h !== !1, v = document.createEvent("Events"), v.initEvent(u, f, h), d != null && n.extend.call(v, d), m.dispatchEvent(v);
        }, elementMatchesSelector: function(u, c) {
          return (u != null ? u.nodeType : void 0) === 1 ? i.call(u, c) : void 0;
        }, findClosestElementFromNode: function(u, c) {
          var d, f, h;
          for (f = c ?? {}, d = f.matchingSelector, h = f.untilNode; u != null && u.nodeType !== Node.ELEMENT_NODE; ) u = u.parentNode;
          if (u != null) {
            if (d == null) return u;
            if (u.closest && h == null) return u.closest(d);
            for (; u && u !== h; ) {
              if (n.elementMatchesSelector(u, d)) return u;
              u = u.parentNode;
            }
          }
        }, findInnerElement: function(u) {
          for (; u != null && u.firstElementChild; ) u = u.firstElementChild;
          return u;
        }, innerElementIsActive: function(u) {
          return document.activeElement !== u && n.elementContainsNode(u, document.activeElement);
        }, elementContainsNode: function(u, c) {
          if (u && c) for (; c; ) {
            if (c === u) return !0;
            c = c.parentNode;
          }
        }, findNodeFromContainerAndOffset: function(u, c) {
          var d;
          if (u) return u.nodeType === Node.TEXT_NODE ? u : c === 0 ? (d = u.firstChild) != null ? d : u : u.childNodes.item(c - 1);
        }, findElementFromContainerAndOffset: function(u, c) {
          var d;
          return d = n.findNodeFromContainerAndOffset(u, c), n.findClosestElementFromNode(d);
        }, findChildIndexOfNode: function(u) {
          var c;
          if (u != null && u.parentNode) {
            for (c = 0; u = u.previousSibling; ) c++;
            return c;
          }
        }, removeNode: function(u) {
          var c;
          return u != null && (c = u.parentNode) != null ? c.removeChild(u) : void 0;
        }, walkTree: function(u, c) {
          var d, f, h, m, v;
          return h = c ?? {}, f = h.onlyNodesOfType, m = h.usingFilter, d = h.expandEntityReferences, v = function() {
            switch (f) {
              case "element":
                return NodeFilter.SHOW_ELEMENT;
              case "text":
                return NodeFilter.SHOW_TEXT;
              case "comment":
                return NodeFilter.SHOW_COMMENT;
              default:
                return NodeFilter.SHOW_ALL;
            }
          }(), document.createTreeWalker(u, v, m ?? null, d === !0);
        }, tagName: function(u) {
          var c;
          return u != null && (c = u.tagName) != null ? c.toLowerCase() : void 0;
        }, makeElement: function(u, c) {
          var d, f, h, m, v, b, y, g, E, S, C, T, O, R;
          if (c == null && (c = {}), typeof u == "object" ? (c = u, u = c.tagName) : c = { attributes: c }, h = document.createElement(u), c.editable != null && (c.attributes == null && (c.attributes = {}), c.attributes.contenteditable = c.editable), c.attributes) {
            E = c.attributes;
            for (b in E) R = E[b], h.setAttribute(b, R);
          }
          if (c.style) {
            S = c.style;
            for (b in S) R = S[b], h.style[b] = R;
          }
          if (c.data) {
            C = c.data;
            for (b in C) R = C[b], h.dataset[b] = R;
          }
          if (c.className) for (T = c.className.split(" "), m = 0, y = T.length; y > m; m++) f = T[m], h.classList.add(f);
          if (c.textContent && (h.textContent = c.textContent), c.childNodes) for (O = [].concat(c.childNodes), v = 0, g = O.length; g > v; v++) d = O[v], h.appendChild(d);
          return h;
        }, getBlockTagNames: function() {
          var u, c;
          return n.blockTagNames != null ? n.blockTagNames : n.blockTagNames = function() {
            var d, f;
            d = n.config.blockAttributes, f = [];
            for (u in d) c = d[u].tagName, c && f.push(c);
            return f;
          }();
        }, nodeIsBlockContainer: function(u) {
          return n.nodeIsBlockStartComment(u != null ? u.firstChild : void 0);
        }, nodeProbablyIsBlockContainer: function(u) {
          var c, d;
          return c = n.tagName(u), l.call(n.getBlockTagNames(), c) >= 0 && (d = n.tagName(u.firstChild), l.call(n.getBlockTagNames(), d) < 0);
        }, nodeIsBlockStart: function(u, c) {
          var d;
          return d = (c ?? { strict: !0 }).strict, d ? n.nodeIsBlockStartComment(u) : n.nodeIsBlockStartComment(u) || !n.nodeIsBlockStartComment(u.firstChild) && n.nodeProbablyIsBlockContainer(u);
        }, nodeIsBlockStartComment: function(u) {
          return n.nodeIsCommentNode(u) && (u != null ? u.data : void 0) === "block";
        }, nodeIsCommentNode: function(u) {
          return (u != null ? u.nodeType : void 0) === Node.COMMENT_NODE;
        }, nodeIsCursorTarget: function(u, c) {
          var d;
          return d = (c ?? {}).name, u ? n.nodeIsTextNode(u) ? u.data === n.ZERO_WIDTH_SPACE ? d ? u.parentNode.dataset.trixCursorTarget === d : !0 : void 0 : n.nodeIsCursorTarget(u.firstChild) : void 0;
        }, nodeIsAttachmentElement: function(u) {
          return n.elementMatchesSelector(u, n.AttachmentView.attachmentSelector);
        }, nodeIsEmptyTextNode: function(u) {
          return n.nodeIsTextNode(u) && (u != null ? u.data : void 0) === "";
        }, nodeIsTextNode: function(u) {
          return (u != null ? u.nodeType : void 0) === Node.TEXT_NODE;
        } });
      }).call(this), (function() {
        var r, i, a, o, s;
        r = n.copyObject, o = n.objectsAreEqual, n.extend({ normalizeRange: a = function(l) {
          var u;
          if (l != null) return Array.isArray(l) || (l = [l, l]), [i(l[0]), i((u = l[1]) != null ? u : l[0])];
        }, rangeIsCollapsed: function(l) {
          var u, c, d;
          if (l != null) return c = a(l), d = c[0], u = c[1], s(d, u);
        }, rangesAreEqual: function(l, u) {
          var c, d, f, h, m, v;
          if (l != null && u != null) return f = a(l), d = f[0], c = f[1], h = a(u), v = h[0], m = h[1], s(d, v) && s(c, m);
        } }), i = function(l) {
          return typeof l == "number" ? l : r(l);
        }, s = function(l, u) {
          return typeof l == "number" ? l === u : o(l, u);
        };
      }).call(this), (function() {
        var r, i, a, o, s, l, u;
        n.registerElement = function(c, d) {
          var f, h;
          return d == null && (d = {}), c = c.toLowerCase(), d = u(d), h = l(d), (f = h.defaultCSS) && (delete h.defaultCSS, o(f, c)), s(c, h);
        }, o = function(c, d) {
          var f;
          return f = a(d), f.textContent = c.replace(/%t/g, d);
        }, a = function(c) {
          var d, f;
          return d = document.createElement("style"), d.setAttribute("type", "text/css"), d.setAttribute("data-tag-name", c.toLowerCase()), (f = r()) && d.setAttribute("nonce", f), document.head.insertBefore(d, document.head.firstChild), d;
        }, r = function() {
          var c;
          return (c = i("trix-csp-nonce") || i("csp-nonce")) ? c.getAttribute("content") : void 0;
        }, i = function(c) {
          return document.head.querySelector("meta[name=" + c + "]");
        }, l = function(c) {
          var d, f, h;
          f = {};
          for (d in c) h = c[d], f[d] = typeof h == "function" ? { value: h } : h;
          return f;
        }, u = function() {
          var c;
          return c = function(d) {
            var f, h, m, v, b;
            for (f = {}, b = ["initialize", "connect", "disconnect"], h = 0, v = b.length; v > h; h++) m = b[h], f[m] = d[m], delete d[m];
            return f;
          }, window.customElements ? function(d) {
            var f, h, m, v, b;
            return b = c(d), m = b.initialize, f = b.connect, h = b.disconnect, m && (v = f, f = function() {
              return this.initialized || (this.initialized = !0, m.call(this)), v != null ? v.call(this) : void 0;
            }), f && (d.connectedCallback = f), h && (d.disconnectedCallback = h), d;
          } : function(d) {
            var f, h, m, v;
            return v = c(d), m = v.initialize, f = v.connect, h = v.disconnect, m && (d.createdCallback = m), f && (d.attachedCallback = f), h && (d.detachedCallback = h), d;
          };
        }(), s = function() {
          return window.customElements ? function(c, d) {
            var f;
            return f = function() {
              return typeof Reflect == "object" ? Reflect.construct(HTMLElement, [], f) : HTMLElement.apply(this);
            }, Object.setPrototypeOf(f.prototype, HTMLElement.prototype), Object.setPrototypeOf(f, HTMLElement), Object.defineProperties(f.prototype, d), window.customElements.define(c, f), f;
          } : function(c, d) {
            var f, h;
            return h = Object.create(HTMLElement.prototype, d), f = document.registerElement(c, { prototype: h }), Object.defineProperty(h, "constructor", { value: f }), f;
          };
        }();
      }).call(this), (function() {
        var r, i;
        n.extend({ getDOMSelection: function() {
          var a;
          return a = window.getSelection(), a.rangeCount > 0 ? a : void 0;
        }, getDOMRange: function() {
          var a, o;
          return (a = (o = n.getDOMSelection()) != null ? o.getRangeAt(0) : void 0) && !r(a) ? a : void 0;
        }, setDOMRange: function(a) {
          var o;
          return o = window.getSelection(), o.removeAllRanges(), o.addRange(a), n.selectionChangeObserver.update();
        } }), r = function(a) {
          return i(a.startContainer) || i(a.endContainer);
        }, i = function(a) {
          return !Object.getPrototypeOf(a);
        };
      }).call(this), (function() {
        var r;
        r = { "application/x-trix-feature-detection": "test" }, n.extend({ dataTransferIsPlainText: function(i) {
          var a, o, s;
          return s = i.getData("text/plain"), o = i.getData("text/html"), s && o ? (a = new DOMParser().parseFromString(o, "text/html").body, a.textContent === s ? !a.querySelector("*") : void 0) : s != null ? s.length : void 0;
        }, dataTransferIsWritable: function(i) {
          var a, o;
          if ((i != null ? i.setData : void 0) != null) {
            for (a in r) if (o = r[a], !function() {
              try {
                return i.setData(a, o), i.getData(a) === o;
              } catch {
              }
            }()) return;
            return !0;
          }
        }, keyEventIsKeyboardCommand: function() {
          return /Mac|^iP/.test(navigator.platform) ? function(i) {
            return i.metaKey;
          } : function(i) {
            return i.ctrlKey;
          };
        }() });
      }).call(this), (function() {
        n.extend({ RTL_PATTERN: /[\u05BE\u05C0\u05C3\u05D0-\u05EA\u05F0-\u05F4\u061B\u061F\u0621-\u063A\u0640-\u064A\u066D\u0671-\u06B7\u06BA-\u06BE\u06C0-\u06CE\u06D0-\u06D5\u06E5\u06E6\u200F\u202B\u202E\uFB1F-\uFB28\uFB2A-\uFB36\uFB38-\uFB3C\uFB3E\uFB40\uFB41\uFB43\uFB44\uFB46-\uFBB1\uFBD3-\uFD3D\uFD50-\uFD8F\uFD92-\uFDC7\uFDF0-\uFDFB\uFE70-\uFE72\uFE74\uFE76-\uFEFC]/, getDirection: function() {
          var r, i, a, o;
          return i = n.makeElement("input", { dir: "auto", name: "x", dirName: "x.dir" }), r = n.makeElement("form"), r.appendChild(i), a = function() {
            try {
              return new FormData(r).has(i.dirName);
            } catch {
            }
          }(), o = function() {
            try {
              return i.matches(":dir(ltr),:dir(rtl)");
            } catch {
            }
          }(), a ? function(s) {
            return i.value = s, new FormData(r).get(i.dirName);
          } : o ? function(s) {
            return i.value = s, i.matches(":dir(rtl)") ? "rtl" : "ltr";
          } : function(s) {
            var l;
            return l = s.trim().charAt(0), n.RTL_PATTERN.test(l) ? "rtl" : "ltr";
          };
        }() });
      }).call(this), (function() {
      }).call(this), (function() {
        var r, i = function(o, s) {
          function l() {
            this.constructor = o;
          }
          for (var u in s) a.call(s, u) && (o[u] = s[u]);
          return l.prototype = s.prototype, o.prototype = new l(), o.__super__ = s.prototype, o;
        }, a = {}.hasOwnProperty;
        r = n.arraysAreEqual, n.Hash = function(o) {
          function s(h) {
            h == null && (h = {}), this.values = u(h), s.__super__.constructor.apply(this, arguments);
          }
          var l, u, c, d, f;
          return i(s, o), s.fromCommonAttributesOfObjects = function(h) {
            var m, v, b, y, g, E;
            if (h == null && (h = []), !h.length) return new this();
            for (m = l(h[0]), b = m.getKeys(), E = h.slice(1), v = 0, y = E.length; y > v; v++) g = E[v], b = m.getKeysCommonToHash(l(g)), m = m.slice(b);
            return m;
          }, s.box = function(h) {
            return l(h);
          }, s.prototype.add = function(h, m) {
            return this.merge(d(h, m));
          }, s.prototype.remove = function(h) {
            return new n.Hash(u(this.values, h));
          }, s.prototype.get = function(h) {
            return this.values[h];
          }, s.prototype.has = function(h) {
            return h in this.values;
          }, s.prototype.merge = function(h) {
            return new n.Hash(c(this.values, f(h)));
          }, s.prototype.slice = function(h) {
            var m, v, b, y;
            for (y = {}, m = 0, b = h.length; b > m; m++) v = h[m], this.has(v) && (y[v] = this.values[v]);
            return new n.Hash(y);
          }, s.prototype.getKeys = function() {
            return Object.keys(this.values);
          }, s.prototype.getKeysCommonToHash = function(h) {
            var m, v, b, y, g;
            for (h = l(h), y = this.getKeys(), g = [], m = 0, b = y.length; b > m; m++) v = y[m], this.values[v] === h.values[v] && g.push(v);
            return g;
          }, s.prototype.isEqualTo = function(h) {
            return r(this.toArray(), l(h).toArray());
          }, s.prototype.isEmpty = function() {
            return this.getKeys().length === 0;
          }, s.prototype.toArray = function() {
            var h, m, v;
            return (this.array != null ? this.array : this.array = (function() {
              var b;
              m = [], b = this.values;
              for (h in b) v = b[h], m.push(h, v);
              return m;
            }).call(this)).slice(0);
          }, s.prototype.toObject = function() {
            return u(this.values);
          }, s.prototype.toJSON = function() {
            return this.toObject();
          }, s.prototype.contentsForInspection = function() {
            return { values: JSON.stringify(this.values) };
          }, d = function(h, m) {
            var v;
            return v = {}, v[h] = m, v;
          }, c = function(h, m) {
            var v, b, y;
            b = u(h);
            for (v in m) y = m[v], b[v] = y;
            return b;
          }, u = function(h, m) {
            var v, b, y, g, E;
            for (g = {}, E = Object.keys(h).sort(), v = 0, y = E.length; y > v; v++) b = E[v], b !== m && (g[b] = h[b]);
            return g;
          }, l = function(h) {
            return h instanceof n.Hash ? h : new n.Hash(h);
          }, f = function(h) {
            return h instanceof n.Hash ? h.values : h;
          }, s;
        }(n.Object);
      }).call(this), (function() {
        n.ObjectGroup = function() {
          function r(i, a) {
            var o, s;
            this.objects = i ?? [], s = a.depth, o = a.asTree, o && (this.depth = s, this.objects = this.constructor.groupObjects(this.objects, { asTree: o, depth: this.depth + 1 }));
          }
          return r.groupObjects = function(i, a) {
            var o, s, l, u, c, d, f, h, m;
            for (i == null && (i = []), m = a ?? {}, l = m.depth, o = m.asTree, o && l == null && (l = 0), h = [], c = 0, d = i.length; d > c; c++) {
              if (f = i[c], u) {
                if (typeof f.canBeGrouped == "function" && f.canBeGrouped(l) && (typeof (s = u[u.length - 1]).canBeGroupedWith == "function" && s.canBeGroupedWith(f, l))) {
                  u.push(f);
                  continue;
                }
                h.push(new this(u, { depth: l, asTree: o })), u = null;
              }
              typeof f.canBeGrouped == "function" && f.canBeGrouped(l) ? u = [f] : h.push(f);
            }
            return u && h.push(new this(u, { depth: l, asTree: o })), h;
          }, r.prototype.getObjects = function() {
            return this.objects;
          }, r.prototype.getDepth = function() {
            return this.depth;
          }, r.prototype.getCacheKey = function() {
            var i, a, o, s, l;
            for (a = ["objectGroup"], l = this.getObjects(), i = 0, o = l.length; o > i; i++) s = l[i], a.push(s.getCacheKey());
            return a.join("/");
          }, r;
        }();
      }).call(this), (function() {
        var r = function(a, o) {
          function s() {
            this.constructor = a;
          }
          for (var l in o) i.call(o, l) && (a[l] = o[l]);
          return s.prototype = o.prototype, a.prototype = new s(), a.__super__ = o.prototype, a;
        }, i = {}.hasOwnProperty;
        n.ObjectMap = function(a) {
          function o(s) {
            var l, u, c, d, f;
            for (s == null && (s = []), this.objects = {}, c = 0, d = s.length; d > c; c++) f = s[c], u = JSON.stringify(f), (l = this.objects)[u] == null && (l[u] = f);
          }
          return r(o, a), o.prototype.find = function(s) {
            var l;
            return l = JSON.stringify(s), this.objects[l];
          }, o;
        }(n.BasicObject);
      }).call(this), (function() {
        n.ElementStore = function() {
          function r(a) {
            this.reset(a);
          }
          var i;
          return r.prototype.add = function(a) {
            var o;
            return o = i(a), this.elements[o] = a;
          }, r.prototype.remove = function(a) {
            var o, s;
            return o = i(a), (s = this.elements[o]) ? (delete this.elements[o], s) : void 0;
          }, r.prototype.reset = function(a) {
            var o, s, l;
            for (a == null && (a = []), this.elements = {}, s = 0, l = a.length; l > s; s++) o = a[s], this.add(o);
            return a;
          }, i = function(a) {
            return a.dataset.trixStoreKey;
          }, r;
        }();
      }).call(this), (function() {
      }).call(this), (function() {
        var r = function(a, o) {
          function s() {
            this.constructor = a;
          }
          for (var l in o) i.call(o, l) && (a[l] = o[l]);
          return s.prototype = o.prototype, a.prototype = new s(), a.__super__ = o.prototype, a;
        }, i = {}.hasOwnProperty;
        n.Operation = function(a) {
          function o() {
            return o.__super__.constructor.apply(this, arguments);
          }
          return r(o, a), o.prototype.isPerforming = function() {
            return this.performing === !0;
          }, o.prototype.hasPerformed = function() {
            return this.performed === !0;
          }, o.prototype.hasSucceeded = function() {
            return this.performed && this.succeeded;
          }, o.prototype.hasFailed = function() {
            return this.performed && !this.succeeded;
          }, o.prototype.getPromise = function() {
            return this.promise != null ? this.promise : this.promise = new Promise(/* @__PURE__ */ function(s) {
              return function(l, u) {
                return s.performing = !0, s.perform(function(c, d) {
                  return s.succeeded = c, s.performing = !1, s.performed = !0, s.succeeded ? l(d) : u(d);
                });
              };
            }(this));
          }, o.prototype.perform = function(s) {
            return s(!1);
          }, o.prototype.release = function() {
            var s;
            return (s = this.promise) != null && typeof s.cancel == "function" && s.cancel(), this.promise = null, this.performing = null, this.performed = null, this.succeeded = null;
          }, o.proxyMethod("getPromise().then"), o.proxyMethod("getPromise().catch"), o;
        }(n.BasicObject);
      }).call(this), (function() {
        var r, i, a, o, s, l = function(c, d) {
          function f() {
            this.constructor = c;
          }
          for (var h in d) u.call(d, h) && (c[h] = d[h]);
          return f.prototype = d.prototype, c.prototype = new f(), c.__super__ = d.prototype, c;
        }, u = {}.hasOwnProperty;
        n.UTF16String = function(c) {
          function d(f, h) {
            this.ucs2String = f, this.codepoints = h, this.length = this.codepoints.length, this.ucs2Length = this.ucs2String.length;
          }
          return l(d, c), d.box = function(f) {
            return f == null && (f = ""), f instanceof this ? f : this.fromUCS2String(f != null ? f.toString() : void 0);
          }, d.fromUCS2String = function(f) {
            return new this(f, o(f));
          }, d.fromCodepoints = function(f) {
            return new this(s(f), f);
          }, d.prototype.offsetToUCS2Offset = function(f) {
            return s(this.codepoints.slice(0, Math.max(0, f))).length;
          }, d.prototype.offsetFromUCS2Offset = function(f) {
            return o(this.ucs2String.slice(0, Math.max(0, f))).length;
          }, d.prototype.slice = function() {
            var f;
            return this.constructor.fromCodepoints((f = this.codepoints).slice.apply(f, arguments));
          }, d.prototype.charAt = function(f) {
            return this.slice(f, f + 1);
          }, d.prototype.isEqualTo = function(f) {
            return this.constructor.box(f).ucs2String === this.ucs2String;
          }, d.prototype.toJSON = function() {
            return this.ucs2String;
          }, d.prototype.getCacheKey = function() {
            return this.ucs2String;
          }, d.prototype.toString = function() {
            return this.ucs2String;
          }, d;
        }(n.BasicObject), r = (typeof Array.from == "function" ? Array.from("👼").length : void 0) === 1, i = (typeof " ".codePointAt == "function" ? " ".codePointAt(0) : void 0) != null, a = (typeof String.fromCodePoint == "function" ? String.fromCodePoint(32, 128124) : void 0) === " 👼", o = r && i ? function(c) {
          return Array.from(c).map(function(d) {
            return d.codePointAt(0);
          });
        } : function(c) {
          var d, f, h, m, v;
          for (m = [], d = 0, h = c.length; h > d; ) v = c.charCodeAt(d++), v >= 55296 && 56319 >= v && h > d && (f = c.charCodeAt(d++), (64512 & f) === 56320 ? v = ((1023 & v) << 10) + (1023 & f) + 65536 : d--), m.push(v);
          return m;
        }, s = a ? function(c) {
          return String.fromCodePoint.apply(String, c);
        } : function(c) {
          var d, f, h;
          return d = function() {
            var m, v, b;
            for (b = [], m = 0, v = c.length; v > m; m++) h = c[m], f = "", h > 65535 && (h -= 65536, f += String.fromCharCode(h >>> 10 & 1023 | 55296), h = 56320 | 1023 & h), b.push(f + String.fromCharCode(h));
            return b;
          }(), d.join("");
        };
      }).call(this), (function() {
      }).call(this), (function() {
      }).call(this), (function() {
        n.config.lang = { attachFiles: "Attach Files", bold: "Bold", bullets: "Bullets", byte: "Byte", bytes: "Bytes", captionPlaceholder: "Add a caption…", code: "Code", heading1: "Heading", indent: "Increase Level", italic: "Italic", link: "Link", numbers: "Numbers", outdent: "Decrease Level", quote: "Quote", redo: "Redo", remove: "Remove", strike: "Strikethrough", undo: "Undo", unlink: "Unlink", url: "URL", urlPlaceholder: "Enter a URL…", GB: "GB", KB: "KB", MB: "MB", PB: "PB", TB: "TB" };
      }).call(this), (function() {
        n.config.css = { attachment: "attachment", attachmentCaption: "attachment__caption", attachmentCaptionEditor: "attachment__caption-editor", attachmentMetadata: "attachment__metadata", attachmentMetadataContainer: "attachment__metadata-container", attachmentName: "attachment__name", attachmentProgress: "attachment__progress", attachmentSize: "attachment__size", attachmentToolbar: "attachment__toolbar", attachmentGallery: "attachment-gallery" };
      }).call(this), (function() {
        var r;
        n.config.blockAttributes = r = { default: { tagName: "div", parse: !1 }, quote: { tagName: "blockquote", nestable: !0 }, heading1: { tagName: "h1", terminal: !0, breakOnReturn: !0, group: !1 }, code: { tagName: "pre", terminal: !0, text: { plaintext: !0 } }, bulletList: { tagName: "ul", parse: !1 }, bullet: { tagName: "li", listAttribute: "bulletList", group: !1, nestable: !0, test: function(i) {
          return n.tagName(i.parentNode) === r[this.listAttribute].tagName;
        } }, numberList: { tagName: "ol", parse: !1 }, number: { tagName: "li", listAttribute: "numberList", group: !1, nestable: !0, test: function(i) {
          return n.tagName(i.parentNode) === r[this.listAttribute].tagName;
        } }, attachmentGallery: { tagName: "div", exclusive: !0, terminal: !0, parse: !1, group: !1 } };
      }).call(this), (function() {
        var r, i;
        r = n.config.lang, i = [r.bytes, r.KB, r.MB, r.GB, r.TB, r.PB], n.config.fileSize = { prefix: "IEC", precision: 2, formatter: function(a) {
          var o, s, l, u, c;
          switch (a) {
            case 0:
              return "0 " + r.bytes;
            case 1:
              return "1 " + r.byte;
            default:
              return o = (function() {
                switch (this.prefix) {
                  case "SI":
                    return 1e3;
                  case "IEC":
                    return 1024;
                }
              }).call(this), s = Math.floor(Math.log(a) / Math.log(o)), l = a / Math.pow(o, s), u = l.toFixed(this.precision), c = u.replace(/0*$/, "").replace(/\.$/, ""), c + " " + i[s];
          }
        } };
      }).call(this), (function() {
        n.config.textAttributes = { bold: { tagName: "strong", inheritable: !0, parser: function(r) {
          var i;
          return i = window.getComputedStyle(r), i.fontWeight === "bold" || i.fontWeight >= 600;
        } }, italic: { tagName: "em", inheritable: !0, parser: function(r) {
          var i;
          return i = window.getComputedStyle(r), i.fontStyle === "italic";
        } }, href: { groupTagName: "a", parser: function(r) {
          var i, a, o;
          return i = n.AttachmentView.attachmentSelector, o = "a:not(" + i + ")", (a = n.findClosestElementFromNode(r, { matchingSelector: o })) ? a.getAttribute("href") : void 0;
        } }, strike: { tagName: "del", inheritable: !0 }, frozen: { style: { backgroundColor: "highlight" } } };
      }).call(this), (function() {
        var r, i, a, o, s;
        s = "[data-trix-serialize=false]", o = ["contenteditable", "data-trix-id", "data-trix-store-key", "data-trix-mutable", "data-trix-placeholder", "tabindex"], i = "data-trix-serialized-attributes", a = "[" + i + "]", r = new RegExp("<!--block-->", "g"), n.extend({ serializers: { "application/json": function(l) {
          var u;
          if (l instanceof n.Document) u = l;
          else {
            if (!(l instanceof HTMLElement)) throw new Error("unserializable object");
            u = n.Document.fromHTML(l.innerHTML);
          }
          return u.toSerializableDocument().toJSONString();
        }, "text/html": function(l) {
          var u, c, d, f, h, m, v, b, y, g, E, S, C, T, O, R, D;
          if (l instanceof n.Document) f = n.DocumentView.render(l);
          else {
            if (!(l instanceof HTMLElement)) throw new Error("unserializable object");
            f = l.cloneNode(!0);
          }
          for (T = f.querySelectorAll(s), h = 0, y = T.length; y > h; h++) d = T[h], n.removeNode(d);
          for (m = 0, g = o.length; g > m; m++) for (u = o[m], O = f.querySelectorAll("[" + u + "]"), v = 0, E = O.length; E > v; v++) d = O[v], d.removeAttribute(u);
          for (R = f.querySelectorAll(a), b = 0, S = R.length; S > b; b++) {
            d = R[b];
            try {
              c = JSON.parse(d.getAttribute(i)), d.removeAttribute(i);
              for (C in c) D = c[C], d.setAttribute(C, D);
            } catch {
            }
          }
          return f.innerHTML.replace(r, "");
        } }, deserializers: { "application/json": function(l) {
          return n.Document.fromJSONString(l);
        }, "text/html": function(l) {
          return n.Document.fromHTML(l);
        } }, serializeToContentType: function(l, u) {
          var c;
          if (c = n.serializers[u]) return c(l);
          throw new Error("unknown content type: " + u);
        }, deserializeFromContentType: function(l, u) {
          var c;
          if (c = n.deserializers[u]) return c(l);
          throw new Error("unknown content type: " + u);
        } });
      }).call(this), (function() {
        var r;
        r = n.config.lang, n.config.toolbar = { getDefaultHTML: function() {
          return `<div class="trix-button-row">
  <span class="trix-button-group trix-button-group--text-tools" data-trix-button-group="text-tools">
    <button type="button" class="trix-button trix-button--icon trix-button--icon-bold" data-trix-attribute="bold" data-trix-key="b" title="` + r.bold + '" tabindex="-1">' + r.bold + `</button>
    <button type="button" class="trix-button trix-button--icon trix-button--icon-italic" data-trix-attribute="italic" data-trix-key="i" title="` + r.italic + '" tabindex="-1">' + r.italic + `</button>
    <button type="button" class="trix-button trix-button--icon trix-button--icon-strike" data-trix-attribute="strike" title="` + r.strike + '" tabindex="-1">' + r.strike + `</button>
    <button type="button" class="trix-button trix-button--icon trix-button--icon-link" data-trix-attribute="href" data-trix-action="link" data-trix-key="k" title="` + r.link + '" tabindex="-1">' + r.link + `</button>
  </span>

  <span class="trix-button-group trix-button-group--block-tools" data-trix-button-group="block-tools">
    <button type="button" class="trix-button trix-button--icon trix-button--icon-heading-1" data-trix-attribute="heading1" title="` + r.heading1 + '" tabindex="-1">' + r.heading1 + `</button>
    <button type="button" class="trix-button trix-button--icon trix-button--icon-quote" data-trix-attribute="quote" title="` + r.quote + '" tabindex="-1">' + r.quote + `</button>
    <button type="button" class="trix-button trix-button--icon trix-button--icon-code" data-trix-attribute="code" title="` + r.code + '" tabindex="-1">' + r.code + `</button>
    <button type="button" class="trix-button trix-button--icon trix-button--icon-bullet-list" data-trix-attribute="bullet" title="` + r.bullets + '" tabindex="-1">' + r.bullets + `</button>
    <button type="button" class="trix-button trix-button--icon trix-button--icon-number-list" data-trix-attribute="number" title="` + r.numbers + '" tabindex="-1">' + r.numbers + `</button>
    <button type="button" class="trix-button trix-button--icon trix-button--icon-decrease-nesting-level" data-trix-action="decreaseNestingLevel" title="` + r.outdent + '" tabindex="-1">' + r.outdent + `</button>
    <button type="button" class="trix-button trix-button--icon trix-button--icon-increase-nesting-level" data-trix-action="increaseNestingLevel" title="` + r.indent + '" tabindex="-1">' + r.indent + `</button>
  </span>

  <span class="trix-button-group trix-button-group--file-tools" data-trix-button-group="file-tools">
    <button type="button" class="trix-button trix-button--icon trix-button--icon-attach" data-trix-action="attachFiles" title="` + r.attachFiles + '" tabindex="-1">' + r.attachFiles + `</button>
  </span>

  <span class="trix-button-group-spacer"></span>

  <span class="trix-button-group trix-button-group--history-tools" data-trix-button-group="history-tools">
    <button type="button" class="trix-button trix-button--icon trix-button--icon-undo" data-trix-action="undo" data-trix-key="z" title="` + r.undo + '" tabindex="-1">' + r.undo + `</button>
    <button type="button" class="trix-button trix-button--icon trix-button--icon-redo" data-trix-action="redo" data-trix-key="shift+z" title="` + r.redo + '" tabindex="-1">' + r.redo + `</button>
  </span>
</div>

<div class="trix-dialogs" data-trix-dialogs>
  <div class="trix-dialog trix-dialog--link" data-trix-dialog="href" data-trix-dialog-attribute="href">
    <div class="trix-dialog__link-fields">
      <input type="url" name="href" class="trix-input trix-input--dialog" placeholder="` + r.urlPlaceholder + '" aria-label="' + r.url + `" required data-trix-input>
      <div class="trix-button-group">
        <input type="button" class="trix-button trix-button--dialog" value="` + r.link + `" data-trix-method="setAttribute">
        <input type="button" class="trix-button trix-button--dialog" value="` + r.unlink + `" data-trix-method="removeAttribute">
      </div>
    </div>
  </div>
</div>`;
        } };
      }).call(this), (function() {
        n.config.undoInterval = 5e3;
      }).call(this), (function() {
        n.config.attachments = { preview: { presentation: "gallery", caption: { name: !0, size: !0 } }, file: { caption: { size: !0 } } };
      }).call(this), (function() {
        n.config.keyNames = { 8: "backspace", 9: "tab", 13: "return", 27: "escape", 37: "left", 39: "right", 46: "delete", 68: "d", 72: "h", 79: "o" };
      }).call(this), (function() {
        n.config.input = { level2Enabled: !0, getLevel: function() {
          return this.level2Enabled && n.browser.supportsInputEvents ? 2 : 0;
        }, pickFiles: function(r) {
          var i;
          return i = n.makeElement("input", { type: "file", multiple: !0, hidden: !0, id: this.fileInputId }), i.addEventListener("change", function() {
            return r(i.files), n.removeNode(i);
          }), n.removeNode(document.getElementById(this.fileInputId)), document.body.appendChild(i), i.click();
        }, fileInputId: "trix-file-input-" + Date.now().toString(16) };
      }).call(this), (function() {
      }).call(this), (function() {
        n.registerElement("trix-toolbar", { defaultCSS: `%t {
  display: block;
}

%t {
  white-space: nowrap;
}

%t [data-trix-dialog] {
  display: none;
}

%t [data-trix-dialog][data-trix-active] {
  display: block;
}

%t [data-trix-dialog] [data-trix-validate]:invalid {
  background-color: #ffdddd;
}`, initialize: function() {
          return this.innerHTML === "" ? this.innerHTML = n.config.toolbar.getDefaultHTML() : void 0;
        } });
      }).call(this), (function() {
        var r = function(o, s) {
          function l() {
            this.constructor = o;
          }
          for (var u in s) i.call(s, u) && (o[u] = s[u]);
          return l.prototype = s.prototype, o.prototype = new l(), o.__super__ = s.prototype, o;
        }, i = {}.hasOwnProperty, a = [].indexOf || function(o) {
          for (var s = 0, l = this.length; l > s; s++) if (s in this && this[s] === o) return s;
          return -1;
        };
        n.ObjectView = function(o) {
          function s(l, u) {
            this.object = l, this.options = u ?? {}, this.childViews = [], this.rootView = this;
          }
          return r(s, o), s.prototype.getNodes = function() {
            var l, u, c, d, f;
            for (this.nodes == null && (this.nodes = this.createNodes()), d = this.nodes, f = [], l = 0, u = d.length; u > l; l++) c = d[l], f.push(c.cloneNode(!0));
            return f;
          }, s.prototype.invalidate = function() {
            var l;
            return this.nodes = null, this.childViews = [], (l = this.parentView) != null ? l.invalidate() : void 0;
          }, s.prototype.invalidateViewForObject = function(l) {
            var u;
            return (u = this.findViewForObject(l)) != null ? u.invalidate() : void 0;
          }, s.prototype.findOrCreateCachedChildView = function(l, u) {
            var c;
            return (c = this.getCachedViewForObject(u)) ? this.recordChildView(c) : (c = this.createChildView.apply(this, arguments), this.cacheViewForObject(c, u)), c;
          }, s.prototype.createChildView = function(l, u, c) {
            var d;
            return c == null && (c = {}), u instanceof n.ObjectGroup && (c.viewClass = l, l = n.ObjectGroupView), d = new l(u, c), this.recordChildView(d);
          }, s.prototype.recordChildView = function(l) {
            return l.parentView = this, l.rootView = this.rootView, this.childViews.push(l), l;
          }, s.prototype.getAllChildViews = function() {
            var l, u, c, d, f;
            for (f = [], d = this.childViews, u = 0, c = d.length; c > u; u++) l = d[u], f.push(l), f = f.concat(l.getAllChildViews());
            return f;
          }, s.prototype.findElement = function() {
            return this.findElementForObject(this.object);
          }, s.prototype.findElementForObject = function(l) {
            var u;
            return (u = l != null ? l.id : void 0) ? this.rootView.element.querySelector("[data-trix-id='" + u + "']") : void 0;
          }, s.prototype.findViewForObject = function(l) {
            var u, c, d, f;
            for (d = this.getAllChildViews(), u = 0, c = d.length; c > u; u++) if (f = d[u], f.object === l) return f;
          }, s.prototype.getViewCache = function() {
            return this.rootView !== this ? this.rootView.getViewCache() : this.isViewCachingEnabled() ? this.viewCache != null ? this.viewCache : this.viewCache = {} : void 0;
          }, s.prototype.isViewCachingEnabled = function() {
            return this.shouldCacheViews !== !1;
          }, s.prototype.enableViewCaching = function() {
            return this.shouldCacheViews = !0;
          }, s.prototype.disableViewCaching = function() {
            return this.shouldCacheViews = !1;
          }, s.prototype.getCachedViewForObject = function(l) {
            var u;
            return (u = this.getViewCache()) != null ? u[l.getCacheKey()] : void 0;
          }, s.prototype.cacheViewForObject = function(l, u) {
            var c;
            return (c = this.getViewCache()) != null ? c[u.getCacheKey()] = l : void 0;
          }, s.prototype.garbageCollectCachedViews = function() {
            var l, u, c, d, f, h;
            if (l = this.getViewCache()) {
              h = this.getAllChildViews().concat(this), c = function() {
                var m, v, b;
                for (b = [], m = 0, v = h.length; v > m; m++) f = h[m], b.push(f.object.getCacheKey());
                return b;
              }(), d = [];
              for (u in l) a.call(c, u) < 0 && d.push(delete l[u]);
              return d;
            }
          }, s;
        }(n.BasicObject);
      }).call(this), (function() {
        var r = function(a, o) {
          function s() {
            this.constructor = a;
          }
          for (var l in o) i.call(o, l) && (a[l] = o[l]);
          return s.prototype = o.prototype, a.prototype = new s(), a.__super__ = o.prototype, a;
        }, i = {}.hasOwnProperty;
        n.ObjectGroupView = function(a) {
          function o() {
            o.__super__.constructor.apply(this, arguments), this.objectGroup = this.object, this.viewClass = this.options.viewClass, delete this.options.viewClass;
          }
          return r(o, a), o.prototype.getChildViews = function() {
            var s, l, u, c;
            if (!this.childViews.length) for (c = this.objectGroup.getObjects(), s = 0, l = c.length; l > s; s++) u = c[s], this.findOrCreateCachedChildView(this.viewClass, u, this.options);
            return this.childViews;
          }, o.prototype.createNodes = function() {
            var s, l, u, c, d, f, h, m, v;
            for (s = this.createContainerElement(), h = this.getChildViews(), l = 0, c = h.length; c > l; l++) for (v = h[l], m = v.getNodes(), u = 0, d = m.length; d > u; u++) f = m[u], s.appendChild(f);
            return [s];
          }, o.prototype.createContainerElement = function(s) {
            return s == null && (s = this.objectGroup.getDepth()), this.getChildViews()[0].createContainerElement(s);
          }, o;
        }(n.ObjectView);
      }).call(this), (function() {
        var r = function(a, o) {
          function s() {
            this.constructor = a;
          }
          for (var l in o) i.call(o, l) && (a[l] = o[l]);
          return s.prototype = o.prototype, a.prototype = new s(), a.__super__ = o.prototype, a;
        }, i = {}.hasOwnProperty;
        n.Controller = function(a) {
          function o() {
            return o.__super__.constructor.apply(this, arguments);
          }
          return r(o, a), o;
        }(n.BasicObject);
      }).call(this), (function() {
        var r, i, a, o, s, l, u = function(h, m) {
          return function() {
            return h.apply(m, arguments);
          };
        }, c = function(h, m) {
          function v() {
            this.constructor = h;
          }
          for (var b in m) d.call(m, b) && (h[b] = m[b]);
          return v.prototype = m.prototype, h.prototype = new v(), h.__super__ = m.prototype, h;
        }, d = {}.hasOwnProperty, f = [].indexOf || function(h) {
          for (var m = 0, v = this.length; v > m; m++) if (m in this && this[m] === h) return m;
          return -1;
        };
        r = n.findClosestElementFromNode, a = n.nodeIsEmptyTextNode, i = n.nodeIsBlockStartComment, o = n.normalizeSpaces, s = n.summarizeStringChange, l = n.tagName, n.MutationObserver = function(h) {
          function m(E) {
            this.element = E, this.didMutate = u(this.didMutate, this), this.observer = new window.MutationObserver(this.didMutate), this.start();
          }
          var v, b, y, g;
          return c(m, h), b = "data-trix-mutable", y = "[" + b + "]", g = { attributes: !0, childList: !0, characterData: !0, characterDataOldValue: !0, subtree: !0 }, m.prototype.start = function() {
            return this.reset(), this.observer.observe(this.element, g);
          }, m.prototype.stop = function() {
            return this.observer.disconnect();
          }, m.prototype.didMutate = function(E) {
            var S, C;
            return (S = this.mutations).push.apply(S, this.findSignificantMutations(E)), this.mutations.length ? ((C = this.delegate) != null && typeof C.elementDidMutate == "function" && C.elementDidMutate(this.getMutationSummary()), this.reset()) : void 0;
          }, m.prototype.reset = function() {
            return this.mutations = [];
          }, m.prototype.findSignificantMutations = function(E) {
            var S, C, T, O;
            for (O = [], S = 0, C = E.length; C > S; S++) T = E[S], this.mutationIsSignificant(T) && O.push(T);
            return O;
          }, m.prototype.mutationIsSignificant = function(E) {
            var S, C, T, O;
            if (this.nodeIsMutable(E.target)) return !1;
            for (O = this.nodesModifiedByMutation(E), S = 0, C = O.length; C > S; S++) if (T = O[S], this.nodeIsSignificant(T)) return !0;
            return !1;
          }, m.prototype.nodeIsSignificant = function(E) {
            return E !== this.element && !this.nodeIsMutable(E) && !a(E);
          }, m.prototype.nodeIsMutable = function(E) {
            return r(E, { matchingSelector: y });
          }, m.prototype.nodesModifiedByMutation = function(E) {
            var S;
            switch (S = [], E.type) {
              case "attributes":
                E.attributeName !== b && S.push(E.target);
                break;
              case "characterData":
                S.push(E.target.parentNode), S.push(E.target);
                break;
              case "childList":
                S.push.apply(S, E.addedNodes), S.push.apply(S, E.removedNodes);
            }
            return S;
          }, m.prototype.getMutationSummary = function() {
            return this.getTextMutationSummary();
          }, m.prototype.getTextMutationSummary = function() {
            var E, S, C, T, O, R, D, q, $, P, Y;
            for (q = this.getTextChangesFromCharacterData(), C = q.additions, O = q.deletions, Y = this.getTextChangesFromChildList(), $ = Y.additions, R = 0, D = $.length; D > R; R++) S = $[R], f.call(C, S) < 0 && C.push(S);
            return O.push.apply(O, Y.deletions), P = {}, (E = C.join("")) && (P.textAdded = E), (T = O.join("")) && (P.textDeleted = T), P;
          }, m.prototype.getMutationsByType = function(E) {
            var S, C, T, O, R;
            for (O = this.mutations, R = [], S = 0, C = O.length; C > S; S++) T = O[S], T.type === E && R.push(T);
            return R;
          }, m.prototype.getTextChangesFromChildList = function() {
            var E, S, C, T, O, R, D, q, $, P, Y;
            for (E = [], D = [], R = this.getMutationsByType("childList"), S = 0, T = R.length; T > S; S++) O = R[S], E.push.apply(E, O.addedNodes), D.push.apply(D, O.removedNodes);
            return q = E.length === 0 && D.length === 1 && i(D[0]), q ? (P = [], Y = [`
`]) : (P = v(E), Y = v(D)), { additions: function() {
              var L, x, I;
              for (I = [], C = L = 0, x = P.length; x > L; C = ++L) $ = P[C], $ !== Y[C] && I.push(o($));
              return I;
            }(), deletions: function() {
              var L, x, I;
              for (I = [], C = L = 0, x = Y.length; x > L; C = ++L) $ = Y[C], $ !== P[C] && I.push(o($));
              return I;
            }() };
          }, m.prototype.getTextChangesFromCharacterData = function() {
            var E, S, C, T, O, R, D, q;
            return S = this.getMutationsByType("characterData"), S.length && (q = S[0], C = S[S.length - 1], O = o(q.oldValue), T = o(C.target.data), R = s(O, T), E = R.added, D = R.removed), { additions: E ? [E] : [], deletions: D ? [D] : [] };
          }, v = function(E) {
            var S, C, T, O;
            for (E == null && (E = []), O = [], S = 0, C = E.length; C > S; S++) switch (T = E[S], T.nodeType) {
              case Node.TEXT_NODE:
                O.push(T.data);
                break;
              case Node.ELEMENT_NODE:
                l(T) === "br" ? O.push(`
`) : O.push.apply(O, v(T.childNodes));
            }
            return O;
          }, m;
        }(n.BasicObject);
      }).call(this), (function() {
        var r = function(a, o) {
          function s() {
            this.constructor = a;
          }
          for (var l in o) i.call(o, l) && (a[l] = o[l]);
          return s.prototype = o.prototype, a.prototype = new s(), a.__super__ = o.prototype, a;
        }, i = {}.hasOwnProperty;
        n.FileVerificationOperation = function(a) {
          function o(s) {
            this.file = s;
          }
          return r(o, a), o.prototype.perform = function(s) {
            var l;
            return l = new FileReader(), l.onerror = function() {
              return s(!1);
            }, l.onload = /* @__PURE__ */ function(u) {
              return function() {
                l.onerror = null;
                try {
                  l.abort();
                } catch {
                }
                return s(!0, u.file);
              };
            }(this), l.readAsArrayBuffer(this.file);
          }, o;
        }(n.Operation);
      }).call(this), (function() {
        var r, i, a = function(s, l) {
          function u() {
            this.constructor = s;
          }
          for (var c in l) o.call(l, c) && (s[c] = l[c]);
          return u.prototype = l.prototype, s.prototype = new u(), s.__super__ = l.prototype, s;
        }, o = {}.hasOwnProperty;
        r = n.handleEvent, i = n.innerElementIsActive, n.InputController = function(s) {
          function l(u) {
            var c;
            this.element = u, this.mutationObserver = new n.MutationObserver(this.element), this.mutationObserver.delegate = this;
            for (c in this.events) r(c, { onElement: this.element, withCallback: this.handlerFor(c) });
          }
          return a(l, s), l.prototype.events = {}, l.prototype.elementDidMutate = function() {
          }, l.prototype.editorWillSyncDocumentView = function() {
            return this.mutationObserver.stop();
          }, l.prototype.editorDidSyncDocumentView = function() {
            return this.mutationObserver.start();
          }, l.prototype.requestRender = function() {
            var u;
            return (u = this.delegate) != null && typeof u.inputControllerDidRequestRender == "function" ? u.inputControllerDidRequestRender() : void 0;
          }, l.prototype.requestReparse = function() {
            var u;
            return (u = this.delegate) != null && typeof u.inputControllerDidRequestReparse == "function" && u.inputControllerDidRequestReparse(), this.requestRender();
          }, l.prototype.attachFiles = function(u) {
            var c, d;
            return d = function() {
              var f, h, m;
              for (m = [], f = 0, h = u.length; h > f; f++) c = u[f], m.push(new n.FileVerificationOperation(c));
              return m;
            }(), Promise.all(d).then(/* @__PURE__ */ function(f) {
              return function(h) {
                return f.handleInput(function() {
                  var m, v;
                  return (m = this.delegate) != null && m.inputControllerWillAttachFiles(), (v = this.responder) != null && v.insertFiles(h), this.requestRender();
                });
              };
            }(this));
          }, l.prototype.handlerFor = function(u) {
            return /* @__PURE__ */ function(c) {
              return function(d) {
                return d.defaultPrevented ? void 0 : c.handleInput(function() {
                  return i(this.element) ? void 0 : (this.eventName = u, this.events[u].call(this, d));
                });
              };
            }(this);
          }, l.prototype.handleInput = function(u) {
            var c, d;
            try {
              return (c = this.delegate) != null && c.inputControllerWillHandleInput(), u.call(this);
            } finally {
              (d = this.delegate) != null && d.inputControllerDidHandleInput();
            }
          }, l.prototype.createLinkHTML = function(u, c) {
            var d;
            return d = document.createElement("a"), d.href = u, d.textContent = c ?? u, d.outerHTML;
          }, l;
        }(n.BasicObject);
      }).call(this), (function() {
        var r, i, a, o, s, l, u, c, d, f, h, m, v = function(g, E) {
          function S() {
            this.constructor = g;
          }
          for (var C in E) b.call(E, C) && (g[C] = E[C]);
          return S.prototype = E.prototype, g.prototype = new S(), g.__super__ = E.prototype, g;
        }, b = {}.hasOwnProperty, y = [].indexOf || function(g) {
          for (var E = 0, S = this.length; S > E; E++) if (E in this && this[E] === g) return E;
          return -1;
        };
        d = n.makeElement, f = n.objectsAreEqual, n.tagName, i = n.browser, u = n.keyEventIsKeyboardCommand, o = n.dataTransferIsWritable, a = n.dataTransferIsPlainText, c = n.config.keyNames, n.Level0InputController = function(g) {
          function E() {
            E.__super__.constructor.apply(this, arguments), this.resetInputSummary();
          }
          var S;
          return v(E, g), S = 0, E.prototype.setInputSummary = function(C) {
            var T, O;
            C == null && (C = {}), this.inputSummary.eventName = this.eventName;
            for (T in C) O = C[T], this.inputSummary[T] = O;
            return this.inputSummary;
          }, E.prototype.resetInputSummary = function() {
            return this.inputSummary = {};
          }, E.prototype.reset = function() {
            return this.resetInputSummary(), n.selectionChangeObserver.reset();
          }, E.prototype.elementDidMutate = function(C) {
            var T;
            return this.isComposing() ? (T = this.delegate) != null && typeof T.inputControllerDidAllowUnhandledInput == "function" ? T.inputControllerDidAllowUnhandledInput() : void 0 : this.handleInput(function() {
              return this.mutationIsSignificant(C) && (this.mutationIsExpected(C) ? this.requestRender() : this.requestReparse()), this.reset();
            });
          }, E.prototype.mutationIsExpected = function(C) {
            var T, O, R, D, q, $, P, Y, L, x;
            return P = C.textAdded, Y = C.textDeleted, this.inputSummary.preferDocument ? !0 : (T = P != null ? P === this.inputSummary.textAdded : !this.inputSummary.textAdded, O = Y != null ? this.inputSummary.didDelete : !this.inputSummary.didDelete, L = (P === `
` || P === ` 
`) && !T, x = Y === `
` && !O, $ = L && !x || x && !L, $ && (D = this.getSelectedRange()) && (R = L ? P.replace(/\n$/, "").length || -1 : (P != null ? P.length : void 0) || 1, (q = this.responder) != null ? q.positionIsBlockBreak(D[1] + R) : void 0) ? !0 : T && O);
          }, E.prototype.mutationIsSignificant = function(C) {
            var T, O, R;
            return R = Object.keys(C).length > 0, T = ((O = this.compositionInput) != null ? O.getEndData() : void 0) === "", R || !T;
          }, E.prototype.events = { keydown: function(C) {
            var T, O, R, D, q, $, P, Y, L;
            if (this.isComposing() || this.resetInputSummary(), this.inputSummary.didInput = !0, D = c[C.keyCode]) {
              for (O = this.keys, Y = ["ctrl", "alt", "shift", "meta"], R = 0, $ = Y.length; $ > R; R++) P = Y[R], C[P + "Key"] && (P === "ctrl" && (P = "control"), O = O != null ? O[P] : void 0);
              (O != null ? O[D] : void 0) != null && (this.setInputSummary({ keyName: D }), n.selectionChangeObserver.reset(), O[D].call(this, C));
            }
            return u(C) && (T = String.fromCharCode(C.keyCode).toLowerCase()) && (q = function() {
              var x, I, k, B;
              for (k = ["alt", "shift"], B = [], x = 0, I = k.length; I > x; x++) P = k[x], C[P + "Key"] && B.push(P);
              return B;
            }(), q.push(T), (L = this.delegate) != null ? L.inputControllerDidReceiveKeyboardCommand(q) : void 0) ? C.preventDefault() : void 0;
          }, keypress: function(C) {
            var T, O, R;
            if (this.inputSummary.eventName == null && !C.metaKey && (!C.ctrlKey || C.altKey)) return (R = m(C)) ? ((T = this.delegate) != null && T.inputControllerWillPerformTyping(), (O = this.responder) != null && O.insertString(R), this.setInputSummary({ textAdded: R, didDelete: this.selectionIsExpanded() })) : void 0;
          }, textInput: function(C) {
            var T, O, R, D;
            return T = C.data, D = this.inputSummary.textAdded, D && D !== T && D.toUpperCase() === T ? (O = this.getSelectedRange(), this.setSelectedRange([O[0], O[1] + D.length]), (R = this.responder) != null && R.insertString(T), this.setInputSummary({ textAdded: T }), this.setSelectedRange(O)) : void 0;
          }, dragenter: function(C) {
            return C.preventDefault();
          }, dragstart: function(C) {
            var T;
            return C.target, this.serializeSelectionToDataTransfer(C.dataTransfer), this.draggedRange = this.getSelectedRange(), (T = this.delegate) != null && typeof T.inputControllerDidStartDrag == "function" ? T.inputControllerDidStartDrag() : void 0;
          }, dragover: function(C) {
            var T, O;
            return !this.draggedRange && !this.canAcceptDataTransfer(C.dataTransfer) || (C.preventDefault(), T = { x: C.clientX, y: C.clientY }, f(T, this.draggingPoint)) ? void 0 : (this.draggingPoint = T, (O = this.delegate) != null && typeof O.inputControllerDidReceiveDragOverPoint == "function" ? O.inputControllerDidReceiveDragOverPoint(this.draggingPoint) : void 0);
          }, dragend: function() {
            var C;
            return (C = this.delegate) != null && typeof C.inputControllerDidCancelDrag == "function" && C.inputControllerDidCancelDrag(), this.draggedRange = null, this.draggingPoint = null;
          }, drop: function(C) {
            var T, O, R, D, q, $, P, Y, L;
            return C.preventDefault(), R = (q = C.dataTransfer) != null ? q.files : void 0, D = { x: C.clientX, y: C.clientY }, ($ = this.responder) != null && $.setLocationRangeFromPointRange(D), R != null && R.length ? this.attachFiles(R) : this.draggedRange ? ((P = this.delegate) != null && P.inputControllerWillMoveText(), (Y = this.responder) != null && Y.moveTextFromRange(this.draggedRange), this.draggedRange = null, this.requestRender()) : (O = C.dataTransfer.getData("application/x-trix-document")) && (T = n.Document.fromJSONString(O), (L = this.responder) != null && L.insertDocument(T), this.requestRender()), this.draggedRange = null, this.draggingPoint = null;
          }, cut: function(C) {
            var T, O;
            return (T = this.responder) != null && T.selectionIsExpanded() && (this.serializeSelectionToDataTransfer(C.clipboardData) && C.preventDefault(), (O = this.delegate) != null && O.inputControllerWillCutText(), this.deleteInDirection("backward"), C.defaultPrevented) ? this.requestRender() : void 0;
          }, copy: function(C) {
            var T;
            return (T = this.responder) != null && T.selectionIsExpanded() && this.serializeSelectionToDataTransfer(C.clipboardData) ? C.preventDefault() : void 0;
          }, paste: function(C) {
            var T, O, R, D, q, $, P, Y, L, x, I, k, B, W, Z, V, K, ne, Ee, oe, ae, pe, Se;
            return T = (Y = C.clipboardData) != null ? Y : C.testClipboardData, P = { clipboard: T }, T == null || h(C) ? void this.getPastedHTMLUsingHiddenElement(/* @__PURE__ */ function(Re) {
              return function(Ye) {
                var nt, ut, Tt;
                return P.type = "text/html", P.html = Ye, (nt = Re.delegate) != null && nt.inputControllerWillPaste(P), (ut = Re.responder) != null && ut.insertHTML(P.html), Re.requestRender(), (Tt = Re.delegate) != null ? Tt.inputControllerDidPaste(P) : void 0;
              };
            }(this)) : ((D = T.getData("URL")) ? (P.type = "text/html", Se = ($ = T.getData("public.url-name")) ? n.squishBreakableWhitespace($).trim() : D, P.html = this.createLinkHTML(D, Se), (L = this.delegate) != null && L.inputControllerWillPaste(P), this.setInputSummary({ textAdded: Se, didDelete: this.selectionIsExpanded() }), (Z = this.responder) != null && Z.insertHTML(P.html), this.requestRender(), (V = this.delegate) != null && V.inputControllerDidPaste(P)) : a(T) ? (P.type = "text/plain", P.string = T.getData("text/plain"), (K = this.delegate) != null && K.inputControllerWillPaste(P), this.setInputSummary({ textAdded: P.string, didDelete: this.selectionIsExpanded() }), (ne = this.responder) != null && ne.insertString(P.string), this.requestRender(), (Ee = this.delegate) != null && Ee.inputControllerDidPaste(P)) : (q = T.getData("text/html")) ? (P.type = "text/html", P.html = q, (oe = this.delegate) != null && oe.inputControllerWillPaste(P), (ae = this.responder) != null && ae.insertHTML(P.html), this.requestRender(), (pe = this.delegate) != null && pe.inputControllerDidPaste(P)) : y.call(T.types, "Files") >= 0 && (R = (x = T.items) != null && (I = x[0]) != null && typeof I.getAsFile == "function" ? I.getAsFile() : void 0) && (!R.name && (O = s(R)) && (R.name = "pasted-file-" + ++S + "." + O), P.type = "File", P.file = R, (k = this.delegate) != null && k.inputControllerWillAttachFiles(), (B = this.responder) != null && B.insertFile(P.file), this.requestRender(), (W = this.delegate) != null && W.inputControllerDidPaste(P)), C.preventDefault());
          }, compositionstart: function(C) {
            return this.getCompositionInput().start(C.data);
          }, compositionupdate: function(C) {
            return this.getCompositionInput().update(C.data);
          }, compositionend: function(C) {
            return this.getCompositionInput().end(C.data);
          }, beforeinput: function() {
            return this.inputSummary.didInput = !0;
          }, input: function(C) {
            return this.inputSummary.didInput = !0, C.stopPropagation();
          } }, E.prototype.keys = { backspace: function(C) {
            var T;
            return (T = this.delegate) != null && T.inputControllerWillPerformTyping(), this.deleteInDirection("backward", C);
          }, delete: function(C) {
            var T;
            return (T = this.delegate) != null && T.inputControllerWillPerformTyping(), this.deleteInDirection("forward", C);
          }, return: function() {
            var C, T;
            return this.setInputSummary({ preferDocument: !0 }), (C = this.delegate) != null && C.inputControllerWillPerformTyping(), (T = this.responder) != null ? T.insertLineBreak() : void 0;
          }, tab: function(C) {
            var T, O;
            return (T = this.responder) != null && T.canIncreaseNestingLevel() ? ((O = this.responder) != null && O.increaseNestingLevel(), this.requestRender(), C.preventDefault()) : void 0;
          }, left: function(C) {
            var T;
            return this.selectionIsInCursorTarget() ? (C.preventDefault(), (T = this.responder) != null ? T.moveCursorInDirection("backward") : void 0) : void 0;
          }, right: function(C) {
            var T;
            return this.selectionIsInCursorTarget() ? (C.preventDefault(), (T = this.responder) != null ? T.moveCursorInDirection("forward") : void 0) : void 0;
          }, control: { d: function(C) {
            var T;
            return (T = this.delegate) != null && T.inputControllerWillPerformTyping(), this.deleteInDirection("forward", C);
          }, h: function(C) {
            var T;
            return (T = this.delegate) != null && T.inputControllerWillPerformTyping(), this.deleteInDirection("backward", C);
          }, o: function(C) {
            var T, O;
            return C.preventDefault(), (T = this.delegate) != null && T.inputControllerWillPerformTyping(), (O = this.responder) != null && O.insertString(`
`, { updatePosition: !1 }), this.requestRender();
          } }, shift: { return: function(C) {
            var T, O;
            return (T = this.delegate) != null && T.inputControllerWillPerformTyping(), (O = this.responder) != null && O.insertString(`
`), this.requestRender(), C.preventDefault();
          }, tab: function(C) {
            var T, O;
            return (T = this.responder) != null && T.canDecreaseNestingLevel() ? ((O = this.responder) != null && O.decreaseNestingLevel(), this.requestRender(), C.preventDefault()) : void 0;
          }, left: function(C) {
            return this.selectionIsInCursorTarget() ? (C.preventDefault(), this.expandSelectionInDirection("backward")) : void 0;
          }, right: function(C) {
            return this.selectionIsInCursorTarget() ? (C.preventDefault(), this.expandSelectionInDirection("forward")) : void 0;
          } }, alt: { backspace: function() {
            var C;
            return this.setInputSummary({ preferDocument: !1 }), (C = this.delegate) != null ? C.inputControllerWillPerformTyping() : void 0;
          } }, meta: { backspace: function() {
            var C;
            return this.setInputSummary({ preferDocument: !1 }), (C = this.delegate) != null ? C.inputControllerWillPerformTyping() : void 0;
          } } }, E.prototype.getCompositionInput = function() {
            return this.isComposing() ? this.compositionInput : this.compositionInput = new r(this);
          }, E.prototype.isComposing = function() {
            return this.compositionInput != null && !this.compositionInput.isEnded();
          }, E.prototype.deleteInDirection = function(C, T) {
            var O;
            return ((O = this.responder) != null ? O.deleteInDirection(C) : void 0) !== !1 ? this.setInputSummary({ didDelete: !0 }) : T ? (T.preventDefault(), this.requestRender()) : void 0;
          }, E.prototype.serializeSelectionToDataTransfer = function(C) {
            var T, O;
            if (o(C)) return T = (O = this.responder) != null ? O.getSelectedDocument().toSerializableDocument() : void 0, C.setData("application/x-trix-document", JSON.stringify(T)), C.setData("text/html", n.DocumentView.render(T).innerHTML), C.setData("text/plain", T.toString().replace(/\n$/, "")), !0;
          }, E.prototype.canAcceptDataTransfer = function(C) {
            var T, O, R, D, q, $;
            for ($ = {}, D = (R = C != null ? C.types : void 0) != null ? R : [], T = 0, O = D.length; O > T; T++) q = D[T], $[q] = !0;
            return $.Files || $["application/x-trix-document"] || $["text/html"] || $["text/plain"];
          }, E.prototype.getPastedHTMLUsingHiddenElement = function(C) {
            var T, O, R;
            return O = this.getSelectedRange(), R = { position: "absolute", left: window.pageXOffset + "px", top: window.pageYOffset + "px", opacity: 0 }, T = d({ style: R, tagName: "div", editable: !0 }), document.body.appendChild(T), T.focus(), requestAnimationFrame(/* @__PURE__ */ function(D) {
              return function() {
                var q;
                return q = T.innerHTML, n.removeNode(T), D.setSelectedRange(O), C(q);
              };
            }(this));
          }, E.proxyMethod("responder?.getSelectedRange"), E.proxyMethod("responder?.setSelectedRange"), E.proxyMethod("responder?.expandSelectionInDirection"), E.proxyMethod("responder?.selectionIsInCursorTarget"), E.proxyMethod("responder?.selectionIsExpanded"), E;
        }(n.InputController), s = function(g) {
          var E, S;
          return (E = g.type) != null && (S = E.match(/\/(\w+)$/)) != null ? S[1] : void 0;
        }, l = (typeof " ".codePointAt == "function" ? " ".codePointAt(0) : void 0) != null, m = function(g) {
          var E;
          return g.key && l && g.key.codePointAt(0) === g.keyCode ? g.key : (g.which === null ? E = g.keyCode : g.which !== 0 && g.charCode !== 0 && (E = g.charCode), E != null && c[E] !== "escape" ? n.UTF16String.fromCodepoints([E]).toString() : void 0);
        }, h = function(g) {
          var E, S, C, T, O, R, D, q, $;
          if (D = g.clipboardData) {
            if (y.call(D.types, "text/html") >= 0) {
              for (q = D.types, C = 0, R = q.length; R > C; C++) if ($ = q[C], E = /^CorePasteboardFlavorType/.test($), S = /^dyn\./.test($) && D.getData($), E || S) return !0;
              return !1;
            }
            return T = y.call(D.types, "com.apple.webarchive") >= 0, O = y.call(D.types, "com.apple.flat-rtfd") >= 0, T || O;
          }
        }, r = function(g) {
          function E(S) {
            var C;
            this.inputController = S, C = this.inputController, this.responder = C.responder, this.delegate = C.delegate, this.inputSummary = C.inputSummary, this.data = {};
          }
          return v(E, g), E.prototype.start = function(S) {
            var C, T;
            return this.data.start = S, this.isSignificant() ? (this.inputSummary.eventName === "keypress" && this.inputSummary.textAdded && (C = this.responder) != null && C.deleteInDirection("left"), this.selectionIsExpanded() || (this.insertPlaceholder(), this.requestRender()), this.range = (T = this.responder) != null ? T.getSelectedRange() : void 0) : void 0;
          }, E.prototype.update = function(S) {
            var C;
            return this.data.update = S, this.isSignificant() && (C = this.selectPlaceholder()) ? (this.forgetPlaceholder(), this.range = C) : void 0;
          }, E.prototype.end = function(S) {
            var C, T, O, R;
            return this.data.end = S, this.isSignificant() ? (this.forgetPlaceholder(), this.canApplyToDocument() ? (this.setInputSummary({ preferDocument: !0, didInput: !1 }), (C = this.delegate) != null && C.inputControllerWillPerformTyping(), (T = this.responder) != null && T.setSelectedRange(this.range), (O = this.responder) != null && O.insertString(this.data.end), (R = this.responder) != null ? R.setSelectedRange(this.range[0] + this.data.end.length) : void 0) : this.data.start != null || this.data.update != null ? (this.requestReparse(), this.inputController.reset()) : void 0) : this.inputController.reset();
          }, E.prototype.getEndData = function() {
            return this.data.end;
          }, E.prototype.isEnded = function() {
            return this.getEndData() != null;
          }, E.prototype.isSignificant = function() {
            return i.composesExistingText ? this.inputSummary.didInput : !0;
          }, E.prototype.canApplyToDocument = function() {
            var S, C;
            return ((S = this.data.start) != null ? S.length : void 0) === 0 && ((C = this.data.end) != null ? C.length : void 0) > 0 && this.range != null;
          }, E.proxyMethod("inputController.setInputSummary"), E.proxyMethod("inputController.requestRender"), E.proxyMethod("inputController.requestReparse"), E.proxyMethod("responder?.selectionIsExpanded"), E.proxyMethod("responder?.insertPlaceholder"), E.proxyMethod("responder?.selectPlaceholder"), E.proxyMethod("responder?.forgetPlaceholder"), E;
        }(n.BasicObject);
      }).call(this), (function() {
        var r, i, a, o = function(c, d) {
          return function() {
            return c.apply(d, arguments);
          };
        }, s = function(c, d) {
          function f() {
            this.constructor = c;
          }
          for (var h in d) l.call(d, h) && (c[h] = d[h]);
          return f.prototype = d.prototype, c.prototype = new f(), c.__super__ = d.prototype, c;
        }, l = {}.hasOwnProperty, u = [].indexOf || function(c) {
          for (var d = 0, f = this.length; f > d; d++) if (d in this && this[d] === c) return d;
          return -1;
        };
        r = n.dataTransferIsPlainText, i = n.keyEventIsKeyboardCommand, a = n.objectsAreEqual, n.Level2InputController = function(c) {
          function d() {
            return this.render = o(this.render, this), d.__super__.constructor.apply(this, arguments);
          }
          var f, h, m, v, b, y;
          return s(d, c), d.prototype.elementDidMutate = function() {
            var g;
            return this.scheduledRender ? this.composing && (g = this.delegate) != null && typeof g.inputControllerDidAllowUnhandledInput == "function" ? g.inputControllerDidAllowUnhandledInput() : void 0 : this.reparse();
          }, d.prototype.scheduleRender = function() {
            return this.scheduledRender != null ? this.scheduledRender : this.scheduledRender = requestAnimationFrame(this.render);
          }, d.prototype.render = function() {
            var g;
            return cancelAnimationFrame(this.scheduledRender), this.scheduledRender = null, this.composing || (g = this.delegate) != null && g.render(), typeof this.afterRender == "function" && this.afterRender(), this.afterRender = null;
          }, d.prototype.reparse = function() {
            var g;
            return (g = this.delegate) != null ? g.reparse() : void 0;
          }, d.prototype.events = { keydown: function(g) {
            var E, S, C, T;
            if (i(g)) {
              if (E = h(g), (T = this.delegate) != null ? T.inputControllerDidReceiveKeyboardCommand(E) : void 0) return g.preventDefault();
            } else if (C = g.key, g.altKey && (C += "+Alt"), g.shiftKey && (C += "+Shift"), S = this.keys[C]) return this.withEvent(g, S);
          }, paste: function(g) {
            var E, S, C, T, O, R, D, q, $;
            return m(g) ? (g.preventDefault(), this.attachFiles(g.clipboardData.files)) : v(g) ? (g.preventDefault(), S = { type: "text/plain", string: g.clipboardData.getData("text/plain") }, (C = this.delegate) != null && C.inputControllerWillPaste(S), (T = this.responder) != null && T.insertString(S.string), this.render(), (O = this.delegate) != null ? O.inputControllerDidPaste(S) : void 0) : (E = (R = g.clipboardData) != null ? R.getData("URL") : void 0) ? (g.preventDefault(), S = { type: "text/html", html: this.createLinkHTML(E) }, (D = this.delegate) != null && D.inputControllerWillPaste(S), (q = this.responder) != null && q.insertHTML(S.html), this.render(), ($ = this.delegate) != null ? $.inputControllerDidPaste(S) : void 0) : void 0;
          }, beforeinput: function(g) {
            var E;
            return (E = this.inputTypes[g.inputType]) ? (this.withEvent(g, E), this.scheduleRender()) : void 0;
          }, input: function() {
            return n.selectionChangeObserver.reset();
          }, dragstart: function(g) {
            var E, S;
            return (E = this.responder) != null && E.selectionContainsAttachments() ? (g.dataTransfer.setData("application/x-trix-dragging", !0), this.dragging = { range: (S = this.responder) != null ? S.getSelectedRange() : void 0, point: b(g) }) : void 0;
          }, dragenter: function(g) {
            return f(g) ? g.preventDefault() : void 0;
          }, dragover: function(g) {
            var E, S;
            if (this.dragging) {
              if (g.preventDefault(), E = b(g), !a(E, this.dragging.point)) return this.dragging.point = E, (S = this.responder) != null ? S.setLocationRangeFromPointRange(E) : void 0;
            } else if (f(g)) return g.preventDefault();
          }, drop: function(g) {
            var E, S, C, T;
            return this.dragging ? (g.preventDefault(), (S = this.delegate) != null && S.inputControllerWillMoveText(), (C = this.responder) != null && C.moveTextFromRange(this.dragging.range), this.dragging = null, this.scheduleRender()) : f(g) ? (g.preventDefault(), E = b(g), (T = this.responder) != null && T.setLocationRangeFromPointRange(E), this.attachFiles(g.dataTransfer.files)) : void 0;
          }, dragend: function() {
            var g;
            return this.dragging ? ((g = this.responder) != null && g.setSelectedRange(this.dragging.range), this.dragging = null) : void 0;
          }, compositionend: function() {
            return this.composing ? (this.composing = !1, this.scheduleRender()) : void 0;
          } }, d.prototype.keys = { ArrowLeft: function() {
            var g, E;
            return (g = this.responder) != null && g.shouldManageMovingCursorInDirection("backward") ? (this.event.preventDefault(), (E = this.responder) != null ? E.moveCursorInDirection("backward") : void 0) : void 0;
          }, ArrowRight: function() {
            var g, E;
            return (g = this.responder) != null && g.shouldManageMovingCursorInDirection("forward") ? (this.event.preventDefault(), (E = this.responder) != null ? E.moveCursorInDirection("forward") : void 0) : void 0;
          }, Backspace: function() {
            var g, E, S;
            return (g = this.responder) != null && g.shouldManageDeletingInDirection("backward") ? (this.event.preventDefault(), (E = this.delegate) != null && E.inputControllerWillPerformTyping(), (S = this.responder) != null && S.deleteInDirection("backward"), this.render()) : void 0;
          }, Tab: function() {
            var g, E;
            return (g = this.responder) != null && g.canIncreaseNestingLevel() ? (this.event.preventDefault(), (E = this.responder) != null && E.increaseNestingLevel(), this.render()) : void 0;
          }, "Tab+Shift": function() {
            var g, E;
            return (g = this.responder) != null && g.canDecreaseNestingLevel() ? (this.event.preventDefault(), (E = this.responder) != null && E.decreaseNestingLevel(), this.render()) : void 0;
          } }, d.prototype.inputTypes = { deleteByComposition: function() {
            return this.deleteInDirection("backward", { recordUndoEntry: !1 });
          }, deleteByCut: function() {
            return this.deleteInDirection("backward");
          }, deleteByDrag: function() {
            return this.event.preventDefault(), this.withTargetDOMRange(function() {
              var g;
              return this.deleteByDragRange = (g = this.responder) != null ? g.getSelectedRange() : void 0;
            });
          }, deleteCompositionText: function() {
            return this.deleteInDirection("backward", { recordUndoEntry: !1 });
          }, deleteContent: function() {
            return this.deleteInDirection("backward");
          }, deleteContentBackward: function() {
            return this.deleteInDirection("backward");
          }, deleteContentForward: function() {
            return this.deleteInDirection("forward");
          }, deleteEntireSoftLine: function() {
            return this.deleteInDirection("forward");
          }, deleteHardLineBackward: function() {
            return this.deleteInDirection("backward");
          }, deleteHardLineForward: function() {
            return this.deleteInDirection("forward");
          }, deleteSoftLineBackward: function() {
            return this.deleteInDirection("backward");
          }, deleteSoftLineForward: function() {
            return this.deleteInDirection("forward");
          }, deleteWordBackward: function() {
            return this.deleteInDirection("backward");
          }, deleteWordForward: function() {
            return this.deleteInDirection("forward");
          }, formatBackColor: function() {
            return this.activateAttributeIfSupported("backgroundColor", this.event.data);
          }, formatBold: function() {
            return this.toggleAttributeIfSupported("bold");
          }, formatFontColor: function() {
            return this.activateAttributeIfSupported("color", this.event.data);
          }, formatFontName: function() {
            return this.activateAttributeIfSupported("font", this.event.data);
          }, formatIndent: function() {
            var g;
            return (g = this.responder) != null && g.canIncreaseNestingLevel() ? this.withTargetDOMRange(function() {
              var E;
              return (E = this.responder) != null ? E.increaseNestingLevel() : void 0;
            }) : void 0;
          }, formatItalic: function() {
            return this.toggleAttributeIfSupported("italic");
          }, formatJustifyCenter: function() {
            return this.toggleAttributeIfSupported("justifyCenter");
          }, formatJustifyFull: function() {
            return this.toggleAttributeIfSupported("justifyFull");
          }, formatJustifyLeft: function() {
            return this.toggleAttributeIfSupported("justifyLeft");
          }, formatJustifyRight: function() {
            return this.toggleAttributeIfSupported("justifyRight");
          }, formatOutdent: function() {
            var g;
            return (g = this.responder) != null && g.canDecreaseNestingLevel() ? this.withTargetDOMRange(function() {
              var E;
              return (E = this.responder) != null ? E.decreaseNestingLevel() : void 0;
            }) : void 0;
          }, formatRemove: function() {
            return this.withTargetDOMRange(function() {
              var g, E, S, C;
              C = [];
              for (g in (E = this.responder) != null ? E.getCurrentAttributes() : void 0) C.push((S = this.responder) != null ? S.removeCurrentAttribute(g) : void 0);
              return C;
            });
          }, formatSetBlockTextDirection: function() {
            return this.activateAttributeIfSupported("blockDir", this.event.data);
          }, formatSetInlineTextDirection: function() {
            return this.activateAttributeIfSupported("textDir", this.event.data);
          }, formatStrikeThrough: function() {
            return this.toggleAttributeIfSupported("strike");
          }, formatSubscript: function() {
            return this.toggleAttributeIfSupported("sub");
          }, formatSuperscript: function() {
            return this.toggleAttributeIfSupported("sup");
          }, formatUnderline: function() {
            return this.toggleAttributeIfSupported("underline");
          }, historyRedo: function() {
            var g;
            return (g = this.delegate) != null ? g.inputControllerWillPerformRedo() : void 0;
          }, historyUndo: function() {
            var g;
            return (g = this.delegate) != null ? g.inputControllerWillPerformUndo() : void 0;
          }, insertCompositionText: function() {
            return this.composing = !0, this.insertString(this.event.data);
          }, insertFromComposition: function() {
            return this.composing = !1, this.insertString(this.event.data);
          }, insertFromDrop: function() {
            var g, E;
            return (g = this.deleteByDragRange) ? (this.deleteByDragRange = null, (E = this.delegate) != null && E.inputControllerWillMoveText(), this.withTargetDOMRange(function() {
              var S;
              return (S = this.responder) != null ? S.moveTextFromRange(g) : void 0;
            })) : void 0;
          }, insertFromPaste: function() {
            var g, E, S, C, T, O, R, D, q, $, P;
            return g = this.event.dataTransfer, T = { dataTransfer: g }, (E = g.getData("URL")) ? (this.event.preventDefault(), T.type = "text/html", P = (C = g.getData("public.url-name")) ? n.squishBreakableWhitespace(C).trim() : E, T.html = this.createLinkHTML(E, P), (O = this.delegate) != null && O.inputControllerWillPaste(T), this.withTargetDOMRange(function() {
              var Y;
              return (Y = this.responder) != null ? Y.insertHTML(T.html) : void 0;
            }), this.afterRender = /* @__PURE__ */ function(Y) {
              return function() {
                var L;
                return (L = Y.delegate) != null ? L.inputControllerDidPaste(T) : void 0;
              };
            }(this)) : r(g) ? (T.type = "text/plain", T.string = g.getData("text/plain"), (R = this.delegate) != null && R.inputControllerWillPaste(T), this.withTargetDOMRange(function() {
              var Y;
              return (Y = this.responder) != null ? Y.insertString(T.string) : void 0;
            }), this.afterRender = /* @__PURE__ */ function(Y) {
              return function() {
                var L;
                return (L = Y.delegate) != null ? L.inputControllerDidPaste(T) : void 0;
              };
            }(this)) : (S = g.getData("text/html")) ? (this.event.preventDefault(), T.type = "text/html", T.html = S, (D = this.delegate) != null && D.inputControllerWillPaste(T), this.withTargetDOMRange(function() {
              var Y;
              return (Y = this.responder) != null ? Y.insertHTML(T.html) : void 0;
            }), this.afterRender = /* @__PURE__ */ function(Y) {
              return function() {
                var L;
                return (L = Y.delegate) != null ? L.inputControllerDidPaste(T) : void 0;
              };
            }(this)) : (q = g.files) != null && q.length ? (T.type = "File", T.file = g.files[0], ($ = this.delegate) != null && $.inputControllerWillPaste(T), this.withTargetDOMRange(function() {
              var Y;
              return (Y = this.responder) != null ? Y.insertFile(T.file) : void 0;
            }), this.afterRender = /* @__PURE__ */ function(Y) {
              return function() {
                var L;
                return (L = Y.delegate) != null ? L.inputControllerDidPaste(T) : void 0;
              };
            }(this)) : void 0;
          }, insertFromYank: function() {
            return this.insertString(this.event.data);
          }, insertLineBreak: function() {
            return this.insertString(`
`);
          }, insertLink: function() {
            return this.activateAttributeIfSupported("href", this.event.data);
          }, insertOrderedList: function() {
            return this.toggleAttributeIfSupported("number");
          }, insertParagraph: function() {
            var g;
            return (g = this.delegate) != null && g.inputControllerWillPerformTyping(), this.withTargetDOMRange(function() {
              var E;
              return (E = this.responder) != null ? E.insertLineBreak() : void 0;
            });
          }, insertReplacementText: function() {
            return this.insertString(this.event.dataTransfer.getData("text/plain"), { updatePosition: !1 });
          }, insertText: function() {
            var g, E;
            return this.insertString((g = this.event.data) != null ? g : (E = this.event.dataTransfer) != null ? E.getData("text/plain") : void 0);
          }, insertTranspose: function() {
            return this.insertString(this.event.data);
          }, insertUnorderedList: function() {
            return this.toggleAttributeIfSupported("bullet");
          } }, d.prototype.insertString = function(g, E) {
            var S;
            return g == null && (g = ""), (S = this.delegate) != null && S.inputControllerWillPerformTyping(), this.withTargetDOMRange(function() {
              var C;
              return (C = this.responder) != null ? C.insertString(g, E) : void 0;
            });
          }, d.prototype.toggleAttributeIfSupported = function(g) {
            var E;
            return u.call(n.getAllAttributeNames(), g) >= 0 ? ((E = this.delegate) != null && E.inputControllerWillPerformFormatting(g), this.withTargetDOMRange(function() {
              var S;
              return (S = this.responder) != null ? S.toggleCurrentAttribute(g) : void 0;
            })) : void 0;
          }, d.prototype.activateAttributeIfSupported = function(g, E) {
            var S;
            return u.call(n.getAllAttributeNames(), g) >= 0 ? ((S = this.delegate) != null && S.inputControllerWillPerformFormatting(g), this.withTargetDOMRange(function() {
              var C;
              return (C = this.responder) != null ? C.setCurrentAttribute(g, E) : void 0;
            })) : void 0;
          }, d.prototype.deleteInDirection = function(g, E) {
            var S, C, T, O;
            return T = (E ?? { recordUndoEntry: !0 }).recordUndoEntry, T && (O = this.delegate) != null && O.inputControllerWillPerformTyping(), C = /* @__PURE__ */ function(R) {
              return function() {
                var D;
                return (D = R.responder) != null ? D.deleteInDirection(g) : void 0;
              };
            }(this), (S = this.getTargetDOMRange({ minLength: 2 })) ? this.withTargetDOMRange(S, C) : C();
          }, d.prototype.withTargetDOMRange = function(g, E) {
            var S;
            return typeof g == "function" && (E = g, g = this.getTargetDOMRange()), g ? (S = this.responder) != null ? S.withTargetDOMRange(g, E.bind(this)) : void 0 : (n.selectionChangeObserver.reset(), E.call(this));
          }, d.prototype.getTargetDOMRange = function(g) {
            var E, S, C, T;
            return C = (g ?? { minLength: 0 }).minLength, (T = typeof (E = this.event).getTargetRanges == "function" ? E.getTargetRanges() : void 0) && T.length && (S = y(T[0]), C === 0 || S.toString().length >= C) ? S : void 0;
          }, y = function(g) {
            var E;
            return E = document.createRange(), E.setStart(g.startContainer, g.startOffset), E.setEnd(g.endContainer, g.endOffset), E;
          }, d.prototype.withEvent = function(g, E) {
            var S;
            this.event = g;
            try {
              S = E.call(this);
            } finally {
              this.event = null;
            }
            return S;
          }, f = function(g) {
            var E, S;
            return u.call((E = (S = g.dataTransfer) != null ? S.types : void 0) != null ? E : [], "Files") >= 0;
          }, m = function(g) {
            var E;
            return (E = g.clipboardData) ? u.call(E.types, "Files") >= 0 && E.types.length === 1 && E.files.length >= 1 : void 0;
          }, v = function(g) {
            var E;
            return (E = g.clipboardData) ? u.call(E.types, "text/plain") >= 0 && E.types.length === 1 : void 0;
          }, h = function(g) {
            var E;
            return E = [], g.altKey && E.push("alt"), g.shiftKey && E.push("shift"), E.push(g.key), E;
          }, b = function(g) {
            return { x: g.clientX, y: g.clientY };
          }, d;
        }(n.InputController);
      }).call(this), (function() {
        var r, i, a, o, s, l, u, c, d = function(m, v) {
          return function() {
            return m.apply(v, arguments);
          };
        }, f = function(m, v) {
          function b() {
            this.constructor = m;
          }
          for (var y in v) h.call(v, y) && (m[y] = v[y]);
          return b.prototype = v.prototype, m.prototype = new b(), m.__super__ = v.prototype, m;
        }, h = {}.hasOwnProperty;
        i = n.defer, a = n.handleEvent, l = n.makeElement, c = n.tagName, u = n.config, s = u.lang, r = u.css, o = u.keyNames, n.AttachmentEditorController = function(m) {
          function v(y, g, E, S) {
            this.attachmentPiece = y, this.element = g, this.container = E, this.options = S ?? {}, this.didBlurCaption = d(this.didBlurCaption, this), this.didChangeCaption = d(this.didChangeCaption, this), this.didInputCaption = d(this.didInputCaption, this), this.didKeyDownCaption = d(this.didKeyDownCaption, this), this.didClickActionButton = d(this.didClickActionButton, this), this.didClickToolbar = d(this.didClickToolbar, this), this.attachment = this.attachmentPiece.attachment, c(this.element) === "a" && (this.element = this.element.firstChild), this.install();
          }
          var b;
          return f(v, m), b = function(y) {
            return function() {
              var g;
              return g = y.apply(this, arguments), g.do(), this.undos == null && (this.undos = []), this.undos.push(g.undo);
            };
          }, v.prototype.install = function() {
            return this.makeElementMutable(), this.addToolbar(), this.attachment.isPreviewable() ? this.installCaptionEditor() : void 0;
          }, v.prototype.uninstall = function() {
            var y, g;
            for (this.savePendingCaption(); g = this.undos.pop(); ) g();
            return (y = this.delegate) != null ? y.didUninstallAttachmentEditor(this) : void 0;
          }, v.prototype.savePendingCaption = function() {
            var y, g, E;
            return this.pendingCaption != null ? (y = this.pendingCaption, this.pendingCaption = null, y ? (g = this.delegate) != null && typeof g.attachmentEditorDidRequestUpdatingAttributesForAttachment == "function" ? g.attachmentEditorDidRequestUpdatingAttributesForAttachment({ caption: y }, this.attachment) : void 0 : (E = this.delegate) != null && typeof E.attachmentEditorDidRequestRemovingAttributeForAttachment == "function" ? E.attachmentEditorDidRequestRemovingAttributeForAttachment("caption", this.attachment) : void 0) : void 0;
          }, v.prototype.makeElementMutable = b(function() {
            return { do: /* @__PURE__ */ function(y) {
              return function() {
                return y.element.dataset.trixMutable = !0;
              };
            }(this), undo: /* @__PURE__ */ function(y) {
              return function() {
                return delete y.element.dataset.trixMutable;
              };
            }(this) };
          }), v.prototype.addToolbar = b(function() {
            var y;
            return y = l({ tagName: "div", className: r.attachmentToolbar, data: { trixMutable: !0 }, childNodes: l({ tagName: "div", className: "trix-button-row", childNodes: l({ tagName: "span", className: "trix-button-group trix-button-group--actions", childNodes: l({ tagName: "button", className: "trix-button trix-button--remove", textContent: s.remove, attributes: { title: s.remove }, data: { trixAction: "remove" } }) }) }) }), this.attachment.isPreviewable() && y.appendChild(l({ tagName: "div", className: r.attachmentMetadataContainer, childNodes: l({ tagName: "span", className: r.attachmentMetadata, childNodes: [l({ tagName: "span", className: r.attachmentName, textContent: this.attachment.getFilename(), attributes: { title: this.attachment.getFilename() } }), l({ tagName: "span", className: r.attachmentSize, textContent: this.attachment.getFormattedFilesize() })] }) })), a("click", { onElement: y, withCallback: this.didClickToolbar }), a("click", { onElement: y, matchingSelector: "[data-trix-action]", withCallback: this.didClickActionButton }), { do: /* @__PURE__ */ function(g) {
              return function() {
                return g.element.appendChild(y);
              };
            }(this), undo: /* @__PURE__ */ function() {
              return function() {
                return n.removeNode(y);
              };
            }() };
          }), v.prototype.installCaptionEditor = b(function() {
            var y, g, E, S, C;
            return S = l({ tagName: "textarea", className: r.attachmentCaptionEditor, attributes: { placeholder: s.captionPlaceholder }, data: { trixMutable: !0 } }), S.value = this.attachmentPiece.getCaption(), C = S.cloneNode(), C.classList.add("trix-autoresize-clone"), C.tabIndex = -1, y = function() {
              return C.value = S.value, S.style.height = C.scrollHeight + "px";
            }, a("input", { onElement: S, withCallback: y }), a("input", { onElement: S, withCallback: this.didInputCaption }), a("keydown", { onElement: S, withCallback: this.didKeyDownCaption }), a("change", { onElement: S, withCallback: this.didChangeCaption }), a("blur", { onElement: S, withCallback: this.didBlurCaption }), E = this.element.querySelector("figcaption"), g = E.cloneNode(), { do: /* @__PURE__ */ function(T) {
              return function() {
                return E.style.display = "none", g.appendChild(S), g.appendChild(C), g.classList.add(r.attachmentCaption + "--editing"), E.parentElement.insertBefore(g, E), y(), T.options.editCaption ? i(function() {
                  return S.focus();
                }) : void 0;
              };
            }(this), undo: function() {
              return n.removeNode(g), E.style.display = null;
            } };
          }), v.prototype.didClickToolbar = function(y) {
            return y.preventDefault(), y.stopPropagation();
          }, v.prototype.didClickActionButton = function(y) {
            var g;
            switch (y.target.getAttribute("data-trix-action")) {
              case "remove":
                return (g = this.delegate) != null ? g.attachmentEditorDidRequestRemovalOfAttachment(this.attachment) : void 0;
            }
          }, v.prototype.didKeyDownCaption = function(y) {
            var g;
            return o[y.keyCode] === "return" ? (y.preventDefault(), this.savePendingCaption(), (g = this.delegate) != null && typeof g.attachmentEditorDidRequestDeselectingAttachment == "function" ? g.attachmentEditorDidRequestDeselectingAttachment(this.attachment) : void 0) : void 0;
          }, v.prototype.didInputCaption = function(y) {
            return this.pendingCaption = y.target.value.replace(/\s/g, " ").trim();
          }, v.prototype.didChangeCaption = function() {
            return this.savePendingCaption();
          }, v.prototype.didBlurCaption = function() {
            return this.savePendingCaption();
          }, v;
        }(n.BasicObject);
      }).call(this), (function() {
        var r, i, a, o = function(l, u) {
          function c() {
            this.constructor = l;
          }
          for (var d in u) s.call(u, d) && (l[d] = u[d]);
          return c.prototype = u.prototype, l.prototype = new c(), l.__super__ = u.prototype, l;
        }, s = {}.hasOwnProperty;
        a = n.makeElement, r = n.config.css, n.AttachmentView = function(l) {
          function u() {
            u.__super__.constructor.apply(this, arguments), this.attachment = this.object, this.attachment.uploadProgressDelegate = this, this.attachmentPiece = this.options.piece;
          }
          var c;
          return o(u, l), u.attachmentSelector = "[data-trix-attachment]", u.prototype.createContentNodes = function() {
            return [];
          }, u.prototype.createNodes = function() {
            var d, f, h, m, v, b, y;
            if (d = m = a({ tagName: "figure", className: this.getClassName(), data: this.getData(), editable: !1 }), (f = this.getHref()) && (m = a({ tagName: "a", editable: !1, attributes: { href: f, tabindex: -1 } }), d.appendChild(m)), this.attachment.hasContent()) m.innerHTML = this.attachment.getContent();
            else for (y = this.createContentNodes(), h = 0, v = y.length; v > h; h++) b = y[h], m.appendChild(b);
            return m.appendChild(this.createCaptionElement()), this.attachment.isPending() && (this.progressElement = a({ tagName: "progress", attributes: { class: r.attachmentProgress, value: this.attachment.getUploadProgress(), max: 100 }, data: { trixMutable: !0, trixStoreKey: ["progressElement", this.attachment.id].join("/") } }), d.appendChild(this.progressElement)), [c("left"), d, c("right")];
          }, u.prototype.createCaptionElement = function() {
            var d, f, h, m, v, b, y;
            return h = a({ tagName: "figcaption", className: r.attachmentCaption }), (d = this.attachmentPiece.getCaption()) ? (h.classList.add(r.attachmentCaption + "--edited"), h.textContent = d) : (f = this.getCaptionConfig(), f.name && (m = this.attachment.getFilename()), f.size && (b = this.attachment.getFormattedFilesize()), m && (v = a({ tagName: "span", className: r.attachmentName, textContent: m }), h.appendChild(v)), b && (m && h.appendChild(document.createTextNode(" ")), y = a({ tagName: "span", className: r.attachmentSize, textContent: b }), h.appendChild(y))), h;
          }, u.prototype.getClassName = function() {
            var d, f;
            return f = [r.attachment, r.attachment + "--" + this.attachment.getType()], (d = this.attachment.getExtension()) && f.push(r.attachment + "--" + d), f.join(" ");
          }, u.prototype.getData = function() {
            var d, f;
            return f = { trixAttachment: JSON.stringify(this.attachment), trixContentType: this.attachment.getContentType(), trixId: this.attachment.id }, d = this.attachmentPiece.attributes, d.isEmpty() || (f.trixAttributes = JSON.stringify(d)), this.attachment.isPending() && (f.trixSerialize = !1), f;
          }, u.prototype.getHref = function() {
            return i(this.attachment.getContent(), "a") ? void 0 : this.attachment.getHref();
          }, u.prototype.getCaptionConfig = function() {
            var d, f, h;
            return h = this.attachment.getType(), d = n.copyObject((f = n.config.attachments[h]) != null ? f.caption : void 0), h === "file" && (d.name = !0), d;
          }, u.prototype.findProgressElement = function() {
            var d;
            return (d = this.findElement()) != null ? d.querySelector("progress") : void 0;
          }, c = function(d) {
            return a({ tagName: "span", textContent: n.ZERO_WIDTH_SPACE, data: { trixCursorTarget: d, trixSerialize: !1 } });
          }, u.prototype.attachmentDidChangeUploadProgress = function() {
            var d, f;
            return f = this.attachment.getUploadProgress(), (d = this.findProgressElement()) != null ? d.value = f : void 0;
          }, u;
        }(n.ObjectView), i = function(l, u) {
          var c;
          return c = a("div"), c.innerHTML = l ?? "", c.querySelector(u);
        };
      }).call(this), (function() {
        var r, i = function(o, s) {
          function l() {
            this.constructor = o;
          }
          for (var u in s) a.call(s, u) && (o[u] = s[u]);
          return l.prototype = s.prototype, o.prototype = new l(), o.__super__ = s.prototype, o;
        }, a = {}.hasOwnProperty;
        r = n.makeElement, n.PreviewableAttachmentView = function(o) {
          function s() {
            s.__super__.constructor.apply(this, arguments), this.attachment.previewDelegate = this;
          }
          return i(s, o), s.prototype.createContentNodes = function() {
            return this.image = r({ tagName: "img", attributes: { src: "" }, data: { trixMutable: !0 } }), this.refresh(this.image), [this.image];
          }, s.prototype.createCaptionElement = function() {
            var l;
            return l = s.__super__.createCaptionElement.apply(this, arguments), l.textContent || l.setAttribute("data-trix-placeholder", n.config.lang.captionPlaceholder), l;
          }, s.prototype.refresh = function(l) {
            var u;
            return l == null && (l = (u = this.findElement()) != null ? u.querySelector("img") : void 0), l ? this.updateAttributesForImage(l) : void 0;
          }, s.prototype.updateAttributesForImage = function(l) {
            var u, c, d, f, h, m;
            return h = this.attachment.getURL(), c = this.attachment.getPreviewURL(), l.src = c || h, c === h ? l.removeAttribute("data-trix-serialized-attributes") : (d = JSON.stringify({ src: h }), l.setAttribute("data-trix-serialized-attributes", d)), m = this.attachment.getWidth(), u = this.attachment.getHeight(), m != null && (l.width = m), u != null && (l.height = u), f = ["imageElement", this.attachment.id, l.src, l.width, l.height].join("/"), l.dataset.trixStoreKey = f;
          }, s.prototype.attachmentDidChangeAttributes = function() {
            return this.refresh(this.image), this.refresh();
          }, s;
        }(n.AttachmentView);
      }).call(this), (function() {
        var r, i, a, o = function(l, u) {
          function c() {
            this.constructor = l;
          }
          for (var d in u) s.call(u, d) && (l[d] = u[d]);
          return c.prototype = u.prototype, l.prototype = new c(), l.__super__ = u.prototype, l;
        }, s = {}.hasOwnProperty;
        a = n.makeElement, r = n.findInnerElement, i = n.getTextConfig, n.PieceView = function(l) {
          function u() {
            var d;
            u.__super__.constructor.apply(this, arguments), this.piece = this.object, this.attributes = this.piece.getAttributes(), d = this.options, this.textConfig = d.textConfig, this.context = d.context, this.piece.attachment ? this.attachment = this.piece.attachment : this.string = this.piece.toString();
          }
          var c;
          return o(u, l), u.prototype.createNodes = function() {
            var d, f, h, m, v, b;
            if (b = this.attachment ? this.createAttachmentNodes() : this.createStringNodes(), d = this.createElement()) {
              for (h = r(d), f = 0, m = b.length; m > f; f++) v = b[f], h.appendChild(v);
              b = [d];
            }
            return b;
          }, u.prototype.createAttachmentNodes = function() {
            var d, f;
            return d = this.attachment.isPreviewable() ? n.PreviewableAttachmentView : n.AttachmentView, f = this.createChildView(d, this.piece.attachment, { piece: this.piece }), f.getNodes();
          }, u.prototype.createStringNodes = function() {
            var d, f, h, m, v, b, y, g, E;
            if ((y = this.textConfig) != null && y.plaintext) return [document.createTextNode(this.string)];
            for (b = [], g = this.string.split(`
`), h = f = 0, m = g.length; m > f; h = ++f) E = g[h], h > 0 && (d = a("br"), b.push(d)), E.length && (v = document.createTextNode(this.preserveSpaces(E)), b.push(v));
            return b;
          }, u.prototype.createElement = function() {
            var d, f, h, m, v, b, y, g, E;
            g = {}, b = this.attributes;
            for (m in b) if (E = b[m], (d = i(m)) && (d.tagName && (v = a(d.tagName), h ? (h.appendChild(v), h = v) : f = h = v), d.styleProperty && (g[d.styleProperty] = E), d.style)) {
              y = d.style;
              for (m in y) E = y[m], g[m] = E;
            }
            if (Object.keys(g).length) {
              f == null && (f = a("span"));
              for (m in g) E = g[m], f.style[m] = E;
            }
            return f;
          }, u.prototype.createContainerElement = function() {
            var d, f, h, m, v;
            m = this.attributes;
            for (h in m) if (v = m[h], (f = i(h)) && f.groupTagName) return d = {}, d[h] = v, a(f.groupTagName, d);
          }, c = n.NON_BREAKING_SPACE, u.prototype.preserveSpaces = function(d) {
            return this.context.isLast && (d = d.replace(/\ $/, c)), d = d.replace(/(\S)\ {3}(\S)/g, "$1 " + c + " $2").replace(/\ {2}/g, c + " ").replace(/\ {2}/g, " " + c), (this.context.isFirst || this.context.followsWhitespace) && (d = d.replace(/^\ /, c)), d;
          }, u;
        }(n.ObjectView);
      }).call(this), (function() {
        var r = function(a, o) {
          function s() {
            this.constructor = a;
          }
          for (var l in o) i.call(o, l) && (a[l] = o[l]);
          return s.prototype = o.prototype, a.prototype = new s(), a.__super__ = o.prototype, a;
        }, i = {}.hasOwnProperty;
        n.TextView = function(a) {
          function o() {
            o.__super__.constructor.apply(this, arguments), this.text = this.object, this.textConfig = this.options.textConfig;
          }
          var s;
          return r(o, a), o.prototype.createNodes = function() {
            var l, u, c, d, f, h, m, v, b, y;
            for (h = [], v = n.ObjectGroup.groupObjects(this.getPieces()), d = v.length - 1, c = u = 0, f = v.length; f > u; c = ++u) m = v[c], l = {}, c === 0 && (l.isFirst = !0), c === d && (l.isLast = !0), s(b) && (l.followsWhitespace = !0), y = this.findOrCreateCachedChildView(n.PieceView, m, { textConfig: this.textConfig, context: l }), h.push.apply(h, y.getNodes()), b = m;
            return h;
          }, o.prototype.getPieces = function() {
            var l, u, c, d, f;
            for (d = this.text.getPieces(), f = [], l = 0, u = d.length; u > l; l++) c = d[l], c.hasAttribute("blockBreak") || f.push(c);
            return f;
          }, s = function(l) {
            return /\s$/.test(l != null ? l.toString() : void 0);
          }, o;
        }(n.ObjectView);
      }).call(this), (function() {
        var r, i, a, o = function(l, u) {
          function c() {
            this.constructor = l;
          }
          for (var d in u) s.call(u, d) && (l[d] = u[d]);
          return c.prototype = u.prototype, l.prototype = new c(), l.__super__ = u.prototype, l;
        }, s = {}.hasOwnProperty;
        a = n.makeElement, i = n.getBlockConfig, r = n.config.css, n.BlockView = function(l) {
          function u() {
            u.__super__.constructor.apply(this, arguments), this.block = this.object, this.attributes = this.block.getAttributes();
          }
          return o(u, l), u.prototype.createNodes = function() {
            var c, d, f, h, m, v, b, y, g, E, S;
            if (d = document.createComment("block"), b = [d], this.block.isEmpty() ? b.push(a("br")) : (E = (y = i(this.block.getLastAttribute())) != null ? y.text : void 0, S = this.findOrCreateCachedChildView(n.TextView, this.block.text, { textConfig: E }), b.push.apply(b, S.getNodes()), this.shouldAddExtraNewlineElement() && b.push(a("br"))), this.attributes.length) return b;
            for (g = n.config.blockAttributes.default.tagName, this.block.isRTL() && (c = { dir: "rtl" }), f = a({ tagName: g, attributes: c }), h = 0, m = b.length; m > h; h++) v = b[h], f.appendChild(v);
            return [f];
          }, u.prototype.createContainerElement = function(c) {
            var d, f, h, m, v;
            return d = this.attributes[c], v = i(d).tagName, c === 0 && this.block.isRTL() && (f = { dir: "rtl" }), d === "attachmentGallery" && (m = this.block.getBlockBreakPosition(), h = r.attachmentGallery + " " + r.attachmentGallery + "--" + m), a({ tagName: v, className: h, attributes: f });
          }, u.prototype.shouldAddExtraNewlineElement = function() {
            return /\n\n$/.test(this.block.toString());
          }, u;
        }(n.ObjectView);
      }).call(this), (function() {
        var r, i, a = function(s, l) {
          function u() {
            this.constructor = s;
          }
          for (var c in l) o.call(l, c) && (s[c] = l[c]);
          return u.prototype = l.prototype, s.prototype = new u(), s.__super__ = l.prototype, s;
        }, o = {}.hasOwnProperty;
        r = n.defer, i = n.makeElement, n.DocumentView = function(s) {
          function l() {
            l.__super__.constructor.apply(this, arguments), this.element = this.options.element, this.elementStore = new n.ElementStore(), this.setDocument(this.object);
          }
          var u, c, d;
          return a(l, s), l.render = function(f) {
            var h, m;
            return h = i("div"), m = new this(f, { element: h }), m.render(), m.sync(), h;
          }, l.prototype.setDocument = function(f) {
            return f.isEqualTo(this.document) ? void 0 : this.document = this.object = f;
          }, l.prototype.render = function() {
            var f, h, m, v, b, y, g;
            if (this.childViews = [], this.shadowElement = i("div"), !this.document.isEmpty()) {
              for (b = n.ObjectGroup.groupObjects(this.document.getBlocks(), { asTree: !0 }), y = [], f = 0, h = b.length; h > f; f++) v = b[f], g = this.findOrCreateCachedChildView(n.BlockView, v), y.push((function() {
                var E, S, C, T;
                for (C = g.getNodes(), T = [], E = 0, S = C.length; S > E; E++) m = C[E], T.push(this.shadowElement.appendChild(m));
                return T;
              }).call(this));
              return y;
            }
          }, l.prototype.isSynced = function() {
            return u(this.shadowElement, this.element);
          }, l.prototype.sync = function() {
            var f;
            for (f = this.createDocumentFragmentForSync(); this.element.lastChild; ) this.element.removeChild(this.element.lastChild);
            return this.element.appendChild(f), this.didSync();
          }, l.prototype.didSync = function() {
            return this.elementStore.reset(c(this.element)), r(/* @__PURE__ */ function(f) {
              return function() {
                return f.garbageCollectCachedViews();
              };
            }(this));
          }, l.prototype.createDocumentFragmentForSync = function() {
            var f, h, m, v, b, y, g, E, S, C;
            for (h = document.createDocumentFragment(), E = this.shadowElement.childNodes, m = 0, b = E.length; b > m; m++) g = E[m], h.appendChild(g.cloneNode(!0));
            for (S = c(h), v = 0, y = S.length; y > v; v++) f = S[v], (C = this.elementStore.remove(f)) && f.parentNode.replaceChild(C, f);
            return h;
          }, c = function(f) {
            return f.querySelectorAll("[data-trix-store-key]");
          }, u = function(f, h) {
            return d(f.innerHTML) === d(h.innerHTML);
          }, d = function(f) {
            return f.replace(/&nbsp;/g, " ");
          }, l;
        }(n.ObjectView);
      }).call(this), (function() {
        var r, i, a, o, s, l = function(d, f) {
          return function() {
            return d.apply(f, arguments);
          };
        }, u = function(d, f) {
          function h() {
            this.constructor = d;
          }
          for (var m in f) c.call(f, m) && (d[m] = f[m]);
          return h.prototype = f.prototype, d.prototype = new h(), d.__super__ = f.prototype, d;
        }, c = {}.hasOwnProperty;
        a = n.findClosestElementFromNode, o = n.handleEvent, s = n.innerElementIsActive, i = n.defer, r = n.AttachmentView.attachmentSelector, n.CompositionController = function(d) {
          function f(h, m) {
            this.element = h, this.composition = m, this.didClickAttachment = l(this.didClickAttachment, this), this.didBlur = l(this.didBlur, this), this.didFocus = l(this.didFocus, this), this.documentView = new n.DocumentView(this.composition.document, { element: this.element }), o("focus", { onElement: this.element, withCallback: this.didFocus }), o("blur", { onElement: this.element, withCallback: this.didBlur }), o("click", { onElement: this.element, matchingSelector: "a[contenteditable=false]", preventDefault: !0 }), o("mousedown", { onElement: this.element, matchingSelector: r, withCallback: this.didClickAttachment }), o("click", { onElement: this.element, matchingSelector: "a" + r, preventDefault: !0 });
          }
          return u(f, d), f.prototype.didFocus = function() {
            var h, m, v;
            return h = /* @__PURE__ */ function(b) {
              return function() {
                var y;
                return b.focused ? void 0 : (b.focused = !0, (y = b.delegate) != null && typeof y.compositionControllerDidFocus == "function" ? y.compositionControllerDidFocus() : void 0);
              };
            }(this), (m = (v = this.blurPromise) != null ? v.then(h) : void 0) != null ? m : h();
          }, f.prototype.didBlur = function() {
            return this.blurPromise = new Promise(/* @__PURE__ */ function(h) {
              return function(m) {
                return i(function() {
                  var v;
                  return s(h.element) || (h.focused = null, (v = h.delegate) != null && typeof v.compositionControllerDidBlur == "function" && v.compositionControllerDidBlur()), h.blurPromise = null, m();
                });
              };
            }(this));
          }, f.prototype.didClickAttachment = function(h, m) {
            var v, b, y;
            return v = this.findAttachmentForElement(m), b = a(h.target, { matchingSelector: "figcaption" }) != null, (y = this.delegate) != null && typeof y.compositionControllerDidSelectAttachment == "function" ? y.compositionControllerDidSelectAttachment(v, { editCaption: b }) : void 0;
          }, f.prototype.getSerializableElement = function() {
            return this.isEditingAttachment() ? this.documentView.shadowElement : this.element;
          }, f.prototype.render = function() {
            var h, m, v;
            return this.revision !== this.composition.revision && (this.documentView.setDocument(this.composition.document), this.documentView.render(), this.revision = this.composition.revision), this.canSyncDocumentView() && !this.documentView.isSynced() && ((h = this.delegate) != null && typeof h.compositionControllerWillSyncDocumentView == "function" && h.compositionControllerWillSyncDocumentView(), this.documentView.sync(), (m = this.delegate) != null && typeof m.compositionControllerDidSyncDocumentView == "function" && m.compositionControllerDidSyncDocumentView()), (v = this.delegate) != null && typeof v.compositionControllerDidRender == "function" ? v.compositionControllerDidRender() : void 0;
          }, f.prototype.rerenderViewForObject = function(h) {
            return this.invalidateViewForObject(h), this.render();
          }, f.prototype.invalidateViewForObject = function(h) {
            return this.documentView.invalidateViewForObject(h);
          }, f.prototype.isViewCachingEnabled = function() {
            return this.documentView.isViewCachingEnabled();
          }, f.prototype.enableViewCaching = function() {
            return this.documentView.enableViewCaching();
          }, f.prototype.disableViewCaching = function() {
            return this.documentView.disableViewCaching();
          }, f.prototype.refreshViewCache = function() {
            return this.documentView.garbageCollectCachedViews();
          }, f.prototype.isEditingAttachment = function() {
            return this.attachmentEditor != null;
          }, f.prototype.installAttachmentEditorForAttachment = function(h, m) {
            var v, b, y;
            if (((y = this.attachmentEditor) != null ? y.attachment : void 0) !== h && (b = this.documentView.findElementForObject(h))) return this.uninstallAttachmentEditor(), v = this.composition.document.getAttachmentPieceForAttachment(h), this.attachmentEditor = new n.AttachmentEditorController(v, b, this.element, m), this.attachmentEditor.delegate = this;
          }, f.prototype.uninstallAttachmentEditor = function() {
            var h;
            return (h = this.attachmentEditor) != null ? h.uninstall() : void 0;
          }, f.prototype.didUninstallAttachmentEditor = function() {
            return this.attachmentEditor = null, this.render();
          }, f.prototype.attachmentEditorDidRequestUpdatingAttributesForAttachment = function(h, m) {
            var v;
            return (v = this.delegate) != null && typeof v.compositionControllerWillUpdateAttachment == "function" && v.compositionControllerWillUpdateAttachment(m), this.composition.updateAttributesForAttachment(h, m);
          }, f.prototype.attachmentEditorDidRequestRemovingAttributeForAttachment = function(h, m) {
            var v;
            return (v = this.delegate) != null && typeof v.compositionControllerWillUpdateAttachment == "function" && v.compositionControllerWillUpdateAttachment(m), this.composition.removeAttributeForAttachment(h, m);
          }, f.prototype.attachmentEditorDidRequestRemovalOfAttachment = function(h) {
            var m;
            return (m = this.delegate) != null && typeof m.compositionControllerDidRequestRemovalOfAttachment == "function" ? m.compositionControllerDidRequestRemovalOfAttachment(h) : void 0;
          }, f.prototype.attachmentEditorDidRequestDeselectingAttachment = function(h) {
            var m;
            return (m = this.delegate) != null && typeof m.compositionControllerDidRequestDeselectingAttachment == "function" ? m.compositionControllerDidRequestDeselectingAttachment(h) : void 0;
          }, f.prototype.canSyncDocumentView = function() {
            return !this.isEditingAttachment();
          }, f.prototype.findAttachmentForElement = function(h) {
            return this.composition.document.getAttachmentById(parseInt(h.dataset.trixId, 10));
          }, f;
        }(n.BasicObject);
      }).call(this), (function() {
        var r, i, a, o = function(u, c) {
          return function() {
            return u.apply(c, arguments);
          };
        }, s = function(u, c) {
          function d() {
            this.constructor = u;
          }
          for (var f in c) l.call(c, f) && (u[f] = c[f]);
          return d.prototype = c.prototype, u.prototype = new d(), u.__super__ = c.prototype, u;
        }, l = {}.hasOwnProperty;
        i = n.handleEvent, a = n.triggerEvent, r = n.findClosestElementFromNode, n.ToolbarController = function(u) {
          function c(T) {
            this.element = T, this.didKeyDownDialogInput = o(this.didKeyDownDialogInput, this), this.didClickDialogButton = o(this.didClickDialogButton, this), this.didClickAttributeButton = o(this.didClickAttributeButton, this), this.didClickActionButton = o(this.didClickActionButton, this), this.attributes = {}, this.actions = {}, this.resetDialogInputs(), i("mousedown", { onElement: this.element, matchingSelector: d, withCallback: this.didClickActionButton }), i("mousedown", { onElement: this.element, matchingSelector: h, withCallback: this.didClickAttributeButton }), i("click", { onElement: this.element, matchingSelector: C, preventDefault: !0 }), i("click", { onElement: this.element, matchingSelector: m, withCallback: this.didClickDialogButton }), i("keydown", { onElement: this.element, matchingSelector: v, withCallback: this.didKeyDownDialogInput });
          }
          var d, f, h, m, v, b, y, g, E, S, C;
          return s(c, u), h = "[data-trix-attribute]", d = "[data-trix-action]", C = h + ", " + d, b = "[data-trix-dialog]", f = b + "[data-trix-active]", m = b + " [data-trix-method]", v = b + " [data-trix-input]", c.prototype.didClickActionButton = function(T, O) {
            var R, D, q;
            return (D = this.delegate) != null && D.toolbarDidClickButton(), T.preventDefault(), R = y(O), this.getDialog(R) ? this.toggleDialog(R) : (q = this.delegate) != null ? q.toolbarDidInvokeAction(R) : void 0;
          }, c.prototype.didClickAttributeButton = function(T, O) {
            var R, D, q;
            return (D = this.delegate) != null && D.toolbarDidClickButton(), T.preventDefault(), R = g(O), this.getDialog(R) ? this.toggleDialog(R) : (q = this.delegate) != null && q.toolbarDidToggleAttribute(R), this.refreshAttributeButtons();
          }, c.prototype.didClickDialogButton = function(T, O) {
            var R, D;
            return R = r(O, { matchingSelector: b }), D = O.getAttribute("data-trix-method"), this[D].call(this, R);
          }, c.prototype.didKeyDownDialogInput = function(T, O) {
            var R, D;
            return T.keyCode === 13 && (T.preventDefault(), R = O.getAttribute("name"), D = this.getDialog(R), this.setAttribute(D)), T.keyCode === 27 ? (T.preventDefault(), this.hideDialog()) : void 0;
          }, c.prototype.updateActions = function(T) {
            return this.actions = T, this.refreshActionButtons();
          }, c.prototype.refreshActionButtons = function() {
            return this.eachActionButton(/* @__PURE__ */ function(T) {
              return function(O, R) {
                return O.disabled = T.actions[R] === !1;
              };
            }(this));
          }, c.prototype.eachActionButton = function(T) {
            var O, R, D, q, $;
            for (q = this.element.querySelectorAll(d), $ = [], R = 0, D = q.length; D > R; R++) O = q[R], $.push(T(O, y(O)));
            return $;
          }, c.prototype.updateAttributes = function(T) {
            return this.attributes = T, this.refreshAttributeButtons();
          }, c.prototype.refreshAttributeButtons = function() {
            return this.eachAttributeButton(/* @__PURE__ */ function(T) {
              return function(O, R) {
                return O.disabled = T.attributes[R] === !1, T.attributes[R] || T.dialogIsVisible(R) ? (O.setAttribute("data-trix-active", ""), O.classList.add("trix-active")) : (O.removeAttribute("data-trix-active"), O.classList.remove("trix-active"));
              };
            }(this));
          }, c.prototype.eachAttributeButton = function(T) {
            var O, R, D, q, $;
            for (q = this.element.querySelectorAll(h), $ = [], R = 0, D = q.length; D > R; R++) O = q[R], $.push(T(O, g(O)));
            return $;
          }, c.prototype.applyKeyboardCommand = function(T) {
            var O, R, D, q, $, P, Y;
            for ($ = JSON.stringify(T.sort()), Y = this.element.querySelectorAll("[data-trix-key]"), q = 0, P = Y.length; P > q; q++) if (O = Y[q], D = O.getAttribute("data-trix-key").split("+"), R = JSON.stringify(D.sort()), R === $) return a("mousedown", { onElement: O }), !0;
            return !1;
          }, c.prototype.dialogIsVisible = function(T) {
            var O;
            return (O = this.getDialog(T)) ? O.hasAttribute("data-trix-active") : void 0;
          }, c.prototype.toggleDialog = function(T) {
            return this.dialogIsVisible(T) ? this.hideDialog() : this.showDialog(T);
          }, c.prototype.showDialog = function(T) {
            var O, R, D, q, $, P, Y, L, x, I;
            for (this.hideDialog(), (Y = this.delegate) != null && Y.toolbarWillShowDialog(), D = this.getDialog(T), D.setAttribute("data-trix-active", ""), D.classList.add("trix-active"), L = D.querySelectorAll("input[disabled]"), q = 0, P = L.length; P > q; q++) R = L[q], R.removeAttribute("disabled");
            return (O = g(D)) && ($ = S(D, T)) && ($.value = (x = this.attributes[O]) != null ? x : "", $.select()), (I = this.delegate) != null ? I.toolbarDidShowDialog(T) : void 0;
          }, c.prototype.setAttribute = function(T) {
            var O, R, D;
            return O = g(T), R = S(T, O), R.willValidate && !R.checkValidity() ? (R.setAttribute("data-trix-validate", ""), R.classList.add("trix-validate"), R.focus()) : ((D = this.delegate) != null && D.toolbarDidUpdateAttribute(O, R.value), this.hideDialog());
          }, c.prototype.removeAttribute = function(T) {
            var O, R;
            return O = g(T), (R = this.delegate) != null && R.toolbarDidRemoveAttribute(O), this.hideDialog();
          }, c.prototype.hideDialog = function() {
            var T, O;
            return (T = this.element.querySelector(f)) ? (T.removeAttribute("data-trix-active"), T.classList.remove("trix-active"), this.resetDialogInputs(), (O = this.delegate) != null ? O.toolbarDidHideDialog(E(T)) : void 0) : void 0;
          }, c.prototype.resetDialogInputs = function() {
            var T, O, R, D, q;
            for (D = this.element.querySelectorAll(v), q = [], T = 0, R = D.length; R > T; T++) O = D[T], O.setAttribute("disabled", "disabled"), O.removeAttribute("data-trix-validate"), q.push(O.classList.remove("trix-validate"));
            return q;
          }, c.prototype.getDialog = function(T) {
            return this.element.querySelector("[data-trix-dialog=" + T + "]");
          }, S = function(T, O) {
            return O == null && (O = g(T)), T.querySelector("[data-trix-input][name='" + O + "']");
          }, y = function(T) {
            return T.getAttribute("data-trix-action");
          }, g = function(T) {
            var O;
            return (O = T.getAttribute("data-trix-attribute")) != null ? O : T.getAttribute("data-trix-dialog-attribute");
          }, E = function(T) {
            return T.getAttribute("data-trix-dialog");
          }, c;
        }(n.BasicObject);
      }).call(this), (function() {
        var r = function(a, o) {
          function s() {
            this.constructor = a;
          }
          for (var l in o) i.call(o, l) && (a[l] = o[l]);
          return s.prototype = o.prototype, a.prototype = new s(), a.__super__ = o.prototype, a;
        }, i = {}.hasOwnProperty;
        n.ImagePreloadOperation = function(a) {
          function o(s) {
            this.url = s;
          }
          return r(o, a), o.prototype.perform = function(s) {
            var l;
            return l = new Image(), l.onload = /* @__PURE__ */ function(u) {
              return function() {
                return l.width = u.width = l.naturalWidth, l.height = u.height = l.naturalHeight, s(!0, l);
              };
            }(this), l.onerror = function() {
              return s(!1);
            }, l.src = this.url;
          }, o;
        }(n.Operation);
      }).call(this), (function() {
        var r = function(o, s) {
          return function() {
            return o.apply(s, arguments);
          };
        }, i = function(o, s) {
          function l() {
            this.constructor = o;
          }
          for (var u in s) a.call(s, u) && (o[u] = s[u]);
          return l.prototype = s.prototype, o.prototype = new l(), o.__super__ = s.prototype, o;
        }, a = {}.hasOwnProperty;
        n.Attachment = function(o) {
          function s(l) {
            l == null && (l = {}), this.releaseFile = r(this.releaseFile, this), s.__super__.constructor.apply(this, arguments), this.attributes = n.Hash.box(l), this.didChangeAttributes();
          }
          return i(s, o), s.previewablePattern = /^image(\/(gif|png|jpe?g)|$)/, s.attachmentForFile = function(l) {
            var u, c;
            return c = this.attributesForFile(l), u = new this(c), u.setFile(l), u;
          }, s.attributesForFile = function(l) {
            return new n.Hash({ filename: l.name, filesize: l.size, contentType: l.type });
          }, s.fromJSON = function(l) {
            return new this(l);
          }, s.prototype.getAttribute = function(l) {
            return this.attributes.get(l);
          }, s.prototype.hasAttribute = function(l) {
            return this.attributes.has(l);
          }, s.prototype.getAttributes = function() {
            return this.attributes.toObject();
          }, s.prototype.setAttributes = function(l) {
            var u, c, d;
            return l == null && (l = {}), u = this.attributes.merge(l), this.attributes.isEqualTo(u) ? void 0 : (this.attributes = u, this.didChangeAttributes(), (c = this.previewDelegate) != null && typeof c.attachmentDidChangeAttributes == "function" && c.attachmentDidChangeAttributes(this), (d = this.delegate) != null && typeof d.attachmentDidChangeAttributes == "function" ? d.attachmentDidChangeAttributes(this) : void 0);
          }, s.prototype.didChangeAttributes = function() {
            return this.isPreviewable() ? this.preloadURL() : void 0;
          }, s.prototype.isPending = function() {
            return this.file != null && !(this.getURL() || this.getHref());
          }, s.prototype.isPreviewable = function() {
            return this.attributes.has("previewable") ? this.attributes.get("previewable") : this.constructor.previewablePattern.test(this.getContentType());
          }, s.prototype.getType = function() {
            return this.hasContent() ? "content" : this.isPreviewable() ? "preview" : "file";
          }, s.prototype.getURL = function() {
            return this.attributes.get("url");
          }, s.prototype.getHref = function() {
            return this.attributes.get("href");
          }, s.prototype.getFilename = function() {
            var l;
            return (l = this.attributes.get("filename")) != null ? l : "";
          }, s.prototype.getFilesize = function() {
            return this.attributes.get("filesize");
          }, s.prototype.getFormattedFilesize = function() {
            var l;
            return l = this.attributes.get("filesize"), typeof l == "number" ? n.config.fileSize.formatter(l) : "";
          }, s.prototype.getExtension = function() {
            var l;
            return (l = this.getFilename().match(/\.(\w+)$/)) != null ? l[1].toLowerCase() : void 0;
          }, s.prototype.getContentType = function() {
            return this.attributes.get("contentType");
          }, s.prototype.hasContent = function() {
            return this.attributes.has("content");
          }, s.prototype.getContent = function() {
            return this.attributes.get("content");
          }, s.prototype.getWidth = function() {
            return this.attributes.get("width");
          }, s.prototype.getHeight = function() {
            return this.attributes.get("height");
          }, s.prototype.getFile = function() {
            return this.file;
          }, s.prototype.setFile = function(l) {
            return this.file = l, this.isPreviewable() ? this.preloadFile() : void 0;
          }, s.prototype.releaseFile = function() {
            return this.releasePreloadedFile(), this.file = null;
          }, s.prototype.getUploadProgress = function() {
            var l;
            return (l = this.uploadProgress) != null ? l : 0;
          }, s.prototype.setUploadProgress = function(l) {
            var u;
            return this.uploadProgress !== l ? (this.uploadProgress = l, (u = this.uploadProgressDelegate) != null && typeof u.attachmentDidChangeUploadProgress == "function" ? u.attachmentDidChangeUploadProgress(this) : void 0) : void 0;
          }, s.prototype.toJSON = function() {
            return this.getAttributes();
          }, s.prototype.getCacheKey = function() {
            return [s.__super__.getCacheKey.apply(this, arguments), this.attributes.getCacheKey(), this.getPreviewURL()].join("/");
          }, s.prototype.getPreviewURL = function() {
            return this.previewURL || this.preloadingURL;
          }, s.prototype.setPreviewURL = function(l) {
            var u, c;
            return l !== this.getPreviewURL() ? (this.previewURL = l, (u = this.previewDelegate) != null && typeof u.attachmentDidChangeAttributes == "function" && u.attachmentDidChangeAttributes(this), (c = this.delegate) != null && typeof c.attachmentDidChangePreviewURL == "function" ? c.attachmentDidChangePreviewURL(this) : void 0) : void 0;
          }, s.prototype.preloadURL = function() {
            return this.preload(this.getURL(), this.releaseFile);
          }, s.prototype.preloadFile = function() {
            return this.file ? (this.fileObjectURL = URL.createObjectURL(this.file), this.preload(this.fileObjectURL)) : void 0;
          }, s.prototype.releasePreloadedFile = function() {
            return this.fileObjectURL ? (URL.revokeObjectURL(this.fileObjectURL), this.fileObjectURL = null) : void 0;
          }, s.prototype.preload = function(l, u) {
            var c;
            return l && l !== this.getPreviewURL() ? (this.preloadingURL = l, c = new n.ImagePreloadOperation(l), c.then(/* @__PURE__ */ function(d) {
              return function(f) {
                var h, m;
                return m = f.width, h = f.height, d.getWidth() && d.getHeight() || d.setAttributes({ width: m, height: h }), d.preloadingURL = null, d.setPreviewURL(l), typeof u == "function" ? u() : void 0;
              };
            }(this)).catch(/* @__PURE__ */ function(d) {
              return function() {
                return d.preloadingURL = null, typeof u == "function" ? u() : void 0;
              };
            }(this))) : void 0;
          }, s;
        }(n.Object);
      }).call(this), (function() {
        var r = function(a, o) {
          function s() {
            this.constructor = a;
          }
          for (var l in o) i.call(o, l) && (a[l] = o[l]);
          return s.prototype = o.prototype, a.prototype = new s(), a.__super__ = o.prototype, a;
        }, i = {}.hasOwnProperty;
        n.Piece = function(a) {
          function o(s, l) {
            l == null && (l = {}), o.__super__.constructor.apply(this, arguments), this.attributes = n.Hash.box(l);
          }
          return r(o, a), o.types = {}, o.registerType = function(s, l) {
            return l.type = s, this.types[s] = l;
          }, o.fromJSON = function(s) {
            var l;
            return (l = this.types[s.type]) ? l.fromJSON(s) : void 0;
          }, o.prototype.copyWithAttributes = function(s) {
            return new this.constructor(this.getValue(), s);
          }, o.prototype.copyWithAdditionalAttributes = function(s) {
            return this.copyWithAttributes(this.attributes.merge(s));
          }, o.prototype.copyWithoutAttribute = function(s) {
            return this.copyWithAttributes(this.attributes.remove(s));
          }, o.prototype.copy = function() {
            return this.copyWithAttributes(this.attributes);
          }, o.prototype.getAttribute = function(s) {
            return this.attributes.get(s);
          }, o.prototype.getAttributesHash = function() {
            return this.attributes;
          }, o.prototype.getAttributes = function() {
            return this.attributes.toObject();
          }, o.prototype.getCommonAttributes = function() {
            var s, l, u;
            return (u = pieceList.getPieceAtIndex(0)) ? (s = u.attributes, l = s.getKeys(), pieceList.eachPiece(function(c) {
              return l = s.getKeysCommonToHash(c.attributes), s = s.slice(l);
            }), s.toObject()) : {};
          }, o.prototype.hasAttribute = function(s) {
            return this.attributes.has(s);
          }, o.prototype.hasSameStringValueAsPiece = function(s) {
            return s != null && this.toString() === s.toString();
          }, o.prototype.hasSameAttributesAsPiece = function(s) {
            return s != null && (this.attributes === s.attributes || this.attributes.isEqualTo(s.attributes));
          }, o.prototype.isBlockBreak = function() {
            return !1;
          }, o.prototype.isEqualTo = function(s) {
            return o.__super__.isEqualTo.apply(this, arguments) || this.hasSameConstructorAs(s) && this.hasSameStringValueAsPiece(s) && this.hasSameAttributesAsPiece(s);
          }, o.prototype.isEmpty = function() {
            return this.length === 0;
          }, o.prototype.isSerializable = function() {
            return !0;
          }, o.prototype.toJSON = function() {
            return { type: this.constructor.type, attributes: this.getAttributes() };
          }, o.prototype.contentsForInspection = function() {
            return { type: this.constructor.type, attributes: this.attributes.inspect() };
          }, o.prototype.canBeGrouped = function() {
            return this.hasAttribute("href");
          }, o.prototype.canBeGroupedWith = function(s) {
            return this.getAttribute("href") === s.getAttribute("href");
          }, o.prototype.getLength = function() {
            return this.length;
          }, o.prototype.canBeConsolidatedWith = function() {
            return !1;
          }, o;
        }(n.Object);
      }).call(this), (function() {
        var r = function(a, o) {
          function s() {
            this.constructor = a;
          }
          for (var l in o) i.call(o, l) && (a[l] = o[l]);
          return s.prototype = o.prototype, a.prototype = new s(), a.__super__ = o.prototype, a;
        }, i = {}.hasOwnProperty;
        n.Piece.registerType("attachment", n.AttachmentPiece = function(a) {
          function o(s) {
            this.attachment = s, o.__super__.constructor.apply(this, arguments), this.length = 1, this.ensureAttachmentExclusivelyHasAttribute("href"), this.attachment.hasContent() || this.removeProhibitedAttributes();
          }
          return r(o, a), o.fromJSON = function(s) {
            return new this(n.Attachment.fromJSON(s.attachment), s.attributes);
          }, o.permittedAttributes = ["caption", "presentation"], o.prototype.ensureAttachmentExclusivelyHasAttribute = function(s) {
            return this.hasAttribute(s) ? (this.attachment.hasAttribute(s) || this.attachment.setAttributes(this.attributes.slice(s)), this.attributes = this.attributes.remove(s)) : void 0;
          }, o.prototype.removeProhibitedAttributes = function() {
            var s;
            return s = this.attributes.slice(this.constructor.permittedAttributes), s.isEqualTo(this.attributes) ? void 0 : this.attributes = s;
          }, o.prototype.getValue = function() {
            return this.attachment;
          }, o.prototype.isSerializable = function() {
            return !this.attachment.isPending();
          }, o.prototype.getCaption = function() {
            var s;
            return (s = this.attributes.get("caption")) != null ? s : "";
          }, o.prototype.isEqualTo = function(s) {
            var l;
            return o.__super__.isEqualTo.apply(this, arguments) && this.attachment.id === (s != null && (l = s.attachment) != null ? l.id : void 0);
          }, o.prototype.toString = function() {
            return n.OBJECT_REPLACEMENT_CHARACTER;
          }, o.prototype.toJSON = function() {
            var s;
            return s = o.__super__.toJSON.apply(this, arguments), s.attachment = this.attachment, s;
          }, o.prototype.getCacheKey = function() {
            return [o.__super__.getCacheKey.apply(this, arguments), this.attachment.getCacheKey()].join("/");
          }, o.prototype.toConsole = function() {
            return JSON.stringify(this.toString());
          }, o;
        }(n.Piece));
      }).call(this), (function() {
        var r, i = function(o, s) {
          function l() {
            this.constructor = o;
          }
          for (var u in s) a.call(s, u) && (o[u] = s[u]);
          return l.prototype = s.prototype, o.prototype = new l(), o.__super__ = s.prototype, o;
        }, a = {}.hasOwnProperty;
        r = n.normalizeNewlines, n.Piece.registerType("string", n.StringPiece = function(o) {
          function s(l) {
            s.__super__.constructor.apply(this, arguments), this.string = r(l), this.length = this.string.length;
          }
          return i(s, o), s.fromJSON = function(l) {
            return new this(l.string, l.attributes);
          }, s.prototype.getValue = function() {
            return this.string;
          }, s.prototype.toString = function() {
            return this.string.toString();
          }, s.prototype.isBlockBreak = function() {
            return this.toString() === `
` && this.getAttribute("blockBreak") === !0;
          }, s.prototype.toJSON = function() {
            var l;
            return l = s.__super__.toJSON.apply(this, arguments), l.string = this.string, l;
          }, s.prototype.canBeConsolidatedWith = function(l) {
            return l != null && this.hasSameConstructorAs(l) && this.hasSameAttributesAsPiece(l);
          }, s.prototype.consolidateWith = function(l) {
            return new this.constructor(this.toString() + l.toString(), this.attributes);
          }, s.prototype.splitAtOffset = function(l) {
            var u, c;
            return l === 0 ? (u = null, c = this) : l === this.length ? (u = this, c = null) : (u = new this.constructor(this.string.slice(0, l), this.attributes), c = new this.constructor(this.string.slice(l), this.attributes)), [u, c];
          }, s.prototype.toConsole = function() {
            var l;
            return l = this.string, l.length > 15 && (l = l.slice(0, 14) + "…"), JSON.stringify(l.toString());
          }, s;
        }(n.Piece));
      }).call(this), (function() {
        var r, i = function(s, l) {
          function u() {
            this.constructor = s;
          }
          for (var c in l) a.call(l, c) && (s[c] = l[c]);
          return u.prototype = l.prototype, s.prototype = new u(), s.__super__ = l.prototype, s;
        }, a = {}.hasOwnProperty, o = [].slice;
        r = n.spliceArray, n.SplittableList = function(s) {
          function l(f) {
            f == null && (f = []), l.__super__.constructor.apply(this, arguments), this.objects = f.slice(0), this.length = this.objects.length;
          }
          var u, c, d;
          return i(l, s), l.box = function(f) {
            return f instanceof this ? f : new this(f);
          }, l.prototype.indexOf = function(f) {
            return this.objects.indexOf(f);
          }, l.prototype.splice = function() {
            var f;
            return f = 1 <= arguments.length ? o.call(arguments, 0) : [], new this.constructor(r.apply(null, [this.objects].concat(o.call(f))));
          }, l.prototype.eachObject = function(f) {
            var h, m, v, b, y, g;
            for (y = this.objects, g = [], m = h = 0, v = y.length; v > h; m = ++h) b = y[m], g.push(f(b, m));
            return g;
          }, l.prototype.insertObjectAtIndex = function(f, h) {
            return this.splice(h, 0, f);
          }, l.prototype.insertSplittableListAtIndex = function(f, h) {
            return this.splice.apply(this, [h, 0].concat(o.call(f.objects)));
          }, l.prototype.insertSplittableListAtPosition = function(f, h) {
            var m, v, b;
            return b = this.splitObjectAtPosition(h), v = b[0], m = b[1], new this.constructor(v).insertSplittableListAtIndex(f, m);
          }, l.prototype.editObjectAtIndex = function(f, h) {
            return this.replaceObjectAtIndex(h(this.objects[f]), f);
          }, l.prototype.replaceObjectAtIndex = function(f, h) {
            return this.splice(h, 1, f);
          }, l.prototype.removeObjectAtIndex = function(f) {
            return this.splice(f, 1);
          }, l.prototype.getObjectAtIndex = function(f) {
            return this.objects[f];
          }, l.prototype.getSplittableListInRange = function(f) {
            var h, m, v, b;
            return v = this.splitObjectsAtRange(f), m = v[0], h = v[1], b = v[2], new this.constructor(m.slice(h, b + 1));
          }, l.prototype.selectSplittableList = function(f) {
            var h, m;
            return m = (function() {
              var v, b, y, g;
              for (y = this.objects, g = [], v = 0, b = y.length; b > v; v++) h = y[v], f(h) && g.push(h);
              return g;
            }).call(this), new this.constructor(m);
          }, l.prototype.removeObjectsInRange = function(f) {
            var h, m, v, b;
            return v = this.splitObjectsAtRange(f), m = v[0], h = v[1], b = v[2], new this.constructor(m).splice(h, b - h + 1);
          }, l.prototype.transformObjectsInRange = function(f, h) {
            var m, v, b, y, g, E, S;
            return g = this.splitObjectsAtRange(f), y = g[0], v = g[1], E = g[2], S = function() {
              var C, T, O;
              for (O = [], m = C = 0, T = y.length; T > C; m = ++C) b = y[m], O.push(m >= v && E >= m ? h(b) : b);
              return O;
            }(), new this.constructor(S);
          }, l.prototype.splitObjectsAtRange = function(f) {
            var h, m, v, b, y, g;
            return b = this.splitObjectAtPosition(d(f)), m = b[0], h = b[1], v = b[2], y = new this.constructor(m).splitObjectAtPosition(u(f) + v), m = y[0], g = y[1], [m, h, g - 1];
          }, l.prototype.getObjectAtPosition = function(f) {
            var h, m;
            return m = this.findIndexAndOffsetAtPosition(f), h = m.index, m.offset, this.objects[h];
          }, l.prototype.splitObjectAtPosition = function(f) {
            var h, m, v, b, y, g, E, S, C, T;
            return g = this.findIndexAndOffsetAtPosition(f), h = g.index, y = g.offset, b = this.objects.slice(0), h != null ? y === 0 ? (C = h, T = 0) : (v = this.getObjectAtIndex(h), E = v.splitAtOffset(y), m = E[0], S = E[1], b.splice(h, 1, m, S), C = h + 1, T = m.getLength() - y) : (C = b.length, T = 0), [b, C, T];
          }, l.prototype.consolidate = function() {
            var f, h, m, v, b, y;
            for (v = [], b = this.objects[0], y = this.objects.slice(1), f = 0, h = y.length; h > f; f++) m = y[f], typeof b.canBeConsolidatedWith == "function" && b.canBeConsolidatedWith(m) ? b = b.consolidateWith(m) : (v.push(b), b = m);
            return b != null && v.push(b), new this.constructor(v);
          }, l.prototype.consolidateFromIndexToIndex = function(f, h) {
            var m, v, b;
            return v = this.objects.slice(0), b = v.slice(f, h + 1), m = new this.constructor(b).consolidate().toArray(), this.splice.apply(this, [f, b.length].concat(o.call(m)));
          }, l.prototype.findIndexAndOffsetAtPosition = function(f) {
            var h, m, v, b, y, g, E;
            for (h = 0, E = this.objects, v = m = 0, b = E.length; b > m; v = ++m) {
              if (g = E[v], y = h + g.getLength(), f >= h && y > f) return { index: v, offset: f - h };
              h = y;
            }
            return { index: null, offset: null };
          }, l.prototype.findPositionAtIndexAndOffset = function(f, h) {
            var m, v, b, y, g, E;
            for (g = 0, E = this.objects, m = v = 0, b = E.length; b > v; m = ++v) if (y = E[m], f > m) g += y.getLength();
            else if (m === f) {
              g += h;
              break;
            }
            return g;
          }, l.prototype.getEndPosition = function() {
            var f, h;
            return this.endPosition != null ? this.endPosition : this.endPosition = (function() {
              var m, v, b;
              for (h = 0, b = this.objects, m = 0, v = b.length; v > m; m++) f = b[m], h += f.getLength();
              return h;
            }).call(this);
          }, l.prototype.toString = function() {
            return this.objects.join("");
          }, l.prototype.toArray = function() {
            return this.objects.slice(0);
          }, l.prototype.toJSON = function() {
            return this.toArray();
          }, l.prototype.isEqualTo = function(f) {
            return l.__super__.isEqualTo.apply(this, arguments) || c(this.objects, f != null ? f.objects : void 0);
          }, c = function(f, h) {
            var m, v, b, y, g;
            if (h == null && (h = []), f.length !== h.length) return !1;
            for (g = !0, v = m = 0, b = f.length; b > m; v = ++m) y = f[v], g && !y.isEqualTo(h[v]) && (g = !1);
            return g;
          }, l.prototype.contentsForInspection = function() {
            var f;
            return { objects: "[" + (function() {
              var h, m, v, b;
              for (v = this.objects, b = [], h = 0, m = v.length; m > h; h++) f = v[h], b.push(f.inspect());
              return b;
            }).call(this).join(", ") + "]" };
          }, d = function(f) {
            return f[0];
          }, u = function(f) {
            return f[1];
          }, l;
        }(n.Object);
      }).call(this), (function() {
        var r = function(a, o) {
          function s() {
            this.constructor = a;
          }
          for (var l in o) i.call(o, l) && (a[l] = o[l]);
          return s.prototype = o.prototype, a.prototype = new s(), a.__super__ = o.prototype, a;
        }, i = {}.hasOwnProperty;
        n.Text = function(a) {
          function o(s) {
            var l;
            s == null && (s = []), o.__super__.constructor.apply(this, arguments), this.pieceList = new n.SplittableList(function() {
              var u, c, d;
              for (d = [], u = 0, c = s.length; c > u; u++) l = s[u], l.isEmpty() || d.push(l);
              return d;
            }());
          }
          return r(o, a), o.textForAttachmentWithAttributes = function(s, l) {
            var u;
            return u = new n.AttachmentPiece(s, l), new this([u]);
          }, o.textForStringWithAttributes = function(s, l) {
            var u;
            return u = new n.StringPiece(s, l), new this([u]);
          }, o.fromJSON = function(s) {
            var l, u;
            return u = function() {
              var c, d, f;
              for (f = [], c = 0, d = s.length; d > c; c++) l = s[c], f.push(n.Piece.fromJSON(l));
              return f;
            }(), new this(u);
          }, o.prototype.copy = function() {
            return this.copyWithPieceList(this.pieceList);
          }, o.prototype.copyWithPieceList = function(s) {
            return new this.constructor(s.consolidate().toArray());
          }, o.prototype.copyUsingObjectMap = function(s) {
            var l, u;
            return u = (function() {
              var c, d, f, h, m;
              for (f = this.getPieces(), m = [], c = 0, d = f.length; d > c; c++) l = f[c], m.push((h = s.find(l)) != null ? h : l);
              return m;
            }).call(this), new this.constructor(u);
          }, o.prototype.appendText = function(s) {
            return this.insertTextAtPosition(s, this.getLength());
          }, o.prototype.insertTextAtPosition = function(s, l) {
            return this.copyWithPieceList(this.pieceList.insertSplittableListAtPosition(s.pieceList, l));
          }, o.prototype.removeTextAtRange = function(s) {
            return this.copyWithPieceList(this.pieceList.removeObjectsInRange(s));
          }, o.prototype.replaceTextAtRange = function(s, l) {
            return this.removeTextAtRange(l).insertTextAtPosition(s, l[0]);
          }, o.prototype.moveTextFromRangeToPosition = function(s, l) {
            var u, c;
            if (!(s[0] <= l && l <= s[1])) return c = this.getTextAtRange(s), u = c.getLength(), s[0] < l && (l -= u), this.removeTextAtRange(s).insertTextAtPosition(c, l);
          }, o.prototype.addAttributeAtRange = function(s, l, u) {
            var c;
            return c = {}, c[s] = l, this.addAttributesAtRange(c, u);
          }, o.prototype.addAttributesAtRange = function(s, l) {
            return this.copyWithPieceList(this.pieceList.transformObjectsInRange(l, function(u) {
              return u.copyWithAdditionalAttributes(s);
            }));
          }, o.prototype.removeAttributeAtRange = function(s, l) {
            return this.copyWithPieceList(this.pieceList.transformObjectsInRange(l, function(u) {
              return u.copyWithoutAttribute(s);
            }));
          }, o.prototype.setAttributesAtRange = function(s, l) {
            return this.copyWithPieceList(this.pieceList.transformObjectsInRange(l, function(u) {
              return u.copyWithAttributes(s);
            }));
          }, o.prototype.getAttributesAtPosition = function(s) {
            var l, u;
            return (l = (u = this.pieceList.getObjectAtPosition(s)) != null ? u.getAttributes() : void 0) != null ? l : {};
          }, o.prototype.getCommonAttributes = function() {
            var s, l;
            return s = (function() {
              var u, c, d, f;
              for (d = this.pieceList.toArray(), f = [], u = 0, c = d.length; c > u; u++) l = d[u], f.push(l.getAttributes());
              return f;
            }).call(this), n.Hash.fromCommonAttributesOfObjects(s).toObject();
          }, o.prototype.getCommonAttributesAtRange = function(s) {
            var l;
            return (l = this.getTextAtRange(s).getCommonAttributes()) != null ? l : {};
          }, o.prototype.getExpandedRangeForAttributeAtOffset = function(s, l) {
            var u, c, d;
            for (u = d = l, c = this.getLength(); u > 0 && this.getCommonAttributesAtRange([u - 1, d])[s]; ) u--;
            for (; c > d && this.getCommonAttributesAtRange([l, d + 1])[s]; ) d++;
            return [u, d];
          }, o.prototype.getTextAtRange = function(s) {
            return this.copyWithPieceList(this.pieceList.getSplittableListInRange(s));
          }, o.prototype.getStringAtRange = function(s) {
            return this.pieceList.getSplittableListInRange(s).toString();
          }, o.prototype.getStringAtPosition = function(s) {
            return this.getStringAtRange([s, s + 1]);
          }, o.prototype.startsWithString = function(s) {
            return this.getStringAtRange([0, s.length]) === s;
          }, o.prototype.endsWithString = function(s) {
            var l;
            return l = this.getLength(), this.getStringAtRange([l - s.length, l]) === s;
          }, o.prototype.getAttachmentPieces = function() {
            var s, l, u, c, d;
            for (c = this.pieceList.toArray(), d = [], s = 0, l = c.length; l > s; s++) u = c[s], u.attachment != null && d.push(u);
            return d;
          }, o.prototype.getAttachments = function() {
            var s, l, u, c, d;
            for (c = this.getAttachmentPieces(), d = [], s = 0, l = c.length; l > s; s++) u = c[s], d.push(u.attachment);
            return d;
          }, o.prototype.getAttachmentAndPositionById = function(s) {
            var l, u, c, d, f, h;
            for (d = 0, f = this.pieceList.toArray(), l = 0, u = f.length; u > l; l++) {
              if (c = f[l], ((h = c.attachment) != null ? h.id : void 0) === s) return { attachment: c.attachment, position: d };
              d += c.length;
            }
            return { attachment: null, position: null };
          }, o.prototype.getAttachmentById = function(s) {
            var l, u;
            return u = this.getAttachmentAndPositionById(s), l = u.attachment, u.position, l;
          }, o.prototype.getRangeOfAttachment = function(s) {
            var l, u;
            return u = this.getAttachmentAndPositionById(s.id), s = u.attachment, l = u.position, s != null ? [l, l + 1] : void 0;
          }, o.prototype.updateAttributesForAttachment = function(s, l) {
            var u;
            return (u = this.getRangeOfAttachment(l)) ? this.addAttributesAtRange(s, u) : this;
          }, o.prototype.getLength = function() {
            return this.pieceList.getEndPosition();
          }, o.prototype.isEmpty = function() {
            return this.getLength() === 0;
          }, o.prototype.isEqualTo = function(s) {
            var l;
            return o.__super__.isEqualTo.apply(this, arguments) || (s != null && (l = s.pieceList) != null ? l.isEqualTo(this.pieceList) : void 0);
          }, o.prototype.isBlockBreak = function() {
            return this.getLength() === 1 && this.pieceList.getObjectAtIndex(0).isBlockBreak();
          }, o.prototype.eachPiece = function(s) {
            return this.pieceList.eachObject(s);
          }, o.prototype.getPieces = function() {
            return this.pieceList.toArray();
          }, o.prototype.getPieceAtPosition = function(s) {
            return this.pieceList.getObjectAtPosition(s);
          }, o.prototype.contentsForInspection = function() {
            return { pieceList: this.pieceList.inspect() };
          }, o.prototype.toSerializableText = function() {
            var s;
            return s = this.pieceList.selectSplittableList(function(l) {
              return l.isSerializable();
            }), this.copyWithPieceList(s);
          }, o.prototype.toString = function() {
            return this.pieceList.toString();
          }, o.prototype.toJSON = function() {
            return this.pieceList.toJSON();
          }, o.prototype.toConsole = function() {
            var s;
            return JSON.stringify((function() {
              var l, u, c, d;
              for (c = this.pieceList.toArray(), d = [], l = 0, u = c.length; u > l; l++) s = c[l], d.push(JSON.parse(s.toConsole()));
              return d;
            }).call(this));
          }, o.prototype.getDirection = function() {
            return n.getDirection(this.toString());
          }, o.prototype.isRTL = function() {
            return this.getDirection() === "rtl";
          }, o;
        }(n.Object);
      }).call(this), (function() {
        var r, i, a, o, s = function(d, f) {
          function h() {
            this.constructor = d;
          }
          for (var m in f) l.call(f, m) && (d[m] = f[m]);
          return h.prototype = f.prototype, d.prototype = new h(), d.__super__ = f.prototype, d;
        }, l = {}.hasOwnProperty, u = [].indexOf || function(d) {
          for (var f = 0, h = this.length; h > f; f++) if (f in this && this[f] === d) return f;
          return -1;
        }, c = [].slice;
        r = n.arraysAreEqual, o = n.spliceArray, i = n.getBlockConfig, n.getBlockAttributeNames, a = n.getListAttributeNames, n.Block = function(d) {
          function f(T, O) {
            T == null && (T = new n.Text()), O == null && (O = []), f.__super__.constructor.apply(this, arguments), this.text = m(T), this.attributes = O;
          }
          var h, m, v, b, y, g, E, S, C;
          return s(f, d), f.fromJSON = function(T) {
            var O;
            return O = n.Text.fromJSON(T.text), new this(O, T.attributes);
          }, f.prototype.isEmpty = function() {
            return this.text.isBlockBreak();
          }, f.prototype.isEqualTo = function(T) {
            return f.__super__.isEqualTo.apply(this, arguments) || this.text.isEqualTo(T != null ? T.text : void 0) && r(this.attributes, T != null ? T.attributes : void 0);
          }, f.prototype.copyWithText = function(T) {
            return new this.constructor(T, this.attributes);
          }, f.prototype.copyWithoutText = function() {
            return this.copyWithText(null);
          }, f.prototype.copyWithAttributes = function(T) {
            return new this.constructor(this.text, T);
          }, f.prototype.copyWithoutAttributes = function() {
            return this.copyWithAttributes(null);
          }, f.prototype.copyUsingObjectMap = function(T) {
            var O;
            return this.copyWithText((O = T.find(this.text)) ? O : this.text.copyUsingObjectMap(T));
          }, f.prototype.addAttribute = function(T) {
            var O;
            return O = this.attributes.concat(b(T)), this.copyWithAttributes(O);
          }, f.prototype.removeAttribute = function(T) {
            var O, R;
            return R = i(T).listAttribute, O = g(g(this.attributes, T), R), this.copyWithAttributes(O);
          }, f.prototype.removeLastAttribute = function() {
            return this.removeAttribute(this.getLastAttribute());
          }, f.prototype.getLastAttribute = function() {
            return y(this.attributes);
          }, f.prototype.getAttributes = function() {
            return this.attributes.slice(0);
          }, f.prototype.getAttributeLevel = function() {
            return this.attributes.length;
          }, f.prototype.getAttributeAtLevel = function(T) {
            return this.attributes[T - 1];
          }, f.prototype.hasAttribute = function(T) {
            return u.call(this.attributes, T) >= 0;
          }, f.prototype.hasAttributes = function() {
            return this.getAttributeLevel() > 0;
          }, f.prototype.getLastNestableAttribute = function() {
            return y(this.getNestableAttributes());
          }, f.prototype.getNestableAttributes = function() {
            var T, O, R, D, q;
            for (D = this.attributes, q = [], O = 0, R = D.length; R > O; O++) T = D[O], i(T).nestable && q.push(T);
            return q;
          }, f.prototype.getNestingLevel = function() {
            return this.getNestableAttributes().length;
          }, f.prototype.decreaseNestingLevel = function() {
            var T;
            return (T = this.getLastNestableAttribute()) ? this.removeAttribute(T) : this;
          }, f.prototype.increaseNestingLevel = function() {
            var T, O, R;
            return (T = this.getLastNestableAttribute()) ? (R = this.attributes.lastIndexOf(T), O = o.apply(null, [this.attributes, R + 1, 0].concat(c.call(b(T)))), this.copyWithAttributes(O)) : this;
          }, f.prototype.getListItemAttributes = function() {
            var T, O, R, D, q;
            for (D = this.attributes, q = [], O = 0, R = D.length; R > O; O++) T = D[O], i(T).listAttribute && q.push(T);
            return q;
          }, f.prototype.isListItem = function() {
            var T;
            return (T = i(this.getLastAttribute())) != null ? T.listAttribute : void 0;
          }, f.prototype.isTerminalBlock = function() {
            var T;
            return (T = i(this.getLastAttribute())) != null ? T.terminal : void 0;
          }, f.prototype.breaksOnReturn = function() {
            var T;
            return (T = i(this.getLastAttribute())) != null ? T.breakOnReturn : void 0;
          }, f.prototype.findLineBreakInDirectionFromPosition = function(T, O) {
            var R, D;
            return D = this.toString(), R = function() {
              switch (T) {
                case "forward":
                  return D.indexOf(`
`, O);
                case "backward":
                  return D.slice(0, O).lastIndexOf(`
`);
              }
            }(), R !== -1 ? R : void 0;
          }, f.prototype.contentsForInspection = function() {
            return { text: this.text.inspect(), attributes: this.attributes };
          }, f.prototype.toString = function() {
            return this.text.toString();
          }, f.prototype.toJSON = function() {
            return { text: this.text, attributes: this.attributes };
          }, f.prototype.getDirection = function() {
            return this.text.getDirection();
          }, f.prototype.isRTL = function() {
            return this.text.isRTL();
          }, f.prototype.getLength = function() {
            return this.text.getLength();
          }, f.prototype.canBeConsolidatedWith = function(T) {
            return !this.hasAttributes() && !T.hasAttributes() && this.getDirection() === T.getDirection();
          }, f.prototype.consolidateWith = function(T) {
            var O, R;
            return O = n.Text.textForStringWithAttributes(`
`), R = this.getTextWithoutBlockBreak().appendText(O), this.copyWithText(R.appendText(T.text));
          }, f.prototype.splitAtOffset = function(T) {
            var O, R;
            return T === 0 ? (O = null, R = this) : T === this.getLength() ? (O = this, R = null) : (O = this.copyWithText(this.text.getTextAtRange([0, T])), R = this.copyWithText(this.text.getTextAtRange([T, this.getLength()]))), [O, R];
          }, f.prototype.getBlockBreakPosition = function() {
            return this.text.getLength() - 1;
          }, f.prototype.getTextWithoutBlockBreak = function() {
            return E(this.text) ? this.text.getTextAtRange([0, this.getBlockBreakPosition()]) : this.text.copy();
          }, f.prototype.canBeGrouped = function(T) {
            return this.attributes[T];
          }, f.prototype.canBeGroupedWith = function(T, O) {
            var R, D, q, $;
            return q = T.getAttributes(), D = q[O], R = this.attributes[O], !(R !== D || i(R).group === !1 && ($ = q[O + 1], u.call(a(), $) < 0) || this.getDirection() !== T.getDirection() && !T.isEmpty());
          }, m = function(T) {
            return T = C(T), T = h(T);
          }, C = function(T) {
            var O, R, D, q, $, P;
            return q = !1, P = T.getPieces(), R = 2 <= P.length ? c.call(P, 0, O = P.length - 1) : (O = 0, []), D = P[O++], D == null ? T : (R = function() {
              var Y, L, x;
              for (x = [], Y = 0, L = R.length; L > Y; Y++) $ = R[Y], $.isBlockBreak() ? (q = !0, x.push(S($))) : x.push($);
              return x;
            }(), q ? new n.Text(c.call(R).concat([D])) : T);
          }, v = n.Text.textForStringWithAttributes(`
`, { blockBreak: !0 }), h = function(T) {
            return E(T) ? T : T.appendText(v);
          }, E = function(T) {
            var O, R;
            return R = T.getLength(), R === 0 ? !1 : (O = T.getTextAtRange([R - 1, R]), O.isBlockBreak());
          }, S = function(T) {
            return T.copyWithoutAttribute("blockBreak");
          }, b = function(T) {
            var O;
            return O = i(T).listAttribute, O != null ? [O, T] : [T];
          }, y = function(T) {
            return T.slice(-1)[0];
          }, g = function(T, O) {
            var R;
            return R = T.lastIndexOf(O), R === -1 ? T : o(T, R, 1);
          }, f;
        }(n.Object);
      }).call(this), (function() {
        var r, i, a, o = function(c, d) {
          function f() {
            this.constructor = c;
          }
          for (var h in d) s.call(d, h) && (c[h] = d[h]);
          return f.prototype = d.prototype, c.prototype = new f(), c.__super__ = d.prototype, c;
        }, s = {}.hasOwnProperty, l = [].indexOf || function(c) {
          for (var d = 0, f = this.length; f > d; d++) if (d in this && this[d] === c) return d;
          return -1;
        }, u = [].slice;
        i = n.tagName, a = n.walkTree, r = n.nodeIsAttachmentElement, n.HTMLSanitizer = function(c) {
          function d(b, y) {
            var g;
            g = y ?? {}, this.allowedAttributes = g.allowedAttributes, this.forbiddenProtocols = g.forbiddenProtocols, this.forbiddenElements = g.forbiddenElements, this.allowedAttributes == null && (this.allowedAttributes = f), this.forbiddenProtocols == null && (this.forbiddenProtocols = m), this.forbiddenElements == null && (this.forbiddenElements = h), this.body = v(b);
          }
          var f, h, m, v;
          return o(d, c), f = "style href src width height class".split(" "), m = "javascript:".split(" "), h = "script iframe".split(" "), d.sanitize = function(b, y) {
            var g;
            return g = new this(b, y), g.sanitize(), g;
          }, d.prototype.sanitize = function() {
            return this.sanitizeElements(), this.normalizeListElementNesting();
          }, d.prototype.getHTML = function() {
            return this.body.innerHTML;
          }, d.prototype.getBody = function() {
            return this.body;
          }, d.prototype.sanitizeElements = function() {
            var b, y, g, E, S;
            for (S = a(this.body), E = []; S.nextNode(); ) switch (g = S.currentNode, g.nodeType) {
              case Node.ELEMENT_NODE:
                this.elementIsRemovable(g) ? E.push(g) : this.sanitizeElement(g);
                break;
              case Node.COMMENT_NODE:
                E.push(g);
            }
            for (b = 0, y = E.length; y > b; b++) g = E[b], n.removeNode(g);
            return this.body;
          }, d.prototype.sanitizeElement = function(b) {
            var y, g, E, S, C;
            for (b.hasAttribute("href") && (S = b.protocol, l.call(this.forbiddenProtocols, S) >= 0 && b.removeAttribute("href")), C = u.call(b.attributes), y = 0, g = C.length; g > y; y++) E = C[y].name, l.call(this.allowedAttributes, E) >= 0 || E.indexOf("data-trix") === 0 || b.removeAttribute(E);
            return b;
          }, d.prototype.normalizeListElementNesting = function() {
            var b, y, g, E, S;
            for (S = u.call(this.body.querySelectorAll("ul,ol")), b = 0, y = S.length; y > b; b++) g = S[b], (E = g.previousElementSibling) && i(E) === "li" && E.appendChild(g);
            return this.body;
          }, d.prototype.elementIsRemovable = function(b) {
            return (b != null ? b.nodeType : void 0) === Node.ELEMENT_NODE ? this.elementIsForbidden(b) || this.elementIsntSerializable(b) : void 0;
          }, d.prototype.elementIsForbidden = function(b) {
            var y;
            return y = i(b), l.call(this.forbiddenElements, y) >= 0;
          }, d.prototype.elementIsntSerializable = function(b) {
            return b.getAttribute("data-trix-serialize") === "false" && !r(b);
          }, v = function(b) {
            var y, g, E, S, C;
            for (b == null && (b = ""), b = b.replace(/<\/html[^>]*>[^]*$/i, "</html>"), y = document.implementation.createHTMLDocument(""), y.documentElement.innerHTML = b, C = y.head.querySelectorAll("style"), E = 0, S = C.length; S > E; E++) g = C[E], y.body.appendChild(g);
            return y.body;
          }, d;
        }(n.BasicObject);
      }).call(this), (function() {
        var r, i, a, o, s, l, u, c, d, f, h, m = function(y, g) {
          function E() {
            this.constructor = y;
          }
          for (var S in g) v.call(g, S) && (y[S] = g[S]);
          return E.prototype = g.prototype, y.prototype = new E(), y.__super__ = g.prototype, y;
        }, v = {}.hasOwnProperty, b = [].indexOf || function(y) {
          for (var g = 0, E = this.length; E > g; g++) if (g in this && this[g] === y) return g;
          return -1;
        };
        r = n.arraysAreEqual, l = n.makeElement, f = n.tagName, s = n.getBlockTagNames, h = n.walkTree, o = n.findClosestElementFromNode, a = n.elementContainsNode, u = n.nodeIsAttachmentElement, c = n.normalizeSpaces, i = n.breakableWhitespacePattern, d = n.squishBreakableWhitespace, n.HTMLParser = function(y) {
          function g(x, I) {
            this.html = x, this.referenceElement = (I ?? {}).referenceElement, this.blocks = [], this.blockElements = [], this.processedElements = [];
          }
          var E, S, C, T, O, R, D, q, $, P, Y, L;
          return m(g, y), g.parse = function(x, I) {
            var k;
            return k = new this(x, I), k.parse(), k;
          }, g.prototype.getDocument = function() {
            return n.Document.fromJSON(this.blocks);
          }, g.prototype.parse = function() {
            var x, I;
            try {
              for (this.createHiddenContainer(), x = n.HTMLSanitizer.sanitize(this.html).getHTML(), this.containerElement.innerHTML = x, I = h(this.containerElement, { usingFilter: D }); I.nextNode(); ) this.processNode(I.currentNode);
              return this.translateBlockElementMarginsToNewlines();
            } finally {
              this.removeHiddenContainer();
            }
          }, g.prototype.createHiddenContainer = function() {
            return this.referenceElement ? (this.containerElement = this.referenceElement.cloneNode(!1), this.containerElement.removeAttribute("id"), this.containerElement.setAttribute("data-trix-internal", ""), this.containerElement.style.display = "none", this.referenceElement.parentNode.insertBefore(this.containerElement, this.referenceElement.nextSibling)) : (this.containerElement = l({ tagName: "div", style: { display: "none" } }), document.body.appendChild(this.containerElement));
          }, g.prototype.removeHiddenContainer = function() {
            return n.removeNode(this.containerElement);
          }, D = function(x) {
            return f(x) === "style" ? NodeFilter.FILTER_REJECT : NodeFilter.FILTER_ACCEPT;
          }, g.prototype.processNode = function(x) {
            switch (x.nodeType) {
              case Node.TEXT_NODE:
                if (!this.isInsignificantTextNode(x)) return this.appendBlockForTextNode(x), this.processTextNode(x);
                break;
              case Node.ELEMENT_NODE:
                return this.appendBlockForElement(x), this.processElement(x);
            }
          }, g.prototype.appendBlockForTextNode = function(x) {
            var I, k, B;
            return k = x.parentNode, k === this.currentBlockElement && this.isBlockElement(x.previousSibling) ? this.appendStringWithAttributes(`
`) : k !== this.containerElement && !this.isBlockElement(k) || (I = this.getBlockAttributes(k), r(I, (B = this.currentBlock) != null ? B.attributes : void 0)) ? void 0 : (this.currentBlock = this.appendBlockForAttributesWithElement(I, k), this.currentBlockElement = k);
          }, g.prototype.appendBlockForElement = function(x) {
            var I, k, B, W;
            if (B = this.isBlockElement(x), k = a(this.currentBlockElement, x), B && !this.isBlockElement(x.firstChild)) {
              if ((!this.isInsignificantTextNode(x.firstChild) || !this.isBlockElement(x.firstElementChild)) && (I = this.getBlockAttributes(x), x.firstChild)) return k && r(I, this.currentBlock.attributes) ? this.appendStringWithAttributes(`
`) : (this.currentBlock = this.appendBlockForAttributesWithElement(I, x), this.currentBlockElement = x);
            } else if (this.currentBlockElement && !k && !B) return (W = this.findParentBlockElement(x)) ? this.appendBlockForElement(W) : (this.currentBlock = this.appendEmptyBlock(), this.currentBlockElement = null);
          }, g.prototype.findParentBlockElement = function(x) {
            var I;
            for (I = x.parentElement; I && I !== this.containerElement; ) {
              if (this.isBlockElement(I) && b.call(this.blockElements, I) >= 0) return I;
              I = I.parentElement;
            }
            return null;
          }, g.prototype.processTextNode = function(x) {
            var I, k;
            return k = x.data, S(x.parentNode) || (k = d(k), Y((I = x.previousSibling) != null ? I.textContent : void 0) && (k = O(k))), this.appendStringWithAttributes(k, this.getTextAttributes(x.parentNode));
          }, g.prototype.processElement = function(x) {
            var I, k, B, W, Z;
            if (u(x)) return I = q(x, "attachment"), Object.keys(I).length && (W = this.getTextAttributes(x), this.appendAttachmentWithAttributes(I, W), x.innerHTML = ""), this.processedElements.push(x);
            switch (f(x)) {
              case "br":
                return this.isExtraBR(x) || this.isBlockElement(x.nextSibling) || this.appendStringWithAttributes(`
`, this.getTextAttributes(x)), this.processedElements.push(x);
              case "img":
                I = { url: x.getAttribute("src"), contentType: "image" }, B = T(x);
                for (k in B) Z = B[k], I[k] = Z;
                return this.appendAttachmentWithAttributes(I, this.getTextAttributes(x)), this.processedElements.push(x);
              case "tr":
                if (x.parentNode.firstChild !== x) return this.appendStringWithAttributes(`
`);
                break;
              case "td":
                if (x.parentNode.firstChild !== x) return this.appendStringWithAttributes(" | ");
            }
          }, g.prototype.appendBlockForAttributesWithElement = function(x, I) {
            var k;
            return this.blockElements.push(I), k = E(x), this.blocks.push(k), k;
          }, g.prototype.appendEmptyBlock = function() {
            return this.appendBlockForAttributesWithElement([], null);
          }, g.prototype.appendStringWithAttributes = function(x, I) {
            return this.appendPiece(P(x, I));
          }, g.prototype.appendAttachmentWithAttributes = function(x, I) {
            return this.appendPiece($(x, I));
          }, g.prototype.appendPiece = function(x) {
            return this.blocks.length === 0 && this.appendEmptyBlock(), this.blocks[this.blocks.length - 1].text.push(x);
          }, g.prototype.appendStringToTextAtIndex = function(x, I) {
            var k, B;
            return B = this.blocks[I].text, k = B[B.length - 1], (k != null ? k.type : void 0) === "string" ? k.string += x : B.push(P(x));
          }, g.prototype.prependStringToTextAtIndex = function(x, I) {
            var k, B;
            return B = this.blocks[I].text, k = B[0], (k != null ? k.type : void 0) === "string" ? k.string = x + k.string : B.unshift(P(x));
          }, P = function(x, I) {
            var k;
            return I == null && (I = {}), k = "string", x = c(x), { string: x, attributes: I, type: k };
          }, $ = function(x, I) {
            var k;
            return I == null && (I = {}), k = "attachment", { attachment: x, attributes: I, type: k };
          }, E = function(x) {
            var I;
            return x == null && (x = {}), I = [], { text: I, attributes: x };
          }, g.prototype.getTextAttributes = function(x) {
            var I, k, B, W, Z, V, K, ne, Ee, oe, ae, pe;
            B = {}, Ee = n.config.textAttributes;
            for (I in Ee) if (Z = Ee[I], Z.tagName && o(x, { matchingSelector: Z.tagName, untilNode: this.containerElement })) B[I] = !0;
            else if (Z.parser) {
              if (pe = Z.parser(x)) {
                for (k = !1, oe = this.findBlockElementAncestors(x), V = 0, ne = oe.length; ne > V; V++) if (W = oe[V], Z.parser(W) === pe) {
                  k = !0;
                  break;
                }
                k || (B[I] = pe);
              }
            } else Z.styleProperty && (pe = x.style[Z.styleProperty]) && (B[I] = pe);
            if (u(x)) {
              ae = q(x, "attributes");
              for (K in ae) pe = ae[K], B[K] = pe;
            }
            return B;
          }, g.prototype.getBlockAttributes = function(x) {
            var I, k, B, W;
            for (k = []; x && x !== this.containerElement; ) {
              W = n.config.blockAttributes;
              for (I in W) B = W[I], B.parse !== !1 && f(x) === B.tagName && (typeof B.test == "function" && B.test(x) || !B.test) && (k.push(I), B.listAttribute && k.push(B.listAttribute));
              x = x.parentNode;
            }
            return k.reverse();
          }, g.prototype.findBlockElementAncestors = function(x) {
            var I, k;
            for (I = []; x && x !== this.containerElement; ) k = f(x), b.call(s(), k) >= 0 && I.push(x), x = x.parentNode;
            return I;
          }, q = function(x, I) {
            try {
              return JSON.parse(x.getAttribute("data-trix-" + I));
            } catch {
              return {};
            }
          }, T = function(x) {
            var I, k, B;
            return B = x.getAttribute("width"), k = x.getAttribute("height"), I = {}, B && (I.width = parseInt(B, 10)), k && (I.height = parseInt(k, 10)), I;
          }, g.prototype.isBlockElement = function(x) {
            var I;
            if ((x != null ? x.nodeType : void 0) === Node.ELEMENT_NODE && !u(x) && !o(x, { matchingSelector: "td", untilNode: this.containerElement })) return I = f(x), b.call(s(), I) >= 0 || window.getComputedStyle(x).display === "block";
          }, g.prototype.isInsignificantTextNode = function(x) {
            var I, k, B;
            if ((x != null ? x.nodeType : void 0) === Node.TEXT_NODE && L(x.data) && (k = x.parentNode, B = x.previousSibling, I = x.nextSibling, (!R(k.previousSibling) || this.isBlockElement(k.previousSibling)) && !S(k))) return !B || this.isBlockElement(B) || !I || this.isBlockElement(I);
          }, g.prototype.isExtraBR = function(x) {
            return f(x) === "br" && this.isBlockElement(x.parentNode) && x.parentNode.lastChild === x;
          }, S = function(x) {
            var I;
            return I = window.getComputedStyle(x).whiteSpace, I === "pre" || I === "pre-wrap" || I === "pre-line";
          }, R = function(x) {
            return x && !Y(x.textContent);
          }, g.prototype.translateBlockElementMarginsToNewlines = function() {
            var x, I, k, B, W, Z, V;
            for (x = this.getMarginOfDefaultBlockElement(), Z = this.blocks, V = [], k = I = 0, B = Z.length; B > I; k = ++I) Z[k], (W = this.getMarginOfBlockElementAtIndex(k)) && (W.top > 2 * x.top && this.prependStringToTextAtIndex(`
`, k), V.push(W.bottom > 2 * x.bottom ? this.appendStringToTextAtIndex(`
`, k) : void 0));
            return V;
          }, g.prototype.getMarginOfBlockElementAtIndex = function(x) {
            var I, k;
            return !(I = this.blockElements[x]) || !I.textContent || (k = f(I), b.call(s(), k) >= 0 || b.call(this.processedElements, I) >= 0) ? void 0 : C(I);
          }, g.prototype.getMarginOfDefaultBlockElement = function() {
            var x;
            return x = l(n.config.blockAttributes.default.tagName), this.containerElement.appendChild(x), C(x);
          }, C = function(x) {
            var I;
            return I = window.getComputedStyle(x), I.display === "block" ? { top: parseInt(I.marginTop), bottom: parseInt(I.marginBottom) } : void 0;
          }, O = function(x) {
            return x.replace(RegExp("^" + i.source + "+"), "");
          }, L = function(x) {
            return RegExp("^" + i.source + "*$").test(x);
          }, Y = function(x) {
            return /\s$/.test(x);
          }, g;
        }(n.BasicObject);
      }).call(this), (function() {
        var r, i, a, o, s = function(d, f) {
          function h() {
            this.constructor = d;
          }
          for (var m in f) l.call(f, m) && (d[m] = f[m]);
          return h.prototype = f.prototype, d.prototype = new h(), d.__super__ = f.prototype, d;
        }, l = {}.hasOwnProperty, u = [].slice, c = [].indexOf || function(d) {
          for (var f = 0, h = this.length; h > f; f++) if (f in this && this[f] === d) return f;
          return -1;
        };
        r = n.arraysAreEqual, a = n.normalizeRange, o = n.rangeIsCollapsed, i = n.getBlockConfig, n.Document = function(d) {
          function f(m) {
            m == null && (m = []), f.__super__.constructor.apply(this, arguments), m.length === 0 && (m = [new n.Block()]), this.blockList = n.SplittableList.box(m);
          }
          var h;
          return s(f, d), f.fromJSON = function(m) {
            var v, b;
            return b = function() {
              var y, g, E;
              for (E = [], y = 0, g = m.length; g > y; y++) v = m[y], E.push(n.Block.fromJSON(v));
              return E;
            }(), new this(b);
          }, f.fromHTML = function(m, v) {
            return n.HTMLParser.parse(m, v).getDocument();
          }, f.fromString = function(m, v) {
            var b;
            return b = n.Text.textForStringWithAttributes(m, v), new this([new n.Block(b)]);
          }, f.prototype.isEmpty = function() {
            var m;
            return this.blockList.length === 1 && (m = this.getBlockAtIndex(0), m.isEmpty() && !m.hasAttributes());
          }, f.prototype.copy = function(m) {
            var v;
            return m == null && (m = {}), v = m.consolidateBlocks ? this.blockList.consolidate().toArray() : this.blockList.toArray(), new this.constructor(v);
          }, f.prototype.copyUsingObjectsFromDocument = function(m) {
            var v;
            return v = new n.ObjectMap(m.getObjects()), this.copyUsingObjectMap(v);
          }, f.prototype.copyUsingObjectMap = function(m) {
            var v, b, y;
            return b = (function() {
              var g, E, S, C;
              for (S = this.getBlocks(), C = [], g = 0, E = S.length; E > g; g++) v = S[g], C.push((y = m.find(v)) ? y : v.copyUsingObjectMap(m));
              return C;
            }).call(this), new this.constructor(b);
          }, f.prototype.copyWithBaseBlockAttributes = function(m) {
            var v, b, y;
            return m == null && (m = []), y = (function() {
              var g, E, S, C;
              for (S = this.getBlocks(), C = [], g = 0, E = S.length; E > g; g++) b = S[g], v = m.concat(b.getAttributes()), C.push(b.copyWithAttributes(v));
              return C;
            }).call(this), new this.constructor(y);
          }, f.prototype.replaceBlock = function(m, v) {
            var b;
            return b = this.blockList.indexOf(m), b === -1 ? this : new this.constructor(this.blockList.replaceObjectAtIndex(v, b));
          }, f.prototype.insertDocumentAtRange = function(m, v) {
            var b, y, g, E, S, C, T;
            return y = m.blockList, S = (v = a(v))[0], C = this.locationFromPosition(S), g = C.index, E = C.offset, T = this, b = this.getBlockAtPosition(S), o(v) && b.isEmpty() && !b.hasAttributes() ? T = new this.constructor(T.blockList.removeObjectAtIndex(g)) : b.getBlockBreakPosition() === E && S++, T = T.removeTextAtRange(v), new this.constructor(T.blockList.insertSplittableListAtPosition(y, S));
          }, f.prototype.mergeDocumentAtRange = function(m, v) {
            var b, y, g, E, S, C, T, O, R, D, q, $;
            return q = (v = a(v))[0], D = this.locationFromPosition(q), y = this.getBlockAtIndex(D.index).getAttributes(), b = m.getBaseBlockAttributes(), $ = y.slice(-b.length), r(b, $) ? (T = y.slice(0, -b.length), C = m.copyWithBaseBlockAttributes(T)) : C = m.copy({ consolidateBlocks: !0 }).copyWithBaseBlockAttributes(y), g = C.getBlockCount(), E = C.getBlockAtIndex(0), r(y, E.getAttributes()) ? (S = E.getTextWithoutBlockBreak(), R = this.insertTextAtRange(S, v), g > 1 && (C = new this.constructor(C.getBlocks().slice(1)), O = q + S.getLength(), R = R.insertDocumentAtRange(C, O))) : R = this.insertDocumentAtRange(C, v), R;
          }, f.prototype.insertTextAtRange = function(m, v) {
            var b, y, g, E, S;
            return S = (v = a(v))[0], E = this.locationFromPosition(S), y = E.index, g = E.offset, b = this.removeTextAtRange(v), new this.constructor(b.blockList.editObjectAtIndex(y, function(C) {
              return C.copyWithText(C.text.insertTextAtPosition(m, g));
            }));
          }, f.prototype.removeTextAtRange = function(m) {
            var v, b, y, g, E, S, C, T, O, R, D, q, $, P, Y, L, x, I, k, B, W;
            return R = m = a(m), T = R[0], I = R[1], o(m) ? this : (D = this.locationRangeFromRange(m), S = D[0], L = D[1], E = S.index, C = S.offset, g = this.getBlockAtIndex(E), Y = L.index, x = L.offset, P = this.getBlockAtIndex(Y), q = I - T === 1 && g.getBlockBreakPosition() === C && P.getBlockBreakPosition() !== x && P.text.getStringAtPosition(x) === `
`, q ? y = this.blockList.editObjectAtIndex(Y, function(Z) {
              return Z.copyWithText(Z.text.removeTextAtRange([x, x + 1]));
            }) : (O = g.text.getTextAtRange([0, C]), k = P.text.getTextAtRange([x, P.getLength()]), B = O.appendText(k), $ = E !== Y && C === 0, W = $ && g.getAttributeLevel() >= P.getAttributeLevel(), b = W ? P.copyWithText(B) : g.copyWithText(B), v = Y + 1 - E, y = this.blockList.splice(E, v, b)), new this.constructor(y));
          }, f.prototype.moveTextFromRangeToPosition = function(m, v) {
            var b, y, g, E, S, C, T, O, R, D;
            return C = m = a(m), R = C[0], g = C[1], v >= R && g >= v ? this : (y = this.getDocumentAtRange(m), O = this.removeTextAtRange(m), S = v > R, S && (v -= y.getLength()), T = y.getBlocks(), E = T[0], b = 2 <= T.length ? u.call(T, 1) : [], b.length === 0 ? (D = E.getTextWithoutBlockBreak(), S && (v += 1)) : D = E.text, O = O.insertTextAtRange(D, v), b.length === 0 ? O : (y = new this.constructor(b), v += D.getLength(), O.insertDocumentAtRange(y, v)));
          }, f.prototype.addAttributeAtRange = function(m, v, b) {
            var y;
            return y = this.blockList, this.eachBlockAtRange(b, function(g, E, S) {
              return y = y.editObjectAtIndex(S, function() {
                return i(m) ? g.addAttribute(m, v) : E[0] === E[1] ? g : g.copyWithText(g.text.addAttributeAtRange(m, v, E));
              });
            }), new this.constructor(y);
          }, f.prototype.addAttribute = function(m, v) {
            var b;
            return b = this.blockList, this.eachBlock(function(y, g) {
              return b = b.editObjectAtIndex(g, function() {
                return y.addAttribute(m, v);
              });
            }), new this.constructor(b);
          }, f.prototype.removeAttributeAtRange = function(m, v) {
            var b;
            return b = this.blockList, this.eachBlockAtRange(v, function(y, g, E) {
              return i(m) ? b = b.editObjectAtIndex(E, function() {
                return y.removeAttribute(m);
              }) : g[0] !== g[1] ? b = b.editObjectAtIndex(E, function() {
                return y.copyWithText(y.text.removeAttributeAtRange(m, g));
              }) : void 0;
            }), new this.constructor(b);
          }, f.prototype.updateAttributesForAttachment = function(m, v) {
            var b, y, g;
            return y = this.getRangeOfAttachment(v)[0], b = this.locationFromPosition(y).index, g = this.getTextAtIndex(b), new this.constructor(this.blockList.editObjectAtIndex(b, function(E) {
              return E.copyWithText(g.updateAttributesForAttachment(m, v));
            }));
          }, f.prototype.removeAttributeForAttachment = function(m, v) {
            var b;
            return b = this.getRangeOfAttachment(v), this.removeAttributeAtRange(m, b);
          }, f.prototype.insertBlockBreakAtRange = function(m) {
            var v, b, y, g;
            return g = (m = a(m))[0], y = this.locationFromPosition(g).offset, b = this.removeTextAtRange(m), y === 0 && (v = [new n.Block()]), new this.constructor(b.blockList.insertSplittableListAtPosition(new n.SplittableList(v), g));
          }, f.prototype.applyBlockAttributeAtRange = function(m, v, b) {
            var y, g, E, S;
            return E = this.expandRangeToLineBreaksAndSplitBlocks(b), g = E.document, b = E.range, y = i(m), y.listAttribute ? (g = g.removeLastListAttributeAtRange(b, { exceptAttributeName: m }), S = g.convertLineBreaksToBlockBreaksInRange(b), g = S.document, b = S.range) : g = y.exclusive ? g.removeBlockAttributesAtRange(b) : y.terminal ? g.removeLastTerminalAttributeAtRange(b) : g.consolidateBlocksAtRange(b), g.addAttributeAtRange(m, v, b);
          }, f.prototype.removeLastListAttributeAtRange = function(m, v) {
            var b;
            return v == null && (v = {}), b = this.blockList, this.eachBlockAtRange(m, function(y, g, E) {
              var S;
              if ((S = y.getLastAttribute()) && i(S).listAttribute && S !== v.exceptAttributeName) return b = b.editObjectAtIndex(E, function() {
                return y.removeAttribute(S);
              });
            }), new this.constructor(b);
          }, f.prototype.removeLastTerminalAttributeAtRange = function(m) {
            var v;
            return v = this.blockList, this.eachBlockAtRange(m, function(b, y, g) {
              var E;
              if ((E = b.getLastAttribute()) && i(E).terminal) return v = v.editObjectAtIndex(g, function() {
                return b.removeAttribute(E);
              });
            }), new this.constructor(v);
          }, f.prototype.removeBlockAttributesAtRange = function(m) {
            var v;
            return v = this.blockList, this.eachBlockAtRange(m, function(b, y, g) {
              return b.hasAttributes() ? v = v.editObjectAtIndex(g, function() {
                return b.copyWithoutAttributes();
              }) : void 0;
            }), new this.constructor(v);
          }, f.prototype.expandRangeToLineBreaksAndSplitBlocks = function(m) {
            var v, b, y, g, E, S, C, T, O;
            return S = m = a(m), O = S[0], g = S[1], T = this.locationFromPosition(O), y = this.locationFromPosition(g), v = this, C = v.getBlockAtIndex(T.index), (T.offset = C.findLineBreakInDirectionFromPosition("backward", T.offset)) != null && (E = v.positionFromLocation(T), v = v.insertBlockBreakAtRange([E, E + 1]), y.index += 1, y.offset -= v.getBlockAtIndex(T.index).getLength(), T.index += 1), T.offset = 0, y.offset === 0 && y.index > T.index ? (y.index -= 1, y.offset = v.getBlockAtIndex(y.index).getBlockBreakPosition()) : (b = v.getBlockAtIndex(y.index), b.text.getStringAtRange([y.offset - 1, y.offset]) === `
` ? y.offset -= 1 : y.offset = b.findLineBreakInDirectionFromPosition("forward", y.offset), y.offset !== b.getBlockBreakPosition() && (E = v.positionFromLocation(y), v = v.insertBlockBreakAtRange([E, E + 1]))), O = v.positionFromLocation(T), g = v.positionFromLocation(y), m = a([O, g]), { document: v, range: m };
          }, f.prototype.convertLineBreaksToBlockBreaksInRange = function(m) {
            var v, b, y;
            return b = (m = a(m))[0], y = this.getStringAtRange(m).slice(0, -1), v = this, y.replace(/.*?\n/g, function(g) {
              return b += g.length, v = v.insertBlockBreakAtRange([b - 1, b]);
            }), { document: v, range: m };
          }, f.prototype.consolidateBlocksAtRange = function(m) {
            var v, b, y, g, E;
            return y = m = a(m), E = y[0], b = y[1], g = this.locationFromPosition(E).index, v = this.locationFromPosition(b).index, new this.constructor(this.blockList.consolidateFromIndexToIndex(g, v));
          }, f.prototype.getDocumentAtRange = function(m) {
            var v;
            return m = a(m), v = this.blockList.getSplittableListInRange(m).toArray(), new this.constructor(v);
          }, f.prototype.getStringAtRange = function(m) {
            var v, b, y;
            return y = m = a(m), b = y[y.length - 1], b !== this.getLength() && (v = -1), this.getDocumentAtRange(m).toString().slice(0, v);
          }, f.prototype.getBlockAtIndex = function(m) {
            return this.blockList.getObjectAtIndex(m);
          }, f.prototype.getBlockAtPosition = function(m) {
            var v;
            return v = this.locationFromPosition(m).index, this.getBlockAtIndex(v);
          }, f.prototype.getTextAtIndex = function(m) {
            var v;
            return (v = this.getBlockAtIndex(m)) != null ? v.text : void 0;
          }, f.prototype.getTextAtPosition = function(m) {
            var v;
            return v = this.locationFromPosition(m).index, this.getTextAtIndex(v);
          }, f.prototype.getPieceAtPosition = function(m) {
            var v, b, y;
            return y = this.locationFromPosition(m), v = y.index, b = y.offset, this.getTextAtIndex(v).getPieceAtPosition(b);
          }, f.prototype.getCharacterAtPosition = function(m) {
            var v, b, y;
            return y = this.locationFromPosition(m), v = y.index, b = y.offset, this.getTextAtIndex(v).getStringAtRange([b, b + 1]);
          }, f.prototype.getLength = function() {
            return this.blockList.getEndPosition();
          }, f.prototype.getBlocks = function() {
            return this.blockList.toArray();
          }, f.prototype.getBlockCount = function() {
            return this.blockList.length;
          }, f.prototype.getEditCount = function() {
            return this.editCount;
          }, f.prototype.eachBlock = function(m) {
            return this.blockList.eachObject(m);
          }, f.prototype.eachBlockAtRange = function(m, v) {
            var b, y, g, E, S, C, T, O, R, D, q, $;
            if (C = m = a(m), q = C[0], g = C[1], D = this.locationFromPosition(q), y = this.locationFromPosition(g), D.index === y.index) return b = this.getBlockAtIndex(D.index), $ = [D.offset, y.offset], v(b, $, D.index);
            for (R = [], S = E = T = D.index, O = y.index; O >= T ? O >= E : E >= O; S = O >= T ? ++E : --E) (b = this.getBlockAtIndex(S)) ? ($ = function() {
              switch (S) {
                case D.index:
                  return [D.offset, b.text.getLength()];
                case y.index:
                  return [0, y.offset];
                default:
                  return [0, b.text.getLength()];
              }
            }(), R.push(v(b, $, S))) : R.push(void 0);
            return R;
          }, f.prototype.getCommonAttributesAtRange = function(m) {
            var v, b, y;
            return b = (m = a(m))[0], o(m) ? this.getCommonAttributesAtPosition(b) : (y = [], v = [], this.eachBlockAtRange(m, function(g, E) {
              return E[0] !== E[1] ? (y.push(g.text.getCommonAttributesAtRange(E)), v.push(h(g))) : void 0;
            }), n.Hash.fromCommonAttributesOfObjects(y).merge(n.Hash.fromCommonAttributesOfObjects(v)).toObject());
          }, f.prototype.getCommonAttributesAtPosition = function(m) {
            var v, b, y, g, E, S, C, T, O, R;
            if (O = this.locationFromPosition(m), E = O.index, T = O.offset, y = this.getBlockAtIndex(E), !y) return {};
            g = h(y), v = y.text.getAttributesAtPosition(T), b = y.text.getAttributesAtPosition(T - 1), S = function() {
              var D, q;
              D = n.config.textAttributes, q = [];
              for (C in D) R = D[C], R.inheritable && q.push(C);
              return q;
            }();
            for (C in b) R = b[C], (R === v[C] || c.call(S, C) >= 0) && (g[C] = R);
            return g;
          }, f.prototype.getRangeOfCommonAttributeAtPosition = function(m, v) {
            var b, y, g, E, S, C, T, O, R;
            return S = this.locationFromPosition(v), g = S.index, E = S.offset, R = this.getTextAtIndex(g), C = R.getExpandedRangeForAttributeAtOffset(m, E), O = C[0], y = C[1], T = this.positionFromLocation({ index: g, offset: O }), b = this.positionFromLocation({ index: g, offset: y }), a([T, b]);
          }, f.prototype.getBaseBlockAttributes = function() {
            var m, v, b, y, g, E, S;
            for (m = this.getBlockAtIndex(0).getAttributes(), b = y = 1, S = this.getBlockCount(); S >= 1 ? S > y : y > S; b = S >= 1 ? ++y : --y) v = this.getBlockAtIndex(b).getAttributes(), E = Math.min(m.length, v.length), m = function() {
              var C, T, O;
              for (O = [], g = C = 0, T = E; (T >= 0 ? T > C : C > T) && v[g] === m[g]; g = T >= 0 ? ++C : --C) O.push(v[g]);
              return O;
            }();
            return m;
          }, h = function(m) {
            var v, b;
            return b = {}, (v = m.getLastAttribute()) && (b[v] = !0), b;
          }, f.prototype.getAttachmentById = function(m) {
            var v, b, y, g;
            for (g = this.getAttachments(), b = 0, y = g.length; y > b; b++) if (v = g[b], v.id === m) return v;
          }, f.prototype.getAttachmentPieces = function() {
            var m;
            return m = [], this.blockList.eachObject(function(v) {
              var b;
              return b = v.text, m = m.concat(b.getAttachmentPieces());
            }), m;
          }, f.prototype.getAttachments = function() {
            var m, v, b, y, g;
            for (y = this.getAttachmentPieces(), g = [], m = 0, v = y.length; v > m; m++) b = y[m], g.push(b.attachment);
            return g;
          }, f.prototype.getRangeOfAttachment = function(m) {
            var v, b, y, g, E, S, C;
            for (g = 0, E = this.blockList.toArray(), b = v = 0, y = E.length; y > v; b = ++v) {
              if (S = E[b].text, C = S.getRangeOfAttachment(m)) return a([g + C[0], g + C[1]]);
              g += S.getLength();
            }
          }, f.prototype.getLocationRangeOfAttachment = function(m) {
            var v;
            return v = this.getRangeOfAttachment(m), this.locationRangeFromRange(v);
          }, f.prototype.getAttachmentPieceForAttachment = function(m) {
            var v, b, y, g;
            for (g = this.getAttachmentPieces(), v = 0, b = g.length; b > v; v++) if (y = g[v], y.attachment === m) return y;
          }, f.prototype.findRangesForBlockAttribute = function(m) {
            var v, b, y, g, E, S, C;
            for (E = 0, S = [], C = this.getBlocks(), b = 0, y = C.length; y > b; b++) v = C[b], g = v.getLength(), v.hasAttribute(m) && S.push([E, E + g]), E += g;
            return S;
          }, f.prototype.findRangesForTextAttribute = function(m, v) {
            var b, y, g, E, S, C, T, O, R, D;
            for (D = (v ?? {}).withValue, C = 0, T = [], O = [], E = function(q) {
              return D != null ? q.getAttribute(m) === D : q.hasAttribute(m);
            }, R = this.getPieces(), b = 0, y = R.length; y > b; b++) S = R[b], g = S.getLength(), E(S) && (T[1] === C ? T[1] = C + g : O.push(T = [C, C + g])), C += g;
            return O;
          }, f.prototype.locationFromPosition = function(m) {
            var v, b;
            return b = this.blockList.findIndexAndOffsetAtPosition(Math.max(0, m)), b.index != null ? b : (v = this.getBlocks(), { index: v.length - 1, offset: v[v.length - 1].getLength() });
          }, f.prototype.positionFromLocation = function(m) {
            return this.blockList.findPositionAtIndexAndOffset(m.index, m.offset);
          }, f.prototype.locationRangeFromPosition = function(m) {
            return a(this.locationFromPosition(m));
          }, f.prototype.locationRangeFromRange = function(m) {
            var v, b, y, g;
            if (m = a(m)) return g = m[0], b = m[1], y = this.locationFromPosition(g), v = this.locationFromPosition(b), a([y, v]);
          }, f.prototype.rangeFromLocationRange = function(m) {
            var v, b;
            return m = a(m), v = this.positionFromLocation(m[0]), o(m) || (b = this.positionFromLocation(m[1])), a([v, b]);
          }, f.prototype.isEqualTo = function(m) {
            return this.blockList.isEqualTo(m != null ? m.blockList : void 0);
          }, f.prototype.getTexts = function() {
            var m, v, b, y, g;
            for (y = this.getBlocks(), g = [], v = 0, b = y.length; b > v; v++) m = y[v], g.push(m.text);
            return g;
          }, f.prototype.getPieces = function() {
            var m, v, b, y, g;
            for (b = [], y = this.getTexts(), m = 0, v = y.length; v > m; m++) g = y[m], b.push.apply(b, g.getPieces());
            return b;
          }, f.prototype.getObjects = function() {
            return this.getBlocks().concat(this.getTexts()).concat(this.getPieces());
          }, f.prototype.toSerializableDocument = function() {
            var m;
            return m = [], this.blockList.eachObject(function(v) {
              return m.push(v.copyWithText(v.text.toSerializableText()));
            }), new this.constructor(m);
          }, f.prototype.toString = function() {
            return this.blockList.toString();
          }, f.prototype.toJSON = function() {
            return this.blockList.toJSON();
          }, f.prototype.toConsole = function() {
            var m;
            return JSON.stringify((function() {
              var v, b, y, g;
              for (y = this.blockList.toArray(), g = [], v = 0, b = y.length; b > v; v++) m = y[v], g.push(JSON.parse(m.text.toConsole()));
              return g;
            }).call(this));
          }, f;
        }(n.Object);
      }).call(this), (function() {
        n.LineBreakInsertion = function() {
          function r(i) {
            var a;
            this.composition = i, this.document = this.composition.document, a = this.composition.getSelectedRange(), this.startPosition = a[0], this.endPosition = a[1], this.startLocation = this.document.locationFromPosition(this.startPosition), this.endLocation = this.document.locationFromPosition(this.endPosition), this.block = this.document.getBlockAtIndex(this.endLocation.index), this.breaksOnReturn = this.block.breaksOnReturn(), this.previousCharacter = this.block.text.getStringAtPosition(this.endLocation.offset - 1), this.nextCharacter = this.block.text.getStringAtPosition(this.endLocation.offset);
          }
          return r.prototype.shouldInsertBlockBreak = function() {
            return this.block.hasAttributes() && this.block.isListItem() && !this.block.isEmpty() ? this.startLocation.offset !== 0 : this.breaksOnReturn && this.nextCharacter !== `
`;
          }, r.prototype.shouldBreakFormattedBlock = function() {
            return this.block.hasAttributes() && !this.block.isListItem() && (this.breaksOnReturn && this.nextCharacter === `
` || this.previousCharacter === `
`);
          }, r.prototype.shouldDecreaseListLevel = function() {
            return this.block.hasAttributes() && this.block.isListItem() && this.block.isEmpty();
          }, r.prototype.shouldPrependListItem = function() {
            return this.block.isListItem() && this.startLocation.offset === 0 && !this.block.isEmpty();
          }, r.prototype.shouldRemoveLastBlockAttribute = function() {
            return this.block.hasAttributes() && !this.block.isListItem() && this.block.isEmpty();
          }, r;
        }();
      }).call(this), (function() {
        var r, i, a, o, s, l, u, c, d, f, h = function(v, b) {
          function y() {
            this.constructor = v;
          }
          for (var g in b) m.call(b, g) && (v[g] = b[g]);
          return y.prototype = b.prototype, v.prototype = new y(), v.__super__ = b.prototype, v;
        }, m = {}.hasOwnProperty;
        l = n.normalizeRange, d = n.rangesAreEqual, c = n.rangeIsCollapsed, u = n.objectsAreEqual, r = n.arrayStartsWith, f = n.summarizeArrayChange, a = n.getAllAttributeNames, o = n.getBlockConfig, s = n.getTextConfig, i = n.extend, n.Composition = function(v) {
          function b() {
            this.document = new n.Document(), this.attachments = [], this.currentAttributes = {}, this.revision = 0;
          }
          var y;
          return h(b, v), b.prototype.setDocument = function(g) {
            var E;
            return g.isEqualTo(this.document) ? void 0 : (this.document = g, this.refreshAttachments(), this.revision++, (E = this.delegate) != null && typeof E.compositionDidChangeDocument == "function" ? E.compositionDidChangeDocument(g) : void 0);
          }, b.prototype.getSnapshot = function() {
            return { document: this.document, selectedRange: this.getSelectedRange() };
          }, b.prototype.loadSnapshot = function(g) {
            var E, S, C, T;
            return E = g.document, T = g.selectedRange, (S = this.delegate) != null && typeof S.compositionWillLoadSnapshot == "function" && S.compositionWillLoadSnapshot(), this.setDocument(E ?? new n.Document()), this.setSelection(T ?? [0, 0]), (C = this.delegate) != null && typeof C.compositionDidLoadSnapshot == "function" ? C.compositionDidLoadSnapshot() : void 0;
          }, b.prototype.insertText = function(g, E) {
            var S, C, T, O;
            return O = (E ?? { updatePosition: !0 }).updatePosition, C = this.getSelectedRange(), this.setDocument(this.document.insertTextAtRange(g, C)), T = C[0], S = T + g.getLength(), O && this.setSelection(S), this.notifyDelegateOfInsertionAtRange([T, S]);
          }, b.prototype.insertBlock = function(g) {
            var E;
            return g == null && (g = new n.Block()), E = new n.Document([g]), this.insertDocument(E);
          }, b.prototype.insertDocument = function(g) {
            var E, S, C;
            return g == null && (g = new n.Document()), S = this.getSelectedRange(), this.setDocument(this.document.insertDocumentAtRange(g, S)), C = S[0], E = C + g.getLength(), this.setSelection(E), this.notifyDelegateOfInsertionAtRange([C, E]);
          }, b.prototype.insertString = function(g, E) {
            var S, C;
            return S = this.getCurrentTextAttributes(), C = n.Text.textForStringWithAttributes(g, S), this.insertText(C, E);
          }, b.prototype.insertBlockBreak = function() {
            var g, E, S;
            return E = this.getSelectedRange(), this.setDocument(this.document.insertBlockBreakAtRange(E)), S = E[0], g = S + 1, this.setSelection(g), this.notifyDelegateOfInsertionAtRange([S, g]);
          }, b.prototype.insertLineBreak = function() {
            var g, E;
            return E = new n.LineBreakInsertion(this), E.shouldDecreaseListLevel() ? (this.decreaseListLevel(), this.setSelection(E.startPosition)) : E.shouldPrependListItem() ? (g = new n.Document([E.block.copyWithoutText()]), this.insertDocument(g)) : E.shouldInsertBlockBreak() ? this.insertBlockBreak() : E.shouldRemoveLastBlockAttribute() ? this.removeLastBlockAttribute() : E.shouldBreakFormattedBlock() ? this.breakFormattedBlock(E) : this.insertString(`
`);
          }, b.prototype.insertHTML = function(g) {
            var E, S, C, T;
            return E = n.Document.fromHTML(g), C = this.getSelectedRange(), this.setDocument(this.document.mergeDocumentAtRange(E, C)), T = C[0], S = T + E.getLength() - 1, this.setSelection(S), this.notifyDelegateOfInsertionAtRange([T, S]);
          }, b.prototype.replaceHTML = function(g) {
            var E, S, C;
            return E = n.Document.fromHTML(g).copyUsingObjectsFromDocument(this.document), S = this.getLocationRange({ strict: !1 }), C = this.document.rangeFromLocationRange(S), this.setDocument(E), this.setSelection(C);
          }, b.prototype.insertFile = function(g) {
            return this.insertFiles([g]);
          }, b.prototype.insertFiles = function(g) {
            var E, S, C, T, O, R;
            for (S = [], T = 0, O = g.length; O > T; T++) C = g[T], (R = this.delegate) != null && R.compositionShouldAcceptFile(C) && (E = n.Attachment.attachmentForFile(C), S.push(E));
            return this.insertAttachments(S);
          }, b.prototype.insertAttachment = function(g) {
            return this.insertAttachments([g]);
          }, b.prototype.insertAttachments = function(g) {
            var E, S, C, T, O, R, D, q, $;
            for (q = new n.Text(), T = 0, O = g.length; O > T; T++) E = g[T], $ = E.getType(), R = (D = n.config.attachments[$]) != null ? D.presentation : void 0, C = this.getCurrentTextAttributes(), R && (C.presentation = R), S = n.Text.textForAttachmentWithAttributes(E, C), q = q.appendText(S);
            return this.insertText(q);
          }, b.prototype.shouldManageDeletingInDirection = function(g) {
            var E;
            if (E = this.getLocationRange(), c(E)) {
              if (g === "backward" && E[0].offset === 0 || this.shouldManageMovingCursorInDirection(g)) return !0;
            } else if (E[0].index !== E[1].index) return !0;
            return !1;
          }, b.prototype.deleteInDirection = function(g, E) {
            var S, C, T, O, R, D, q, $;
            return O = (E ?? {}).length, R = this.getLocationRange(), D = this.getSelectedRange(), q = c(D), q ? T = g === "backward" && R[0].offset === 0 : $ = R[0].index !== R[1].index, T && this.canDecreaseBlockAttributeLevel() && (C = this.getBlock(), C.isListItem() ? this.decreaseListLevel() : this.decreaseBlockAttributeLevel(), this.setSelection(D[0]), C.isEmpty()) ? !1 : (q && (D = this.getExpandedRangeInDirection(g, { length: O }), g === "backward" && (S = this.getAttachmentAtRange(D))), S ? (this.editAttachment(S), !1) : (this.setDocument(this.document.removeTextAtRange(D)), this.setSelection(D[0]), T || $ ? !1 : void 0));
          }, b.prototype.moveTextFromRange = function(g) {
            var E;
            return E = this.getSelectedRange()[0], this.setDocument(this.document.moveTextFromRangeToPosition(g, E)), this.setSelection(E);
          }, b.prototype.removeAttachment = function(g) {
            var E;
            return (E = this.document.getRangeOfAttachment(g)) ? (this.stopEditingAttachment(), this.setDocument(this.document.removeTextAtRange(E)), this.setSelection(E[0])) : void 0;
          }, b.prototype.removeLastBlockAttribute = function() {
            var g, E, S, C;
            return S = this.getSelectedRange(), C = S[0], E = S[1], g = this.document.getBlockAtPosition(E), this.removeCurrentAttribute(g.getLastAttribute()), this.setSelection(C);
          }, y = " ", b.prototype.insertPlaceholder = function() {
            return this.placeholderPosition = this.getPosition(), this.insertString(y);
          }, b.prototype.selectPlaceholder = function() {
            return this.placeholderPosition != null ? (this.setSelectedRange([this.placeholderPosition, this.placeholderPosition + y.length]), this.getSelectedRange()) : void 0;
          }, b.prototype.forgetPlaceholder = function() {
            return this.placeholderPosition = null;
          }, b.prototype.hasCurrentAttribute = function(g) {
            var E;
            return E = this.currentAttributes[g], E != null && E !== !1;
          }, b.prototype.toggleCurrentAttribute = function(g) {
            var E;
            return (E = !this.currentAttributes[g]) ? this.setCurrentAttribute(g, E) : this.removeCurrentAttribute(g);
          }, b.prototype.canSetCurrentAttribute = function(g) {
            return o(g) ? this.canSetCurrentBlockAttribute(g) : this.canSetCurrentTextAttribute(g);
          }, b.prototype.canSetCurrentTextAttribute = function() {
            var g, E, S, C, T;
            if (E = this.getSelectedDocument()) {
              for (T = E.getAttachments(), S = 0, C = T.length; C > S; S++) if (g = T[S], !g.hasContent()) return !1;
              return !0;
            }
          }, b.prototype.canSetCurrentBlockAttribute = function() {
            var g;
            if (g = this.getBlock()) return !g.isTerminalBlock();
          }, b.prototype.setCurrentAttribute = function(g, E) {
            return o(g) ? this.setBlockAttribute(g, E) : (this.setTextAttribute(g, E), this.currentAttributes[g] = E, this.notifyDelegateOfCurrentAttributesChange());
          }, b.prototype.setTextAttribute = function(g, E) {
            var S, C, T, O;
            if (C = this.getSelectedRange()) return T = C[0], S = C[1], T !== S ? this.setDocument(this.document.addAttributeAtRange(g, E, C)) : g === "href" ? (O = n.Text.textForStringWithAttributes(E, { href: E }), this.insertText(O)) : void 0;
          }, b.prototype.setBlockAttribute = function(g, E) {
            var S;
            if (S = this.getSelectedRange()) return this.canSetCurrentAttribute(g) ? (this.getBlock(), this.setDocument(this.document.applyBlockAttributeAtRange(g, E, S)), this.setSelection(S)) : void 0;
          }, b.prototype.removeCurrentAttribute = function(g) {
            return o(g) ? (this.removeBlockAttribute(g), this.updateCurrentAttributes()) : (this.removeTextAttribute(g), delete this.currentAttributes[g], this.notifyDelegateOfCurrentAttributesChange());
          }, b.prototype.removeTextAttribute = function(g) {
            var E;
            if (E = this.getSelectedRange()) return this.setDocument(this.document.removeAttributeAtRange(g, E));
          }, b.prototype.removeBlockAttribute = function(g) {
            var E;
            if (E = this.getSelectedRange()) return this.setDocument(this.document.removeAttributeAtRange(g, E));
          }, b.prototype.canDecreaseNestingLevel = function() {
            var g;
            return ((g = this.getBlock()) != null ? g.getNestingLevel() : void 0) > 0;
          }, b.prototype.canIncreaseNestingLevel = function() {
            var g, E, S;
            if (g = this.getBlock()) return (S = o(g.getLastNestableAttribute())) != null && S.listAttribute ? (E = this.getPreviousBlock()) ? r(E.getListItemAttributes(), g.getListItemAttributes()) : void 0 : g.getNestingLevel() > 0;
          }, b.prototype.decreaseNestingLevel = function() {
            var g;
            if (g = this.getBlock()) return this.setDocument(this.document.replaceBlock(g, g.decreaseNestingLevel()));
          }, b.prototype.increaseNestingLevel = function() {
            var g;
            if (g = this.getBlock()) return this.setDocument(this.document.replaceBlock(g, g.increaseNestingLevel()));
          }, b.prototype.canDecreaseBlockAttributeLevel = function() {
            var g;
            return ((g = this.getBlock()) != null ? g.getAttributeLevel() : void 0) > 0;
          }, b.prototype.decreaseBlockAttributeLevel = function() {
            var g, E;
            return (g = (E = this.getBlock()) != null ? E.getLastAttribute() : void 0) ? this.removeCurrentAttribute(g) : void 0;
          }, b.prototype.decreaseListLevel = function() {
            var g, E, S, C, T, O;
            for (O = this.getSelectedRange()[0], T = this.document.locationFromPosition(O).index, S = T, g = this.getBlock().getAttributeLevel(); (E = this.document.getBlockAtIndex(S + 1)) && E.isListItem() && E.getAttributeLevel() > g; ) S++;
            return O = this.document.positionFromLocation({ index: T, offset: 0 }), C = this.document.positionFromLocation({ index: S, offset: 0 }), this.setDocument(this.document.removeLastListAttributeAtRange([O, C]));
          }, b.prototype.updateCurrentAttributes = function() {
            var g, E, S, C, T, O;
            if (O = this.getSelectedRange({ ignoreLock: !0 })) {
              for (E = this.document.getCommonAttributesAtRange(O), T = a(), S = 0, C = T.length; C > S; S++) g = T[S], E[g] || this.canSetCurrentAttribute(g) || (E[g] = !1);
              if (!u(E, this.currentAttributes)) return this.currentAttributes = E, this.notifyDelegateOfCurrentAttributesChange();
            }
          }, b.prototype.getCurrentAttributes = function() {
            return i.call({}, this.currentAttributes);
          }, b.prototype.getCurrentTextAttributes = function() {
            var g, E, S, C;
            g = {}, S = this.currentAttributes;
            for (E in S) C = S[E], C !== !1 && s(E) && (g[E] = C);
            return g;
          }, b.prototype.freezeSelection = function() {
            return this.setCurrentAttribute("frozen", !0);
          }, b.prototype.thawSelection = function() {
            return this.removeCurrentAttribute("frozen");
          }, b.prototype.hasFrozenSelection = function() {
            return this.hasCurrentAttribute("frozen");
          }, b.proxyMethod("getSelectionManager().getPointRange"), b.proxyMethod("getSelectionManager().setLocationRangeFromPointRange"), b.proxyMethod("getSelectionManager().createLocationRangeFromDOMRange"), b.proxyMethod("getSelectionManager().locationIsCursorTarget"), b.proxyMethod("getSelectionManager().selectionIsExpanded"), b.proxyMethod("delegate?.getSelectionManager"), b.prototype.setSelection = function(g) {
            var E, S;
            return E = this.document.locationRangeFromRange(g), (S = this.delegate) != null ? S.compositionDidRequestChangingSelectionToLocationRange(E) : void 0;
          }, b.prototype.getSelectedRange = function() {
            var g;
            return (g = this.getLocationRange()) ? this.document.rangeFromLocationRange(g) : void 0;
          }, b.prototype.setSelectedRange = function(g) {
            var E;
            return E = this.document.locationRangeFromRange(g), this.getSelectionManager().setLocationRange(E);
          }, b.prototype.getPosition = function() {
            var g;
            return (g = this.getLocationRange()) ? this.document.positionFromLocation(g[0]) : void 0;
          }, b.prototype.getLocationRange = function(g) {
            var E, S;
            return (E = (S = this.targetLocationRange) != null ? S : this.getSelectionManager().getLocationRange(g)) != null ? E : l({ index: 0, offset: 0 });
          }, b.prototype.withTargetLocationRange = function(g, E) {
            var S;
            this.targetLocationRange = g;
            try {
              S = E();
            } finally {
              this.targetLocationRange = null;
            }
            return S;
          }, b.prototype.withTargetRange = function(g, E) {
            var S;
            return S = this.document.locationRangeFromRange(g), this.withTargetLocationRange(S, E);
          }, b.prototype.withTargetDOMRange = function(g, E) {
            var S;
            return S = this.createLocationRangeFromDOMRange(g, { strict: !1 }), this.withTargetLocationRange(S, E);
          }, b.prototype.getExpandedRangeInDirection = function(g, E) {
            var S, C, T, O;
            return C = (E ?? {}).length, T = this.getSelectedRange(), O = T[0], S = T[1], g === "backward" ? C ? O -= C : O = this.translateUTF16PositionFromOffset(O, -1) : C ? S += C : S = this.translateUTF16PositionFromOffset(S, 1), l([O, S]);
          }, b.prototype.shouldManageMovingCursorInDirection = function(g) {
            var E;
            return this.editingAttachment ? !0 : (E = this.getExpandedRangeInDirection(g), this.getAttachmentAtRange(E) != null);
          }, b.prototype.moveCursorInDirection = function(g) {
            var E, S, C, T;
            return this.editingAttachment ? C = this.document.getRangeOfAttachment(this.editingAttachment) : (T = this.getSelectedRange(), C = this.getExpandedRangeInDirection(g), S = !d(T, C)), this.setSelectedRange(g === "backward" ? C[0] : C[1]), S && (E = this.getAttachmentAtRange(C)) ? this.editAttachment(E) : void 0;
          }, b.prototype.expandSelectionInDirection = function(g, E) {
            var S, C;
            return S = (E ?? {}).length, C = this.getExpandedRangeInDirection(g, { length: S }), this.setSelectedRange(C);
          }, b.prototype.expandSelectionForEditing = function() {
            return this.hasCurrentAttribute("href") ? this.expandSelectionAroundCommonAttribute("href") : void 0;
          }, b.prototype.expandSelectionAroundCommonAttribute = function(g) {
            var E, S;
            return E = this.getPosition(), S = this.document.getRangeOfCommonAttributeAtPosition(g, E), this.setSelectedRange(S);
          }, b.prototype.selectionContainsAttachments = function() {
            var g;
            return ((g = this.getSelectedAttachments()) != null ? g.length : void 0) > 0;
          }, b.prototype.selectionIsInCursorTarget = function() {
            return this.editingAttachment || this.positionIsCursorTarget(this.getPosition());
          }, b.prototype.positionIsCursorTarget = function(g) {
            var E;
            return (E = this.document.locationFromPosition(g)) ? this.locationIsCursorTarget(E) : void 0;
          }, b.prototype.positionIsBlockBreak = function(g) {
            var E;
            return (E = this.document.getPieceAtPosition(g)) != null ? E.isBlockBreak() : void 0;
          }, b.prototype.getSelectedDocument = function() {
            var g;
            return (g = this.getSelectedRange()) ? this.document.getDocumentAtRange(g) : void 0;
          }, b.prototype.getSelectedAttachments = function() {
            var g;
            return (g = this.getSelectedDocument()) != null ? g.getAttachments() : void 0;
          }, b.prototype.getAttachments = function() {
            return this.attachments.slice(0);
          }, b.prototype.refreshAttachments = function() {
            var g, E, S, C, T, O, R, D, q, $, P, Y;
            for (S = this.document.getAttachments(), D = f(this.attachments, S), g = D.added, P = D.removed, this.attachments = S, C = 0, O = P.length; O > C; C++) E = P[C], E.delegate = null, (q = this.delegate) != null && typeof q.compositionDidRemoveAttachment == "function" && q.compositionDidRemoveAttachment(E);
            for (Y = [], T = 0, R = g.length; R > T; T++) E = g[T], E.delegate = this, Y.push(($ = this.delegate) != null && typeof $.compositionDidAddAttachment == "function" ? $.compositionDidAddAttachment(E) : void 0);
            return Y;
          }, b.prototype.attachmentDidChangeAttributes = function(g) {
            var E;
            return this.revision++, (E = this.delegate) != null && typeof E.compositionDidEditAttachment == "function" ? E.compositionDidEditAttachment(g) : void 0;
          }, b.prototype.attachmentDidChangePreviewURL = function(g) {
            var E;
            return this.revision++, (E = this.delegate) != null && typeof E.compositionDidChangeAttachmentPreviewURL == "function" ? E.compositionDidChangeAttachmentPreviewURL(g) : void 0;
          }, b.prototype.editAttachment = function(g, E) {
            var S;
            if (g !== this.editingAttachment) return this.stopEditingAttachment(), this.editingAttachment = g, (S = this.delegate) != null && typeof S.compositionDidStartEditingAttachment == "function" ? S.compositionDidStartEditingAttachment(this.editingAttachment, E) : void 0;
          }, b.prototype.stopEditingAttachment = function() {
            var g;
            if (this.editingAttachment) return (g = this.delegate) != null && typeof g.compositionDidStopEditingAttachment == "function" && g.compositionDidStopEditingAttachment(this.editingAttachment), this.editingAttachment = null;
          }, b.prototype.updateAttributesForAttachment = function(g, E) {
            return this.setDocument(this.document.updateAttributesForAttachment(g, E));
          }, b.prototype.removeAttributeForAttachment = function(g, E) {
            return this.setDocument(this.document.removeAttributeForAttachment(g, E));
          }, b.prototype.breakFormattedBlock = function(g) {
            var E, S, C, T, O;
            return S = g.document, E = g.block, T = g.startPosition, O = [T - 1, T], E.getBlockBreakPosition() === g.startLocation.offset ? (E.breaksOnReturn() && g.nextCharacter === `
` ? T += 1 : S = S.removeTextAtRange(O), O = [T, T]) : g.nextCharacter === `
` ? g.previousCharacter === `
` ? O = [T - 1, T + 1] : (O = [T, T + 1], T += 1) : g.startLocation.offset - 1 !== 0 && (T += 1), C = new n.Document([E.removeLastAttribute().copyWithoutText()]), this.setDocument(S.insertDocumentAtRange(C, O)), this.setSelection(T);
          }, b.prototype.getPreviousBlock = function() {
            var g, E;
            return (E = this.getLocationRange()) && (g = E[0].index, g > 0) ? this.document.getBlockAtIndex(g - 1) : void 0;
          }, b.prototype.getBlock = function() {
            var g;
            return (g = this.getLocationRange()) ? this.document.getBlockAtIndex(g[0].index) : void 0;
          }, b.prototype.getAttachmentAtRange = function(g) {
            var E;
            return E = this.document.getDocumentAtRange(g), E.toString() === n.OBJECT_REPLACEMENT_CHARACTER + `
` ? E.getAttachments()[0] : void 0;
          }, b.prototype.notifyDelegateOfCurrentAttributesChange = function() {
            var g;
            return (g = this.delegate) != null && typeof g.compositionDidChangeCurrentAttributes == "function" ? g.compositionDidChangeCurrentAttributes(this.currentAttributes) : void 0;
          }, b.prototype.notifyDelegateOfInsertionAtRange = function(g) {
            var E;
            return (E = this.delegate) != null && typeof E.compositionDidPerformInsertionAtRange == "function" ? E.compositionDidPerformInsertionAtRange(g) : void 0;
          }, b.prototype.translateUTF16PositionFromOffset = function(g, E) {
            var S, C;
            return C = this.document.toUTF16String(), S = C.offsetFromUCS2Offset(g), C.offsetToUCS2Offset(S + E);
          }, b;
        }(n.BasicObject);
      }).call(this), (function() {
        var r = function(a, o) {
          function s() {
            this.constructor = a;
          }
          for (var l in o) i.call(o, l) && (a[l] = o[l]);
          return s.prototype = o.prototype, a.prototype = new s(), a.__super__ = o.prototype, a;
        }, i = {}.hasOwnProperty;
        n.UndoManager = function(a) {
          function o(l) {
            this.composition = l, this.undoEntries = [], this.redoEntries = [];
          }
          var s;
          return r(o, a), o.prototype.recordUndoEntry = function(l, u) {
            var c, d, f, h, m;
            return h = u ?? {}, d = h.context, c = h.consolidatable, f = this.undoEntries.slice(-1)[0], c && s(f, l, d) ? void 0 : (m = this.createEntry({ description: l, context: d }), this.undoEntries.push(m), this.redoEntries = []);
          }, o.prototype.undo = function() {
            var l, u;
            return (u = this.undoEntries.pop()) ? (l = this.createEntry(u), this.redoEntries.push(l), this.composition.loadSnapshot(u.snapshot)) : void 0;
          }, o.prototype.redo = function() {
            var l, u;
            return (l = this.redoEntries.pop()) ? (u = this.createEntry(l), this.undoEntries.push(u), this.composition.loadSnapshot(l.snapshot)) : void 0;
          }, o.prototype.canUndo = function() {
            return this.undoEntries.length > 0;
          }, o.prototype.canRedo = function() {
            return this.redoEntries.length > 0;
          }, o.prototype.createEntry = function(l) {
            var u, c, d;
            return d = l ?? {}, c = d.description, u = d.context, { description: c != null ? c.toString() : void 0, context: JSON.stringify(u), snapshot: this.composition.getSnapshot() };
          }, s = function(l, u, c) {
            return (l != null ? l.description : void 0) === (u != null ? u.toString() : void 0) && (l != null ? l.context : void 0) === JSON.stringify(c);
          }, o;
        }(n.BasicObject);
      }).call(this), (function() {
        var r;
        n.attachmentGalleryFilter = function(i) {
          var a;
          return a = new r(i), a.perform(), a.getSnapshot();
        }, r = function() {
          function i(l) {
            this.document = l.document, this.selectedRange = l.selectedRange;
          }
          var a, o, s;
          return a = "attachmentGallery", o = "presentation", s = "gallery", i.prototype.perform = function() {
            return this.removeBlockAttribute(), this.applyBlockAttribute();
          }, i.prototype.getSnapshot = function() {
            return { document: this.document, selectedRange: this.selectedRange };
          }, i.prototype.removeBlockAttribute = function() {
            var l, u, c, d, f;
            for (d = this.findRangesOfBlocks(), f = [], l = 0, u = d.length; u > l; l++) c = d[l], f.push(this.document = this.document.removeAttributeAtRange(a, c));
            return f;
          }, i.prototype.applyBlockAttribute = function() {
            var l, u, c, d, f, h;
            for (c = 0, f = this.findRangesOfPieces(), h = [], l = 0, u = f.length; u > l; l++) d = f[l], d[1] - d[0] > 1 && (d[0] += c, d[1] += c, this.document.getCharacterAtPosition(d[1]) !== `
` && (this.document = this.document.insertBlockBreakAtRange(d[1]), d[1] < this.selectedRange[1] && this.moveSelectedRangeForward(), d[1]++, c++), d[0] !== 0 && this.document.getCharacterAtPosition(d[0] - 1) !== `
` && (this.document = this.document.insertBlockBreakAtRange(d[0]), d[0] < this.selectedRange[0] && this.moveSelectedRangeForward(), d[0]++, c++), h.push(this.document = this.document.applyBlockAttributeAtRange(a, !0, d)));
            return h;
          }, i.prototype.findRangesOfBlocks = function() {
            return this.document.findRangesForBlockAttribute(a);
          }, i.prototype.findRangesOfPieces = function() {
            return this.document.findRangesForTextAttribute(o, { withValue: s });
          }, i.prototype.moveSelectedRangeForward = function() {
            return this.selectedRange[0] += 1, this.selectedRange[1] += 1;
          }, i;
        }();
      }).call(this), (function() {
        var r = function(i, a) {
          return function() {
            return i.apply(a, arguments);
          };
        };
        n.Editor = function() {
          function i(o, s, l) {
            this.composition = o, this.selectionManager = s, this.element = l, this.insertFiles = r(this.insertFiles, this), this.undoManager = new n.UndoManager(this.composition), this.filters = a.slice(0);
          }
          var a;
          return a = [n.attachmentGalleryFilter], i.prototype.loadDocument = function(o) {
            return this.loadSnapshot({ document: o, selectedRange: [0, 0] });
          }, i.prototype.loadHTML = function(o) {
            return o == null && (o = ""), this.loadDocument(n.Document.fromHTML(o, { referenceElement: this.element }));
          }, i.prototype.loadJSON = function(o) {
            var s, l;
            return s = o.document, l = o.selectedRange, s = n.Document.fromJSON(s), this.loadSnapshot({ document: s, selectedRange: l });
          }, i.prototype.loadSnapshot = function(o) {
            return this.undoManager = new n.UndoManager(this.composition), this.composition.loadSnapshot(o);
          }, i.prototype.getDocument = function() {
            return this.composition.document;
          }, i.prototype.getSelectedDocument = function() {
            return this.composition.getSelectedDocument();
          }, i.prototype.getSnapshot = function() {
            return this.composition.getSnapshot();
          }, i.prototype.toJSON = function() {
            return this.getSnapshot();
          }, i.prototype.deleteInDirection = function(o) {
            return this.composition.deleteInDirection(o);
          }, i.prototype.insertAttachment = function(o) {
            return this.composition.insertAttachment(o);
          }, i.prototype.insertAttachments = function(o) {
            return this.composition.insertAttachments(o);
          }, i.prototype.insertDocument = function(o) {
            return this.composition.insertDocument(o);
          }, i.prototype.insertFile = function(o) {
            return this.composition.insertFile(o);
          }, i.prototype.insertFiles = function(o) {
            return this.composition.insertFiles(o);
          }, i.prototype.insertHTML = function(o) {
            return this.composition.insertHTML(o);
          }, i.prototype.insertString = function(o) {
            return this.composition.insertString(o);
          }, i.prototype.insertText = function(o) {
            return this.composition.insertText(o);
          }, i.prototype.insertLineBreak = function() {
            return this.composition.insertLineBreak();
          }, i.prototype.getSelectedRange = function() {
            return this.composition.getSelectedRange();
          }, i.prototype.getPosition = function() {
            return this.composition.getPosition();
          }, i.prototype.getClientRectAtPosition = function(o) {
            var s;
            return s = this.getDocument().locationRangeFromRange([o, o + 1]), this.selectionManager.getClientRectAtLocationRange(s);
          }, i.prototype.expandSelectionInDirection = function(o) {
            return this.composition.expandSelectionInDirection(o);
          }, i.prototype.moveCursorInDirection = function(o) {
            return this.composition.moveCursorInDirection(o);
          }, i.prototype.setSelectedRange = function(o) {
            return this.composition.setSelectedRange(o);
          }, i.prototype.activateAttribute = function(o, s) {
            return s == null && (s = !0), this.composition.setCurrentAttribute(o, s);
          }, i.prototype.attributeIsActive = function(o) {
            return this.composition.hasCurrentAttribute(o);
          }, i.prototype.canActivateAttribute = function(o) {
            return this.composition.canSetCurrentAttribute(o);
          }, i.prototype.deactivateAttribute = function(o) {
            return this.composition.removeCurrentAttribute(o);
          }, i.prototype.canDecreaseNestingLevel = function() {
            return this.composition.canDecreaseNestingLevel();
          }, i.prototype.canIncreaseNestingLevel = function() {
            return this.composition.canIncreaseNestingLevel();
          }, i.prototype.decreaseNestingLevel = function() {
            return this.canDecreaseNestingLevel() ? this.composition.decreaseNestingLevel() : void 0;
          }, i.prototype.increaseNestingLevel = function() {
            return this.canIncreaseNestingLevel() ? this.composition.increaseNestingLevel() : void 0;
          }, i.prototype.canRedo = function() {
            return this.undoManager.canRedo();
          }, i.prototype.canUndo = function() {
            return this.undoManager.canUndo();
          }, i.prototype.recordUndoEntry = function(o, s) {
            var l, u, c;
            return c = s ?? {}, u = c.context, l = c.consolidatable, this.undoManager.recordUndoEntry(o, { context: u, consolidatable: l });
          }, i.prototype.redo = function() {
            return this.canRedo() ? this.undoManager.redo() : void 0;
          }, i.prototype.undo = function() {
            return this.canUndo() ? this.undoManager.undo() : void 0;
          }, i;
        }();
      }).call(this), (function() {
        var r = function(a, o) {
          function s() {
            this.constructor = a;
          }
          for (var l in o) i.call(o, l) && (a[l] = o[l]);
          return s.prototype = o.prototype, a.prototype = new s(), a.__super__ = o.prototype, a;
        }, i = {}.hasOwnProperty;
        n.ManagedAttachment = function(a) {
          function o(s, l) {
            var u;
            this.attachmentManager = s, this.attachment = l, u = this.attachment, this.id = u.id, this.file = u.file;
          }
          return r(o, a), o.prototype.remove = function() {
            return this.attachmentManager.requestRemovalOfAttachment(this.attachment);
          }, o.proxyMethod("attachment.getAttribute"), o.proxyMethod("attachment.hasAttribute"), o.proxyMethod("attachment.setAttribute"), o.proxyMethod("attachment.getAttributes"), o.proxyMethod("attachment.setAttributes"), o.proxyMethod("attachment.isPending"), o.proxyMethod("attachment.isPreviewable"), o.proxyMethod("attachment.getURL"), o.proxyMethod("attachment.getHref"), o.proxyMethod("attachment.getFilename"), o.proxyMethod("attachment.getFilesize"), o.proxyMethod("attachment.getFormattedFilesize"), o.proxyMethod("attachment.getExtension"), o.proxyMethod("attachment.getContentType"), o.proxyMethod("attachment.getFile"), o.proxyMethod("attachment.setFile"), o.proxyMethod("attachment.releaseFile"), o.proxyMethod("attachment.getUploadProgress"), o.proxyMethod("attachment.setUploadProgress"), o;
        }(n.BasicObject);
      }).call(this), (function() {
        var r = function(a, o) {
          function s() {
            this.constructor = a;
          }
          for (var l in o) i.call(o, l) && (a[l] = o[l]);
          return s.prototype = o.prototype, a.prototype = new s(), a.__super__ = o.prototype, a;
        }, i = {}.hasOwnProperty;
        n.AttachmentManager = function(a) {
          function o(s) {
            var l, u, c;
            for (s == null && (s = []), this.managedAttachments = {}, u = 0, c = s.length; c > u; u++) l = s[u], this.manageAttachment(l);
          }
          return r(o, a), o.prototype.getAttachments = function() {
            var s, l, u, c;
            u = this.managedAttachments, c = [];
            for (l in u) s = u[l], c.push(s);
            return c;
          }, o.prototype.manageAttachment = function(s) {
            var l, u;
            return (l = this.managedAttachments)[u = s.id] != null ? l[u] : l[u] = new n.ManagedAttachment(this, s);
          }, o.prototype.attachmentIsManaged = function(s) {
            return s.id in this.managedAttachments;
          }, o.prototype.requestRemovalOfAttachment = function(s) {
            var l;
            return this.attachmentIsManaged(s) && (l = this.delegate) != null && typeof l.attachmentManagerDidRequestRemovalOfAttachment == "function" ? l.attachmentManagerDidRequestRemovalOfAttachment(s) : void 0;
          }, o.prototype.unmanageAttachment = function(s) {
            var l;
            return l = this.managedAttachments[s.id], delete this.managedAttachments[s.id], l;
          }, o;
        }(n.BasicObject);
      }).call(this), (function() {
        var r, i, a, o, s, l, u, c, d, f, h;
        r = n.elementContainsNode, i = n.findChildIndexOfNode, s = n.nodeIsBlockStart, l = n.nodeIsBlockStartComment, o = n.nodeIsBlockContainer, u = n.nodeIsCursorTarget, c = n.nodeIsEmptyTextNode, d = n.nodeIsTextNode, a = n.nodeIsAttachmentElement, f = n.tagName, h = n.walkTree, n.LocationMapper = function() {
          function m(E) {
            this.element = E;
          }
          var v, b, y, g;
          return m.prototype.findLocationFromContainerAndOffset = function(E, S, C) {
            var T, O, R, D, q, $, P;
            for ($ = (C ?? { strict: !0 }).strict, O = 0, R = !1, D = { index: 0, offset: 0 }, (T = this.findAttachmentElementParentForNode(E)) && (E = T.parentNode, S = i(T)), P = h(this.element, { usingFilter: y }); P.nextNode(); ) {
              if (q = P.currentNode, q === E && d(E)) {
                u(q) || (D.offset += S);
                break;
              }
              if (q.parentNode === E) {
                if (O++ === S) break;
              } else if (!r(E, q) && O > 0) break;
              s(q, { strict: $ }) ? (R && D.index++, D.offset = 0, R = !0) : D.offset += b(q);
            }
            return D;
          }, m.prototype.findContainerAndOffsetFromLocation = function(E) {
            var S, C, T, O, R;
            if (E.index === 0 && E.offset === 0) {
              for (S = this.element, O = 0; S.firstChild; ) if (S = S.firstChild, o(S)) {
                O = 1;
                break;
              }
              return [S, O];
            }
            if (R = this.findNodeAndOffsetFromLocation(E), C = R[0], T = R[1], C) {
              if (d(C)) b(C) === 0 ? (S = C.parentNode.parentNode, O = i(C.parentNode), u(C, { name: "right" }) && O++) : (S = C, O = E.offset - T);
              else {
                if (S = C.parentNode, !s(C.previousSibling) && !o(S)) for (; C === S.lastChild && (C = S, S = S.parentNode, !o(S)); ) ;
                O = i(C), E.offset !== 0 && O++;
              }
              return [S, O];
            }
          }, m.prototype.findNodeAndOffsetFromLocation = function(E) {
            var S, C, T, O, R, D, q, $;
            for (q = 0, $ = this.getSignificantNodesForIndex(E.index), C = 0, T = $.length; T > C; C++) {
              if (S = $[C], O = b(S), E.offset <= q + O) if (d(S)) {
                if (R = S, D = q, E.offset === D && u(R)) break;
              } else R || (R = S, D = q);
              if (q += O, q > E.offset) break;
            }
            return [R, D];
          }, m.prototype.findAttachmentElementParentForNode = function(E) {
            for (; E && E !== this.element; ) {
              if (a(E)) return E;
              E = E.parentNode;
            }
          }, m.prototype.getSignificantNodesForIndex = function(E) {
            var S, C, T, O, R;
            for (T = [], R = h(this.element, { usingFilter: v }), O = !1; R.nextNode(); ) if (C = R.currentNode, l(C)) {
              if (typeof S < "u" && S !== null ? S++ : S = 0, S === E) O = !0;
              else if (O) break;
            } else O && T.push(C);
            return T;
          }, b = function(E) {
            var S;
            return E.nodeType === Node.TEXT_NODE ? u(E) ? 0 : (S = E.textContent, S.length) : f(E) === "br" || a(E) ? 1 : 0;
          }, v = function(E) {
            return g(E) === NodeFilter.FILTER_ACCEPT ? y(E) : NodeFilter.FILTER_REJECT;
          }, g = function(E) {
            return c(E) ? NodeFilter.FILTER_REJECT : NodeFilter.FILTER_ACCEPT;
          }, y = function(E) {
            return a(E.parentNode) ? NodeFilter.FILTER_REJECT : NodeFilter.FILTER_ACCEPT;
          }, m;
        }();
      }).call(this), (function() {
        var r, i, a = [].slice;
        r = n.getDOMRange, i = n.setDOMRange, n.PointMapper = function() {
          function o() {
          }
          return o.prototype.createDOMRangeFromPoint = function(s) {
            var l, u, c, d, f, h, m, v;
            if (m = s.x, v = s.y, document.caretPositionFromPoint) return f = document.caretPositionFromPoint(m, v), c = f.offsetNode, u = f.offset, l = document.createRange(), l.setStart(c, u), l;
            if (document.caretRangeFromPoint) return document.caretRangeFromPoint(m, v);
            if (document.body.createTextRange) {
              d = r();
              try {
                h = document.body.createTextRange(), h.moveToPoint(m, v), h.select();
              } catch {
              }
              return l = r(), i(d), l;
            }
          }, o.prototype.getClientRectsForDOMRange = function(s) {
            var l, u, c;
            return u = a.call(s.getClientRects()), c = u[0], l = u[u.length - 1], [c, l];
          }, o;
        }();
      }).call(this), (function() {
        var r, i = function(l, u) {
          return function() {
            return l.apply(u, arguments);
          };
        }, a = function(l, u) {
          function c() {
            this.constructor = l;
          }
          for (var d in u) o.call(u, d) && (l[d] = u[d]);
          return c.prototype = u.prototype, l.prototype = new c(), l.__super__ = u.prototype, l;
        }, o = {}.hasOwnProperty, s = [].indexOf || function(l) {
          for (var u = 0, c = this.length; c > u; u++) if (u in this && this[u] === l) return u;
          return -1;
        };
        r = n.getDOMRange, n.SelectionChangeObserver = function(l) {
          function u() {
            this.run = i(this.run, this), this.update = i(this.update, this), this.selectionManagers = [];
          }
          var c;
          return a(u, l), u.prototype.start = function() {
            return this.started ? void 0 : (this.started = !0, "onselectionchange" in document ? document.addEventListener("selectionchange", this.update, !0) : this.run());
          }, u.prototype.stop = function() {
            return this.started ? (this.started = !1, document.removeEventListener("selectionchange", this.update, !0)) : void 0;
          }, u.prototype.registerSelectionManager = function(d) {
            return s.call(this.selectionManagers, d) < 0 ? (this.selectionManagers.push(d), this.start()) : void 0;
          }, u.prototype.unregisterSelectionManager = function(d) {
            var f;
            return this.selectionManagers = (function() {
              var h, m, v, b;
              for (v = this.selectionManagers, b = [], h = 0, m = v.length; m > h; h++) f = v[h], f !== d && b.push(f);
              return b;
            }).call(this), this.selectionManagers.length === 0 ? this.stop() : void 0;
          }, u.prototype.notifySelectionManagersOfSelectionChange = function() {
            var d, f, h, m, v;
            for (h = this.selectionManagers, m = [], d = 0, f = h.length; f > d; d++) v = h[d], m.push(v.selectionDidChange());
            return m;
          }, u.prototype.update = function() {
            var d;
            return d = r(), c(d, this.domRange) ? void 0 : (this.domRange = d, this.notifySelectionManagersOfSelectionChange());
          }, u.prototype.reset = function() {
            return this.domRange = null, this.update();
          }, u.prototype.run = function() {
            return this.started ? (this.update(), requestAnimationFrame(this.run)) : void 0;
          }, c = function(d, f) {
            return (d != null ? d.startContainer : void 0) === (f != null ? f.startContainer : void 0) && (d != null ? d.startOffset : void 0) === (f != null ? f.startOffset : void 0) && (d != null ? d.endContainer : void 0) === (f != null ? f.endContainer : void 0) && (d != null ? d.endOffset : void 0) === (f != null ? f.endOffset : void 0);
          }, u;
        }(n.BasicObject), n.selectionChangeObserver == null && (n.selectionChangeObserver = new n.SelectionChangeObserver());
      }).call(this), (function() {
        var r, i, a, o, s, l, u, c, d, f, h = function(b, y) {
          return function() {
            return b.apply(y, arguments);
          };
        }, m = function(b, y) {
          function g() {
            this.constructor = b;
          }
          for (var E in y) v.call(y, E) && (b[E] = y[E]);
          return g.prototype = y.prototype, b.prototype = new g(), b.__super__ = y.prototype, b;
        }, v = {}.hasOwnProperty;
        a = n.getDOMSelection, i = n.getDOMRange, f = n.setDOMRange, r = n.elementContainsNode, l = n.nodeIsCursorTarget, s = n.innerElementIsActive, o = n.handleEvent, u = n.normalizeRange, c = n.rangeIsCollapsed, d = n.rangesAreEqual, n.SelectionManager = function(b) {
          function y(g) {
            this.element = g, this.selectionDidChange = h(this.selectionDidChange, this), this.didMouseDown = h(this.didMouseDown, this), this.locationMapper = new n.LocationMapper(this.element), this.pointMapper = new n.PointMapper(), this.lockCount = 0, o("mousedown", { onElement: this.element, withCallback: this.didMouseDown });
          }
          return m(y, b), y.prototype.getLocationRange = function(g) {
            var E;
            return g == null && (g = {}), g.strict === !1 ? this.createLocationRangeFromDOMRange(i(), { strict: !1 }) : g.ignoreLock ? this.currentLocationRange : (E = this.lockedLocationRange) != null ? E : this.currentLocationRange;
          }, y.prototype.setLocationRange = function(g) {
            var E;
            if (!this.lockedLocationRange) return g = u(g), (E = this.createDOMRangeFromLocationRange(g)) ? (f(E), this.updateCurrentLocationRange(g)) : void 0;
          }, y.prototype.setLocationRangeFromPointRange = function(g) {
            var E, S;
            return g = u(g), S = this.getLocationAtPoint(g[0]), E = this.getLocationAtPoint(g[1]), this.setLocationRange([S, E]);
          }, y.prototype.getClientRectAtLocationRange = function(g) {
            var E;
            return (E = this.createDOMRangeFromLocationRange(g)) ? this.getClientRectsForDOMRange(E)[1] : void 0;
          }, y.prototype.locationIsCursorTarget = function(g) {
            var E, S;
            return S = this.findNodeAndOffsetFromLocation(g), E = S[0], S[1], l(E);
          }, y.prototype.lock = function() {
            return this.lockCount++ === 0 ? (this.updateCurrentLocationRange(), this.lockedLocationRange = this.getLocationRange()) : void 0;
          }, y.prototype.unlock = function() {
            var g;
            return --this.lockCount === 0 && (g = this.lockedLocationRange, this.lockedLocationRange = null, g != null) ? this.setLocationRange(g) : void 0;
          }, y.prototype.clearSelection = function() {
            var g;
            return (g = a()) != null ? g.removeAllRanges() : void 0;
          }, y.prototype.selectionIsCollapsed = function() {
            var g;
            return ((g = i()) != null ? g.collapsed : void 0) === !0;
          }, y.prototype.selectionIsExpanded = function() {
            return !this.selectionIsCollapsed();
          }, y.prototype.createLocationRangeFromDOMRange = function(g, E) {
            var S, C;
            if (g != null && this.domRangeWithinElement(g) && (C = this.findLocationFromContainerAndOffset(g.startContainer, g.startOffset, E))) return g.collapsed || (S = this.findLocationFromContainerAndOffset(g.endContainer, g.endOffset, E)), u([C, S]);
          }, y.proxyMethod("locationMapper.findLocationFromContainerAndOffset"), y.proxyMethod("locationMapper.findContainerAndOffsetFromLocation"), y.proxyMethod("locationMapper.findNodeAndOffsetFromLocation"), y.proxyMethod("pointMapper.createDOMRangeFromPoint"), y.proxyMethod("pointMapper.getClientRectsForDOMRange"), y.prototype.didMouseDown = function() {
            return this.pauseTemporarily();
          }, y.prototype.pauseTemporarily = function() {
            var g, E, S, C;
            return this.paused = !0, E = /* @__PURE__ */ function(T) {
              return function() {
                var O, R, D;
                for (T.paused = !1, clearTimeout(C), R = 0, D = S.length; D > R; R++) O = S[R], O.destroy();
                return r(document, T.element) ? T.selectionDidChange() : void 0;
              };
            }(this), C = setTimeout(E, 200), S = function() {
              var T, O, R, D;
              for (R = ["mousemove", "keydown"], D = [], T = 0, O = R.length; O > T; T++) g = R[T], D.push(o(g, { onElement: document, withCallback: E }));
              return D;
            }();
          }, y.prototype.selectionDidChange = function() {
            return this.paused || s(this.element) ? void 0 : this.updateCurrentLocationRange();
          }, y.prototype.updateCurrentLocationRange = function(g) {
            var E;
            return (g ?? (g = this.createLocationRangeFromDOMRange(i()))) && !d(g, this.currentLocationRange) ? (this.currentLocationRange = g, (E = this.delegate) != null && typeof E.locationRangeDidChange == "function" ? E.locationRangeDidChange(this.currentLocationRange.slice(0)) : void 0) : void 0;
          }, y.prototype.createDOMRangeFromLocationRange = function(g) {
            var E, S, C, T;
            return C = this.findContainerAndOffsetFromLocation(g[0]), S = c(g) ? C : (T = this.findContainerAndOffsetFromLocation(g[1])) != null ? T : C, C != null && S != null ? (E = document.createRange(), E.setStart.apply(E, C), E.setEnd.apply(E, S), E) : void 0;
          }, y.prototype.getLocationAtPoint = function(g) {
            var E, S;
            return (E = this.createDOMRangeFromPoint(g)) && (S = this.createLocationRangeFromDOMRange(E)) != null ? S[0] : void 0;
          }, y.prototype.domRangeWithinElement = function(g) {
            return g.collapsed ? r(this.element, g.startContainer) : r(this.element, g.startContainer) && r(this.element, g.endContainer);
          }, y;
        }(n.BasicObject);
      }).call(this), (function() {
        var r, i, a, o, s = function(c, d) {
          function f() {
            this.constructor = c;
          }
          for (var h in d) l.call(d, h) && (c[h] = d[h]);
          return f.prototype = d.prototype, c.prototype = new f(), c.__super__ = d.prototype, c;
        }, l = {}.hasOwnProperty, u = [].slice;
        a = n.rangeIsCollapsed, o = n.rangesAreEqual, i = n.objectsAreEqual, r = n.getBlockConfig, n.EditorController = function(c) {
          function d(h) {
            var m, v;
            this.editorElement = h.editorElement, m = h.document, v = h.html, this.selectionManager = new n.SelectionManager(this.editorElement), this.selectionManager.delegate = this, this.composition = new n.Composition(), this.composition.delegate = this, this.attachmentManager = new n.AttachmentManager(this.composition.getAttachments()), this.attachmentManager.delegate = this, this.inputController = new n["Level" + n.config.input.getLevel() + "InputController"](this.editorElement), this.inputController.delegate = this, this.inputController.responder = this.composition, this.compositionController = new n.CompositionController(this.editorElement, this.composition), this.compositionController.delegate = this, this.toolbarController = new n.ToolbarController(this.editorElement.toolbarElement), this.toolbarController.delegate = this, this.editor = new n.Editor(this.composition, this.selectionManager, this.editorElement), m != null ? this.editor.loadDocument(m) : this.editor.loadHTML(v);
          }
          var f;
          return s(d, c), d.prototype.registerSelectionManager = function() {
            return n.selectionChangeObserver.registerSelectionManager(this.selectionManager);
          }, d.prototype.unregisterSelectionManager = function() {
            return n.selectionChangeObserver.unregisterSelectionManager(this.selectionManager);
          }, d.prototype.render = function() {
            return this.compositionController.render();
          }, d.prototype.reparse = function() {
            return this.composition.replaceHTML(this.editorElement.innerHTML);
          }, d.prototype.compositionDidChangeDocument = function() {
            return this.notifyEditorElement("document-change"), this.handlingInput ? void 0 : this.render();
          }, d.prototype.compositionDidChangeCurrentAttributes = function(h) {
            return this.currentAttributes = h, this.toolbarController.updateAttributes(this.currentAttributes), this.updateCurrentActions(), this.notifyEditorElement("attributes-change", { attributes: this.currentAttributes });
          }, d.prototype.compositionDidPerformInsertionAtRange = function(h) {
            return this.pasting ? this.pastedRange = h : void 0;
          }, d.prototype.compositionShouldAcceptFile = function(h) {
            return this.notifyEditorElement("file-accept", { file: h });
          }, d.prototype.compositionDidAddAttachment = function(h) {
            var m;
            return m = this.attachmentManager.manageAttachment(h), this.notifyEditorElement("attachment-add", { attachment: m });
          }, d.prototype.compositionDidEditAttachment = function(h) {
            var m;
            return this.compositionController.rerenderViewForObject(h), m = this.attachmentManager.manageAttachment(h), this.notifyEditorElement("attachment-edit", { attachment: m }), this.notifyEditorElement("change");
          }, d.prototype.compositionDidChangeAttachmentPreviewURL = function(h) {
            return this.compositionController.invalidateViewForObject(h), this.notifyEditorElement("change");
          }, d.prototype.compositionDidRemoveAttachment = function(h) {
            var m;
            return m = this.attachmentManager.unmanageAttachment(h), this.notifyEditorElement("attachment-remove", { attachment: m });
          }, d.prototype.compositionDidStartEditingAttachment = function(h, m) {
            return this.attachmentLocationRange = this.composition.document.getLocationRangeOfAttachment(h), this.compositionController.installAttachmentEditorForAttachment(h, m), this.selectionManager.setLocationRange(this.attachmentLocationRange);
          }, d.prototype.compositionDidStopEditingAttachment = function() {
            return this.compositionController.uninstallAttachmentEditor(), this.attachmentLocationRange = null;
          }, d.prototype.compositionDidRequestChangingSelectionToLocationRange = function(h) {
            return !this.loadingSnapshot || this.isFocused() ? (this.requestedLocationRange = h, this.compositionRevisionWhenLocationRangeRequested = this.composition.revision, this.handlingInput ? void 0 : this.render()) : void 0;
          }, d.prototype.compositionWillLoadSnapshot = function() {
            return this.loadingSnapshot = !0;
          }, d.prototype.compositionDidLoadSnapshot = function() {
            return this.compositionController.refreshViewCache(), this.render(), this.loadingSnapshot = !1;
          }, d.prototype.getSelectionManager = function() {
            return this.selectionManager;
          }, d.proxyMethod("getSelectionManager().setLocationRange"), d.proxyMethod("getSelectionManager().getLocationRange"), d.prototype.attachmentManagerDidRequestRemovalOfAttachment = function(h) {
            return this.removeAttachment(h);
          }, d.prototype.compositionControllerWillSyncDocumentView = function() {
            return this.inputController.editorWillSyncDocumentView(), this.selectionManager.lock(), this.selectionManager.clearSelection();
          }, d.prototype.compositionControllerDidSyncDocumentView = function() {
            return this.inputController.editorDidSyncDocumentView(), this.selectionManager.unlock(), this.updateCurrentActions(), this.notifyEditorElement("sync");
          }, d.prototype.compositionControllerDidRender = function() {
            return this.requestedLocationRange != null && (this.compositionRevisionWhenLocationRangeRequested === this.composition.revision && this.selectionManager.setLocationRange(this.requestedLocationRange), this.requestedLocationRange = null, this.compositionRevisionWhenLocationRangeRequested = null), this.renderedCompositionRevision !== this.composition.revision && (this.runEditorFilters(), this.composition.updateCurrentAttributes(), this.notifyEditorElement("render")), this.renderedCompositionRevision = this.composition.revision;
          }, d.prototype.compositionControllerDidFocus = function() {
            return this.isFocusedInvisibly() && this.setLocationRange({ index: 0, offset: 0 }), this.toolbarController.hideDialog(), this.notifyEditorElement("focus");
          }, d.prototype.compositionControllerDidBlur = function() {
            return this.notifyEditorElement("blur");
          }, d.prototype.compositionControllerDidSelectAttachment = function(h, m) {
            return this.toolbarController.hideDialog(), this.composition.editAttachment(h, m);
          }, d.prototype.compositionControllerDidRequestDeselectingAttachment = function(h) {
            var m, v;
            return m = (v = this.attachmentLocationRange) != null ? v : this.composition.document.getLocationRangeOfAttachment(h), this.selectionManager.setLocationRange(m[1]);
          }, d.prototype.compositionControllerWillUpdateAttachment = function(h) {
            return this.editor.recordUndoEntry("Edit Attachment", { context: h.id, consolidatable: !0 });
          }, d.prototype.compositionControllerDidRequestRemovalOfAttachment = function(h) {
            return this.removeAttachment(h);
          }, d.prototype.inputControllerWillHandleInput = function() {
            return this.handlingInput = !0, this.requestedRender = !1;
          }, d.prototype.inputControllerDidRequestRender = function() {
            return this.requestedRender = !0;
          }, d.prototype.inputControllerDidHandleInput = function() {
            return this.handlingInput = !1, this.requestedRender ? (this.requestedRender = !1, this.render()) : void 0;
          }, d.prototype.inputControllerDidAllowUnhandledInput = function() {
            return this.notifyEditorElement("change");
          }, d.prototype.inputControllerDidRequestReparse = function() {
            return this.reparse();
          }, d.prototype.inputControllerWillPerformTyping = function() {
            return this.recordTypingUndoEntry();
          }, d.prototype.inputControllerWillPerformFormatting = function(h) {
            return this.recordFormattingUndoEntry(h);
          }, d.prototype.inputControllerWillCutText = function() {
            return this.editor.recordUndoEntry("Cut");
          }, d.prototype.inputControllerWillPaste = function(h) {
            return this.editor.recordUndoEntry("Paste"), this.pasting = !0, this.notifyEditorElement("before-paste", { paste: h });
          }, d.prototype.inputControllerDidPaste = function(h) {
            return h.range = this.pastedRange, this.pastedRange = null, this.pasting = null, this.notifyEditorElement("paste", { paste: h });
          }, d.prototype.inputControllerWillMoveText = function() {
            return this.editor.recordUndoEntry("Move");
          }, d.prototype.inputControllerWillAttachFiles = function() {
            return this.editor.recordUndoEntry("Drop Files");
          }, d.prototype.inputControllerWillPerformUndo = function() {
            return this.editor.undo();
          }, d.prototype.inputControllerWillPerformRedo = function() {
            return this.editor.redo();
          }, d.prototype.inputControllerDidReceiveKeyboardCommand = function(h) {
            return this.toolbarController.applyKeyboardCommand(h);
          }, d.prototype.inputControllerDidStartDrag = function() {
            return this.locationRangeBeforeDrag = this.selectionManager.getLocationRange();
          }, d.prototype.inputControllerDidReceiveDragOverPoint = function(h) {
            return this.selectionManager.setLocationRangeFromPointRange(h);
          }, d.prototype.inputControllerDidCancelDrag = function() {
            return this.selectionManager.setLocationRange(this.locationRangeBeforeDrag), this.locationRangeBeforeDrag = null;
          }, d.prototype.locationRangeDidChange = function(h) {
            return this.composition.updateCurrentAttributes(), this.updateCurrentActions(), this.attachmentLocationRange && !o(this.attachmentLocationRange, h) && this.composition.stopEditingAttachment(), this.notifyEditorElement("selection-change");
          }, d.prototype.toolbarDidClickButton = function() {
            return this.getLocationRange() ? void 0 : this.setLocationRange({ index: 0, offset: 0 });
          }, d.prototype.toolbarDidInvokeAction = function(h) {
            return this.invokeAction(h);
          }, d.prototype.toolbarDidToggleAttribute = function(h) {
            return this.recordFormattingUndoEntry(h), this.composition.toggleCurrentAttribute(h), this.render(), this.selectionFrozen ? void 0 : this.editorElement.focus();
          }, d.prototype.toolbarDidUpdateAttribute = function(h, m) {
            return this.recordFormattingUndoEntry(h), this.composition.setCurrentAttribute(h, m), this.render(), this.selectionFrozen ? void 0 : this.editorElement.focus();
          }, d.prototype.toolbarDidRemoveAttribute = function(h) {
            return this.recordFormattingUndoEntry(h), this.composition.removeCurrentAttribute(h), this.render(), this.selectionFrozen ? void 0 : this.editorElement.focus();
          }, d.prototype.toolbarWillShowDialog = function() {
            return this.composition.expandSelectionForEditing(), this.freezeSelection();
          }, d.prototype.toolbarDidShowDialog = function(h) {
            return this.notifyEditorElement("toolbar-dialog-show", { dialogName: h });
          }, d.prototype.toolbarDidHideDialog = function(h) {
            return this.thawSelection(), this.editorElement.focus(), this.notifyEditorElement("toolbar-dialog-hide", { dialogName: h });
          }, d.prototype.freezeSelection = function() {
            return this.selectionFrozen ? void 0 : (this.selectionManager.lock(), this.composition.freezeSelection(), this.selectionFrozen = !0, this.render());
          }, d.prototype.thawSelection = function() {
            return this.selectionFrozen ? (this.composition.thawSelection(), this.selectionManager.unlock(), this.selectionFrozen = !1, this.render()) : void 0;
          }, d.prototype.actions = { undo: { test: function() {
            return this.editor.canUndo();
          }, perform: function() {
            return this.editor.undo();
          } }, redo: { test: function() {
            return this.editor.canRedo();
          }, perform: function() {
            return this.editor.redo();
          } }, link: { test: function() {
            return this.editor.canActivateAttribute("href");
          } }, increaseNestingLevel: { test: function() {
            return this.editor.canIncreaseNestingLevel();
          }, perform: function() {
            return this.editor.increaseNestingLevel() && this.render();
          } }, decreaseNestingLevel: { test: function() {
            return this.editor.canDecreaseNestingLevel();
          }, perform: function() {
            return this.editor.decreaseNestingLevel() && this.render();
          } }, attachFiles: { test: function() {
            return !0;
          }, perform: function() {
            return n.config.input.pickFiles(this.editor.insertFiles);
          } } }, d.prototype.canInvokeAction = function(h) {
            var m, v;
            return this.actionIsExternal(h) ? !0 : !!((m = this.actions[h]) != null && (v = m.test) != null && v.call(this));
          }, d.prototype.invokeAction = function(h) {
            var m, v;
            return this.actionIsExternal(h) ? this.notifyEditorElement("action-invoke", { actionName: h }) : (m = this.actions[h]) != null && (v = m.perform) != null ? v.call(this) : void 0;
          }, d.prototype.actionIsExternal = function(h) {
            return /^x-./.test(h);
          }, d.prototype.getCurrentActions = function() {
            var h, m;
            m = {};
            for (h in this.actions) m[h] = this.canInvokeAction(h);
            return m;
          }, d.prototype.updateCurrentActions = function() {
            var h;
            return h = this.getCurrentActions(), i(h, this.currentActions) ? void 0 : (this.currentActions = h, this.toolbarController.updateActions(this.currentActions), this.notifyEditorElement("actions-change", { actions: this.currentActions }));
          }, d.prototype.runEditorFilters = function() {
            var h, m, v, b, y, g, E, S;
            for (S = this.composition.getSnapshot(), y = this.editor.filters, v = 0, b = y.length; b > v; v++) m = y[v], h = S.document, E = S.selectedRange, S = (g = m.call(this.editor, S)) != null ? g : {}, S.document == null && (S.document = h), S.selectedRange == null && (S.selectedRange = E);
            return f(S, this.composition.getSnapshot()) ? void 0 : this.composition.loadSnapshot(S);
          }, f = function(h, m) {
            return o(h.selectedRange, m.selectedRange) && h.document.isEqualTo(m.document);
          }, d.prototype.updateInputElement = function() {
            var h, m;
            return h = this.compositionController.getSerializableElement(), m = n.serializeToContentType(h, "text/html"), this.editorElement.setInputElementValue(m);
          }, d.prototype.notifyEditorElement = function(h, m) {
            switch (h) {
              case "document-change":
                this.documentChangedSinceLastRender = !0;
                break;
              case "render":
                this.documentChangedSinceLastRender && (this.documentChangedSinceLastRender = !1, this.notifyEditorElement("change"));
                break;
              case "change":
              case "attachment-add":
              case "attachment-edit":
              case "attachment-remove":
                this.updateInputElement();
            }
            return this.editorElement.notify(h, m);
          }, d.prototype.removeAttachment = function(h) {
            return this.editor.recordUndoEntry("Delete Attachment"), this.composition.removeAttachment(h), this.render();
          }, d.prototype.recordFormattingUndoEntry = function(h) {
            var m, v;
            return m = r(h), v = this.selectionManager.getLocationRange(), m || !a(v) ? this.editor.recordUndoEntry("Formatting", { context: this.getUndoContext(), consolidatable: !0 }) : void 0;
          }, d.prototype.recordTypingUndoEntry = function() {
            return this.editor.recordUndoEntry("Typing", { context: this.getUndoContext(this.currentAttributes), consolidatable: !0 });
          }, d.prototype.getUndoContext = function() {
            var h;
            return h = 1 <= arguments.length ? u.call(arguments, 0) : [], [this.getLocationContext(), this.getTimeContext()].concat(u.call(h));
          }, d.prototype.getLocationContext = function() {
            var h;
            return h = this.selectionManager.getLocationRange(), a(h) ? h[0].index : h;
          }, d.prototype.getTimeContext = function() {
            return n.config.undoInterval > 0 ? Math.floor((/* @__PURE__ */ new Date()).getTime() / n.config.undoInterval) : 0;
          }, d.prototype.isFocused = function() {
            var h;
            return this.editorElement === ((h = this.editorElement.ownerDocument) != null ? h.activeElement : void 0);
          }, d.prototype.isFocusedInvisibly = function() {
            return this.isFocused() && !this.getLocationRange();
          }, d;
        }(n.Controller);
      }).call(this), (function() {
        var r, i, a, o, s, l, u, c = [].indexOf || function(d) {
          for (var f = 0, h = this.length; h > f; f++) if (f in this && this[f] === d) return f;
          return -1;
        };
        i = n.browser, l = n.makeElement, u = n.triggerEvent, o = n.handleEvent, s = n.handleEventOnce, a = n.findClosestElementFromNode, r = n.AttachmentView.attachmentSelector, n.registerElement("trix-editor", function() {
          var d, f, h, m, v, b, y, g, E;
          return y = 0, f = function(S) {
            return !document.querySelector(":focus") && S.hasAttribute("autofocus") && document.querySelector("[autofocus]") === S ? S.focus() : void 0;
          }, g = function(S) {
            return S.hasAttribute("contenteditable") ? void 0 : (S.setAttribute("contenteditable", ""), s("focus", { onElement: S, withCallback: function() {
              return h(S);
            } }));
          }, h = function(S) {
            return v(S), E(S);
          }, v = function(S) {
            return typeof document.queryCommandSupported == "function" && document.queryCommandSupported("enableObjectResizing") ? (document.execCommand("enableObjectResizing", !1, !1), o("mscontrolselect", { onElement: S, preventDefault: !0 })) : void 0;
          }, E = function() {
            var S;
            return typeof document.queryCommandSupported == "function" && document.queryCommandSupported("DefaultParagraphSeparator") && (S = n.config.blockAttributes.default.tagName, S === "div" || S === "p") ? document.execCommand("DefaultParagraphSeparator", !1, S) : void 0;
          }, d = function(S) {
            return S.hasAttribute("role") ? void 0 : S.setAttribute("role", "textbox");
          }, b = function(S) {
            var C;
            if (!S.hasAttribute("aria-label") && !S.hasAttribute("aria-labelledby")) return (C = function() {
              var T, O, R;
              return R = function() {
                var D, q, $, P;
                for ($ = S.labels, P = [], D = 0, q = $.length; q > D; D++) T = $[D], T.contains(S) || P.push(T.textContent);
                return P;
              }(), (O = R.join(" ")) ? S.setAttribute("aria-label", O) : S.removeAttribute("aria-label");
            })(), o("focus", { onElement: S, withCallback: C });
          }, m = function() {
            return i.forcesObjectResizing ? { display: "inline", width: "auto" } : { display: "inline-block", width: "1px" };
          }(), { defaultCSS: `%t {
  display: block;
}

%t:empty:not(:focus)::before {
  content: attr(placeholder);
  color: graytext;
  cursor: text;
  pointer-events: none;
}

%t a[contenteditable=false] {
  cursor: text;
}

%t img {
  max-width: 100%;
  height: auto;
}

%t ` + r + ` figcaption textarea {
  resize: none;
}

%t ` + r + ` figcaption textarea.trix-autoresize-clone {
  position: absolute;
  left: -9999px;
  max-height: 0px;
}

%t ` + r + ` figcaption[data-trix-placeholder]:empty::before {
  content: attr(data-trix-placeholder);
  color: graytext;
}

%t [data-trix-cursor-target] {
  display: ` + m.display + ` !important;
  width: ` + m.width + ` !important;
  padding: 0 !important;
  margin: 0 !important;
  border: none !important;
}

%t [data-trix-cursor-target=left] {
  vertical-align: top !important;
  margin-left: -1px !important;
}

%t [data-trix-cursor-target=right] {
  vertical-align: bottom !important;
  margin-right: -1px !important;
}`, trixId: { get: function() {
            return this.hasAttribute("trix-id") ? this.getAttribute("trix-id") : (this.setAttribute("trix-id", ++y), this.trixId);
          } }, labels: { get: function() {
            var S, C, T;
            return C = [], this.id && this.ownerDocument && C.push.apply(C, this.ownerDocument.querySelectorAll("label[for='" + this.id + "']")), (S = a(this, { matchingSelector: "label" })) && ((T = S.control) === this || T === null) && C.push(S), C;
          } }, toolbarElement: { get: function() {
            var S, C, T;
            return this.hasAttribute("toolbar") ? (C = this.ownerDocument) != null ? C.getElementById(this.getAttribute("toolbar")) : void 0 : this.parentNode ? (T = "trix-toolbar-" + this.trixId, this.setAttribute("toolbar", T), S = l("trix-toolbar", { id: T }), this.parentNode.insertBefore(S, this), S) : void 0;
          } }, inputElement: { get: function() {
            var S, C, T;
            return this.hasAttribute("input") ? (T = this.ownerDocument) != null ? T.getElementById(this.getAttribute("input")) : void 0 : this.parentNode ? (C = "trix-input-" + this.trixId, this.setAttribute("input", C), S = l("input", { type: "hidden", id: C }), this.parentNode.insertBefore(S, this.nextElementSibling), S) : void 0;
          } }, editor: { get: function() {
            var S;
            return (S = this.editorController) != null ? S.editor : void 0;
          } }, name: { get: function() {
            var S;
            return (S = this.inputElement) != null ? S.name : void 0;
          } }, value: { get: function() {
            var S;
            return (S = this.inputElement) != null ? S.value : void 0;
          }, set: function(S) {
            var C;
            return this.defaultValue = S, (C = this.editor) != null ? C.loadHTML(this.defaultValue) : void 0;
          } }, notify: function(S, C) {
            return this.editorController ? u("trix-" + S, { onElement: this, attributes: C }) : void 0;
          }, setInputElementValue: function(S) {
            var C;
            return (C = this.inputElement) != null ? C.value = S : void 0;
          }, initialize: function() {
            return this.hasAttribute("data-trix-internal") ? void 0 : (g(this), d(this), b(this));
          }, connect: function() {
            return this.hasAttribute("data-trix-internal") ? void 0 : (this.editorController || (u("trix-before-initialize", { onElement: this }), this.editorController = new n.EditorController({ editorElement: this, html: this.defaultValue = this.value }), requestAnimationFrame(/* @__PURE__ */ function(S) {
              return function() {
                return u("trix-initialize", { onElement: S });
              };
            }(this))), this.editorController.registerSelectionManager(), this.registerResetListener(), this.registerClickListener(), f(this));
          }, disconnect: function() {
            var S;
            return (S = this.editorController) != null && S.unregisterSelectionManager(), this.unregisterResetListener(), this.unregisterClickListener();
          }, registerResetListener: function() {
            return this.resetListener = this.resetBubbled.bind(this), window.addEventListener("reset", this.resetListener, !1);
          }, unregisterResetListener: function() {
            return window.removeEventListener("reset", this.resetListener, !1);
          }, registerClickListener: function() {
            return this.clickListener = this.clickBubbled.bind(this), window.addEventListener("click", this.clickListener, !1);
          }, unregisterClickListener: function() {
            return window.removeEventListener("click", this.clickListener, !1);
          }, resetBubbled: function(S) {
            var C;
            if (!S.defaultPrevented && S.target === ((C = this.inputElement) != null ? C.form : void 0)) return this.reset();
          }, clickBubbled: function(S) {
            var C;
            if (!(S.defaultPrevented || this.contains(S.target) || !(C = a(S.target, { matchingSelector: "label" })) || c.call(this.labels, C) < 0)) return this.focus();
          }, reset: function() {
            return this.value = this.defaultValue;
          } };
        }());
      }).call(this), (function() {
      }).call(this);
    }).call(this), e.exports && (e.exports = n);
  }).call(Mc);
})(CHe);
var L_ = {
  name: "EditorWrapper",
  data() {
    return {
      merge: !0,
      defaultClasses: {
        container: ""
      }
    };
  }
};
const AHe = ["id", "value"];
function OHe(e, t, n, r, i, a) {
  return U(), ee(
    "div",
    {
      class: re(e.classes.container)
    },
    [
      de("input", {
        id: `editor-input-${e.id}`,
        value: e.value,
        type: "hidden"
      }, null, 8, AHe),
      (U(), Ae(ze(e.editorComponent)))
    ],
    2
    /* CLASS */
  );
}
L_.render = OHe;
L_.__file = "themes/blank/templates/wrappers/EditorWrapper.vue";
var S9 = {
  name: "EditorWrapper",
  render: L_.render,
  data: L_.data
}, RHe = `@charset "UTF-8";

trix-toolbar {
  padding: 0.5rem 0.375rem;
  border-radius: 0.25rem;
  flex-wrap: wrap;
}

trix-toolbar .trix-button-row {
  display: block;
  margin-bottom: -0.25rem;
  flex-wrap: nowrap;
  justify-content: space-between;
  overflow-x: auto;
}

trix-toolbar .trix-button-group {
  display: inline;
}

trix-toolbar .trix-button-group-spacer {
  display: hidden;
  flex-grow: 1;
}

trix-toolbar .trix-button {
  position: relative;
  margin-bottom: 0.25rem;
  color: var(--vf-bg-icon);
  padding-left: 0.5rem;
  padding-right: 0.5rem;
  outline: none;
  border-radius: 0.25rem;
  white-space: nowrap;
  float: left;
  border: 0;
  background: none;
}

trix-toolbar .trix-button.trix-active {
  background-color: var(--vf-bg-selected);
  filter: brightness(0.9);
}

trix-toolbar .trix-button:not(.trix-active):hover {
  background-color: var(--vf-bg-selected);
}

.is-disabled trix-toolbar .trix-button:not(.trix-active):hover {
  background: transparent;
  cursor: default;
}

trix-toolbar .trix-button:not(:disabled) {
  cursor: pointer;
}

.is-disabled trix-toolbar .trix-button {
  cursor: default;
  pointer-events: none;
}

trix-toolbar .trix-button--icon {
  width: 2.5rem;
  height: 1.5rem;
  font-size: 0.75rem;
  line-height: 1rem;
  text-indent: -9999px;
}

trix-toolbar .trix-button--icon::before {
  position: absolute;
  top: 0px;
  right: 0px;
  bottom: 0px;
  left: 0px;
  display: inline-block;
  content: "";
  mask-repeat: no-repeat;
  -webkit-mask-repeat: no-repeat;
  mask-position: center center;
  -webkit-mask-position: center center;
  mask-size: contain;
  -webkit-mask-size: contain;
  background-color: var(--vf-bg-icon);
  top: 0.125rem;
  bottom: 0.125rem;
  margin-top: 0.125rem;
  margin-bottom: 0.125rem;
}

trix-toolbar .trix-button--icon.trix-active::before {
  opacity: 1;
}

trix-toolbar .trix-button--icon:disabled::before {
  opacity: 0.4;
}

trix-toolbar .trix-button--icon-attach::before {
  mask-image: url("data:image/svg+xml,%3csvg viewBox='0 0 512 512' fill='currentColor' xmlns='http://www.w3.org/2000/svg'%3e%3cpath d='M67.508 468.467c-58.005-58.013-58.016-151.92 0-209.943l225.011-225.04c44.643-44.645 117.279-44.645 161.92 0 44.743 44.749 44.753 117.186 0 161.944l-189.465 189.49c-31.41 31.413-82.518 31.412-113.926.001-31.479-31.482-31.49-82.453 0-113.944L311.51 110.491c4.687-4.687 12.286-4.687 16.972 0l16.967 16.971c4.685 4.686 4.685 12.283 0 16.969L184.983 304.917c-12.724 12.724-12.73 33.328 0 46.058 12.696 12.697 33.356 12.699 46.054-.001l189.465-189.489c25.987-25.989 25.994-68.06.001-94.056-25.931-25.934-68.119-25.932-94.049 0l-225.01 225.039c-39.249 39.252-39.258 102.795-.001 142.057 39.285 39.29 102.885 39.287 142.162-.028A739446.174 739446.174 0 0 1 439.497 238.49c4.686-4.687 12.282-4.684 16.969.004l16.967 16.971c4.685 4.686 4.689 12.279.004 16.965a755654.128 755654.128 0 0 0-195.881 195.996c-58.034 58.092-152.004 58.093-210.048.041z'%3e%3c/path%3e%3c/svg%3e");
  -webkit-mask-image: url("data:image/svg+xml,%3csvg viewBox='0 0 512 512' fill='currentColor' xmlns='http://www.w3.org/2000/svg'%3e%3cpath d='M67.508 468.467c-58.005-58.013-58.016-151.92 0-209.943l225.011-225.04c44.643-44.645 117.279-44.645 161.92 0 44.743 44.749 44.753 117.186 0 161.944l-189.465 189.49c-31.41 31.413-82.518 31.412-113.926.001-31.479-31.482-31.49-82.453 0-113.944L311.51 110.491c4.687-4.687 12.286-4.687 16.972 0l16.967 16.971c4.685 4.686 4.685 12.283 0 16.969L184.983 304.917c-12.724 12.724-12.73 33.328 0 46.058 12.696 12.697 33.356 12.699 46.054-.001l189.465-189.489c25.987-25.989 25.994-68.06.001-94.056-25.931-25.934-68.119-25.932-94.049 0l-225.01 225.039c-39.249 39.252-39.258 102.795-.001 142.057 39.285 39.29 102.885 39.287 142.162-.028A739446.174 739446.174 0 0 1 439.497 238.49c4.686-4.687 12.282-4.684 16.969.004l16.967 16.971c4.685 4.686 4.689 12.279.004 16.965a755654.128 755654.128 0 0 0-195.881 195.996c-58.034 58.092-152.004 58.093-210.048.041z'%3e%3c/path%3e%3c/svg%3e");
}

trix-toolbar .trix-button--icon-bold::before {
  mask-image: url("data:image/svg+xml,%3csvg viewBox='0 0 384 512' fill='currentColor' xmlns='http://www.w3.org/2000/svg'%3e%3cpath d='M333.49 238a122 122 0 0 0 27-65.21C367.87 96.49 308 32 233.42 32H34a16 16 0 0 0-16 16v48a16 16 0 0 0 16 16h31.87v288H34a16 16 0 0 0-16 16v48a16 16 0 0 0 16 16h209.32c70.8 0 134.14-51.75 141-122.4 4.74-48.45-16.39-92.06-50.83-119.6zM145.66 112h87.76a48 48 0 0 1 0 96h-87.76zm87.76 288h-87.76V288h87.76a56 56 0 0 1 0 112z'%3e%3c/path%3e%3c/svg%3e");
  -webkit-mask-image: url("data:image/svg+xml,%3csvg viewBox='0 0 384 512' fill='currentColor' xmlns='http://www.w3.org/2000/svg'%3e%3cpath d='M333.49 238a122 122 0 0 0 27-65.21C367.87 96.49 308 32 233.42 32H34a16 16 0 0 0-16 16v48a16 16 0 0 0 16 16h31.87v288H34a16 16 0 0 0-16 16v48a16 16 0 0 0 16 16h209.32c70.8 0 134.14-51.75 141-122.4 4.74-48.45-16.39-92.06-50.83-119.6zM145.66 112h87.76a48 48 0 0 1 0 96h-87.76zm87.76 288h-87.76V288h87.76a56 56 0 0 1 0 112z'%3e%3c/path%3e%3c/svg%3e");
}

trix-toolbar .trix-button--icon-italic::before {
  mask-image: url("data:image/svg+xml,%3csvg viewBox='0 0 320 512' fill='currentColor' xmlns='http://www.w3.org/2000/svg'%3e%3cpath d='M320 48v32a16 16 0 0 1-16 16h-62.76l-80 320H208a16 16 0 0 1 16 16v32a16 16 0 0 1-16 16H16a16 16 0 0 1-16-16v-32a16 16 0 0 1 16-16h62.76l80-320H112a16 16 0 0 1-16-16V48a16 16 0 0 1 16-16h192a16 16 0 0 1 16 16z'%3e%3c/path%3e%3c/svg%3e");
  -webkit-mask-image: url("data:image/svg+xml,%3csvg viewBox='0 0 320 512' fill='currentColor' xmlns='http://www.w3.org/2000/svg'%3e%3cpath d='M320 48v32a16 16 0 0 1-16 16h-62.76l-80 320H208a16 16 0 0 1 16 16v32a16 16 0 0 1-16 16H16a16 16 0 0 1-16-16v-32a16 16 0 0 1 16-16h62.76l80-320H112a16 16 0 0 1-16-16V48a16 16 0 0 1 16-16h192a16 16 0 0 1 16 16z'%3e%3c/path%3e%3c/svg%3e");
}

trix-toolbar .trix-button--icon-link::before {
  mask-image: url("data:image/svg+xml,%3csvg viewBox='0 0 512 512' fill='currentColor' xmlns='http://www.w3.org/2000/svg'%3e%3cpath d='M314.222 197.78c51.091 51.091 54.377 132.287 9.75 187.16-6.242 7.73-2.784 3.865-84.94 86.02-54.696 54.696-143.266 54.745-197.99 0-54.711-54.69-54.734-143.255 0-197.99 32.773-32.773 51.835-51.899 63.409-63.457 7.463-7.452 20.331-2.354 20.486 8.192a173.31 173.31 0 0 0 4.746 37.828c.966 4.029-.272 8.269-3.202 11.198L80.632 312.57c-32.755 32.775-32.887 85.892 0 118.8 32.775 32.755 85.892 32.887 118.8 0l75.19-75.2c32.718-32.725 32.777-86.013 0-118.79a83.722 83.722 0 0 0-22.814-16.229c-4.623-2.233-7.182-7.25-6.561-12.346 1.356-11.122 6.296-21.885 14.815-30.405l4.375-4.375c3.625-3.626 9.177-4.594 13.76-2.294 12.999 6.524 25.187 15.211 36.025 26.049zM470.958 41.04c-54.724-54.745-143.294-54.696-197.99 0-82.156 82.156-78.698 78.29-84.94 86.02-44.627 54.873-41.341 136.069 9.75 187.16 10.838 10.838 23.026 19.525 36.025 26.049 4.582 2.3 10.134 1.331 13.76-2.294l4.375-4.375c8.52-8.519 13.459-19.283 14.815-30.405.621-5.096-1.938-10.113-6.561-12.346a83.706 83.706 0 0 1-22.814-16.229c-32.777-32.777-32.718-86.065 0-118.79l75.19-75.2c32.908-32.887 86.025-32.755 118.8 0 32.887 32.908 32.755 86.025 0 118.8l-45.848 45.84c-2.93 2.929-4.168 7.169-3.202 11.198a173.31 173.31 0 0 1 4.746 37.828c.155 10.546 13.023 15.644 20.486 8.192 11.574-11.558 30.636-30.684 63.409-63.457 54.733-54.735 54.71-143.3-.001-197.991z'%3e%3c/path%3e%3c/svg%3e");
  -webkit-mask-image: url("data:image/svg+xml,%3csvg viewBox='0 0 512 512' fill='currentColor' xmlns='http://www.w3.org/2000/svg'%3e%3cpath d='M314.222 197.78c51.091 51.091 54.377 132.287 9.75 187.16-6.242 7.73-2.784 3.865-84.94 86.02-54.696 54.696-143.266 54.745-197.99 0-54.711-54.69-54.734-143.255 0-197.99 32.773-32.773 51.835-51.899 63.409-63.457 7.463-7.452 20.331-2.354 20.486 8.192a173.31 173.31 0 0 0 4.746 37.828c.966 4.029-.272 8.269-3.202 11.198L80.632 312.57c-32.755 32.775-32.887 85.892 0 118.8 32.775 32.755 85.892 32.887 118.8 0l75.19-75.2c32.718-32.725 32.777-86.013 0-118.79a83.722 83.722 0 0 0-22.814-16.229c-4.623-2.233-7.182-7.25-6.561-12.346 1.356-11.122 6.296-21.885 14.815-30.405l4.375-4.375c3.625-3.626 9.177-4.594 13.76-2.294 12.999 6.524 25.187 15.211 36.025 26.049zM470.958 41.04c-54.724-54.745-143.294-54.696-197.99 0-82.156 82.156-78.698 78.29-84.94 86.02-44.627 54.873-41.341 136.069 9.75 187.16 10.838 10.838 23.026 19.525 36.025 26.049 4.582 2.3 10.134 1.331 13.76-2.294l4.375-4.375c8.52-8.519 13.459-19.283 14.815-30.405.621-5.096-1.938-10.113-6.561-12.346a83.706 83.706 0 0 1-22.814-16.229c-32.777-32.777-32.718-86.065 0-118.79l75.19-75.2c32.908-32.887 86.025-32.755 118.8 0 32.887 32.908 32.755 86.025 0 118.8l-45.848 45.84c-2.93 2.929-4.168 7.169-3.202 11.198a173.31 173.31 0 0 1 4.746 37.828c.155 10.546 13.023 15.644 20.486 8.192 11.574-11.558 30.636-30.684 63.409-63.457 54.733-54.735 54.71-143.3-.001-197.991z'%3e%3c/path%3e%3c/svg%3e");
}

trix-toolbar .trix-button--icon-strike::before {
  mask-image: url("data:image/svg+xml,%3csvg viewBox='0 0 512 512' fill='currentColor' xmlns='http://www.w3.org/2000/svg'%3e%3cpath d='M496 224H293.9l-87.17-26.83A43.55 43.55 0 0 1 219.55 112h66.79A49.89 49.89 0 0 1 331 139.58a16 16 0 0 0 21.46 7.15l42.94-21.47a16 16 0 0 0 7.16-21.46l-.53-1A128 128 0 0 0 287.51 32h-68a123.68 123.68 0 0 0-123 135.64c2 20.89 10.1 39.83 21.78 56.36H16a16 16 0 0 0-16 16v32a16 16 0 0 0 16 16h480a16 16 0 0 0 16-16v-32a16 16 0 0 0-16-16zm-180.24 96A43 43 0 0 1 336 356.45 43.59 43.59 0 0 1 292.45 400h-66.79A49.89 49.89 0 0 1 181 372.42a16 16 0 0 0-21.46-7.15l-42.94 21.47a16 16 0 0 0-7.16 21.46l.53 1A128 128 0 0 0 224.49 480h68a123.68 123.68 0 0 0 123-135.64 114.25 114.25 0 0 0-5.34-24.36z'%3e%3c/path%3e%3c/svg%3e");
  -webkit-mask-image: url("data:image/svg+xml,%3csvg viewBox='0 0 512 512' fill='currentColor' xmlns='http://www.w3.org/2000/svg'%3e%3cpath d='M496 224H293.9l-87.17-26.83A43.55 43.55 0 0 1 219.55 112h66.79A49.89 49.89 0 0 1 331 139.58a16 16 0 0 0 21.46 7.15l42.94-21.47a16 16 0 0 0 7.16-21.46l-.53-1A128 128 0 0 0 287.51 32h-68a123.68 123.68 0 0 0-123 135.64c2 20.89 10.1 39.83 21.78 56.36H16a16 16 0 0 0-16 16v32a16 16 0 0 0 16 16h480a16 16 0 0 0 16-16v-32a16 16 0 0 0-16-16zm-180.24 96A43 43 0 0 1 336 356.45 43.59 43.59 0 0 1 292.45 400h-66.79A49.89 49.89 0 0 1 181 372.42a16 16 0 0 0-21.46-7.15l-42.94 21.47a16 16 0 0 0-7.16 21.46l.53 1A128 128 0 0 0 224.49 480h68a123.68 123.68 0 0 0 123-135.64 114.25 114.25 0 0 0-5.34-24.36z'%3e%3c/path%3e%3c/svg%3e");
}

trix-toolbar .trix-button--icon-quote::before {
  mask-image: url("data:image/svg+xml,%3csvg viewBox='0 0 512 512' fill='currentColor' xmlns='http://www.w3.org/2000/svg'%3e%3cpath d='M464 32H336c-26.5 0-48 21.5-48 48v128c0 26.5 21.5 48 48 48h80v64c0 35.3-28.7 64-64 64h-8c-13.3 0-24 10.7-24 24v48c0 13.3 10.7 24 24 24h8c88.4 0 160-71.6 160-160V80c0-26.5-21.5-48-48-48zm-288 0H48C21.5 32 0 53.5 0 80v128c0 26.5 21.5 48 48 48h80v64c0 35.3-28.7 64-64 64h-8c-13.3 0-24 10.7-24 24v48c0 13.3 10.7 24 24 24h8c88.4 0 160-71.6 160-160V80c0-26.5-21.5-48-48-48z'%3e%3c/path%3e%3c/svg%3e");
  -webkit-mask-image: url("data:image/svg+xml,%3csvg viewBox='0 0 512 512' fill='currentColor' xmlns='http://www.w3.org/2000/svg'%3e%3cpath d='M464 32H336c-26.5 0-48 21.5-48 48v128c0 26.5 21.5 48 48 48h80v64c0 35.3-28.7 64-64 64h-8c-13.3 0-24 10.7-24 24v48c0 13.3 10.7 24 24 24h8c88.4 0 160-71.6 160-160V80c0-26.5-21.5-48-48-48zm-288 0H48C21.5 32 0 53.5 0 80v128c0 26.5 21.5 48 48 48h80v64c0 35.3-28.7 64-64 64h-8c-13.3 0-24 10.7-24 24v48c0 13.3 10.7 24 24 24h8c88.4 0 160-71.6 160-160V80c0-26.5-21.5-48-48-48z'%3e%3c/path%3e%3c/svg%3e");
  top: 0.25rem;
  bottom: 0.25rem;
  margin-top: 1px;
  margin-bottom: 1px;
}

trix-toolbar .trix-button--icon-heading-1::before {
  mask-image: url("data:image/svg+xml,%3csvg viewBox='0 0 512 512' fill='currentColor' xmlns='http://www.w3.org/2000/svg'%3e%3cpath d='M448 96v320h32a16 16 0 0 1 16 16v32a16 16 0 0 1-16 16H320a16 16 0 0 1-16-16v-32a16 16 0 0 1 16-16h32V288H160v128h32a16 16 0 0 1 16 16v32a16 16 0 0 1-16 16H32a16 16 0 0 1-16-16v-32a16 16 0 0 1 16-16h32V96H32a16 16 0 0 1-16-16V48a16 16 0 0 1 16-16h160a16 16 0 0 1 16 16v32a16 16 0 0 1-16 16h-32v128h192V96h-32a16 16 0 0 1-16-16V48a16 16 0 0 1 16-16h160a16 16 0 0 1 16 16v32a16 16 0 0 1-16 16z'%3e%3c/path%3e%3c/svg%3e");
  -webkit-mask-image: url("data:image/svg+xml,%3csvg viewBox='0 0 512 512' fill='currentColor' xmlns='http://www.w3.org/2000/svg'%3e%3cpath d='M448 96v320h32a16 16 0 0 1 16 16v32a16 16 0 0 1-16 16H320a16 16 0 0 1-16-16v-32a16 16 0 0 1 16-16h32V288H160v128h32a16 16 0 0 1 16 16v32a16 16 0 0 1-16 16H32a16 16 0 0 1-16-16v-32a16 16 0 0 1 16-16h32V96H32a16 16 0 0 1-16-16V48a16 16 0 0 1 16-16h160a16 16 0 0 1 16 16v32a16 16 0 0 1-16 16h-32v128h192V96h-32a16 16 0 0 1-16-16V48a16 16 0 0 1 16-16h160a16 16 0 0 1 16 16v32a16 16 0 0 1-16 16z'%3e%3c/path%3e%3c/svg%3e");
}

trix-toolbar .trix-button--icon-code::before {
  mask-image: url("data:image/svg+xml,%3csvg viewBox='0 0 640 304' fill='currentColor' xmlns='http://www.w3.org/2000/svg'%3e%3cpath d='M165.9%2c291.3 L209.4%2c244.9 C214%2c240 213.7%2c232.2 208.6%2c227.7 L118%2c148 L208.6%2c68.3 C213.7%2c63.8 214.1%2c56 209.4%2c51.1 L165.9%2c4.7 C161.4%2c-0.1 153.8%2c-0.4 148.9%2c4.2 L4.8%2c139.2 C-0.3%2c143.9 -0.3%2c152 4.8%2c156.7 L148.9%2c291.8 C153.8%2c296.4 161.4%2c296.2 165.9%2c291.3 Z M493.1%2c291.9 L637.2%2c156.8 C642.3%2c152.1 642.3%2c144 637.2%2c139.3 L493.1%2c4.1 C488.3%2c-0.4 480.7%2c-0.2 476.1%2c4.6 L432.6%2c51 C428%2c55.9 428.3%2c63.7 433.4%2c68.2 L524%2c148 L433.4%2c227.7 C428.3%2c232.2 427.9%2c240 432.6%2c244.9 L476.1%2c291.3 C480.6%2c296.2 488.2%2c296.4 493.1%2c291.9 Z'%3e%3c/path%3e%3c/svg%3e");
  -webkit-mask-image: url("data:image/svg+xml,%3csvg viewBox='0 0 640 304' fill='currentColor' xmlns='http://www.w3.org/2000/svg'%3e%3cpath d='M165.9%2c291.3 L209.4%2c244.9 C214%2c240 213.7%2c232.2 208.6%2c227.7 L118%2c148 L208.6%2c68.3 C213.7%2c63.8 214.1%2c56 209.4%2c51.1 L165.9%2c4.7 C161.4%2c-0.1 153.8%2c-0.4 148.9%2c4.2 L4.8%2c139.2 C-0.3%2c143.9 -0.3%2c152 4.8%2c156.7 L148.9%2c291.8 C153.8%2c296.4 161.4%2c296.2 165.9%2c291.3 Z M493.1%2c291.9 L637.2%2c156.8 C642.3%2c152.1 642.3%2c144 637.2%2c139.3 L493.1%2c4.1 C488.3%2c-0.4 480.7%2c-0.2 476.1%2c4.6 L432.6%2c51 C428%2c55.9 428.3%2c63.7 433.4%2c68.2 L524%2c148 L433.4%2c227.7 C428.3%2c232.2 427.9%2c240 432.6%2c244.9 L476.1%2c291.3 C480.6%2c296.2 488.2%2c296.4 493.1%2c291.9 Z'%3e%3c/path%3e%3c/svg%3e");
  top: 0.375rem;
  bottom: 0.375rem;
  margin-top: 1px;
  margin-bottom: 1px;
}

trix-toolbar .trix-button--icon-bullet-list::before {
  mask-image: url("data:image/svg+xml,%3csvg viewBox='0 0 512 512' fill='currentColor' xmlns='http://www.w3.org/2000/svg'%3e%3cpath d='M48 48a48 48 0 1 0 48 48 48 48 0 0 0-48-48zm0 160a48 48 0 1 0 48 48 48 48 0 0 0-48-48zm0 160a48 48 0 1 0 48 48 48 48 0 0 0-48-48zm448 16H176a16 16 0 0 0-16 16v32a16 16 0 0 0 16 16h320a16 16 0 0 0 16-16v-32a16 16 0 0 0-16-16zm0-320H176a16 16 0 0 0-16 16v32a16 16 0 0 0 16 16h320a16 16 0 0 0 16-16V80a16 16 0 0 0-16-16zm0 160H176a16 16 0 0 0-16 16v32a16 16 0 0 0 16 16h320a16 16 0 0 0 16-16v-32a16 16 0 0 0-16-16z'%3e%3c/path%3e%3c/svg%3e");
  -webkit-mask-image: url("data:image/svg+xml,%3csvg viewBox='0 0 512 512' fill='currentColor' xmlns='http://www.w3.org/2000/svg'%3e%3cpath d='M48 48a48 48 0 1 0 48 48 48 48 0 0 0-48-48zm0 160a48 48 0 1 0 48 48 48 48 0 0 0-48-48zm0 160a48 48 0 1 0 48 48 48 48 0 0 0-48-48zm448 16H176a16 16 0 0 0-16 16v32a16 16 0 0 0 16 16h320a16 16 0 0 0 16-16v-32a16 16 0 0 0-16-16zm0-320H176a16 16 0 0 0-16 16v32a16 16 0 0 0 16 16h320a16 16 0 0 0 16-16V80a16 16 0 0 0-16-16zm0 160H176a16 16 0 0 0-16 16v32a16 16 0 0 0 16 16h320a16 16 0 0 0 16-16v-32a16 16 0 0 0-16-16z'%3e%3c/path%3e%3c/svg%3e");
  margin-top: 1px;
  margin-bottom: 1px;
}

trix-toolbar .trix-button--icon-number-list::before {
  mask-image: url("data:image/svg+xml,%3csvg viewBox='0 0 512 512' fill='currentColor' xmlns='http://www.w3.org/2000/svg'%3e%3cpath d='M61.77 401l17.5-20.15a19.92 19.92 0 0 0 5.07-14.19v-3.31C84.34 356 80.5 352 73 352H16a8 8 0 0 0-8 8v16a8 8 0 0 0 8 8h22.83a157.41 157.41 0 0 0-11 12.31l-5.61 7c-4 5.07-5.25 10.13-2.8 14.88l1.05 1.93c3 5.76 6.29 7.88 12.25 7.88h4.73c10.33 0 15.94 2.44 15.94 9.09 0 4.72-4.2 8.22-14.36 8.22a41.54 41.54 0 0 1-15.47-3.12c-6.49-3.88-11.74-3.5-15.6 3.12l-5.59 9.31c-3.72 6.13-3.19 11.72 2.63 15.94 7.71 4.69 20.38 9.44 37 9.44 34.16 0 48.5-22.75 48.5-44.12-.03-14.38-9.12-29.76-28.73-34.88zM496 224H176a16 16 0 0 0-16 16v32a16 16 0 0 0 16 16h320a16 16 0 0 0 16-16v-32a16 16 0 0 0-16-16zm0-160H176a16 16 0 0 0-16 16v32a16 16 0 0 0 16 16h320a16 16 0 0 0 16-16V80a16 16 0 0 0-16-16zm0 320H176a16 16 0 0 0-16 16v32a16 16 0 0 0 16 16h320a16 16 0 0 0 16-16v-32a16 16 0 0 0-16-16zM16 160h64a8 8 0 0 0 8-8v-16a8 8 0 0 0-8-8H64V40a8 8 0 0 0-8-8H32a8 8 0 0 0-7.14 4.42l-8 16A8 8 0 0 0 24 64h8v64H16a8 8 0 0 0-8 8v16a8 8 0 0 0 8 8zm-3.91 160H80a8 8 0 0 0 8-8v-16a8 8 0 0 0-8-8H41.32c3.29-10.29 48.34-18.68 48.34-56.44 0-29.06-25-39.56-44.47-39.56-21.36 0-33.8 10-40.46 18.75-4.37 5.59-3 10.84 2.8 15.37l8.58 6.88c5.61 4.56 11 2.47 16.12-2.44a13.44 13.44 0 0 1 9.46-3.84c3.33 0 9.28 1.56 9.28 8.75C51 248.19 0 257.31 0 304.59v4C0 316 5.08 320 12.09 320z'%3e%3c/path%3e%3c/svg%3e");
  -webkit-mask-image: url("data:image/svg+xml,%3csvg viewBox='0 0 512 512' fill='currentColor' xmlns='http://www.w3.org/2000/svg'%3e%3cpath d='M61.77 401l17.5-20.15a19.92 19.92 0 0 0 5.07-14.19v-3.31C84.34 356 80.5 352 73 352H16a8 8 0 0 0-8 8v16a8 8 0 0 0 8 8h22.83a157.41 157.41 0 0 0-11 12.31l-5.61 7c-4 5.07-5.25 10.13-2.8 14.88l1.05 1.93c3 5.76 6.29 7.88 12.25 7.88h4.73c10.33 0 15.94 2.44 15.94 9.09 0 4.72-4.2 8.22-14.36 8.22a41.54 41.54 0 0 1-15.47-3.12c-6.49-3.88-11.74-3.5-15.6 3.12l-5.59 9.31c-3.72 6.13-3.19 11.72 2.63 15.94 7.71 4.69 20.38 9.44 37 9.44 34.16 0 48.5-22.75 48.5-44.12-.03-14.38-9.12-29.76-28.73-34.88zM496 224H176a16 16 0 0 0-16 16v32a16 16 0 0 0 16 16h320a16 16 0 0 0 16-16v-32a16 16 0 0 0-16-16zm0-160H176a16 16 0 0 0-16 16v32a16 16 0 0 0 16 16h320a16 16 0 0 0 16-16V80a16 16 0 0 0-16-16zm0 320H176a16 16 0 0 0-16 16v32a16 16 0 0 0 16 16h320a16 16 0 0 0 16-16v-32a16 16 0 0 0-16-16zM16 160h64a8 8 0 0 0 8-8v-16a8 8 0 0 0-8-8H64V40a8 8 0 0 0-8-8H32a8 8 0 0 0-7.14 4.42l-8 16A8 8 0 0 0 24 64h8v64H16a8 8 0 0 0-8 8v16a8 8 0 0 0 8 8zm-3.91 160H80a8 8 0 0 0 8-8v-16a8 8 0 0 0-8-8H41.32c3.29-10.29 48.34-18.68 48.34-56.44 0-29.06-25-39.56-44.47-39.56-21.36 0-33.8 10-40.46 18.75-4.37 5.59-3 10.84 2.8 15.37l8.58 6.88c5.61 4.56 11 2.47 16.12-2.44a13.44 13.44 0 0 1 9.46-3.84c3.33 0 9.28 1.56 9.28 8.75C51 248.19 0 257.31 0 304.59v4C0 316 5.08 320 12.09 320z'%3e%3c/path%3e%3c/svg%3e");
  margin-top: 1px;
  margin-bottom: 1px;
}

trix-toolbar .trix-button--icon-undo::before {
  mask-image: url("data:image/svg+xml,%3csvg viewBox='0 0 512 512' fill='currentColor' xmlns='http://www.w3.org/2000/svg'%3e%3cpath d='M255.545 8c-66.269.119-126.438 26.233-170.86 68.685L48.971 40.971C33.851 25.851 8 36.559 8 57.941V192c0 13.255 10.745 24 24 24h134.059c21.382 0 32.09-25.851 16.971-40.971l-41.75-41.75c30.864-28.899 70.801-44.907 113.23-45.273 92.398-.798 170.283 73.977 169.484 169.442C423.236 348.009 349.816 424 256 424c-41.127 0-79.997-14.678-110.63-41.556-4.743-4.161-11.906-3.908-16.368.553L89.34 422.659c-4.872 4.872-4.631 12.815.482 17.433C133.798 479.813 192.074 504 256 504c136.966 0 247.999-111.033 248-247.998C504.001 119.193 392.354 7.755 255.545 8z'%3e%3c/path%3e%3c/svg%3e");
  -webkit-mask-image: url("data:image/svg+xml,%3csvg viewBox='0 0 512 512' fill='currentColor' xmlns='http://www.w3.org/2000/svg'%3e%3cpath d='M255.545 8c-66.269.119-126.438 26.233-170.86 68.685L48.971 40.971C33.851 25.851 8 36.559 8 57.941V192c0 13.255 10.745 24 24 24h134.059c21.382 0 32.09-25.851 16.971-40.971l-41.75-41.75c30.864-28.899 70.801-44.907 113.23-45.273 92.398-.798 170.283 73.977 169.484 169.442C423.236 348.009 349.816 424 256 424c-41.127 0-79.997-14.678-110.63-41.556-4.743-4.161-11.906-3.908-16.368.553L89.34 422.659c-4.872 4.872-4.631 12.815.482 17.433C133.798 479.813 192.074 504 256 504c136.966 0 247.999-111.033 248-247.998C504.001 119.193 392.354 7.755 255.545 8z'%3e%3c/path%3e%3c/svg%3e");
  top: 0.25rem;
  bottom: 0.25rem;
}

trix-toolbar .trix-button--icon-redo::before {
  mask-image: url("data:image/svg+xml,%3csvg viewBox='0 0 512 512' fill='currentColor' xmlns='http://www.w3.org/2000/svg'%3e%3cpath d='M256.455 8c66.269.119 126.437 26.233 170.859 68.685l35.715-35.715C478.149 25.851 504 36.559 504 57.941V192c0 13.255-10.745 24-24 24H345.941c-21.382 0-32.09-25.851-16.971-40.971l41.75-41.75c-30.864-28.899-70.801-44.907-113.23-45.273-92.398-.798-170.283 73.977-169.484 169.442C88.764 348.009 162.184 424 256 424c41.127 0 79.997-14.678 110.629-41.556 4.743-4.161 11.906-3.908 16.368.553l39.662 39.662c4.872 4.872 4.631 12.815-.482 17.433C378.202 479.813 319.926 504 256 504 119.034 504 8.001 392.967 8 256.002 7.999 119.193 119.646 7.755 256.455 8z'%3e%3c/path%3e%3c/svg%3e");
  -webkit-mask-image: url("data:image/svg+xml,%3csvg viewBox='0 0 512 512' fill='currentColor' xmlns='http://www.w3.org/2000/svg'%3e%3cpath d='M256.455 8c66.269.119 126.437 26.233 170.859 68.685l35.715-35.715C478.149 25.851 504 36.559 504 57.941V192c0 13.255-10.745 24-24 24H345.941c-21.382 0-32.09-25.851-16.971-40.971l41.75-41.75c-30.864-28.899-70.801-44.907-113.23-45.273-92.398-.798-170.283 73.977-169.484 169.442C88.764 348.009 162.184 424 256 424c41.127 0 79.997-14.678 110.629-41.556 4.743-4.161 11.906-3.908 16.368.553l39.662 39.662c4.872 4.872 4.631 12.815-.482 17.433C378.202 479.813 319.926 504 256 504 119.034 504 8.001 392.967 8 256.002 7.999 119.193 119.646 7.755 256.455 8z'%3e%3c/path%3e%3c/svg%3e");
  top: 0.25rem;
  bottom: 0.25rem;
}

trix-toolbar .trix-button--icon-decrease-nesting-level::before {
  mask-image: url("data:image/svg+xml,%3csvg viewBox='0 0 448 512' fill='currentColor' xmlns='http://www.w3.org/2000/svg'%3e%3cpath d='M100.682584%2c116.695158 L4.68258422%2c212.695158 C-1.56086141%2c218.942698 -1.56086141%2c229.067619 4.68258422%2c235.315158 L100.682584%2c331.315158 C110.722584%2c341.335158 127.992584%2c334.215158 127.992584%2c319.995158 L127.992584%2c127.995158 C127.992584%2c113.685158 110.662584%2c106.695158 100.682584%2c116.695158 Z M432%2c384 L16%2c384 C7.163444%2c384 1.082166e-15%2c391.163444 0%2c400 L0%2c432 C1.082166e-15%2c440.836556 7.163444%2c448 16%2c448 L432%2c448 C440.836556%2c448 448%2c440.836556 448%2c432 L448%2c400 C448%2c391.163444 440.836556%2c384 432%2c384 Z M204.83%2c256 C201.426459%2c255.997344 198.161555%2c257.348219 195.754887%2c259.754887 C193.348219%2c262.161555 191.997344%2c265.426459 192%2c268.83 L192%2c307.17 C191.997344%2c310.573541 193.348219%2c313.838445 195.754887%2c316.245113 C198.161555%2c318.651781 201.426459%2c320.002656 204.83%2c320 L435.17%2c320 C438.573541%2c320.002656 441.838445%2c318.651781 444.245113%2c316.245113 C446.651781%2c313.838445 448.002656%2c310.573541 448%2c307.17 L448%2c268.83 C448.002656%2c265.426459 446.651781%2c262.161555 444.245113%2c259.754887 C441.838445%2c257.348219 438.573541%2c255.997344 435.17%2c256 L204.83%2c256 Z M435.17%2c128 L204.83%2c128 C201.426459%2c127.997344 198.161555%2c129.348219 195.754887%2c131.754887 C193.348219%2c134.161555 191.997344%2c137.426459 192%2c140.83 L192%2c179.17 C191.997344%2c182.573541 193.348219%2c185.838445 195.754887%2c188.245113 C198.161555%2c190.651781 201.426459%2c192.002656 204.83%2c192 L435.17%2c192 C438.573541%2c192.002656 441.838445%2c190.651781 444.245113%2c188.245113 C446.651781%2c185.838445 448.002656%2c182.573541 448%2c179.17 L448%2c140.83 C448.002656%2c137.426459 446.651781%2c134.161555 444.245113%2c131.754887 C441.838445%2c129.348219 438.573541%2c127.997344 435.17%2c128 Z M432%2c0 L16%2c0 C7.163444%2c0 1.082166e-15%2c7.163444 0%2c16 L0%2c48 C1.082166e-15%2c56.836556 7.163444%2c64 16%2c64 L432%2c64 C440.836556%2c64 448%2c56.836556 448%2c48 L448%2c16 C448%2c7.163444 440.836556%2c0 432%2c0 Z'%3e%3c/path%3e%3c/svg%3e");
  -webkit-mask-image: url("data:image/svg+xml,%3csvg viewBox='0 0 448 512' fill='currentColor' xmlns='http://www.w3.org/2000/svg'%3e%3cpath d='M100.682584%2c116.695158 L4.68258422%2c212.695158 C-1.56086141%2c218.942698 -1.56086141%2c229.067619 4.68258422%2c235.315158 L100.682584%2c331.315158 C110.722584%2c341.335158 127.992584%2c334.215158 127.992584%2c319.995158 L127.992584%2c127.995158 C127.992584%2c113.685158 110.662584%2c106.695158 100.682584%2c116.695158 Z M432%2c384 L16%2c384 C7.163444%2c384 1.082166e-15%2c391.163444 0%2c400 L0%2c432 C1.082166e-15%2c440.836556 7.163444%2c448 16%2c448 L432%2c448 C440.836556%2c448 448%2c440.836556 448%2c432 L448%2c400 C448%2c391.163444 440.836556%2c384 432%2c384 Z M204.83%2c256 C201.426459%2c255.997344 198.161555%2c257.348219 195.754887%2c259.754887 C193.348219%2c262.161555 191.997344%2c265.426459 192%2c268.83 L192%2c307.17 C191.997344%2c310.573541 193.348219%2c313.838445 195.754887%2c316.245113 C198.161555%2c318.651781 201.426459%2c320.002656 204.83%2c320 L435.17%2c320 C438.573541%2c320.002656 441.838445%2c318.651781 444.245113%2c316.245113 C446.651781%2c313.838445 448.002656%2c310.573541 448%2c307.17 L448%2c268.83 C448.002656%2c265.426459 446.651781%2c262.161555 444.245113%2c259.754887 C441.838445%2c257.348219 438.573541%2c255.997344 435.17%2c256 L204.83%2c256 Z M435.17%2c128 L204.83%2c128 C201.426459%2c127.997344 198.161555%2c129.348219 195.754887%2c131.754887 C193.348219%2c134.161555 191.997344%2c137.426459 192%2c140.83 L192%2c179.17 C191.997344%2c182.573541 193.348219%2c185.838445 195.754887%2c188.245113 C198.161555%2c190.651781 201.426459%2c192.002656 204.83%2c192 L435.17%2c192 C438.573541%2c192.002656 441.838445%2c190.651781 444.245113%2c188.245113 C446.651781%2c185.838445 448.002656%2c182.573541 448%2c179.17 L448%2c140.83 C448.002656%2c137.426459 446.651781%2c134.161555 444.245113%2c131.754887 C441.838445%2c129.348219 438.573541%2c127.997344 435.17%2c128 Z M432%2c0 L16%2c0 C7.163444%2c0 1.082166e-15%2c7.163444 0%2c16 L0%2c48 C1.082166e-15%2c56.836556 7.163444%2c64 16%2c64 L432%2c64 C440.836556%2c64 448%2c56.836556 448%2c48 L448%2c16 C448%2c7.163444 440.836556%2c0 432%2c0 Z'%3e%3c/path%3e%3c/svg%3e");
  margin-bottom: 0;
}

trix-toolbar .trix-button--icon-increase-nesting-level::before {
  mask-image: url("data:image/svg+xml,%3csvg viewBox='0 0 448 512' fill='currentColor' xmlns='http://www.w3.org/2000/svg'%3e%3cpath d='M27.31 363.3l96-96a16 16 0 0 0 0-22.62l-96-96C17.27 138.66 0 145.78 0 160v192c0 14.31 17.33 21.3 27.31 11.3zM432 416H16a16 16 0 0 0-16 16v32a16 16 0 0 0 16 16h416a16 16 0 0 0 16-16v-32a16 16 0 0 0-16-16zm3.17-128H204.83A12.82 12.82 0 0 0 192 300.83v38.34A12.82 12.82 0 0 0 204.83 352h230.34A12.82 12.82 0 0 0 448 339.17v-38.34A12.82 12.82 0 0 0 435.17 288zm0-128H204.83A12.82 12.82 0 0 0 192 172.83v38.34A12.82 12.82 0 0 0 204.83 224h230.34A12.82 12.82 0 0 0 448 211.17v-38.34A12.82 12.82 0 0 0 435.17 160zM432 32H16A16 16 0 0 0 0 48v32a16 16 0 0 0 16 16h416a16 16 0 0 0 16-16V48a16 16 0 0 0-16-16z'%3e%3c/path%3e%3c/svg%3e");
  -webkit-mask-image: url("data:image/svg+xml,%3csvg viewBox='0 0 448 512' fill='currentColor' xmlns='http://www.w3.org/2000/svg'%3e%3cpath d='M27.31 363.3l96-96a16 16 0 0 0 0-22.62l-96-96C17.27 138.66 0 145.78 0 160v192c0 14.31 17.33 21.3 27.31 11.3zM432 416H16a16 16 0 0 0-16 16v32a16 16 0 0 0 16 16h416a16 16 0 0 0 16-16v-32a16 16 0 0 0-16-16zm3.17-128H204.83A12.82 12.82 0 0 0 192 300.83v38.34A12.82 12.82 0 0 0 204.83 352h230.34A12.82 12.82 0 0 0 448 339.17v-38.34A12.82 12.82 0 0 0 435.17 288zm0-128H204.83A12.82 12.82 0 0 0 192 172.83v38.34A12.82 12.82 0 0 0 204.83 224h230.34A12.82 12.82 0 0 0 448 211.17v-38.34A12.82 12.82 0 0 0 435.17 160zM432 32H16A16 16 0 0 0 0 48v32a16 16 0 0 0 16 16h416a16 16 0 0 0 16-16V48a16 16 0 0 0-16-16z'%3e%3c/path%3e%3c/svg%3e");
  margin-top: 1px;
  margin-bottom: 1px;
}

trix-toolbar .trix-dialogs {
  position: relative;
}

trix-toolbar .trix-dialog {
  position: absolute;
  top: 0;
  left: 0;
  right: 0;
  font-size: 0.75rem;
  line-height: 1rem;
  padding: 1rem 0.625rem;
  background-color: var(--vf-bg-input);
  box-shadow: 0 0px 15px 0px rgba(0, 0, 0, 0.3);
  margin-top: 0.375rem;
  border-radius: 0.25rem;
  z-index: 2;
}

trix-toolbar .trix-input--dialog {
  padding: 0.375rem 0.75rem;
  border: 1px solid var(--vf-border-color-input);
  border-radius: 0.25rem;
  margin-right: 0.5rem;
  font-size: 0.75rem;
  line-height: 1rem;
  background: var(--vf-bg-input);
  color: var(--vf-color-input);
}

trix-toolbar .trix-input--dialog:focus {
  outline: var(--vf-ring-width) solid var(--vf-ring-color) !important;
}

trix-toolbar .trix-input--dialog.validate:invalid {
  border-color: var(--vf-color-danger);
}

trix-toolbar .trix-button--dialog {
  padding: 0.5rem;
  border-left-width: 1px;
  border-color: var(--vf-border-color-input);
  background-color: transparent;
  border-radius: 0;
}

trix-toolbar .trix-button--dialog:not(.trix-active):hover {
  background-color: transparent;
}

trix-toolbar .trix-button--dialog:first-of-type {
  border: 0;
}

trix-toolbar .trix-dialog--link {
  max-width: 36rem;
}

trix-toolbar .trix-dialog__link-fields {
  display: flex;
  align-items: center;
  width: 100%;
}

trix-toolbar .trix-dialog__link-fields .trix-input {
  flex: 1 1 0%;
}

trix-toolbar .trix-dialog__link-fields .trix-button-group {
  flex-grow: 0;
  flex-shrink: 0;
}

trix-editor {
  padding-left: var(--vf-px-input);
  padding-right: var(--vf-px-input);
  padding-bottom: var(--vf-py-input);
  border-radius: var(--vf-radius-large);
  outline: none;
  min-height: 6rem;
}

trix-editor:empty:not(:focus)::before {
  color: var(--vf-color-placeholder);
}

trix-editor [data-trix-mutable]:not(.attachment__caption-editor) {
  -webkit-user-select: none;
     -moz-user-select: none;
          user-select: none;
}

trix-editor [data-trix-mutable]::-moz-selection,
trix-editor [data-trix-cursor-target]::-moz-selection,
trix-editor [data-trix-mutable] ::-moz-selection {
  background-image: none;
}

trix-editor [data-trix-mutable]::-moz-selection, trix-editor [data-trix-cursor-target]::-moz-selection, trix-editor [data-trix-mutable] ::-moz-selection {
  background-image: none;
}

trix-editor [data-trix-mutable]::selection,
trix-editor [data-trix-cursor-target]::selection,
trix-editor [data-trix-mutable] ::selection {
  background-image: none;
}

trix-editor [data-trix-mutable].attachment__caption-editor:focus::-moz-selection {
  background: highlight;
}

trix-editor [data-trix-mutable].attachment__caption-editor:focus::selection {
  background: highlight;
}

trix-editor [data-trix-mutable].attachment.attachment--file {
  background-color: var(--vf-bg-selected);
}

trix-editor [data-trix-mutable].attachment img {
  box-shadow: 0 1px 3px 0 rgba(0, 0, 0, 0.1), 0 1px 2px 0 rgba(0, 0, 0, 0.06);
}

trix-editor .attachment {
  position: relative;
}

trix-editor .attachment:hover {
  cursor: default;
}

trix-editor .attachment--preview .attachment__caption:hover {
  cursor: text;
}

trix-editor .attachment__progress {
  position: absolute;
  z-index: 1;
  height: 1.25rem;
  top: 50%;
  left: 0;
  transform: translateY(-0.625rem);
  width: 100%;
  padding-left: 1rem;
  padding-right: 1rem;
  opacity: 0.2;
  transition-property: opacity;
  transition-timing-function: cubic-bezier(0.4, 0, 0.2, 1);
  transition-duration: 150ms;
}

trix-editor .attachment__progress[value="100"] {
  opacity: 0;
}

trix-editor .attachment__caption-editor {
  display: inline-block;
  padding: 0;
  margin: 0;
  font-size: 0.875rem;
  line-height: 1.25rem;
  text-align: center;
  vertical-align: top;
  width: 100%;
  border-width: 0;
  -webkit-appearance: none;
     -moz-appearance: none;
          appearance: none;
  outline: 0;
  background: var(--vf-bg-input);
  color: var(--vf-color-input);
  font-family: inherit;
}

trix-editor .attachment__toolbar {
  position: absolute;
  top: 0;
  left: 0;
  z-index: 1;
  transform: translateY(-50%);
  text-align: center;
  width: 100%;
}

trix-editor .trix-button-group {
  display: inline-flex;
}

trix-editor .trix-button {
  position: relative;
  padding-top: 0;
  padding-bottom: 0;
  padding-left: 0.75rem;
  padding-right: 0.75rem;
  margin: 0;
  background-color: transparent;
  color: var(--vf-bg-icon);
  font-size: 0.875rem;
  line-height: 1.25rem;
  white-space: nowrap;
  border-radius: 0;
  border-width: 0;
  outline: 0;
}

trix-editor .trix-button:not(:disabled) {
  cursor: pointer;
}

trix-editor .trix-button--remove {
  display: inline-block;
  overflow-x: hidden;
  padding: 0;
  background-color: var(--vf-bg-input);
  line-height: 1.75rem;
  border-color: var(--vf-color-selected);
  border-radius: 9999px;
  border-width: 1px;
  border-style: solid;
  outline: 0;
  text-indent: -9999px;
  width: 24px;
  height: 24px;
}

trix-editor .trix-button--remove:hover {
  background-color: var(--vf-bg-selected);
}

trix-editor .trix-button--remove::before {
  content: "";
  display: inline-block;
  position: absolute;
  top: 0.125rem;
  right: 0.125rem;
  bottom: 0.125rem;
  left: 0.125rem;
  background-color: var(--vf-color-input);
  opacity: 0.7;
  background-position: center;
  background-repeat: no-repeat;
  mask-repeat: no-repeat;
  -webkit-mask-repeat: no-repeat;
  mask-position: center center;
  -webkit-mask-position: center center;
  mask-size: contain;
  -webkit-mask-size: contain;
  mask-image: url("data:image/svg+xml,%3csvg viewBox='0 0 320 512' fill='currentColor' xmlns='http://www.w3.org/2000/svg'%3e%3cpath d='M193.94 256L296.5 153.44l21.15-21.15c3.12-3.12 3.12-8.19 0-11.31l-22.63-22.63c-3.12-3.12-8.19-3.12-11.31 0L160 222.06 36.29 98.34c-3.12-3.12-8.19-3.12-11.31 0L2.34 120.97c-3.12 3.12-3.12 8.19 0 11.31L126.06 256 2.34 379.71c-3.12 3.12-3.12 8.19 0 11.31l22.63 22.63c3.12 3.12 8.19 3.12 11.31 0L160 289.94 262.56 392.5l21.15 21.15c3.12 3.12 8.19 3.12 11.31 0l22.63-22.63c3.12-3.12 3.12-8.19 0-11.31L193.94 256z'%3e%3c/path%3e%3c/svg%3e");
  -webkit-mask-image: url("data:image/svg+xml,%3csvg viewBox='0 0 320 512' fill='currentColor' xmlns='http://www.w3.org/2000/svg'%3e%3cpath d='M193.94 256L296.5 153.44l21.15-21.15c3.12-3.12 3.12-8.19 0-11.31l-22.63-22.63c-3.12-3.12-8.19-3.12-11.31 0L160 222.06 36.29 98.34c-3.12-3.12-8.19-3.12-11.31 0L2.34 120.97c-3.12 3.12-3.12 8.19 0 11.31L126.06 256 2.34 379.71c-3.12 3.12-3.12 8.19 0 11.31l22.63 22.63c3.12 3.12 8.19 3.12 11.31 0L160 289.94 262.56 392.5l21.15 21.15c3.12 3.12 8.19 3.12 11.31 0l22.63-22.63c3.12-3.12 3.12-8.19 0-11.31L193.94 256z'%3e%3c/path%3e%3c/svg%3e");
}

trix-editor .attachment__metadata-container {
  position: relative;
}

trix-editor .attachment__metadata {
  position: absolute;
  top: 1rem;
  left: 50%;
  padding-top: 0.125rem;
  padding-bottom: 0.125rem;
  padding-left: 0.5rem;
  padding-right: 0.5rem;
  background-color: #000000;
  opacity: 0.7;
  transform: translateX(-50%);
  color: #ffffff;
  font-size: 0.875rem;
  line-height: 1.25rem;
  border-radius: 0.25rem;
}

trix-editor .attachment__metadata .attachment__name {
  display: inline-block;
  overflow: hidden;
  text-overflow: ellipsis;
  vertical-align: bottom;
  white-space: nowrap;
  max-width: 100%;
}

trix-editor .attachment__metadata .attachment__size {
  margin-left: 0.25rem;
  white-space: nowrap;
}

.trix-content h1,
trix-editor h1 {
  font-size: 1.875rem;
  line-height: 2.25rem;
  font-weight: 700;
  line-height: 1.25;
}

.trix-content a,
trix-editor a {
  color: var(--vf-primary);
}

.trix-content ul,
trix-editor ul {
  padding-left: 2.5rem;
  list-style-type: disc;
}

.trix-content [dir=rtl] ul,
trix-editor [dir=rtl] ul {
  padding-right: 2.5rem;
  list-style-type: disc;
}

.trix-content ol,
trix-editor ol {
  padding-left: 2.5rem;
  list-style-type: decimal;
}

.trix-content [dir=rtl] ol,
trix-editor [dir=rtl] ol {
  padding-right: 2.5rem;
  list-style-type: decimal;
}

.trix-content blockquote,
trix-editor blockquote {
  padding-left: 0.625rem;
  border-left-width: 4px;
  border-color: var(--vf-gray-300);
  border-left-style: solid;
  margin: 0;
}

.trix-content [dir=rtl] blockquote,
.trix-content blockquote[dir=rtl],
trix-editor [dir=rtl] blockquote,
trix-editor blockquote[dir=rtl] {
  padding-left: 0.625rem;
  border-left-width: 4px;
  border-color: var(--vf-gray-300);
}

.trix-content pre,
trix-editor pre {
  display: inline-block;
  overscroll-behavior-x: auto;
  padding: 0.5rem;
  background-color: var(--vf-gray-50);
  font-family: ui-monospace, SFMono-Regular, Menlo, Monaco, Consolas, "Liberation Mono", "Courier New", monospace;
  font-size: 0.875rem;
  line-height: 1.25rem;
  vertical-align: top;
  white-space: pre;
  width: 100%;
}

.trix-content img,
trix-editor img {
  max-width: 100%;
  height: auto;
}

.trix-content .attachment__caption,
trix-editor .attachment__caption {
  font-size: 0.875rem;
  line-height: 1.25rem;
  text-align: center;
}

.trix-content .attachment__caption .attachment__name + .attachment__size::before,
trix-editor .attachment__caption .attachment__name + .attachment__size::before {
  content: " · ";
}

.trix-content * {
  box-sizing: border-box;
  padding: 0;
  margin: 0;
}

.trix-content .attachment {
  display: inline-block;
  position: relative;
  max-width: 100%;
}

.trix-content .attachment a {
  text-decoration: none;
}

.trix-content .attachment--preview {
  text-align: center;
  width: 100%;
}

.trix-content .attachment--preview .attachment__caption {
  color: var(--vf-gray-500);
  font-size: 0.875rem;
  line-height: 1.25rem;
}

.trix-content .attachment--file {
  padding-top: 0.375rem;
  padding-bottom: 0.375rem;
  padding-left: 1rem;
  padding-right: 1rem;
  margin: 0.125rem;
  margin-top: 0;
  color: var(--vf-gray-700);
  line-height: 1;
  border-radius: 0.25rem;
  border-width: 1px;
  border-color: var(--vf-gray-300);
}

.trix-content .attachment-gallery {
  display: flex;
  position: relative;
  display: flex;
  flex-wrap: wrap;
}

.trix-content .attachment-gallery .attachment {
  padding-top: 0;
  padding-bottom: 0;
  padding-left: 0.5rem;
  padding-right: 0.5rem;
  flex-grow: 1;
  flex-shrink: 0;
  width: 33.333333%;
}

.trix-content .attachment-gallery.attachment-gallery--2 .attachment, .trix-content .attachment-gallery.attachment-gallery--4 .attachment {
  width: 50%;
}

.trix-content .attachment__progress {
  display: none;
}

[class*=form-editor-sm] trix-editor {
  padding-left: var(--vf-px-input-sm);
  padding-right: var(--vf-px-input-sm);
  padding-bottom: var(--vf-py-input-sm);
  border-radius: var(--vf-radius-large-sm);
  min-height: 5rem;
}

[class*=form-editor-sm] .trix-content h1,
[class*=form-editor-sm] trix-editor h1 {
  font-size: 1.625rem;
  font-weight: 700;
  line-height: 1.25;
}

[class*=form-editor-sm] trix-toolbar {
  padding: var(--vf-py-input-sm) var(--vf-py-input-sm);
}

[class*=form-editor-sm] trix-toolbar .trix-button--icon {
  width: 2.25rem;
}

[class*=form-editor-lg] trix-editor {
  padding-left: var(--vf-px-input-lg);
  padding-right: var(--vf-px-input-lg);
  padding-bottom: var(--vf-py-input-lg);
  border-radius: var(--vf-radius-large-lg);
}

[class*=form-editor-disabled] trix-toolbar {
  pointer-events: none;
}

[class*=form-editor-hide-bold] .trix-button--icon-bold {
  display: none;
}

[class*=form-editor-hide-italic] .trix-button--icon-italic {
  display: none;
}

[class*=form-editor-hide-strike] .trix-button--icon-strike {
  display: none;
}

[class*=form-editor-hide-link] .trix-button--icon-link {
  display: none;
}

[class*=form-editor-hide-heading] .trix-button--icon-heading-1 {
  display: none;
}

[class*=form-editor-hide-quote] .trix-button--icon-quote {
  display: none;
}

[class*=form-editor-hide-code] .trix-button--icon-code {
  display: none;
}

[class*=form-editor-hide-bullet-list] .trix-button--icon-bullet-list {
  display: none;
}

[class*=form-editor-hide-number-list] .trix-button--icon-number-list {
  display: none;
}

[class*=form-editor-hide-decrease-nesting] .trix-button--icon-decrease-nesting-level {
  display: none;
}

[class*=form-editor-hide-increase-nesting] .trix-button--icon-increase-nesting-level {
  display: none;
}

[class*=form-editor-hide-attach] .trix-button--icon-attach {
  display: none;
}

[class*=form-editor-hide-undo] .trix-button--icon-undo {
  display: none;
}

[class*=form-editor-hide-redo] .trix-button--icon-redo {
  display: none;
}

.dark .trix-content blockquote,
.dark trix-editor blockquote {
  border-color: var(--vf-dark-700);
}

.dark .trix-content pre,
.dark trix-editor pre {
  background-color: var(--vf-dark-900);
}`;
aR(RHe);
S9.__file = "themes/tailwind/templates/wrappers/EditorWrapper.vue";
function wHe(e, t) {
  var n = arguments.length > 2 && arguments[2] !== void 0 ? arguments[2] : "", r = ["col-span-1", "col-span-2", "col-span-3", "col-span-4", "col-span-5", "col-span-6", "col-span-7", "col-span-8", "col-span-9", "col-span-10", "col-span-11", "col-span-12", "sm:col-span-1", "sm:col-span-2", "sm:col-span-3", "sm:col-span-4", "sm:col-span-5", "sm:col-span-6", "sm:col-span-7", "sm:col-span-8", "sm:col-span-9", "sm:col-span-10", "sm:col-span-11", "sm:col-span-12", "md:col-span-1", "md:col-span-2", "md:col-span-3", "md:col-span-4", "md:col-span-5", "md:col-span-6", "md:col-span-7", "md:col-span-8", "md:col-span-9", "md:col-span-10", "md:col-span-11", "md:col-span-12", "lg:col-span-1", "lg:col-span-2", "lg:col-span-3", "lg:col-span-4", "lg:col-span-5", "lg:col-span-6", "lg:col-span-7", "lg:col-span-8", "lg:col-span-9", "lg:col-span-10", "lg:col-span-11", "lg:col-span-12", "xl:col-span-1", "xl:col-span-2", "xl:col-span-3", "xl:col-span-4", "xl:col-span-5", "xl:col-span-6", "xl:col-span-7", "xl:col-span-8", "xl:col-span-9", "xl:col-span-10", "xl:col-span-11", "xl:col-span-12", "2xl:col-span-1", "2xl:col-span-2", "2xl:col-span-3", "2xl:col-span-4", "2xl:col-span-5", "2xl:col-span-6", "2xl:col-span-7", "2xl:col-span-8", "2xl:col-span-9", "2xl:col-span-10", "2xl:col-span-11", "2xl:col-span-12"];
  switch (e) {
    case "default":
      return "".concat(n, "col-span-").concat(t);
    case "safelist":
      return r;
    default:
      return "".concat(e, ":").concat(n, "col-span-").concat(t);
  }
}
function ZP(e, t) {
  var n = Object.keys(e);
  if (Object.getOwnPropertySymbols) {
    var r = Object.getOwnPropertySymbols(e);
    t && (r = r.filter(function(i) {
      return Object.getOwnPropertyDescriptor(e, i).enumerable;
    })), n.push.apply(n, r);
  }
  return n;
}
function Cn(e) {
  for (var t = 1; t < arguments.length; t++) {
    var n = arguments[t] != null ? arguments[t] : {};
    t % 2 ? ZP(Object(n), !0).forEach(function(r) {
      DHe(e, r, n[r]);
    }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(n)) : ZP(Object(n)).forEach(function(r) {
      Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(n, r));
    });
  }
  return e;
}
function xHe(e, t) {
  if (typeof e != "object" || !e) return e;
  var n = e[Symbol.toPrimitive];
  if (n !== void 0) {
    var r = n.call(e, t || "default");
    if (typeof r != "object") return r;
    throw new TypeError("@@toPrimitive must return a primitive value.");
  }
  return (t === "string" ? String : Number)(e);
}
function NHe(e) {
  var t = xHe(e, "string");
  return typeof t == "symbol" ? t : String(t);
}
function DHe(e, t, n) {
  return t = NHe(t), t in e ? Object.defineProperty(e, t, {
    value: n,
    enumerable: !0,
    configurable: !0,
    writable: !0
  }) : e[t] = n, e;
}
var Wr = {
  default: "form-bg-input form-color-input form-border-color-input hover:form-bg-input-hover hover:form-color-input-hover hover:form-border-color-input-hover hover:form-shadow-input-hover focused:form-bg-input-focus focused:form-color-input-focus focused:form-border-color-input-focus focused:form-shadow-input-focus focused:form-ring focused-hover:form-shadow-input-hover",
  disabled: "form-bg-disabled form-color-disabled form-border-color-input",
  success: "form-bg-input-success form-color-input-success form-border-color-input-success hover:form-shadow-input-hover focused:form-shadow-input-focus focused:form-ring focused-hover:form-shadow-input-hover",
  danger: "form-bg-input-danger form-color-input-danger form-border-color-input-danger hover:form-shadow-input-hover focused:form-shadow-input-focus focused:form-ring focused-hover:form-shadow-input-hover"
}, Td = {
  default: "form-bg-checkbox form-border-color-checkbox hover:form-bg-checkbox-hover hover:form-border-color-checkbox-hover hover:form-shadow-handles-hover focused:form-bg-checkbox-focus focused:form-border-color-checkbox-focus focused:form-shadow-handles-focus focused-hover:form-shadow-handles-hover checked:form-bg-primary checked:form-border-color-checked checked-hover:form-bg-primary checked-hover:form-border-color-checked checked-focused:form-bg-primary",
  disabled: "form-bg-disabled form-border-color-checkbox opacity-50 checked:form-bg-primary checked:form-border-color-checked",
  danger: "form-bg-checkbox-danger form-border-color-checkbox-danger hover:form-shadow-handles-hover focused:form-shadow-handles-focus focused-hover:form-shadow-handles-hover checked:form-bg-primary checked:form-border-color-checked"
}, fo = {
  input: "flex-shrink-0 appearance-none cursor-pointer outline-zero transition-input duration-200 border-solid form-border-width-checkbox focus:form-ring checked:form-bg-icon-check",
  input_default: Td.default,
  input_disabled: Td.disabled,
  input_sm: "form-w-checkbox-sm form-h-checkbox-sm form-radius-checkbox-sm form-mr-space-checkbox-sm rtl:mr-0 rtl:form-ml-space-checkbox-sm",
  input_md: "form-w-checkbox form-h-checkbox form-radius-checkbox form-mr-space-checkbox rtl:mr-0 rtl:form-ml-space-checkbox",
  input_lg: "form-w-checkbox-lg form-h-checkbox-lg form-radius-checkbox-lg form-mr-space-checkbox-lg rtl:mr-0 rtl:form-ml-space-checkbox-lg",
  input_left: "!ml-0",
  input_left_sm: "!form-mr-space-checkbox-sm",
  input_left_md: "!form-mr-space-checkbox",
  input_left_lg: "!form-mr-space-checkbox-lg",
  input_right: "!mr-0",
  input_right_sm: "form-ml-space-checkbox-sm",
  input_right_md: "form-ml-space-checkbox",
  input_right_lg: "form-ml-space-checkbox-lg",
  $input: (e, t) => {
    var {
      isDisabled: n,
      Size: r
    } = t;
    return [e.input, e["input_".concat(r)], n ? e.input_disabled : e.input_default];
  }
}, po = {
  input: "flex items-center justify-center flex-shrink-0 appearance-none cursor-pointer rounded-full outline-zero transition-input duration-200 border-solid form-border-width-radio form-shadow-input focus:form-ring checked:form-bg-icon-radio",
  input_default: Td.default,
  input_disabled: Td.disabled,
  input_sm: "form-w-checkbox-sm form-h-checkbox-sm form-mr-space-checkbox-sm rtl:mr-0 rtl:form-ml-space-checkbox-sm",
  input_md: "form-w-checkbox form-h-checkbox form-mr-space-checkbox rtl:mr-0 rtl:form-ml-space-checkbox",
  input_lg: "form-w-checkbox-lg form-h-checkbox-lg form-mr-space-checkbox-lg rtl:mr-0 rtl:form-ml-space-checkbox-lg",
  input_left: "!ml-0",
  input_left_sm: "!form-mr-space-checkbox-sm",
  input_left_md: "!form-mr-space-checkbox",
  input_left_lg: "!form-mr-space-checkbox-lg",
  input_right: "!mr-0",
  input_right_sm: "form-ml-space-checkbox-sm",
  input_right_md: "form-ml-space-checkbox",
  input_right_lg: "form-ml-space-checkbox-lg",
  $input: (e, t) => {
    var {
      isDisabled: n,
      Size: r
    } = t;
    return [e.input, e["input_".concat(r)], n ? e.input_disabled : e.input_default];
  }
}, Yc = {
  container: "form-text-type",
  inputContainer: "w-full flex flex-1 transition-input duration-200 border-solid form-border-width-input form-shadow-input form-input-group group",
  inputContainer_sm: "form-radius-input-sm form-h-input-height-sm",
  inputContainer_md: "form-radius-input form-h-input-height",
  inputContainer_lg: "form-radius-input-lg form-h-input-height-lg",
  inputContainer_focused: "form-focus",
  inputContainer_default: Wr.default,
  inputContainer_disabled: Wr.disabled,
  inputContainer_success: Wr.success,
  inputContainer_danger: Wr.danger,
  input: "w-full bg-transparent h-full",
  input_sm: "form-p-input-sm form-radius-input-sm form-text-sm with-floating:form-p-input-floating-sm",
  input_md: "form-p-input form-radius-input form-text with-floating:form-p-input-floating",
  input_lg: "form-p-input-lg form-radius-input-lg form-text-lg with-floating:form-p-input-floating-lg",
  input_enabled: "border-0 form-color-input group-hover:form-color-input-hover form-autofill-default",
  input_disabled: "form-color-disabled",
  input_focused: "form-color-input-focus form-autofill-focus",
  input_success: "form-color-input-success form-autofill-success",
  input_danger: "form-color-input-danger form-autofill-danger",
  $inputContainer: (e, t) => {
    var {
      isDisabled: n,
      Size: r,
      isSuccess: i,
      isDanger: a,
      focused: o
    } = t;
    return [e.inputContainer, e["inputContainer_".concat(r)], n ? e.inputContainer_disabled : null, !n && !i && !a ? e.inputContainer_default : null, !n && o ? e.inputContainer_focused : null, !n && i ? e.inputContainer_success : null, !n && a ? e.inputContainer_danger : null];
  },
  $input: (e, t) => {
    var {
      isDisabled: n,
      Size: r,
      isSuccess: i,
      isDanger: a,
      focused: o
    } = t;
    return [e.input, e["input_".concat(r)], n ? e.input_disabled : null, !n && !i && !a && !o ? e.input_enabled : null, !n && o && !i && !a ? e.input_focused : null, !n && a ? e.input_danger : null, !n && i ? e.input_success : null];
  }
}, JP = Cn(Cn({}, Yc), {}, {
  inputContainer_sm: "form-radius-large-sm",
  inputContainer_md: "form-radius-large",
  inputContainer_lg: "form-radius-large-lg",
  input_sm: "form-p-input-sm form-radius-large-sm form-text-sm with-floating:form-p-input-floating-sm",
  input_md: "form-p-input form-radius-large form-text with-floating:form-p-input-floating",
  input_lg: "form-p-input-lg form-radius-large-lg form-text-lg with-floating:form-p-input-floating-lg"
}), eF = {
  container: "form-text-type",
  input: "border-solid transition-input duration-200 form-border-width-input form-shadow-input",
  input_focused: "form-focus",
  input_default: Wr.default,
  input_disabled: Wr.disabled,
  input_success: Wr.success,
  input_danger: Wr.danger,
  input_sm: "form-radius-large-sm form-editor-sm",
  input_md: " form-radius-large",
  input_lg: "form-radius-large-lg form-editor-lg",
  $input: (e, t) => {
    var {
      isDisabled: n,
      focused: r,
      Size: i,
      isSuccess: a,
      isDanger: o
    } = t;
    return [e.input, e["input_".concat(i)], n ? e.input_disabled : null, !n && !a && !o ? e.input_default : null, !n && r ? e.input_focused : null, !n && a ? e.input_success : null, !n && o ? e.input_danger : null];
  }
}, VT = {
  container: "relative mx-auto w-full flex items-center justify-end box-border cursor-pointer outline-zero transition-input duration-200 border-solid form-border-width-input form-shadow-input form-text-type",
  container_default: Wr.default,
  container_disabled: Wr.disabled,
  container_success: Wr.success,
  container_danger: Wr.danger,
  container_sm: "form-text-sm form-radius-input-sm form-min-h-input-height-sm",
  container_md: "form-text form-radius-input form-min-h-input-height",
  container_lg: "form-text-lg form-radius-input-lg form-min-h-input-height-lg",
  containerDisabled: "",
  containerOpen: "!rounded-b-none",
  containerOpenTop: "!rounded-t-none",
  containerActive: "form-focus",
  wrapper: "relative mx-auto w-full flex items-center justify-end box-border cursor-pointer outline-zero",
  wrapper_sm: "form-min-h-input-height-inner-sm",
  wrapper_md: "form-min-h-input-height-inner",
  wrapper_lg: "form-min-h-input-height-inner-lg",
  search: "w-full h-full absolute inset-0 outline-zero appearance-none box-border border-0 bg-transparent form-color-input",
  search_sm: "form-text-sm form-radius-input-sm form-pl-input-sm form-pr-select-no-clear-sm with-floating:form-p-input-floating-sm rtl:form-pl-select-no-clear-sm rtl:form-pr-input-sm",
  search_md: "form-text form-radius-input form-pl-input form-pr-select-no-clear with-floating:form-p-input-floating rtl:form-pl-select-no-clear rtl:form-pr-input",
  search_lg: "form-text-lg form-radius-input-lg form-pl-input-lg form-pr-select-no-clear-lg with-floating:form-p-input-floating-lg rtl:form-pl-select-no-clear-lg rtl:form-pr-input-lg",
  placeholder: "flex items-center h-full absolute left-0 top-0 pointer-events-none bg-transparent form-color-placeholder rtl:left-auto rtl:right-0 rtl:pl-0",
  placeholder_sm: "form-pl-input-sm rtl:form-pr-input-sm",
  placeholder_md: "form-pl-input rtl:form-pr-input",
  placeholder_lg: "form-pl-input-lg rtl:form-pr-input-lg",
  caret: "mask-bg mask-form-caret form-bg-icon w-2.5 h-4 py-px box-content relative flex-shrink-0 flex-grow-0 transition-transform transform pointer-events-none rtl:mr-0",
  caret_sm: "form-mr-input-sm rtl:form-ml-input-sm",
  caret_md: "form-mr-input rtl:form-ml-input",
  caret_lg: "form-mr-input-lg rtl:form-ml-input-lg",
  caretOpen: "rotate-180 pointer-events-auto",
  clear: "relative opacity-50 transition duration-300 flex-shrink-0 flex-grow-0 flex hover:opacity-100 rtl:pr-0 rtl:pl-3.5",
  clear_sm: "form-pr-input-sm rtl:form-pl-input-sm",
  clear_md: "form-pr-input rtl:form-pl-input",
  clear_lg: "form-pr-input-lg rtl:form-pl-input-lg",
  clearIcon: "mask-bg mask-form-remove form-bg-icon w-2.5 h-4 py-px box-content inline-block",
  spinner: "mask-bg mask-form-spinner form-bg-primary w-4 h-4 animate-spin flex-shrink-0 flex-grow-0 rtl:mr-0",
  spinner_sm: "form-mr-input-sm rtl:form-ml-input-sm",
  spinner_md: "form-mr-input rtl:form-ml-input",
  spinner_lg: "form-mr-input-lg rtl:form-ml-input-lg",
  infinite: "flex items-center justify-center w-full",
  infinite_sm: "form-min-h-input-height-sm",
  infinite_md: "form-min-h-input-height",
  infinite_lg: "form-min-h-input-height-lg",
  infiniteSpinner: "mask-bg mask-form-spinner form-bg-primary w-4 h-4 animate-spin flex-shrink-0 flex-grow-0",
  dropdown: "max-h-60 absolute z-999 -left-px -right-px bottom-0 transform form-shadow-dropdown form-border-width-dropdown border-solid form-border-color-input form-bg-input -mt-px overflow-y-scroll flex flex-col",
  dropdown_sm: "form-radius-input-b-sm",
  dropdown_md: "form-radius-input-b",
  dropdown_lg: "form-radius-input-b-lg",
  dropdownBottom: "translate-y-full",
  dropdownTop: "-translate-y-full top-px bottom-auto !rounded-b-none !rounded-t",
  dropdownTop_sm: "form-radius-input-t-sm",
  dropdownTop_md: "form-radius-input-t",
  dropdownTop_lg: "form-radius-input-t-lg",
  dropdownHidden: "hidden",
  options: "flex flex-col p-0 m-0 list-none form-color-input",
  optionsTop: "",
  group: "p-0 m-0",
  groupLabel: "flex box-border items-center justify-start text-left form-py-0.5input font-semibold form-bg-selected form-color-input filter brightness-90 cursor-default",
  groupLabel_sm: "form-px-input-sm form-text-small-sm",
  groupLabel_md: "form-px-input form-text-small",
  groupLabel_lg: "form-px-input-lg form-text-small-lg",
  groupLabelPointable: "cursor-pointer",
  groupLabelPointed: "brightness-95",
  groupLabelSelected: "form-bg-primary-darker !form-color-on-primary brightness-100",
  groupLabelDisabled: "form-bg-disabled form-color-disabled cursor-not-allowed",
  groupLabelSelectedPointed: "form-bg-primary-darker !form-color-on-primary brightness-100 opacity-90",
  groupLabelSelectedDisabled: "form-bg-primary-darker !form-color-on-primary brightness-100 opacity-50 cursor-not-allowed",
  groupOptions: "p-0 m-0",
  option: "flex items-center justify-start box-border text-left cursor-pointer",
  option_sm: "form-px-input-sm form-py-input-border-sm",
  option_md: "form-px-input form-py-input-border",
  option_lg: "form-px-input-lg form-py-input-border-lg",
  optionPointed: "form-color-input form-bg-selected",
  optionSelected: "form-bg-primary form-color-on-primary",
  optionDisabled: "form-color-disabled cursor-not-allowed",
  optionSelectedPointed: "form-color-on-primary form-bg-primary opacity-90",
  optionSelectedDisabled: "form-color-on-primary form-bg-primary opacity-50 cursor-not-allowed",
  fakeInput: "bg-transparent absolute left-0 right-0 -bottom-px w-full h-px border-0 p-0 appearance-none outline-zero text-transparent",
  assist: "form-assistive-text",
  spacer: "box-content",
  spacer_sm: "form-h-input-height-inner-sm",
  spacer_md: "form-h-input-height-inner",
  spacer_lg: "form-h-input-height-inner-lg",
  noOptions: "form-color-muted",
  noOptions_sm: "form-p-input-sm",
  noOptions_md: "form-p-input",
  noOptions_lg: "form-p-input-lg",
  noResults: "form-color-muted",
  noResults_sm: "form-p-input-sm",
  noResults_md: "form-p-input",
  noResults_lg: "form-p-input-lg",
  $container: (e, t) => {
    var {
      Size: n,
      isDanger: r,
      isSuccess: i,
      isDisabled: a
    } = t;
    return [e.select.container, e.select["container_".concat(n)], a ? e.select.container_disabled : null, !a && !i && !r ? e.select.container_default : null, !a && r ? e.select.container_danger : null, !a && i ? e.select.container_success : null];
  },
  $wrapper: (e, t) => {
    var {
      Size: n
    } = t;
    return [e.select.wrapper, e.select["wrapper_".concat(n)]];
  },
  $search: (e, t) => {
    var {
      Size: n
    } = t;
    return [e.select.search, e.select["search_".concat(n)]];
  },
  $placeholder: (e, t) => {
    var {
      Size: n
    } = t;
    return [e.select.placeholder, e.select["placeholder_".concat(n)]];
  },
  $caret: (e, t) => {
    var {
      Size: n
    } = t;
    return [e.select.caret, e.select["caret_".concat(n)]];
  },
  $clear: (e, t) => {
    var {
      Size: n
    } = t;
    return [e.select.clear, e.select["clear_".concat(n)]];
  },
  $spinner: (e, t) => {
    var {
      Size: n
    } = t;
    return [e.select.spinner, e.select["spinner_".concat(n)]];
  },
  $dropdown: (e, t) => {
    var {
      Size: n,
      openDirection: r
    } = t;
    return [e.select.dropdown, e.select["dropdown_".concat(n)], r === "top" ? null : e.select.dropdownBottom];
  },
  $dropdownTop: (e, t) => {
    var {
      Size: n
    } = t;
    return [e.select.dropdownTop, e.select["dropdownTop_".concat(n)]];
  },
  $groupLabel: (e, t) => {
    var {
      Size: n
    } = t;
    return [e.select.groupLabel, e.select["groupLabel_".concat(n)]];
  },
  $option: (e, t) => {
    var {
      Size: n
    } = t;
    return [e.select.option, e.select["option_".concat(n)]];
  },
  $spacer: (e, t) => {
    var {
      Size: n
    } = t;
    return [e.select.spacer, e.select["spacer_".concat(n)]];
  },
  $noOptions: (e, t) => {
    var {
      Size: n
    } = t;
    return [e.select.noOptions, e.select["noOptions_".concat(n)]];
  },
  $noResults: (e, t) => {
    var {
      Size: n
    } = t;
    return [e.select.noResults, e.select["noResults_".concat(n)]];
  }
}, tF = {
  container: "flex align-start cursor-pointer",
  wrapper: "flex items-center justify-center w-full border-solid form-border-width-input",
  wrapper_not_last: "!border-r-0",
  wrapper_first: "",
  wrapper_first_sm: "form-radius-input-l-sm",
  wrapper_first_md: "form-radius-input-l",
  wrapper_first_lg: "form-radius-input-l-lg",
  wrapper_last: "",
  wrapper_last_sm: "form-radius-input-r-sm",
  wrapper_last_md: "form-radius-input-r",
  wrapper_last_lg: "form-radius-input-r-lg",
  wrapper_selected: "form-bg-primary form-color-on-primary border-black border-opacity-15",
  wrapper_unselected: "form-bg-input form-color-input form-border-color-input hover:form-bg-input-hover hover:form-color-input-hover",
  wrapper_disabled: "opacity-50 pointer-events-none",
  wrapper_sm: "form-text-sm form-p-group-tabs-sm",
  wrapper_md: "form-text form-p-group-tabs",
  wrapper_lg: "form-text-lg form-p-group-tabs-lg",
  input: "hidden",
  text: ""
}, nF = {
  container: "flex align-start cursor-pointer form-bg-input",
  container_sm: "form-radius-large-sm",
  container_md: "form-radius-large",
  container_lg: "form-radius-large",
  wrapper: "flex items-center w-full border-solid form-border-width-input form-border-color-input form-color-input",
  wrapper_not_last: "!border-b-0",
  wrapper_first: "",
  wrapper_first_sm: "form-radius-large-t-sm",
  wrapper_first_md: "form-radius-large-t",
  wrapper_first_lg: "form-radius-large-t-lg",
  wrapper_last: "",
  wrapper_last_sm: "form-radius-large-b-sm",
  wrapper_last_md: "form-radius-large-b",
  wrapper_last_lg: "form-radius-large-b-lg",
  wrapper_selected: "form-bg-selected",
  wrapper_unselected: "form-bg-input",
  wrapper_disabled: "opacity-50",
  wrapper_sm: "px-4 py-2.5 form-text-sm form-p-group-blocks-sm",
  wrapper_md: "px-4 py-3 form-text form-p-group-blocks",
  wrapper_lg: "px-4 py-3.5 form-text-lg form-p-group-blocks-lg",
  text_wrapper: "ml-2",
  text: "",
  description: "form-color-muted",
  description_sm: "form-text-small-sm -mt-0.5",
  description_md: "form-text-small -mt-0.5",
  description_lg: "form-text-small-lg -mt-0.5",
  $container: (e, t) => {
    var {
      Size: n
    } = t;
    return [e.container, e["container_".concat(n)]];
  }
}, IHe = {
  // Elements
  ButtonElement: {
    container: "form-text-type",
    button: "inline-block transition form-border-width-btn form-shadow-btn focus:outline-zero",
    button_enabled: "cursor-pointer transition-transform ease-linear focus:form-ring transform hover:scale-105",
    button_disabled: "opacity-60 cursor-not-allowed",
    button_loading: "form-color-transparent opacity-60 cursor-not-allowed",
    button_loading_primary: "form-bg-spinner-on-primary",
    button_loading_secondary: "form-bg-spinner-btn-secondary",
    button_loading_danger: "form-bg-spinner-white",
    button_primary: "form-bg-btn form-color-btn form-border-color-btn",
    button_secondary: "form-bg-btn-secondary form-color-btn-secondary form-border-color-btn-secondary",
    button_danger: "form-bg-btn-danger form-color-btn-danger form-border-color-btn-danger",
    button_full: "w-full",
    button_not_full: "",
    button_left: "float-left",
    button_center: "flex mx-auto items-center justify-center",
    button_right: "float-right",
    button_sm: "form-p-btn-sm form-radius-btn-sm form-text-sm",
    button_md: "form-p-btn form-radius-btn form-text",
    button_lg: "form-p-btn-lg form-radius-btn-lg form-text-lg",
    $button: (e, t) => {
      var {
        isDisabled: n,
        isLoading: r,
        buttonClass: i,
        Size: a,
        danger: o,
        secondary: s,
        full: l,
        align: u
      } = t;
      return [e.button, o ? e.button_danger : null, s ? e.button_secondary : null, !o && !s ? e.button_primary : null, e["button_".concat(a)], n ? e.button_disabled : null, !n && !r ? e.button_enabled : null, r ? e.button_loading : null, r && o ? e.button_loading_danger : null, r && s ? e.button_loading_secondary : null, r && !s && !o ? e.button_loading_primary : null, l ? e.button_full : e.button_not_full, u === "left" ? e.button_left : null, u === "center" ? e.button_center : null, u === "right" ? e.button_right : null, i];
    }
  },
  CheckboxElement: Cn(Cn({}, fo), {}, {
    container: "",
    wrapper: "flex align-start",
    wrapper_sm: "form-text-sm",
    wrapper_md: "form-text",
    wrapper_lg: "form-text-lg",
    wrapper_left: "rtl:justify-end",
    wrapper_right: "justify-end rtl:justify-start",
    input: fo.input + " form-shadow-handles",
    input_danger: Td.danger,
    input_sm: fo.input_sm + " form-mt-checkbox-sm",
    input_md: fo.input_md + " form-mt-checkbox",
    input_lg: fo.input_lg + " form-mt-checkbox-lg",
    text: "cursor-pointer",
    text_left: "rtl:-order-1",
    text_right: "-order-1 rtl:order-none",
    $wrapper: (e, t) => {
      var {
        Size: n,
        align: r
      } = t;
      return [e.wrapper, e["wrapper_".concat(n)], r === "left" ? e.wrapper_left : null, r === "right" ? e.wrapper_right : null];
    },
    $input: (e, t) => {
      var {
        isDisabled: n,
        Size: r,
        isDanger: i,
        align: a
      } = t;
      return [e.input, e["input_".concat(r)], !n && !i ? e.input_default : null, n ? e.input_disabled : null, i ? e.input_danger : null, a === "left" ? [e.input_left, e["input_left_".concat(r)]] : null, a === "right" ? [e.input_right, e["input_right_".concat(r)]] : null];
    },
    $text: (e, t) => {
      var {
        align: n
      } = t;
      return [e.text, n === "left" ? e.text_left : null, n === "right" ? e.text_right : null];
    }
  }),
  CheckboxgroupElement: {
    container: "",
    wrapper: "flex flex-col justify-start",
    wrapper_sm: "",
    wrapper_md: "",
    wrapper_lg: "",
    $wrapper: (e, t) => {
      var {
        Size: n
      } = t;
      return [e.wrapper, e["wrapper_".concat(n)]];
    }
  },
  CheckboxgroupElement_tabs: {
    container: "form-text-type",
    wrapper: "grid grid-flow-col form-shadow-input",
    wrapper_sm: "form-radius-large-sm",
    wrapper_md: "form-radius-large",
    wrapper_lg: "form-radius-large-lg",
    $wrapper: (e, t) => {
      var {
        Size: n
      } = t;
      return [e.wrapper, e["wrapper_".concat(n)]];
    }
  },
  CheckboxgroupElement_blocks: {
    container: "",
    wrapper: "flex flex-col justify-start form-shadow-input",
    wrapper_sm: "form-radius-large-sm",
    wrapper_md: "form-radius-large",
    wrapper_lg: "form-radius-large-lg",
    $wrapper: (e, t) => {
      var {
        Size: n
      } = t;
      return [e.wrapper, e["wrapper_".concat(n)]];
    }
  },
  DateElement: Cn({
    inputWrapper: "block w-full h-full"
  }, Yc),
  DatesElement: Cn({
    inputWrapper: "block w-full h-full"
  }, Yc),
  EditorElement: Cn({}, eF),
  FileElement: {
    container: "form-text-type",
    container_removing: "opacity-50",
    button: "form-border-width-btn form-shadow-btn inline-block transition focus:outline-zero",
    button_enabled: "form-bg-btn-secondary form-color-btn-secondary form-border-color-btn-secondary cursor-pointer transition-transform transform hover:scale-105 focus:form-ring",
    button_disabled: "opacity-50 cursor-not-allowed",
    button_sm: "form-p-btn-sm form-radius-btn-sm form-text-sm",
    button_md: "form-p-btn form-radius-btn form-text",
    button_lg: "form-p-btn-lg form-radius-btn-lg form-text-lg",
    $container: (e, t) => {
      var {
        removing: n
      } = t;
      return [e.container, n ? e.container_removing : null];
    },
    $button: (e, t) => {
      var {
        isDisabled: n,
        preparing: r,
        Size: i
      } = t;
      return [e.button, e["button_".concat(i)], !n && !r ? e.button_enabled : null, n || r ? e.button_disabled : null];
    }
  },
  GroupElement: {
    container: "",
    wrapper: "grid grid-cols-12",
    wrapper_sm: "form-gap-gutter-sm",
    wrapper_md: "form-gap-gutter",
    wrapper_lg: "form-gap-gutter-lg",
    $wrapper: (e, t) => {
      var {
        Size: n
      } = t;
      return [e.wrapper, e["wrapper_".concat(n)]];
    }
  },
  ListElement: {
    container: "",
    list: "grid",
    list_sm: "form-gap-y-gutter-sm",
    list_md: "form-gap-y-gutter",
    list_lg: "form-gap-y-gutter-lg",
    list_disabled: "",
    list_sorting: "",
    listItem: "grid grid-cols-12 relative form-list-group ghost:opacity-60",
    listItem_sm: "form-gap-gutter-sm",
    listItem_md: "form-gap-gutter",
    listItem_lg: "form-gap-gutter-lg",
    handle: "absolute left-0 top-0 z-999 transform -translate-x-full cursor-grab active:cursor-grabbing opacity-0 transition list-group-hover:opacity-100",
    handle_sm: "form-w-input-height-sm form-h-input-height-sm",
    handle_md: "form-w-input-height form-h-input-height",
    handle_lg: "form-w-input-height-lg form-h-input-height-lg",
    handleIcon: "mask-bg mask-form-sort-handle form-bg-icon mask-size-2.8 block w-full h-full",
    remove: "absolute z-999 w-4 h-4 box-content p-0.5 top-px left-0 form-bg-passive rounded-full transform -translate-x-1/2 -translate-y-1/2 transition opacity-0 filter hover:brightness-90 list-group-hover:opacity-100 focus:opacity-100",
    removeIcon: "mask-bg mask-form-remove-light form-bg-passive-color mask-size-3 block w-full h-full",
    add: "inline-block form-bg-primary form-border-width-btn form-border-color-primary form-color-on-primary form-shadow-btn ease-linear transition-transform transform hover:scale-105 focus:form-ring",
    add_sm: "form-mt-gutter-sm form-radius-small-sm form-text-small-sm form-p-btn-small-sm",
    add_md: "form-mt-gutter form-radius-small form-text-small form-p-btn-small",
    add_lg: "form-mt-gutter-lg form-radius-small-lg form-text-small-lg form-p-btn-small-lg",
    $list: (e, t) => {
      var {
        isDisabled: n,
        sorting: r,
        Size: i
      } = t;
      return [e.list, e["list_".concat(i)], n ? e.list_disabled : null, r ? e.list_sorting : null];
    },
    $listItem: (e, t) => {
      var {
        Size: n
      } = t;
      return [e.listItem, e["listItem_".concat(n)]];
    },
    $handle: (e, t) => {
      var {
        Size: n
      } = t;
      return [e.handle, e["handle_".concat(n)]];
    },
    $add: (e, t) => {
      var {
        Size: n
      } = t;
      return [e.add, e["add_".concat(n)]];
    }
  },
  LocationElement: Cn({}, Yc),
  MultifileElement: {
    container: "form-text-type",
    list: "",
    list_sm: "form-mt-gutter-sm",
    list_md: "form-mt-gutter",
    list_lg: "form-mt-gutter-lg",
    list_file: "grid",
    list_file_sm: "form-gap-y-0.5gutter-sm",
    list_file_md: "form-gap-y-0.5gutter",
    list_file_lg: "form-gap-y-0.5gutter-lg",
    list_image: "grid",
    list_image_sm: "form-gap-y-0.5gutter-sm",
    list_image_md: "form-gap-y-0.5gutter",
    list_image_lg: "form-gap-y-0.5gutter-lg",
    list_gallery: "flex flex-wrap",
    list_gallery_sm: "form-gap-0.5gutter-sm",
    list_gallery_md: "form-gap-0.5gutter",
    list_gallery_lg: "form-gap-0.5gutter-lg",
    list_disabled: "",
    list_sorting: "",
    listItem: "relative group ghost:opacity-60",
    handle: "",
    handle_file: "absolute left-0 top-0 transform -translate-x-full cursor-grab active:cursor-grabbing opacity-0 transition group-hover:opacity-100",
    handle_file_sm: "form-w-input-height-sm form-h-input-height-sm",
    handle_file_md: "form-w-input-height form-h-input-height",
    handle_file_lg: "form-w-input-height-lg form-h-input-height-lg",
    handle_image: "absolute left-0 top-0 transform -translate-x-full cursor-grab active:cursor-grabbing opacity-0 transition group-hover:opacity-100",
    handle_image_sm: "form-w-input-height-sm form-h-input-height-sm",
    handle_image_md: "form-w-input-height form-h-input-height",
    handle_image_lg: "form-w-input-height-lg form-h-input-height-lg",
    handle_gallery: "absolute w-4 h-4 box-content top-0.5 left-0.5 mt-px ml-px form-bg-passive bg-center bg-no-repeat rounded-full transition opacity-0 group-hover:opacity-100 cursor-grab active:cursor-grabbing filter hover:brightness-90",
    handle_gallery_sm: "",
    handle_gallery_md: "",
    handle_gallery_lg: "",
    handleIcon: "",
    handleIcon_file: "mask-bg mask-form-sort-handle form-bg-icon mask-size-2.8 block w-full h-full",
    handleIcon_image: "mask-bg mask-form-sort-handle form-bg-icon mask-size-2.8 block w-full h-full",
    handleIcon_gallery: "mask-bg mask-form-arrows form-bg-input-color mask-size-3 block w-full h-full",
    dnd: "",
    button: "inline-block transition form-border-width-btn focus:outline-zero",
    button_enabled: "form-bg-btn-secondary form-color-btn-secondary form-border-color-btn-secondary form-shadow-btn cursor-pointer transition-transform transform hover:scale-105 focus:form-ring",
    button_disabled: "opacity-50 cursor-not-allowed",
    button_sm: "form-p-btn-sm form-radius-btn-sm form-text-sm",
    button_md: "form-p-btn form-radius-btn form-text",
    button_lg: "form-p-btn-lg form-radius-btn-lg form-text-lg",
    $list: (e, t) => {
      var {
        isDisabled: n,
        sorting: r,
        view: i,
        Size: a
      } = t;
      return [e.list, e["list_".concat(a)], n ? e.list_disabled : null, r ? e.list_sorting : null, e["list_".concat(i)], e["list_".concat(i, "_").concat(a)]];
    },
    $handle: (e, t) => {
      var {
        view: n,
        Size: r
      } = t;
      return [e.handle, e["handle_".concat(n)], e["handle_".concat(n, "_").concat(r)]];
    },
    $handleIcon: (e, t) => {
      var {
        view: n
      } = t;
      return [e.handleIcon, e["handleIcon_".concat(n)]];
    },
    $button: (e, t) => {
      var {
        isDisabled: n,
        preparing: r,
        Size: i
      } = t;
      return [e.button, e["button_".concat(i)], !n && !r ? e.button_enabled : null, n || r ? e.button_disabled : null];
    }
  },
  MultiselectElement: {
    container: "form-text-type",
    input: "w-full form-p-input transition-input duration-200 border-solid form-border-width-input form-shadow-input",
    input_default: Wr.default,
    input_disabled: Wr.disabled,
    input_success: Wr.success,
    input_danger: Wr.danger,
    input_sm: "form-p-input-sm form-radius-large-sm form-text-sm with-floating:form-p-input-floating-sm",
    input_md: "form-p-input form-radius-large form-text with-floating:form-p-input-floating",
    input_lg: "form-p-input-lg form-radius-large-lg form-text-lg with-floating:form-p-input-floating-lg",
    inputWrapper: "",
    select: Cn(Cn({}, VT), {}, {
      multipleLabel: "flex items-center h-full absolute left-0 top-0 pointer-events-none bg-transparent rtl:left-auto rtl:right-0 rtl:pl-0",
      multipleLabel_sm: "form-py-input-sm form-pl-input-sm form-pr-select-no-clear-sm form-radius-input-sm form-text-sm form-min-h-input-height-inner-sm with-floating:form-p-input-floating-sm rtl:form-pr-input-sm rtl:form-pl-select-no-clear-sm",
      multipleLabel_md: "form-py-input form-pl-input form-pr-select-no-clear form-radius-input form-text form-min-h-input-height-inner with-floating:form-p-input-floating rtl:form-pr-input rtl:form-pl-select-no-clear",
      multipleLabel_lg: "form-py-input-lg form-pl-input-lg form-pr-select-no-clear-lg form-radius-input-lg form-text-lg form-min-h-input-height-inner-lg with-floating:form-p-input-floating-lg rtl:form-pr-input-lg rtl:form-pl-select-no-clear-lg",
      multipleLabel_caretClear_sm: "form-pl-input-sm form-pr-select-sm with-floating:form-p-input-floating-sm rtl:form-pr-input-sm rtl:form-pl-select-sm",
      multipleLabel_caretClear_md: "form-pl-input form-pr-select with-floating:form-p-input-floating rtl:form-pr-input rtl:form-pl-select",
      multipleLabel_caretClear_lg: "form-pl-input-sm form-pr-select-sm with-floating:form-p-input-floating-sm rtl:form-pr-input-sm rtl:form-pl-select-sm",
      multipleLabel_noCaret_sm: "form-pl-input-sm form-pr-select-no-caret-sm with-floating:form-p-input-floating-sm rtl:form-pr-input-sm rtl:form-pl-select-no-caret-sm",
      multipleLabel_noCaret_md: "form-pl-input form-pr-select-no-caret with-floating:form-p-input-floating rtl:form-pr-input rtl:form-pl-select-no-caret",
      multipleLabel_noCaret_lg: "form-pl-input-lg form-pr-select-no-caret-lg with-floating:form-p-input-floating-lg rtl:form-pr-input-lg rtl:form-pl-select-no-caret-lg",
      multipleLabel_noClear_sm: "form-pl-input-sm form-pr-select-no-clear-sm with-floating:form-p-input-floating-sm rtl:form-pr-input-sm rtl:form-pl-select-no-clear-sm",
      multipleLabel_noClear_md: "form-pl-input form-pr-select-no-clear with-floating:form-p-input-floating rtl:form-pr-input rtl:form-pl-select-no-clear",
      multipleLabel_noClear_lg: "form-pl-input-lg form-pr-select-no-clear-lg with-floating:form-p-input-floating-lg rtl:form-pr-input-lg rtl:form-pl-select-no-clear-lg",
      multipleLabel_noCaretClear_sm: "form-pl-input-sm form-pr-input-sm with-floating:form-p-input-floating-sm rtl:form-pr-input-sm rtl:form-pl-input-sm",
      multipleLabel_noCaretClear_md: "form-pl-input form-pr-input with-floating:form-p-input-floating rtl:form-pr-input rtl:form-pl-input",
      multipleLabel_noCaretClear_lg: "form-pl-input-lg form-pr-input-lg with-floating:form-p-input-floating-lg rtl:form-pr-input-lg rtl:form-pl-input-lg",
      $multipleLabel: (e, t) => {
        var {
          Size: n,
          caret: r,
          canClear: i
        } = t;
        return [e.select.multipleLabel, e.select["multipleLabel_".concat(n)], i && r ? e.select["multipleLabel_caretClear_".concat(n)] : null, !r && i ? e.select["multipleLabel_noCaret_".concat(n)] : null, !i && r ? e.select["multipleLabel_noClear_".concat(n)] : null, !i && !r ? e.select["multipleLabel_noCaretClear_".concat(n)] : null];
      }
    }),
    $input: (e, t) => {
      var {
        isDisabled: n,
        Size: r,
        isDanger: i,
        isSuccess: a
      } = t;
      return [e.input, e["input_".concat(r)], n ? e.input_disabled : null, !n && !a && !i ? e.input_default : null, !n && i ? e.input_danger : null, !n && a ? e.input_success : null];
    }
  },
  ObjectElement: {
    container: "",
    wrapper: "grid grid-cols-12",
    wrapper_sm: "form-gap-gutter-sm",
    wrapper_md: "form-gap-gutter",
    wrapper_lg: "form-gap-gutter-lg",
    wrapper_embed: "!block",
    $wrapper: (e, t) => {
      var {
        Size: n,
        embed: r
      } = t;
      return [e.wrapper, e["wrapper_".concat(n)], r ? e.wrapper_embed : null];
    }
  },
  RadioElement: Cn(Cn({}, po), {}, {
    container: "",
    wrapper: "flex align-start rtl:justify-start",
    wrapper_sm: "form-text-sm",
    wrapper_md: "form-text",
    wrapper_lg: "form-text-lg",
    wrapper_left: "rtl:justify-end",
    wrapper_right: "justify-end rtl:justify-start",
    input: po.input + " form-shadow-handles",
    input_danger: Td.danger,
    input_sm: po.input_sm + " form-mt-checkbox-sm",
    input_md: po.input_md + " form-mt-checkbox",
    input_lg: po.input_lg + " form-mt-checkbox-lg",
    text: "cursor-pointer",
    text_left: "rtl:-order-1",
    text_right: "-order-1 rtl:order-none",
    $wrapper: (e, t) => {
      var {
        Size: n,
        align: r
      } = t;
      return [e.wrapper, e["wrapper_".concat(n)], r === "left" ? e.wrapper_left : null, r === "right" ? e.wrapper_right : null];
    },
    $input: (e, t) => {
      var {
        isDisabled: n,
        Size: r,
        isDanger: i,
        align: a
      } = t;
      return [e.input, e["input_".concat(r)], !n && !i ? e.input_default : null, n ? e.input_disabled : null, i ? e.input_danger : null, a === "left" ? [e.input_left, e["input_left_".concat(r)]] : null, a === "right" ? [e.input_right, e["input_right_".concat(r)]] : null];
    },
    $text: (e, t) => {
      var {
        align: n
      } = t;
      return [e.text, n === "left" ? e.text_left : null, n === "right" ? e.text_right : null];
    }
  }),
  RadiogroupElement: {
    container: "",
    wrapper: "flex flex-col justify-start",
    wrapper_sm: "",
    wrapper_md: "",
    wrapper_lg: "",
    $wrapper: (e, t) => {
      var {
        Size: n
      } = t;
      return [e.wrapper, e["wrapper_".concat(n)]];
    }
  },
  RadiogroupElement_tabs: {
    container: " form-text-type",
    wrapper: "grid grid-flow-col grid form-shadow-input",
    wrapper_sm: "form-radius-large-sm",
    wrapper_md: "form-radius-large",
    wrapper_lg: "form-radius-large-lg",
    $wrapper: (e, t) => {
      var {
        Size: n
      } = t;
      return [e.wrapper, e["wrapper_".concat(n)]];
    }
  },
  RadiogroupElement_blocks: {
    container: "",
    wrapper: "flex flex-col justify-start form-shadow-input",
    wrapper_sm: "form-radius-large-sm",
    wrapper_md: "form-radius-large",
    wrapper_lg: "form-radius-large-lg",
    $wrapper: (e, t) => {
      var {
        Size: n
      } = t;
      return [e.wrapper, e["wrapper_".concat(n)]];
    }
  },
  SelectElement: {
    container: "form-text-type",
    input: "w-full transition-input duration-200 border-solid form-border-width-input form-shadow-input",
    input_default: Wr.default,
    input_disabled: Wr.disabled,
    input_success: Wr.success,
    input_danger: Wr.danger,
    input_sm: "form-py-input-sm form-pl-input-sm form-pr-select-no-clear-sm form-radius-input-sm form-text-sm form-min-h-input-height-inner-sm with-floating:form-p-input-floating-sm rtl:form-pr-input-sm rtl:form-pl-select-no-clear-sm",
    input_md: "form-py-input form-pl-input form-pr-select-no-clear form-radius-input form-text form-min-h-input-height-inner with-floating:form-p-input-floating rtl:form-pr-input rtl:form-pl-select-no-clear",
    input_lg: "form-py-input-lg form-pl-input-lg form-pr-select-no-clear-lg form-radius-input-lg form-text-lg form-min-h-input-height-inner-lg with-floating:form-p-input-floating-lg rtl:form-pr-input-lg rtl:form-pl-select-no-clear-lg",
    inputWrapper: "relative",
    inputPlaceholder: "absolute left-0 top-0 bottom-0 form-color-placeholder pointer-events-none flex items-center",
    inputPlaceholder_sm: "form-p-input-border-sm",
    inputPlaceholder_md: "form-p-input-border",
    inputPlaceholder_lg: "form-p-input-border-lg",
    inputCaret: "mask-bg mask-form-caret form-bg-icon w-2.5 h-4 py-px box-content absolute right-0 top-1/2 transform -translate-y-1/2 transition-transform transform pointer-events-none rtl:right-auto rtl:left-0",
    inputCaret_sm: "form-mr-input-sm rtl:mr-0 rtl:form-ml-input-sm",
    inputCaret_md: "form-mr-input rtl:mr-0 rtl:form-ml-input",
    inputCaret_lg: "form-mr-input-lg rtl:mr-0 rtl:form-ml-input-lg",
    select: Cn(Cn({}, VT), {}, {
      singleLabel: "flex items-center h-full max-w-full absolute left-0 top-0 pointer-events-none bg-transparent box-border rtl:left-auto rtl:right-0 rtl:pl-0",
      singleLabel_sm: "form-py-input-sm form-pl-input-sm form-pr-select-no-clear-sm form-radius-input-sm form-text-sm form-min-h-input-height-inner-sm with-floating:form-p-input-floating-sm rtl:form-pr-input-sm rtl:form-pl-select-no-clear-sm",
      singleLabel_md: "form-py-input form-pl-input form-pr-select-no-clear form-radius-input form-text form-min-h-input-height-inner with-floating:form-p-input-floating rtl:form-pr-input rtl:form-pl-select-no-clear",
      singleLabel_lg: "form-py-input-lg form-pl-input-lg form-pr-select-no-clear-lg form-radius-input-lg form-text-lg form-min-h-input-height-inner-lg with-floating:form-p-input-floating-lg rtl:form-pr-input-lg rtl:form-pl-select-no-clear-lg",
      singleLabel_caretClear_sm: "form-pl-input-sm form-pr-select-sm with-floating:form-p-input-floating-sm rtl:form-pr-input-sm rtl:form-pl-select-sm",
      singleLabel_caretClear_md: "form-pl-input form-pr-select with-floating:form-p-input-floating rtl:form-pr-input rtl:form-pl-select",
      singleLabel_caretClear_lg: "form-pl-input-sm form-pr-select-sm with-floating:form-p-input-floating-sm rtl:form-pr-input-sm rtl:form-pl-select-sm",
      singleLabel_noCaret_sm: "form-pl-input-sm form-pr-select-no-caret-sm with-floating:form-p-input-floating-sm rtl:form-pr-input-sm rtl:form-pl-select-no-caret-sm",
      singleLabel_noCaret_md: "form-pl-input form-pr-select-no-caret with-floating:form-p-input-floating rtl:form-pr-input rtl:form-pl-select-no-caret",
      singleLabel_noCaret_lg: "form-pl-input-lg form-pr-select-no-caret-lg with-floating:form-p-input-floating-lg rtl:form-pr-input-lg rtl:form-pl-select-no-caret-lg",
      singleLabel_noClear_sm: "form-pl-input-sm form-pr-select-no-clear-sm with-floating:form-p-input-floating-sm rtl:form-pr-input-sm rtl:form-pl-select-no-clear-sm",
      singleLabel_noClear_md: "form-pl-input form-pr-select-no-clear with-floating:form-p-input-floating rtl:form-pr-input rtl:form-pl-select-no-clear",
      singleLabel_noClear_lg: "form-pl-input-lg form-pr-select-no-clear-lg with-floating:form-p-input-floating-lg rtl:form-pr-input-lg rtl:form-pl-select-no-clear-lg",
      singleLabel_noCaretClear_sm: "form-pl-input-sm form-pr-input-sm with-floating:form-p-input-floating-sm rtl:form-pr-input-sm rtl:form-pl-input-sm",
      singleLabel_noCaretClear_md: "form-pl-input form-pr-input with-floating:form-p-input-floating rtl:form-pr-input rtl:form-pl-input",
      singleLabel_noCaretClear_lg: "form-pl-input-lg form-pr-input-lg with-floating:form-p-input-floating-lg rtl:form-pr-input-lg rtl:form-pl-input-lg",
      singleLabelText: "overflow-hidden block whitespace-nowrap max-w-full",
      singleLabelText_truncate: "overflow-ellipsis",
      $singleLabel: (e, t) => {
        var {
          Size: n,
          caret: r,
          canClear: i
        } = t;
        return [e.select.singleLabel, e.select["singleLabel_".concat(n)], i && r ? e.select["singleLabel_caretClear_".concat(n)] : null, !r && i ? e.select["singleLabel_noCaret_".concat(n)] : null, !i && r ? e.select["singleLabel_noClear_".concat(n)] : null, !i && !r ? e.select["singleLabel_noCaretClear_".concat(n)] : null];
      },
      $singleLabelText: (e, t) => {
        var {
          truncate: n
        } = t;
        return [e.select.singleLabelText, n ? e.select.singleLabelText_truncate : null];
      }
    }),
    $input: (e, t) => {
      var {
        isDisabled: n,
        Size: r,
        isSuccess: i,
        isDanger: a
      } = t;
      return [e.input, e["input_".concat(r)], n ? e.input_disabled : null, !n && !i && !a ? e.input_default : null, !n && a ? e.input_danger : null, !n && i ? e.input_success : null];
    },
    $inputWrapper: (e, t) => {
      var {
        Size: n
      } = t;
      return [e.inputWrapper, e["inputWrapper_".concat(n)]];
    },
    $inputPlaceholder: (e, t) => {
      var {
        Size: n
      } = t;
      return [e.inputPlaceholder, e["inputPlaceholder_".concat(n)]];
    },
    $inputCaret: (e, t) => {
      var {
        Size: n
      } = t;
      return [e.inputCaret, e["inputCaret_".concat(n)]];
    }
  },
  SliderElement: {
    container: "",
    wrapper: "",
    wrapper_sm: "",
    wrapper_md: "",
    wrapper_lg: "",
    slider: {
      target: "relative box-border user-select-none touch-none tap-highlight-transparent touch-callout-none disabled:cursor-not-allowed disabled:opacity-50",
      target_sm: "form-my-slider-sm",
      target_md: "form-my-slider",
      target_lg: "form-my-slider-lg",
      focused: "slider-focused",
      tooltipFocus: "slider-tooltip-focus",
      tooltipDrag: "slider-tooltip-drag",
      ltr: "slider-ltr",
      rtl: "slider-rtl",
      horizontal: "slider-horizontal",
      horizontal_sm: "form-h-slider-horizontal-sm",
      horizontal_md: "form-h-slider-horizontal",
      horizontal_lg: "form-h-slider-horizontal-lg",
      vertical: "slider-vertical",
      vertical_sm: "form-h-slider-vertical-sm form-w-slider-vertical-sm",
      vertical_md: "form-h-slider-vertical form-w-slider-vertical",
      vertical_lg: "form-h-slider-vertical-lg form-w-slider-vertical-lg",
      textDirectionRtl: "slider-txt-rtl",
      textDirectionLtr: "slider-txt-ltr",
      base: "form-shadow-input w-full h-full relative z-1 form-bg-passive",
      base_sm: "form-radius-slider-sm",
      base_md: "form-radius-slider",
      base_lg: "form-radius-slider-lg",
      connects: "w-full h-full relative overflow-hidden z-0 form-radius-slider",
      connects_sm: "form-radius-slider-sm",
      connects_md: "form-radius-slider",
      connects_lg: "form-radius-slider-lg",
      connect: "absolute z-1 top-0 right-0 transform-origin-0 transform-style-flat h-full w-full form-bg-primary cursor-pointer tap:duration-300 tap:transition-transform disabled:cursor-not-allowed",
      connect_sm: "form-radius-slider-sm",
      connect_md: "form-radius-slider",
      connect_lg: "form-radius-slider-lg",
      origin: "slider-origin absolute z-1 top-0 right-0 transform-origin-0 transform-style-flat h-full w-full h:h-0 v:-top-full txt-rtl-h:left-0 txt-rtl-h:right-auto v:w-0 tap:duration-300 tap:transition-transform",
      handle: "absolute rounded-full transition-shadow border-0 cursor-grab txt-rtl-h:-left-2 txt-rtl-h:right-auto disabled:cursor-not-allowed disabled:pointer-events-none form-bg-slider-handle form-shadow-handles hover:form-shadow-handles-hover focus:form-shadow-handles-focus focused-hover:form-shadow-handles-hover focus:outline-zero focus:form-ring",
      handle_sm: "form-size-slider-handle-sm h:form-top-slider-handle-horizontal-sm h:form-right-slider-handle-horizontal-sm v:form-bottom-slider-handle-vertical-sm v:form-right-slider-handle-vertical-sm",
      handle_md: "form-size-slider-handle h:form-top-slider-handle-horizontal h:form-right-slider-handle-horizontal v:form-bottom-slider-handle-vertical v:form-right-slider-handle-vertical",
      handle_lg: "form-size-slider-handle-lg h:form-top-slider-handle-horizontal-lg h:form-right-slider-handle-horizontal-lg v:form-bottom-slider-handle-vertical-lg v:form-right-slider-handle-vertical-lg",
      handleUpper: "slider-handle-upper",
      handleLower: "slider-handle-lower",
      touchArea: "h-full w-full",
      tooltip: "absolute block font-semibold whitespace-nowrap min-w-5 text-center border form-border-color-slider-tooltip form-bg-primary form-color-on-primary transform tt-focus:hidden tt-focused:block tt-drag:hidden tt-dragging:block h:-translate-x-1/2 h:left-1/2 v:-translate-y-1/2 v:top-1/2 merge-h:translate-x-1/2 merge-v:translate-y-1/2 merge-h:left-auto merge-v:top-auto",
      tooltip_sm: "form-text-small-sm form-py-slider-tooltip-sm form-px-slider-tooltip-sm form-radius-small-sm",
      tooltip_md: "form-text-small form-py-slider-tooltip form-px-slider-tooltip form-radius-small",
      tooltip_lg: "form-text-small-lg form-py-slider-tooltip-lg form-px-slider-tooltip-lg form-radius-small-lg",
      tooltipTop: "form-slider-tooltip-top",
      tooltipTop_sm: "form-bottom-slider-tooltip-top-sm merge-h:form-bottom-slider-tooltip-top-merged-sm h:arrow-bottom-sm",
      tooltipTop_md: "form-bottom-slider-tooltip-top merge-h:form-bottom-slider-tooltip-top-merged h:arrow-bottom",
      tooltipTop_lg: "form-bottom-slider-tooltip-top-lg merge-h:form-bottom-slider-tooltip-top-merged-lg h:arrow-bottom-lg",
      tooltipBottom: "form-slider-tooltip-bottom",
      tooltipBottom_sm: "form-top-slider-tooltip-bottom-sm merge-h:form-top-slider-tooltip-bottom-merged-sm h:arrow-top-sm",
      tooltipBottom_md: "form-top-slider-tooltip-bottom merge-h:form-top-slider-tooltip-bottom-merged h:arrow-top",
      tooltipBottom_lg: "form-top-slider-tooltip-bottom-lg merge-h:form-top-slider-tooltip-bottom-merged-lg h:arrow-top-lg",
      tooltipLeft: "form-slider-tooltip-left",
      tooltipLeft_sm: "form-right-slider-tooltip-left-sm merge-v:form-right-slider-tooltip-left-merged-sm v:arrow-right-sm",
      tooltipLeft_md: "form-right-slider-tooltip-left merge-v:form-right-slider-tooltip-left-merged v:arrow-right",
      tooltipLeft_lg: "form-right-slider-tooltip-left-lg merge-v:form-right-slider-tooltip-left-merged-lg v:arrow-right-lg",
      tooltipRight: "form-slider-tooltip-right",
      tooltipRight_sm: "form-left-slider-tooltip-right-sm merge-v:form-left-slider-tooltip-right-merged-sm v:arrow-left-sm",
      tooltipRight_md: "form-left-slider-tooltip-right merge-v:form-left-slider-tooltip-right-merged v:arrow-left",
      tooltipRight_lg: "form-left-slider-tooltip-right-lg merge-v:form-left-slider-tooltip-right-merged-lg v:arrow-left-lg",
      tooltipHidden: "slider-tooltip-hidden",
      active: "slider-active cursor-grabbing",
      draggable: "cursor-ew-resize v:cursor-ns-resize",
      tap: "slider-state-tap",
      drag: "slider-state-drag",
      $target: (e, t) => {
        var {
          Size: n
        } = t;
        return [e.slider.target, e.slider["target_".concat(n)]];
      },
      $horizontal: (e, t) => {
        var {
          Size: n
        } = t;
        return [e.slider.horizontal, e.slider["horizontal_".concat(n)]];
      },
      $vertical: (e, t) => {
        var {
          Size: n
        } = t;
        return [e.slider.vertical, e.slider["vertical_".concat(n)]];
      },
      $base: (e, t) => {
        var {
          Size: n
        } = t;
        return [e.slider.base, e.slider["base_".concat(n)]];
      },
      $connects: (e, t) => {
        var {
          Size: n
        } = t;
        return [e.slider.connects, e.slider["connects_".concat(n)]];
      },
      $connect: (e, t) => {
        var {
          Size: n
        } = t;
        return [e.slider.connect, e.slider["connect_".concat(n)]];
      },
      $handle: (e, t) => {
        var {
          Size: n
        } = t;
        return [e.slider.handle, e.slider["handle_".concat(n)]];
      },
      $tooltip: (e, t) => {
        var {
          Size: n
        } = t;
        return [e.slider.tooltip, e.slider["tooltip_".concat(n)]];
      },
      $tooltipTop: (e, t) => {
        var {
          Size: n
        } = t;
        return [e.slider.tooltipTop, e.slider["tooltipTop_".concat(n)]];
      },
      $tooltipBottom: (e, t) => {
        var {
          Size: n
        } = t;
        return [e.slider.tooltipBottom, e.slider["tooltipBottom_".concat(n)]];
      },
      $tooltipLeft: (e, t) => {
        var {
          Size: n
        } = t;
        return [e.slider.tooltipLeft, e.slider["tooltipLeft_".concat(n)]];
      },
      $tooltipRight: (e, t) => {
        var {
          Size: n
        } = t;
        return [e.slider.tooltipRight, e.slider["tooltipRight_".concat(n)]];
      }
    },
    $wrapper: (e, t) => {
      var {
        Size: n
      } = t;
      return [e.wrapper, e["wrapper_".concat(n)]];
    }
  },
  StaticElement: {
    container: "",
    content: "",
    content_sm: "form-text-sm",
    content_md: "form-text",
    content_lg: "form-text-lg",
    content_top_1: "form-mt-tag-1",
    content_top_2: "form-mt-tag-2",
    content_top_3: "form-mt-tag-3",
    content_bottom_1: "form-mb-tag-1",
    content_bottom_2: "form-mb-tag-2",
    content_bottom_3: "form-mb-tag-3",
    tag: "",
    tag_sm: "",
    tag_md: "",
    tag_lg: "",
    tag_top_1: "form-mt-tag-1",
    tag_top_2: "form-mt-tag-2",
    tag_top_3: "form-mt-tag-3",
    tag_bottom_1: "form-mb-tag-1",
    tag_bottom_2: "form-mb-tag-2",
    tag_bottom_3: "form-mb-tag-3",
    tag_left: "text-left",
    tag_center: "text-center",
    tag_right: "text-right",
    tag_p: "",
    tag_p_sm: "",
    tag_p_md: "",
    tag_p_lg: "",
    tag_h1: "font-bold",
    tag_h1_sm: "form-text-h1-mobile-sm md:form-text-h1-sm",
    tag_h1_md: "form-text-h1-mobile md:form-text-h1",
    tag_h1_lg: "form-text-h1-mobile-lg md:form-text-h1-lg",
    tag_h2: "font-bold",
    tag_h2_sm: "form-text-h2-mobile-sm md:form-text-h2-sm",
    tag_h2_md: "form-text-h2-mobile md:form-text-h2",
    tag_h2_lg: "form-text-h2-mobile-lg md:form-text-h2-lg",
    tag_h3: "font-bold",
    tag_h3_sm: "form-text-h3-mobile-sm md:form-text-h3-sm",
    tag_h3_md: "form-text-h3-mobile md:form-text-h3",
    tag_h3_lg: "form-text-h3-mobile-lg md:form-text-h3-lg",
    tag_h4: "font-bold",
    tag_h4_sm: "form-text-h4-mobile-sm md:form-text-h4-sm",
    tag_h4_md: "form-text-h4-mobile md:form-text-h4",
    tag_h4_lg: "form-text-h4-mobile-lg md:form-text-h4-lg",
    tag_blockquote: "form-border-width-blockquote form-border-color-blockquote",
    tag_blockquote_sm: "form-text-blockquote-sm form-p-blockquote-sm",
    tag_blockquote_md: "form-text-blockquote form-p-blockquote",
    tag_blockquote_lg: "form-text-blockquote-lg form-p-blockquote-lg",
    tag_a: "form-color-link form-decoration-link",
    tag_a_sm: "",
    tag_a_md: "",
    tag_a_lg: "",
    tag_hr: "form-static-tag-hr-wrapper form-border-color-hr form-py-hr",
    tag_img: "form-static-tag-img",
    $content: (e, t) => {
      var {
        Size: n,
        top: r,
        bottom: i
      } = t;
      return [e.content, e["content_".concat(n)], r >= 1 ? e["content_top_".concat(r)] : null, i >= 1 ? e["content_bottom_".concat(i)] : null];
    },
    $tag: (e, t) => {
      var {
        Size: n,
        tag: r,
        align: i,
        top: a,
        bottom: o
      } = t;
      return [e.tag, e["tag_".concat(n)], e["tag_".concat(r)], e["tag_".concat(r, "_").concat(n)] || null, i === "left" ? e.tag_left : null, i === "center" ? e.tag_center : null, i === "right" ? e.tag_right : null, a >= 1 ? e["tag_top_".concat(a)] : null, o >= 1 ? e["tag_bottom_".concat(o)] : null];
    }
  },
  TagsElement: {
    container: "form-text-type",
    select: Cn(Cn({}, VT), {}, {
      tags: "flex-grow flex-shrink flex flex-wrap items-center min-w-0 rtl:pl-0",
      tags_sm: "form-pl-input-y-sm form-mt-space-tags-sm with-floating:form-p-tags-floating-sm rtl:form-pr-input-y-sm",
      tags_md: "form-pl-input-y form-mt-space-tags with-floating:form-p-tags-floating rtl:form-pr-input-y",
      tags_lg: "form-pl-input-y-lg form-mt-space-tags-lg with-floating:form-p-tags-floating-lg rtl:form-pr-input-y-lg",
      tag: "form-bg-tag form-color-tag form-border-width-tag form-border-color-tag font-semibold  flex items-center whitespace-nowrap min-w-0 rtl:pl-0 rtl:mr-0",
      tag_sm: "form-radius-input-tag-sm form-text-small-sm form-py-tag-sm form-pl-tag-sm form-mr-space-tags-sm form-mb-space-tags-sm rtl:form-pr-tag-sm rtl:form-ml-space-tags-sm",
      tag_md: "form-radius-input-tag form-text-small form-py-tag form-pl-tag form-mr-space-tags form-mb-space-tags rtl:form-pr-tag rtl:form-ml-space-tags",
      tag_lg: "form-radius-input-tag-lg form-text-small-lg form-py-tag-lg form-pl-tag-lg form-mr-space-tags-lg form-mb-space-tags-lg rtl:form-pr-tag-lg rtl:form-ml-space-tags-lg",
      tagDisabled: "opacity-50",
      tagDisabled_sm: "form-pr-tag-sm rtl:form-pl-tag-sm",
      tagDisabled_md: "form-pr-tag rtl:form-pl-tag",
      tagDisabled_lg: "form-pr-tag-lg rtl:form-pl-tag-lg",
      tagWrapper: "overflow-hidden overflow-ellipsis",
      tagWrapper_nobreak: "whitespace-nowrap",
      tagWrapperBreak: "whitespace-normal break-all",
      tagRemove: "flex items-center justify-center p-1 mx-0.5 hover:bg-black hover:bg-opacity-10 group",
      tagRemove_sm: "form-radius-input-tag-sm",
      tagRemove_md: "form-radius-input-tag",
      tagRemove_lg: "form-radius-input-tag-lg",
      tagRemoveIcon: "mask-bg mask-form-remove bg-current inline-block w-3 h-3",
      tagsSearchWrapper: "inline-block relative form-ml-space-tags form-mr-space-tags form-mb-space-tags flex-grow flex-shrink h-full max-w-full",
      tagsSearchWrapper_sm: "form-ml-space-tags-sm form-mr-space-tags-sm form-mb-space-tags-sm",
      tagsSearchWrapper_md: "form-ml-space-tags form-mr-space-tags form-mb-space-tags",
      tagsSearchWrapper_lg: "form-ml-space-tags-lg form-mr-space-tags-lg form-mb-space-tags-lg",
      tagsSearch: "absolute bg-transparent form-color-input inset-0 border-0 outline-zero appearance-none p-0 box-border w-full pr-2",
      tagsSearch_sm: "form-text-sm",
      tagsSearch_md: "form-text",
      tagsSearch_lg: "form-text-lg",
      tagsSearchCopy: "invisible whitespace-pre-wrap inline-block h-px",
      $tags: (e, t) => {
        var {
          Size: n
        } = t;
        return [e.select.tags, e.select["tags_".concat(n)]];
      },
      $tag: (e, t) => {
        var {
          Size: n
        } = t;
        return [e.select.tag, e.select["tag_".concat(n)]];
      },
      $tagWrapper: (e, t) => {
        var {
          breakTags: n
        } = t;
        return [e.select.tagWrapper, n.value ? null : e.select.tagWrapper_noBreak];
      },
      $tagDisabled: (e, t) => {
        var {
          Size: n
        } = t;
        return [e.select.tagDisabled, e.select["tagDisabled_".concat(n)]];
      },
      $tagRemove: (e, t) => {
        var {
          Size: n
        } = t;
        return [e.select.tagRemove, e.select["tagRemove_".concat(n)]];
      },
      $tagsSearchWrapper: (e, t) => {
        var {
          Size: n
        } = t;
        return [e.select.tagsSearchWrapper, e.select["tagsSearchWrapper_".concat(n)]];
      },
      $tagsSearch: (e, t) => {
        var {
          Size: n
        } = t;
        return [e.select.tagsSearch, e.select["tagsSearch_".concat(n)]];
      }
    })
  },
  TextareaElement: Cn({}, JP),
  TextElement: Cn({}, Yc),
  ToggleElement: {
    container: "",
    wrapper: "flex items-start",
    wrapper_left: "rtl:justify-end",
    wrapper_right: "justify-end rtl:justify-start",
    text: "",
    text_sm: "form-ml-space-checkbox-sm rtl:form-mr-space-checkbox-sm rtl:ml-0",
    text_md: "form-ml-space-checkbox rtl:form-mr-space-checkbox rtl:ml-0",
    text_lg: "form-ml-space-checkbox-lg rtl:form-mr-space-checkbox-lg rtl:ml-0",
    text_left: "rtl:-order-1 rtl:!mr-0",
    text_left_sm: "!form-ml-space-checkbox-sm",
    text_left_md: "!form-ml-space-checkbox",
    text_left_lg: "!form-ml-space-checkbox-lg",
    text_right: "!ml-0 -order-1 rtl:order-none",
    text_right_sm: "form-mr-space-checkbox-sm",
    text_right_md: "form-mr-space-checkbox",
    text_right_lg: "form-mr-space-checkbox-lg",
    toggle: {
      container: "form-shadow-handles inline-block rounded-full outline-zero transition-input duration-200 ease-in-out focus:form-ring",
      container_enabled: "hover:form-shadow-handles-hover focus:form-shadow-handles-focus focused-hover:form-shadow-handles-hover",
      container_disabled: "cursor-not-allowed opacity-50",
      toggle: "flex rounded-full relative cursor-pointer transition-colors items-center box-content form-border-width-toggle leading-none",
      toggle_sm: "form-w-toggle-sm form-h-toggle-sm text-xs",
      toggle_md: "form-w-toggle form-h-toggle text-xs",
      toggle_lg: "form-w-toggle-lg form-h-toggle-lg text-0.5sm",
      toggleOn: "form-bg-primary form-border-color-primary justify-start form-color-on-primary",
      toggleOff: "form-bg-passive form-border-color-passive form-color-passive justify-end",
      toggleOnDisabled: "form-bg-primary form-border-color-primary justify-start form-color-on-primary",
      toggleOffDisabled: "form-bg-passive form-border-color-passive form-color-passive justify-end",
      handle: "inline-block form-bg-toggle-handle top-0 rounded-full absolute transition-all",
      handle_sm: "form-size-toggle-handle-sm",
      handle_md: "form-size-toggle-handle",
      handle_lg: "form-size-toggle-handle-lg",
      handleOn: "left-full transform -translate-x-full",
      handleOff: "left-0",
      handleOnDisabled: "left-full transform -translate-x-full",
      handleOffDisabled: "left-0",
      label: "text-center border-box whitespace-nowrap select-none",
      label_sm: "form-w-toggle-label-sm",
      label_md: "form-w-toggle-label",
      label_lg: "form-w-toggle-label-lg",
      $container: (e, t) => {
        var {
          Size: n,
          isDisabled: r
        } = t;
        return [e.toggle.container, e.toggle["container_".concat(n)], r ? e.toggle.container_disabled : e.toggle.container_enabled];
      },
      $toggle: (e, t) => {
        var {
          Size: n
        } = t;
        return [e.toggle.toggle, e.toggle["toggle_".concat(n)]];
      },
      $handle: (e, t) => {
        var {
          Size: n
        } = t;
        return [e.toggle.handle, e.toggle["handle_".concat(n)]];
      },
      $label: (e, t) => {
        var {
          Size: n
        } = t;
        return [e.toggle.label, e.toggle["label_".concat(n)]];
      }
    },
    $text: (e, t) => {
      var {
        Size: n,
        align: r
      } = t;
      return [e.text, e["text_".concat(n)], r === "left" ? [e.text_left, e["text_left_".concat(n)]] : null, r === "right" ? [e.text_right, e["text_right_".concat(n)]] : null];
    },
    $wrapper: (e, t) => {
      var {
        align: n
      } = t;
      return [e.wrapper, n === "left" ? e.wrapper_left : null, n === "right" ? e.wrapper_right : null];
    }
  },
  TTextareaElement: Cn({}, JP),
  TTextElement: Cn({}, Yc),
  TEditorElement: Cn({}, eF),
  // Wrappers
  DatepickerWrapper: {
    datepicker: "",
    calendarContainer: ""
  },
  EditorWrapper: {
    container: "form-bg-input form-color-input",
    container_hideBold: "form-editor-hide-bold",
    container_hideItalic: "form-editor-hide-italic",
    container_hideStrike: "form-editor-hide-strike",
    container_hideLink: "form-editor-hide-link",
    container_hideHeading: "form-editor-hide-heading",
    container_hideQuote: "form-editor-hide-quote",
    container_hideCode: "form-editor-hide-code",
    container_hideBulletList: "form-editor-hide-bullet-list",
    container_hideNumberList: "form-editor-hide-number-list",
    container_hideDecreaseNesting: "form-editor-hide-decrease-nesting",
    container_hideIncreaseNesting: "form-editor-hide-increase-nesting",
    container_hideAttach: "form-editor-hide-attach",
    container_hideUndo: "form-editor-hide-undo",
    container_hideRedo: "form-editor-hide-redo",
    $container: (e, t) => {
      var {
        hideTools: n
      } = t;
      return [e.container].concat(n.map((r) => e["container_hide".concat(r.split("-").map((i) => i.charAt(0).toUpperCase() + i.slice(1)).join(""))]));
    }
  },
  // Components
  ElementAddon: {
    container: "form-bg-addon form-color-addon flex items-center justify-center flex-grow-0 flex-shrink-0",
    container_before: "",
    container_after: "order-2",
    container_sm: "",
    container_md: "",
    container_lg: "",
    container_before_sm: "form-radius-input-l-sm form-pl-input-sm form-pr-space-addon-sm",
    container_before_md: "form-radius-input-l form-pl-input form-pr-space-addon",
    container_before_lg: "form-radius-input-l-lg form-pl-input-lg form-pr-space-addon-lg",
    container_after_sm: "form-radius-input-r-sm form-pr-input-sm form-pl-space-addon-sm",
    container_after_md: "form-radius-input-r form-pr-input form-pl-space-addon",
    container_after_lg: "form-radius-input-r-lg form-pr-input-lg form-pl-space-addon-lg",
    wrapper: "contents items-center justify-center",
    $container: (e, t) => {
      var {
        type: n,
        Size: r
      } = t;
      return [e.container, e["container_".concat(r)], e["container_".concat(n)], e["container_".concat(n, "_").concat(r)]];
    }
  },
  ElementDescription: {
    container: "form-color-muted",
    container_sm: "form-text-small-sm mt-0.5",
    container_md: "form-text-small mt-1",
    container_lg: "form-text-small-lg mt-1",
    $container: (e, t) => {
      var {
        Size: n
      } = t;
      return [e.container, e["container_".concat(n)]];
    }
  },
  ElementError: {
    container: "form-color-danger block",
    container_sm: "form-text-small-sm mt-0.5",
    container_md: "form-text-small mt-1",
    container_lg: "form-text-small-lg mt-1",
    $container: (e, t) => {
      var {
        Size: n
      } = t;
      return [e.container, e["container_".concat(n)]];
    }
  },
  ElementInfo: {
    container: "inline-block w-3.5 h-3.5 form-bg-info relative ml-1 cursor-pointer form-info-group",
    wrapper: "absolute z-999 -mt-px opacity-0 invisible info-group-hover:opacity-100 info-group-hover:form-visible transition-opacity w-52 flex",
    wrapper_left: "right-5 -top-0.5 justify-end",
    wrapper_right: "left-5 -top-0.5 justify-start",
    wrapper_top: "left-1/2 transform -translate-x-1/2 bottom-8 justify-center",
    wrapper_bottom: "left-1/2 transform -translate-x-1/2 top-6 justify-center",
    content: "bg-black bg-opacity-90 text-white rounded-md form-text-small py-1 px-2.5 not-italic inline-block relative",
    $wrapper: (e, t) => {
      var {
        position: n
      } = t;
      return [e.wrapper, e["wrapper_".concat(n)]];
    }
  },
  ElementLabel: {
    container: "flex items-start",
    container_sm: "form-text-sm",
    container_md: "form-text",
    container_lg: "form-text-lg",
    container_vertical_sm: "form-pb-gutter/3-sm form-pt-0 form-pr-0",
    container_vertical_md: "form-pb-gutter/3 form-pt-0 form-pr-0",
    container_vertical_lg: "form-pb-gutter/3-lg form-pt-0 form-pr-0",
    container_vertical_sm_SM: "sm:form-pb-gutter/3-sm sm:form-pt-0 sm:form-pr-0",
    container_vertical_md_SM: "sm:form-pb-gutter/3 sm:form-pt-0 sm:form-pr-0",
    container_vertical_lg_SM: "sm:form-pb-gutter/3-lg sm:form-pt-0 sm:form-pr-0",
    container_vertical_sm_MD: "md:form-pb-gutter/3-sm md:form-pt-0 md:form-pr-0",
    container_vertical_md_MD: "md:form-pb-gutter/3 md:form-pt-0 md:form-pr-0",
    container_vertical_lg_MD: "md:form-pb-gutter/3-lg md:form-pt-0 md:form-pr-0",
    container_vertical_sm_LG: "lg:form-pb-gutter/3-sm lg:form-pt-0 lg:form-pr-0",
    container_vertical_md_LG: "lg:form-pb-gutter/3 lg:form-pt-0 lg:form-pr-0",
    container_vertical_lg_LG: "lg:form-pb-gutter/3-lg lg:form-pt-0 lg:form-pr-0",
    container_vertical_sm_XL: "xl:form-pb-gutter/3-sm xl:form-pt-0 xl:form-pr-0",
    container_vertical_md_XL: "xl:form-pb-gutter/3 xl:form-pt-0 xl:form-pr-0",
    container_vertical_lg_XL: "xl:form-pb-gutter/3-lg xl:form-pt-0 xl:form-pr-0",
    container_vertical_sm_2XL: "2xl:form-pb-gutter/3-sm 2xl:form-pt-0 2xl:form-pr-0",
    container_vertical_md_2XL: "2xl:form-pb-gutter/3 2xl:form-pt-0 2xl:form-pr-0",
    container_vertical_lg_2XL: "2xl:form-pb-gutter/3-lg 2xl:form-pt-0 2xl:form-pr-0",
    container_horizontal_sm: "form-pr-gutter-sm text-type:form-pt-input-border-sm pb-0",
    container_horizontal_md: "form-pr-gutter text-type:form-pt-input-border pb-0",
    container_horizontal_lg: "form-pr-gutter-lg text-type:form-pt-input-border-lg pb-0",
    container_horizontal_sm_SM: "sm:form-pr-gutter-sm sm:text-type:form-pt-input-border-sm sm:pb-0",
    container_horizontal_md_SM: "sm:form-pr-gutter sm:text-type:form-pt-input-border sm:pb-0",
    container_horizontal_lg_SM: "sm:form-pr-gutter-lg sm:text-type:form-pt-input-border-lg sm:pb-0",
    container_horizontal_sm_MD: "md:form-pr-gutter-sm md:text-type:form-pt-input-border-sm md:pb-0",
    container_horizontal_md_MD: "md:form-pr-gutter md:text-type:form-pt-input-border md:pb-0",
    container_horizontal_lg_MD: "md:form-pr-gutter-lg md:text-type:form-pt-input-border-lg md:pb-0",
    container_horizontal_sm_LG: "lg:form-pr-gutter-sm lg:text-type:form-pt-input-border-sm lg:pb-0",
    container_horizontal_md_LG: "lg:form-pr-gutter lg:text-type:form-pt-input-border lg:pb-0",
    container_horizontal_lg_LG: "lg:form-pr-gutter-lg lg:text-type:form-pt-input-border-lg lg:pb-0",
    container_horizontal_sm_XL: "xl:form-pr-gutter-sm xl:text-type:form-pt-input-border-sm xl:pb-0",
    container_horizontal_md_XL: "xl:form-pr-gutter xl:text-type:form-pt-input-border xl:pb-0",
    container_horizontal_lg_XL: "xl:form-pr-gutter-lg xl:text-type:form-pt-input-border-lg xl:pb-0",
    container_horizontal_sm_2XL: "2xl:form-pr-gutter-sm 2xl:text-type:form-pt-input-border-sm 2xl:pb-0",
    container_horizontal_md_2XL: "2xl:form-pr-gutter 2xl:text-type:form-pt-input-border 2xl:pb-0",
    container_horizontal_lg_2XL: "2xl:form-pr-gutter-lg 2xl:text-type:form-pt-input-border-lg 2xl:pb-0",
    wrapper: "",
    $container: (e, t) => {
      var {
        el$: n,
        Size: r
      } = t;
      return [e.container, e["container_".concat(r)], n.inline ? null : n.columnsClasses.label, n.cols.default.label < 12 ? e["container_horizontal_".concat(r)] : e["container_vertical_".concat(r)], ...Object.keys(n.cols).length > 1 ? (n.$vueform.config.breakpoints || ["sm", "md", "lg", "xl", "2xl"]).map((i) => {
        var a;
        return (a = n.cols[i]) !== null && a !== void 0 && a.label ? n.cols[i].label < 12 ? e["container_horizontal_".concat(r, "_").concat(i.toUpperCase())].join(" ") : e["container_vertical_".concat(r, "_").concat(i.toUpperCase())].join(" ") : null;
      }) : []];
    }
  },
  ElementLabelFloating: {
    container: "label-floating relative pointer-events-none",
    label: "absolute z-1 leading-px text-0.5xs px-px transition-input duration-200 ease-in-out whitespace-nowrap in-input-group:-form-top-border-width-input-t",
    label_enabled: "form-bg-input form-color-floating",
    label_disabled: "form-bg-disabled form-color-floating",
    label_danger: "form-bg-input-danger form-color-floating-danger",
    label_success: "form-bg-input-success form-color-floating-success",
    label_focused: "form-bg-input-focus form-color-floating-focus",
    label_sm: "form-left-input-sm form-mt-floating-sm rtl:left-auto rtl:form-right-input-sm",
    label_md: "form-left-input form-mt-floating rtl:left-auto rtl:form-right-input",
    label_lg: "form-left-input-lg form-mt-floating-lg rtl:left-auto rtl:form-right-input-lg",
    label_invisible: "opacity-0 invisible",
    label_visible: "opacity-100 visible",
    $label: (e, t) => {
      var {
        visible: n,
        Size: r,
        el$: i
      } = t;
      return [e.label, e["label_".concat(r)], n ? e.label_visible : e.label_invisible, i.focused && !i.isDanger && !i.isSuccess ? e.label_focused : null, !i.isDisabled && !i.isDanger && !i.isSuccess ? e.label_enabled : null, i.isDisabled ? e.label_disabled : null, i.isDanger ? e.label_danger : null, i.isSuccess ? e.label_success : null];
    }
  },
  ElementLayout: {
    container: "",
    container_sm: "form-text-sm",
    container_md: "form-text",
    container_lg: "form-text-lg",
    container_error: "has-error",
    outerWrapper: "grid grid-cols-12",
    innerContainer: "flex-1 grid grid-cols-12",
    innerWrapperBefore: "col-span-12",
    innerWrapper: "",
    innerWrapperAfter: "col-span-12",
    $container: (e, t) => {
      var {
        el$: n,
        Size: r
      } = t;
      return [e.container, e["container_".concat(r)], n.columnsClasses.container, n.classes.container, !n.isStatic && n.errors && n.errors.length ? e.container_error : null];
    },
    $innerContainer: (e, t) => {
      var {
        el$: n
      } = t;
      return [e.innerContainer, n.columnsClasses.innerContainer];
    },
    $innerWrapper: (e, t) => {
      var {
        el$: n
      } = t;
      return [e.innerWrapper, n.columnsClasses.wrapper];
    }
  },
  ElementLayoutInline: {
    container: "flex",
    container_error: "has-error",
    $container: (e, t) => {
      var {
        el$: n
      } = t;
      return [e.container, !n.isStatic && n.errors && n.errors.length ? e.container_error : null, n.classes.container];
    }
  },
  ElementLoader: {
    container: "relative z-1 order-1",
    loader: "absolute w-4 h-4 right-full mask-bg mask-form-spinner form-bg-primary animate-spin",
    loader_sm: "form-top-input-border-sm form-mr-input-sm mt-0.5",
    loader_md: "form-top-input-border form-mr-input mt-1",
    loader_lg: "form-top-input-border-lg form-mr-input-lg mt-1",
    $loader: (e, t) => {
      var {
        Size: n
      } = t;
      return [e.loader, e["loader_".concat(n)]];
    }
  },
  ElementMessage: {
    container: "form-color-success block",
    container_sm: "form-text-small-sm mt-0.5",
    container_md: "form-text-small mt-1",
    container_lg: "form-text-small-lg mt-1",
    $container: (e, t) => {
      var {
        Size: n
      } = t;
      return [e.container, e["container_".concat(n)]];
    }
  },
  ElementText: {
    container: "",
    container_before: "",
    container_between: "",
    container_after: "",
    $container: (e, t) => {
      var {
        type: n
      } = t;
      return [e.container, e["container_".concat(n)]];
    }
  },
  FormElements: {
    container: "grid grid-cols-12",
    container_sm: "form-gap-x-gutter-sm form-gap-y-gutter-sm",
    container_md: "form-gap-x-gutter form-gap-y-gutter",
    container_lg: "form-gap-x-gutter-lg form-gap-y-gutter-lg",
    $container: (e, t) => {
      var {
        Size: n
      } = t;
      return [e.container, e["container_".concat(n)]];
    }
  },
  FormErrors: {
    container: "form-bg-danger form-color-danger",
    container_sm: "form-radius-input-sm form-text-sm form-mb-gutter-sm py-2 px-3",
    container_md: "form-radius-input form-text form-mb-gutter py-2 px-3",
    container_lg: "form-radius-input-lg form-text-lg form-mb-gutter-lg py-3 px-4",
    error: "",
    $container: (e, t) => {
      var {
        Size: n
      } = t;
      return [e.container, e["container_".concat(n)]];
    }
  },
  FormLanguage: {
    container: "flex-grow flex-shrink w-full",
    wrapper: "block border-b-2 text-center",
    wrapper_active: "form-border-color-primary",
    wrapper_inactive: "border-transparent",
    wrapper_valid: "",
    wrapper_invalid: "form-color-danger form-border-color-danger",
    wrapper_sm: "py-1.5 px-3.5",
    wrapper_md: "py-2 px-4",
    wrapper_lg: "py-2 px-4",
    $wrapper: (e, t) => {
      var {
        selected: n,
        Size: r
      } = t;
      return [e.wrapper, e["wrapper_".concat(r)], n ? e.wrapper_active : e.wrapper_inactive];
    }
  },
  FormLanguages: {
    container: "flex items-center justify-between",
    container_sm: "form-mb-gutter form-text-sm",
    container_md: "form-mb-gutter-lg form-text",
    container_lg: "form-mb-gutter-lg form-text-lg",
    $container: (e, t) => {
      var {
        Size: n
      } = t;
      return [e.container, e["container_".concat(n)]];
    }
  },
  FormMessages: {
    container: "form-bg-success form-color-success",
    container_sm: "form-radius-input-sm form-text-sm form-mb-gutter-sm py-2 px-3",
    container_md: "form-radius-input form-text form-mb-gutter py-2 px-3",
    container_lg: "form-radius-input-lg form-text-lg form-mb-gutter-lg py-3 px-4",
    message: "",
    $container: (e, t) => {
      var {
        Size: n
      } = t;
      return [e.container, e["container_".concat(n)]];
    }
  },
  FormStep: {
    container: "form-step",
    container_active: "form-step-active",
    container_inactive: "",
    container_invalid: "form-step-has-errors",
    container_valid: "",
    container_disabled: "form-step-disabled",
    container_enabled: "",
    container_completed: "form-step-completed",
    container_incompleted: "",
    container_pending: "form-step-pending",
    wrapper: "",
    $container: (e, t) => {
      var {
        active: n,
        isDisabled: r,
        completed: i,
        invalid: a,
        pending: o
      } = t;
      return [e.container, n ? e.container_active : e.container_inactive, r ? e.container_disabled : e.container_enabled, i ? e.container_completed : e.container_incompleted, a ? e.container_invalid : e.container_valid, o ? e.container_pending : null];
    }
  },
  FormSteps: {
    container: "form-steps",
    container_sm: "form-mb-gutter form-text-sm",
    container_md: "form-mb-gutter-lg form-text",
    container_lg: "form-mb-gutter-lg form-text-lg",
    wrapper: "flex justify-between overflow-x-auto",
    $container: (e, t) => {
      var {
        Size: n
      } = t;
      return [e.container, e["container_".concat(n)]];
    }
  },
  FormStepsControl: {
    button: "form-border-width-btn form-shadow-btn focus:form-ring focus:outline-zero disabled:pointer-events-none disabled:opacity-60 disabled:cursor-not-allowed",
    button_previous: "",
    button_previous_enabled: "form-bg-btn-secondary form-color-btn-secondary form-border-color-btn-secondary transition-transform transform hover:scale-105",
    button_previous_disabled: "form-bg-btn-secondary form-color-btn-secondary form-border-color-btn-secondary opacity-60 pointer-events-none",
    button_next: "",
    button_next_enabled: "form-bg-primary form-color-on-primary form-border-color-btn transition-transform transform hover:scale-105",
    button_next_disabled: "form-bg-primary form-color-on-primary form-border-color-btn opacity-60 pointer-events-none cursor-not-allowed",
    button_next_loading: "text-transparent form-bg-primary form-border-color-btn form-bg-spinner-on-primary opacity-60 pointer-events-none cursor-not-allowed",
    button_finish: "",
    button_finish_enabled: "form-bg-primary form-color-on-primary form-border-color-btn transition-transform transform hover:scale-105",
    button_finish_disabled: "form-bg-primary form-color-on-primary form-border-color-btn opacity-60 pointer-events-none cursor-not-allowed",
    button_finish_loading: "text-transparent form-bg-primary form-border-color-btn form-bg-spinner-on-primary opacity-60 pointer-events-none cursor-not-allowed",
    button_sm: "form-p-btn-sm form-radius-btn-sm form-text-sm",
    button_md: "form-p-btn form-radius-btn form-text",
    button_lg: "form-p-btn-lg form-radius-btn-lg form-text-lg",
    $button: (e, t) => {
      var {
        isDisabled: n,
        isLoading: r,
        type: i,
        Size: a
      } = t;
      return [e.button, e["button_".concat(a)], e["button_".concat(i)], n && !r ? e["button_".concat(i, "_disabled")] : null, !n && !r ? e["button_".concat(i, "_enabled")] : null, r ? e["button_".concat(i, "_loading")] : null];
    }
  },
  FormStepsControls: {
    container: "flex justify-between",
    container_sm: "form-mt-gutter form-text-sm",
    container_md: "form-mt-gutter-lg form-text",
    container_lg: "form-mt-gutter-lg form-text-lg",
    $container: (e, t) => {
      var {
        Size: n
      } = t;
      return [e.container, e["container_".concat(n)]];
    }
  },
  FormTab: {
    container: "cursor-pointer",
    wrapper: "block border-b-2",
    wrapper_active: "form-border-color-primary",
    wrapper_inactive: "border-transparent",
    wrapper_valid: "",
    wrapper_invalid: "form-color-danger form-border-color-danger",
    wrapper_sm: "py-1.5 px-3.5",
    wrapper_md: "py-2 px-4",
    wrapper_lg: "py-2 px-4",
    $container: (e, t) => [e.container],
    $wrapper: (e, t) => {
      var {
        active: n,
        invalid: r,
        Size: i
      } = t;
      return [e.wrapper, e["wrapper_".concat(i)], n ? e.wrapper_active : e.wrapper_inactive, r ? e.wrapper_invalid : e.wrapper_valid];
    }
  },
  FormTabs: {
    container: "flex items-end",
    container_sm: "form-mb-gutter form-text-sm",
    container_md: "form-mb-gutter-lg form-text",
    container_lg: "form-mb-gutter-lg form-text-lg",
    $container: (e, t) => {
      var {
        Size: n
      } = t;
      return [e.container, e["container_".concat(n)]];
    }
  },
  Vueform: {
    form: ""
  },
  // Slots
  CheckboxgroupCheckbox: Cn(Cn({}, fo), {}, {
    container: "flex align-start cursor-pointer",
    text: "",
    input: fo.input + " form-shadow-handles",
    input_sm: fo.input_sm + " form-mt-checkbox-sm",
    input_md: fo.input_md + " form-mt-checkbox",
    input_lg: fo.input_lg + " form-mt-checkbox-lg"
  }),
  CheckboxgroupCheckbox_tabs: Cn(Cn({}, tF), {}, {
    $wrapper: (e, t) => {
      var {
        index: n,
        items: r,
        el$: i,
        value: a,
        isDisabled: o,
        Size: s
      } = t;
      return [e.wrapper, e["wrapper_".concat(s)], n < Object.keys(r).length - 1 ? e.wrapper_not_last : null, n === 0 ? e.wrapper_first : null, n === 0 ? e["wrapper_first_".concat(s)] : null, n === Object.keys(r).length - 1 ? e.wrapper_last : null, n === Object.keys(r).length - 1 ? e["wrapper_last_".concat(s)] : null, i.value.indexOf(a) !== -1 ? e.wrapper_selected : e.wrapper_unselected, o ? e.wrapper_disabled : null];
    }
  }),
  CheckboxgroupCheckbox_blocks: Cn(Cn(Cn({}, fo), nF), {}, {
    $wrapper: (e, t) => {
      var {
        index: n,
        items: r,
        el$: i,
        value: a,
        isDisabled: o,
        Size: s
      } = t;
      return [e.wrapper, e["wrapper_".concat(s)], n < Object.keys(r).length - 1 ? e.wrapper_not_last : null, n === 0 ? e.wrapper_first : null, n === 0 ? e["wrapper_first_".concat(s)] : null, n === Object.keys(r).length - 1 ? e.wrapper_last : null, n === Object.keys(r).length - 1 ? e["wrapper_last_".concat(s)] : null, i.value.indexOf(a) !== -1 ? e.wrapper_selected : e.wrapper_unselected, o ? e.wrapper_disabled : null];
    },
    $description: (e, t) => {
      var {
        Size: n
      } = t;
      return [e.description, e["description_".concat(n)]];
    }
  }),
  DragAndDrop: {
    container: "form-shadow-input form-bg-input form-color-input form-border-width-input border-dashed w-full transition inline-flex flex-col items-center justify-center p-6 cursor-pointer text-center",
    container_sm: "form-radius-large-sm",
    container_md: "form-radius-large",
    container_lg: "form-radius-large-lg",
    container_inactive: "form-border-color-input",
    container_active: "form-border-color-primary",
    container_enabled: "",
    container_disabled: "opacity-50 cursor-not-allowed",
    icon: "inline-block w-9 h-8 mask-bg mask-form-inbox-in form-bg-primary",
    title: "font-semibold mt-3",
    description: "",
    $container: (e, t) => {
      var {
        dragging: n,
        disabled: r,
        Size: i
      } = t;
      return [e.container, e["container_".concat(i)], n ? e.container_active : e.container_inactive, r ? e.container_disabled : e.container_enabled];
    }
  },
  FilePreview: {
    container: "flex justify-center flex-row group relative",
    container_sm: "form-h-input-height-sm",
    container_md: "form-h-input-height",
    container_lg: "form-h-input-height",
    wrapper: "flex justify-between items-center w-full",
    file: "flex items-center",
    filenameLink: "hover:underline",
    filenameStatic: "",
    actions: "flex items-center",
    percent: "flex justify-between items-center text-sm form-color-muted group-hover:form-hidden",
    upload: "form-bg-primary form-color-on-primary form-radius-small text-xs py-0.5 px-1.5 ml-1.5 whitespace-nowrap transition-transform transform hover:scale-105 focus:form-ring",
    progressBar: "form-bg-passive h-0.75 absolute bottom-0 w-full",
    progress: "w-0 form-bg-primary transition-all ease-out duration-500 h-0.75",
    warning: "flex w-4 h-4 items-center justify-center form-bg-danger rounded-full group-hover:form-hidden",
    warningIcon: "mask-bg mask-form-exclamation-solid form-bg-danger-color mask-size-2.5 block w-full h-full",
    uploaded: "flex w-4 h-4 items-center justify-center form-bg-success rounded-full group-hover:form-hidden",
    uploadedIcon: "mask-bg mask-form-check-solid form-bg-success-color mask-size-2.5 block w-full h-full",
    remove: "flex w-4 h-4 items-center justify-center form-bg-passive form-color-passive rounded-full transition filter hover:brightness-90 form-hidden group-hover:form-inline-block",
    removeIcon: "mask-bg mask-form-remove-light form-bg-input-color mask-size-3 block w-full h-full",
    assistiveText: "form-assistive-text",
    $container: (e, t) => {
      var {
        Size: n
      } = t;
      return [e.container, e["container_".concat(n)]];
    }
  },
  FilePreview_image: {
    container: "flex justify-start flex-row group relative",
    wrapper: "flex justify-between items-center w-full",
    image: "form-shadow-input flex items-center form-bg-passive flex-grow-0 flex-shrink-0",
    image_link: "",
    image_static: "",
    image_sm: "form-radius-image-sm",
    image_md: "form-radius-image",
    image_lg: "form-radius-image-lg",
    img: "form-w-input-height form-h-input-height form-hide-empty-img object-cover",
    img_sm: "form-w-input-height-sm form-h-input-height-sm form-radius-image-sm",
    img_md: "form-w-input-height form-h-input-height form-radius-image",
    img_lg: "form-w-input-height-lg form-h-input-height-lg form-radius-image-lg",
    file: "flex items-center flex-grow flex-shrink ml-2.5",
    filenameLink: "hover:underline",
    filenameStatic: "",
    actions: "flex items-center",
    percent: "flex justify-between items-center text-sm form-color-muted group-hover:form-hidden",
    upload: "form-bg-primary form-color-on-primary form-radius-small text-xs py-0.5 px-1.5 ml-1.5 whitespace-nowrap transition-transform transform hover:scale-105 focus:form-ring",
    progressBar: "form-bg-passive h-0.75 ml-2.5 absolute bottom-0 right-0",
    progressBar_sm: "form-left-input-height-sm",
    progressBar_md: "form-left-input-height",
    progressBar_lg: "form-left-input-height-lg",
    progress: "w-0 form-bg-primary transition-all ease-out duration-500 h-0.75",
    warning: "flex w-4 h-4 items-center justify-center form-bg-danger rounded-full group-hover:form-hidden",
    warningIcon: "mask-bg mask-form-exclamation-solid form-bg-danger-color mask-size-2.5 block w-full h-full",
    uploaded: "flex w-4 h-4 items-center justify-center form-bg-success rounded-full group-hover:form-hidden",
    uploadedIcon: "mask-bg mask-form-check-solid form-bg-success-color mask-size-2.5 block w-full h-full",
    remove: "flex w-4 h-4 items-center justify-center form-bg-passive form-color-passive rounded-full transition filter hover:brightness-90 form-hidden group-hover:form-inline-block",
    removeIcon: "mask-bg mask-form-remove-light form-bg-input-color mask-size-3 block w-full h-full",
    assistiveText: "form-assistive-text",
    $image: (e, t) => {
      var {
        hasLink: n,
        Size: r
      } = t;
      return [e.image, e["image_".concat(r)], n ? e.image_link : e.image_static];
    },
    $img: (e, t) => {
      var {
        Size: n
      } = t;
      return [e.img, e["img_".concat(n)]];
    },
    $progressBar: (e, t) => {
      var {
        Size: n
      } = t;
      return [e.progressBar, e["progressBar_".concat(n)]];
    }
  },
  FilePreview_gallery: {
    container: "flex justify-start flex-col transition duration-500 relative group",
    container_sm: "form-w-gallery-sm form-h-gallery-sm",
    container_md: "form-w-gallery form-h-gallery",
    container_lg: "form-w-gallery-lg form-h-gallery-lg",
    image: "form-shadow-input w-full h-full form-bg-passive",
    image_sm: "form-radius-gallery-sm",
    image_md: "form-radius-gallery",
    image_lg: "form-radius-gallery-lg",
    image_link: "",
    image_static: "",
    img: "w-full h-full object-cover form-hide-empty-img",
    img_sm: "form-radius-gallery-sm",
    img_md: "form-radius-gallery",
    img_lg: "form-radius-gallery-lg",
    overlay: "absolute inset-0 bg-white bg-opacity-50 transition duration-300 opacity-0 invisible flex items-center justify-center p-3 form-radius-input group-hover:form-visible group-hover:opacity-100",
    overlay_sm: "form-radius-gallery-sm",
    overlay_md: "form-radius-gallery",
    overlay_lg: "form-radius-gallery-lg",
    upload: "relative z-1 form-bg-primary form-color-on-primary form-radius-small text-xs py-0.5 px-1.5 whitespace-nowrap transition-transform transform hover:scale-105 focus:form-ring",
    progressBar: "bg-white absolute left-1 right-1 bottom-1 h-0.75 z-1",
    progress: "w-0 form-bg-primary transition-all ease-out duration-500 h-0.75",
    warning: "absolute right-0.5 bottom-0.5 mr-px mb-px flex w-4 h-4 items-center justify-center form-bg-danger rounded-full",
    warningIcon: "mask-bg mask-form-exclamation-solid form-bg-danger-color mask-size-2.5 block w-full h-full",
    uploaded: "absolute right-0.5 bottom-0.5 mr-px mb-px flex w-4 h-4 items-center justify-center form-bg-success rounded-full",
    uploadedIcon: "mask-bg mask-form-check-solid form-bg-success-color mask-size-2.5 block w-full h-full",
    remove: "flex w-4 h-4 items-center justify-center form-bg-passive form-color-passive absolute top-0.5 right-0.5 mt-px mr-px form-hidden rounded-full transition filter hover:brightness-90 group-hover:form-inline-block ",
    removeIcon: "mask-bg mask-form-remove-light form-bg-input-color mask-size-3 block w-full h-full",
    assistiveText: "form-assistive-text",
    $container: (e, t) => {
      var {
        Size: n
      } = t;
      return [e.container, e["container_".concat(n)]];
    },
    $image: (e, t) => {
      var {
        Size: n
      } = t;
      return [e.image, e["image_".concat(n)]];
    },
    $img: (e, t) => {
      var {
        Size: n
      } = t;
      return [e.img, e["img_".concat(n)]];
    },
    $overlay: (e, t) => {
      var {
        Size: n
      } = t;
      return [e.overlay, e["overlay_".concat(n)]];
    }
  },
  RadiogroupRadio: Cn(Cn({}, po), {}, {
    container: "flex align-start cursor-pointer",
    text: "",
    input: po.input + " form-shadow-handles",
    input_sm: po.input_sm + " form-mt-checkbox-sm",
    input_md: po.input_md + " form-mt-checkbox",
    input_lg: po.input_lg + " form-mt-checkbox-lg"
  }),
  RadiogroupRadio_tabs: Cn(Cn({}, tF), {}, {
    $wrapper: (e, t) => {
      var {
        index: n,
        items: r,
        el$: i,
        value: a,
        isDisabled: o,
        Size: s
      } = t;
      return [e.wrapper, e["wrapper_".concat(s)], n < Object.keys(r).length - 1 ? e.wrapper_not_last : null, n === 0 ? e.wrapper_first : null, n === 0 ? e["wrapper_first_".concat(s)] : null, n === Object.keys(r).length - 1 ? e.wrapper_last : null, n === Object.keys(r).length - 1 ? e["wrapper_last_".concat(s)] : null, i.value == a ? e.wrapper_selected : e.wrapper_unselected, o ? e.wrapper_disabled : null];
    }
  }),
  RadiogroupRadio_blocks: Cn(Cn(Cn({}, po), nF), {}, {
    $wrapper: (e, t) => {
      var {
        index: n,
        items: r,
        el$: i,
        value: a,
        isDisabled: o,
        Size: s
      } = t;
      return [e.wrapper, e["wrapper_".concat(s)], n < Object.keys(r).length - 1 ? e.wrapper_not_last : null, n === 0 ? e.wrapper_first : null, n === 0 ? e["wrapper_first_".concat(s)] : null, n === Object.keys(r).length - 1 ? e.wrapper_last : null, n === Object.keys(r).length - 1 ? e["wrapper_last_".concat(s)] : null, i.value == a ? e.wrapper_selected : e.wrapper_unselected, o ? e.wrapper_disabled : null];
    },
    $description: (e, t) => {
      var {
        Size: n
      } = t;
      return [e.description, e["description_".concat(n)]];
    }
  })
}, LHe = {
  templates: {
    Vueform: NO,
    FormErrors: DO,
    FormMessages: IO,
    FormLanguages: LO,
    FormLanguage: kO,
    FormTabs: MO,
    FormTab: PO,
    FormSteps: FO,
    FormStepsControls: BO,
    FormStepsControl: $O,
    FormStep: UO,
    FormElements: qO,
    ElementLayout: GO,
    ElementLayoutInline: YO,
    ElementLoader: HO,
    ElementLabelFloating: zO,
    ElementLabel: VO,
    ElementInfo: WO,
    ElementDescription: KO,
    ElementError: jO,
    ElementMessage: QO,
    ElementText: XO,
    ElementAddon: ZO,
    ButtonElement: JO,
    CheckboxElement: eR,
    CheckboxgroupElement: dp,
    CheckboxgroupElement_tabs: dp,
    CheckboxgroupElement_blocks: dp,
    DateElement: Jp,
    DatesElement: n9,
    FileElement: tR,
    GroupElement: nR,
    HiddenElement: rR,
    ListElement: iR,
    LocationElement: r9,
    MultifileElement: oR,
    MultiselectElement: pR,
    ObjectElement: mR,
    RadioElement: hR,
    RadiogroupElement: pp,
    RadiogroupElement_tabs: pp,
    RadiogroupElement_blocks: pp,
    SelectElement: gR,
    SliderElement: bR,
    StaticElement: ER,
    TagsElement: SR,
    TextareaElement: nm,
    TextElement: rm,
    ToggleElement: TR,
    EditorElement: im,
    TTextareaElement: _9,
    TTextElement: v9,
    TEditorElement: b9,
    CheckboxgroupCheckbox: CR,
    CheckboxgroupCheckbox_tabs: AR,
    CheckboxgroupCheckbox_blocks: OR,
    DragAndDrop: RR,
    FilePreview: wR,
    FilePreview_image: xR,
    FilePreview_gallery: NR,
    RadiogroupRadio: DR,
    RadiogroupRadio_tabs: IR,
    RadiogroupRadio_blocks: LR,
    DatepickerWrapper: E9,
    EditorWrapper: S9
  },
  classes: IHe,
  columns: wHe
}, k_ = { exports: {} };
/**
 * @license
 * Lodash <https://lodash.com/>
 * Copyright OpenJS Foundation and other contributors <https://openjsf.org/>
 * Released under MIT license <https://lodash.com/license>
 * Based on Underscore.js 1.8.3 <http://underscorejs.org/LICENSE>
 * Copyright Jeremy Ashkenas, DocumentCloud and Investigative Reporters & Editors
 */
k_.exports;
(function(e, t) {
  (function() {
    var n, r = "4.17.21", i = 200, a = "Unsupported core-js use. Try https://npms.io/search?q=ponyfill.", o = "Expected a function", s = "Invalid `variable` option passed into `_.template`", l = "__lodash_hash_undefined__", u = 500, c = "__lodash_placeholder__", d = 1, f = 2, h = 4, m = 1, v = 2, b = 1, y = 2, g = 4, E = 8, S = 16, C = 32, T = 64, O = 128, R = 256, D = 512, q = 30, $ = "...", P = 800, Y = 16, L = 1, x = 2, I = 3, k = 1 / 0, B = 9007199254740991, W = 17976931348623157e292, Z = NaN, V = 4294967295, K = V - 1, ne = V >>> 1, Ee = [
      ["ary", O],
      ["bind", b],
      ["bindKey", y],
      ["curry", E],
      ["curryRight", S],
      ["flip", D],
      ["partial", C],
      ["partialRight", T],
      ["rearg", R]
    ], oe = "[object Arguments]", ae = "[object Array]", pe = "[object AsyncFunction]", Se = "[object Boolean]", Re = "[object Date]", Ye = "[object DOMException]", nt = "[object Error]", ut = "[object Function]", Tt = "[object GeneratorFunction]", Ot = "[object Map]", Xt = "[object Number]", We = "[object Null]", st = "[object Object]", Pt = "[object Promise]", Ke = "[object Proxy]", Je = "[object RegExp]", Be = "[object Set]", pt = "[object String]", ft = "[object Symbol]", Ze = "[object Undefined]", _t = "[object WeakMap]", St = "[object WeakSet]", we = "[object ArrayBuffer]", je = "[object DataView]", yt = "[object Float32Array]", Rt = "[object Float64Array]", sn = "[object Int8Array]", me = "[object Int16Array]", He = "[object Int32Array]", tt = "[object Uint8Array]", ot = "[object Uint8ClampedArray]", xn = "[object Uint16Array]", kt = "[object Uint32Array]", Dn = /\b__p \+= '';/g, gn = /\b(__p \+=) '' \+/g, Vn = /(__e\(.*?\)|\b__t\)) \+\n'';/g, X = /&(?:amp|lt|gt|quot|#39);/g, te = /[&<>"']/g, _e = RegExp(X.source), M = RegExp(te.source), G = /<%-([\s\S]+?)%>/g, j = /<%([\s\S]+?)%>/g, ce = /<%=([\s\S]+?)%>/g, be = /\.|\[(?:[^[\]]*|(["'])(?:(?!\1)[^\\]|\\.)*?\1)\]/, Ie = /^\w*$/, Ue = /[^.[\]]+|\[(?:(-?\d+(?:\.\d+)?)|(["'])((?:(?!\2)[^\\]|\\.)*?)\2)\]|(?=(?:\.|\[\])(?:\.|\[\]|$))/g, Ve = /[\\^$.*+?()[\]{}|]/g, dt = RegExp(Ve.source), Pe = /^\s+/, xe = /\s/, Mt = /\{(?:\n\/\* \[wrapped with .+\] \*\/)?\n?/, Zt = /\{\n\/\* \[wrapped with (.+)\] \*/, Jt = /,? & /, xr = /[^\x00-\x2f\x3a-\x40\x5b-\x60\x7b-\x7f]+/g, Un = /[()=,{}\[\]\/\s]/, pi = /\\(\\)?/g, Cr = /\$\{([^\\}]*(?:\\.[^\\}]*)*)\}/g, ti = /\w*$/, Si = /^[-+]0x[0-9a-f]+$/i, yi = /^0b[01]+$/i, vt = /^\[object .+?Constructor\]$/, ue = /^0o[0-7]+$/i, Q = /^(?:0|[1-9]\d*)$/, ye = /[\xc0-\xd6\xd8-\xf6\xf8-\xff\u0100-\u017f]/g, ct = /($^)/, en = /['\n\r\u2028\u2029\\]/g, Rn = "\\ud800-\\udfff", Nr = "\\u0300-\\u036f", mi = "\\ufe20-\\ufe2f", ha = "\\u20d0-\\u20ff", Er = Nr + mi + ha, ds = "\\u2700-\\u27bf", Js = "a-z\\xdf-\\xf6\\xf8-\\xff", Zd = "\\xac\\xb1\\xd7\\xf7", Jd = "\\x00-\\x2f\\x3a-\\x40\\x5b-\\x60\\x7b-\\xbf", Kl = "\\u2000-\\u206f", Ym = " \\t\\x0b\\f\\xa0\\ufeff\\n\\r\\u2028\\u2029\\u1680\\u180e\\u2000\\u2001\\u2002\\u2003\\u2004\\u2005\\u2006\\u2007\\u2008\\u2009\\u200a\\u202f\\u205f\\u3000", jl = "A-Z\\xc0-\\xd6\\xd8-\\xde", ef = "\\ufe0e\\ufe0f", tf = Zd + Jd + Kl + Ym, el = "['’]", Hm = "[" + Rn + "]", tl = "[" + tf + "]", io = "[" + Er + "]", nf = "\\d+", zm = "[" + ds + "]", oc = "[" + Js + "]", Ql = "[^" + Rn + tf + nf + ds + Js + jl + "]", No = "\\ud83c[\\udffb-\\udfff]", sc = "(?:" + io + "|" + No + ")", Xl = "[^" + Rn + "]", Zl = "(?:\\ud83c[\\udde6-\\uddff]){2}", Jl = "[\\ud800-\\udbff][\\udc00-\\udfff]", Do = "[" + jl + "]", lc = "\\u200d", uc = "(?:" + oc + "|" + Ql + ")", eu = "(?:" + Do + "|" + Ql + ")", nl = "(?:" + el + "(?:d|ll|m|re|s|t|ve))?", rl = "(?:" + el + "(?:D|LL|M|RE|S|T|VE))?", tu = sc + "?", nu = "[" + ef + "]?", cc = "(?:" + lc + "(?:" + [Xl, Zl, Jl].join("|") + ")" + nu + tu + ")*", il = "\\d*(?:1st|2nd|3rd|(?![123])\\dth)(?=\\b|[A-Z_])", ru = "\\d*(?:1ST|2ND|3RD|(?![123])\\dTH)(?=\\b|[a-z_])", iu = nu + tu + cc, al = "(?:" + [zm, Zl, Jl].join("|") + ")" + iu, dc = "(?:" + [Xl + io + "?", io, Zl, Jl, Hm].join("|") + ")", Vm = RegExp(el, "g"), au = RegExp(io, "g"), rf = RegExp(No + "(?=" + No + ")|" + dc + iu, "g"), Wm = RegExp([
      Do + "?" + oc + "+" + nl + "(?=" + [tl, Do, "$"].join("|") + ")",
      eu + "+" + rl + "(?=" + [tl, Do + uc, "$"].join("|") + ")",
      Do + "?" + uc + "+" + nl,
      Do + "+" + rl,
      ru,
      il,
      nf,
      al
    ].join("|"), "g"), Le = RegExp("[" + lc + Rn + Er + ef + "]"), it = /[a-z][A-Z]|[A-Z]{2}[a-z]|[0-9][a-zA-Z]|[a-zA-Z][0-9]|[^a-zA-Z0-9 ]/, qt = [
      "Array",
      "Buffer",
      "DataView",
      "Date",
      "Error",
      "Float32Array",
      "Float64Array",
      "Function",
      "Int8Array",
      "Int16Array",
      "Int32Array",
      "Map",
      "Math",
      "Object",
      "Promise",
      "RegExp",
      "Set",
      "String",
      "Symbol",
      "TypeError",
      "Uint8Array",
      "Uint8ClampedArray",
      "Uint16Array",
      "Uint32Array",
      "WeakMap",
      "_",
      "clearTimeout",
      "isFinite",
      "parseInt",
      "setTimeout"
    ], Pn = -1, _n = {};
    _n[yt] = _n[Rt] = _n[sn] = _n[me] = _n[He] = _n[tt] = _n[ot] = _n[xn] = _n[kt] = !0, _n[oe] = _n[ae] = _n[we] = _n[Se] = _n[je] = _n[Re] = _n[nt] = _n[ut] = _n[Ot] = _n[Xt] = _n[st] = _n[Je] = _n[Be] = _n[pt] = _n[_t] = !1;
    var jt = {};
    jt[oe] = jt[ae] = jt[we] = jt[je] = jt[Se] = jt[Re] = jt[yt] = jt[Rt] = jt[sn] = jt[me] = jt[He] = jt[Ot] = jt[Xt] = jt[st] = jt[Je] = jt[Be] = jt[pt] = jt[ft] = jt[tt] = jt[ot] = jt[xn] = jt[kt] = !0, jt[nt] = jt[ut] = jt[_t] = !1;
    var ol = {
      // Latin-1 Supplement block.
      À: "A",
      Á: "A",
      Â: "A",
      Ã: "A",
      Ä: "A",
      Å: "A",
      à: "a",
      á: "a",
      â: "a",
      ã: "a",
      ä: "a",
      å: "a",
      Ç: "C",
      ç: "c",
      Ð: "D",
      ð: "d",
      È: "E",
      É: "E",
      Ê: "E",
      Ë: "E",
      è: "e",
      é: "e",
      ê: "e",
      ë: "e",
      Ì: "I",
      Í: "I",
      Î: "I",
      Ï: "I",
      ì: "i",
      í: "i",
      î: "i",
      ï: "i",
      Ñ: "N",
      ñ: "n",
      Ò: "O",
      Ó: "O",
      Ô: "O",
      Õ: "O",
      Ö: "O",
      Ø: "O",
      ò: "o",
      ó: "o",
      ô: "o",
      õ: "o",
      ö: "o",
      ø: "o",
      Ù: "U",
      Ú: "U",
      Û: "U",
      Ü: "U",
      ù: "u",
      ú: "u",
      û: "u",
      ü: "u",
      Ý: "Y",
      ý: "y",
      ÿ: "y",
      Æ: "Ae",
      æ: "ae",
      Þ: "Th",
      þ: "th",
      ß: "ss",
      // Latin Extended-A block.
      Ā: "A",
      Ă: "A",
      Ą: "A",
      ā: "a",
      ă: "a",
      ą: "a",
      Ć: "C",
      Ĉ: "C",
      Ċ: "C",
      Č: "C",
      ć: "c",
      ĉ: "c",
      ċ: "c",
      č: "c",
      Ď: "D",
      Đ: "D",
      ď: "d",
      đ: "d",
      Ē: "E",
      Ĕ: "E",
      Ė: "E",
      Ę: "E",
      Ě: "E",
      ē: "e",
      ĕ: "e",
      ė: "e",
      ę: "e",
      ě: "e",
      Ĝ: "G",
      Ğ: "G",
      Ġ: "G",
      Ģ: "G",
      ĝ: "g",
      ğ: "g",
      ġ: "g",
      ģ: "g",
      Ĥ: "H",
      Ħ: "H",
      ĥ: "h",
      ħ: "h",
      Ĩ: "I",
      Ī: "I",
      Ĭ: "I",
      Į: "I",
      İ: "I",
      ĩ: "i",
      ī: "i",
      ĭ: "i",
      į: "i",
      ı: "i",
      Ĵ: "J",
      ĵ: "j",
      Ķ: "K",
      ķ: "k",
      ĸ: "k",
      Ĺ: "L",
      Ļ: "L",
      Ľ: "L",
      Ŀ: "L",
      Ł: "L",
      ĺ: "l",
      ļ: "l",
      ľ: "l",
      ŀ: "l",
      ł: "l",
      Ń: "N",
      Ņ: "N",
      Ň: "N",
      Ŋ: "N",
      ń: "n",
      ņ: "n",
      ň: "n",
      ŋ: "n",
      Ō: "O",
      Ŏ: "O",
      Ő: "O",
      ō: "o",
      ŏ: "o",
      ő: "o",
      Ŕ: "R",
      Ŗ: "R",
      Ř: "R",
      ŕ: "r",
      ŗ: "r",
      ř: "r",
      Ś: "S",
      Ŝ: "S",
      Ş: "S",
      Š: "S",
      ś: "s",
      ŝ: "s",
      ş: "s",
      š: "s",
      Ţ: "T",
      Ť: "T",
      Ŧ: "T",
      ţ: "t",
      ť: "t",
      ŧ: "t",
      Ũ: "U",
      Ū: "U",
      Ŭ: "U",
      Ů: "U",
      Ű: "U",
      Ų: "U",
      ũ: "u",
      ū: "u",
      ŭ: "u",
      ů: "u",
      ű: "u",
      ų: "u",
      Ŵ: "W",
      ŵ: "w",
      Ŷ: "Y",
      ŷ: "y",
      Ÿ: "Y",
      Ź: "Z",
      Ż: "Z",
      Ž: "Z",
      ź: "z",
      ż: "z",
      ž: "z",
      Ĳ: "IJ",
      ĳ: "ij",
      Œ: "Oe",
      œ: "oe",
      ŉ: "'n",
      ſ: "s"
    }, Zv = {
      "&": "&amp;",
      "<": "&lt;",
      ">": "&gt;",
      '"': "&quot;",
      "'": "&#39;"
    }, Km = {
      "&amp;": "&",
      "&lt;": "<",
      "&gt;": ">",
      "&quot;": '"',
      "&#39;": "'"
    }, ao = {
      "\\": "\\",
      "'": "'",
      "\n": "n",
      "\r": "r",
      "\u2028": "u2028",
      "\u2029": "u2029"
    }, fc = parseFloat, y9 = parseInt, kR = typeof Pc == "object" && Pc && Pc.Object === Object && Pc, T9 = typeof self == "object" && self && self.Object === Object && self, hi = kR || T9 || Function("return this")(), Jv = t && !t.nodeType && t, ou = Jv && !0 && e && !e.nodeType && e, MR = ou && ou.exports === Jv, eb = MR && kR.process, Pa = function() {
      try {
        var fe = ou && ou.require && ou.require("util").types;
        return fe || eb && eb.binding && eb.binding("util");
      } catch {
      }
    }(), PR = Pa && Pa.isArrayBuffer, FR = Pa && Pa.isDate, BR = Pa && Pa.isMap, $R = Pa && Pa.isRegExp, UR = Pa && Pa.isSet, qR = Pa && Pa.isTypedArray;
    function ga(fe, Ne, Ce) {
      switch (Ce.length) {
        case 0:
          return fe.call(Ne);
        case 1:
          return fe.call(Ne, Ce[0]);
        case 2:
          return fe.call(Ne, Ce[0], Ce[1]);
        case 3:
          return fe.call(Ne, Ce[0], Ce[1], Ce[2]);
      }
      return fe.apply(Ne, Ce);
    }
    function C9(fe, Ne, Ce, bt) {
      for (var tn = -1, Fn = fe == null ? 0 : fe.length; ++tn < Fn; ) {
        var ni = fe[tn];
        Ne(bt, ni, Ce(ni), fe);
      }
      return bt;
    }
    function Fa(fe, Ne) {
      for (var Ce = -1, bt = fe == null ? 0 : fe.length; ++Ce < bt && Ne(fe[Ce], Ce, fe) !== !1; )
        ;
      return fe;
    }
    function A9(fe, Ne) {
      for (var Ce = fe == null ? 0 : fe.length; Ce-- && Ne(fe[Ce], Ce, fe) !== !1; )
        ;
      return fe;
    }
    function GR(fe, Ne) {
      for (var Ce = -1, bt = fe == null ? 0 : fe.length; ++Ce < bt; )
        if (!Ne(fe[Ce], Ce, fe))
          return !1;
      return !0;
    }
    function sl(fe, Ne) {
      for (var Ce = -1, bt = fe == null ? 0 : fe.length, tn = 0, Fn = []; ++Ce < bt; ) {
        var ni = fe[Ce];
        Ne(ni, Ce, fe) && (Fn[tn++] = ni);
      }
      return Fn;
    }
    function jm(fe, Ne) {
      var Ce = fe == null ? 0 : fe.length;
      return !!Ce && pc(fe, Ne, 0) > -1;
    }
    function tb(fe, Ne, Ce) {
      for (var bt = -1, tn = fe == null ? 0 : fe.length; ++bt < tn; )
        if (Ce(Ne, fe[bt]))
          return !0;
      return !1;
    }
    function Sr(fe, Ne) {
      for (var Ce = -1, bt = fe == null ? 0 : fe.length, tn = Array(bt); ++Ce < bt; )
        tn[Ce] = Ne(fe[Ce], Ce, fe);
      return tn;
    }
    function ll(fe, Ne) {
      for (var Ce = -1, bt = Ne.length, tn = fe.length; ++Ce < bt; )
        fe[tn + Ce] = Ne[Ce];
      return fe;
    }
    function nb(fe, Ne, Ce, bt) {
      var tn = -1, Fn = fe == null ? 0 : fe.length;
      for (bt && Fn && (Ce = fe[++tn]); ++tn < Fn; )
        Ce = Ne(Ce, fe[tn], tn, fe);
      return Ce;
    }
    function O9(fe, Ne, Ce, bt) {
      var tn = fe == null ? 0 : fe.length;
      for (bt && tn && (Ce = fe[--tn]); tn--; )
        Ce = Ne(Ce, fe[tn], tn, fe);
      return Ce;
    }
    function rb(fe, Ne) {
      for (var Ce = -1, bt = fe == null ? 0 : fe.length; ++Ce < bt; )
        if (Ne(fe[Ce], Ce, fe))
          return !0;
      return !1;
    }
    var R9 = ib("length");
    function w9(fe) {
      return fe.split("");
    }
    function x9(fe) {
      return fe.match(xr) || [];
    }
    function YR(fe, Ne, Ce) {
      var bt;
      return Ce(fe, function(tn, Fn, ni) {
        if (Ne(tn, Fn, ni))
          return bt = Fn, !1;
      }), bt;
    }
    function Qm(fe, Ne, Ce, bt) {
      for (var tn = fe.length, Fn = Ce + (bt ? 1 : -1); bt ? Fn-- : ++Fn < tn; )
        if (Ne(fe[Fn], Fn, fe))
          return Fn;
      return -1;
    }
    function pc(fe, Ne, Ce) {
      return Ne === Ne ? q9(fe, Ne, Ce) : Qm(fe, HR, Ce);
    }
    function N9(fe, Ne, Ce, bt) {
      for (var tn = Ce - 1, Fn = fe.length; ++tn < Fn; )
        if (bt(fe[tn], Ne))
          return tn;
      return -1;
    }
    function HR(fe) {
      return fe !== fe;
    }
    function zR(fe, Ne) {
      var Ce = fe == null ? 0 : fe.length;
      return Ce ? ob(fe, Ne) / Ce : Z;
    }
    function ib(fe) {
      return function(Ne) {
        return Ne == null ? n : Ne[fe];
      };
    }
    function ab(fe) {
      return function(Ne) {
        return fe == null ? n : fe[Ne];
      };
    }
    function VR(fe, Ne, Ce, bt, tn) {
      return tn(fe, function(Fn, ni, Kn) {
        Ce = bt ? (bt = !1, Fn) : Ne(Ce, Fn, ni, Kn);
      }), Ce;
    }
    function D9(fe, Ne) {
      var Ce = fe.length;
      for (fe.sort(Ne); Ce--; )
        fe[Ce] = fe[Ce].value;
      return fe;
    }
    function ob(fe, Ne) {
      for (var Ce, bt = -1, tn = fe.length; ++bt < tn; ) {
        var Fn = Ne(fe[bt]);
        Fn !== n && (Ce = Ce === n ? Fn : Ce + Fn);
      }
      return Ce;
    }
    function sb(fe, Ne) {
      for (var Ce = -1, bt = Array(fe); ++Ce < fe; )
        bt[Ce] = Ne(Ce);
      return bt;
    }
    function I9(fe, Ne) {
      return Sr(Ne, function(Ce) {
        return [Ce, fe[Ce]];
      });
    }
    function WR(fe) {
      return fe && fe.slice(0, XR(fe) + 1).replace(Pe, "");
    }
    function _a(fe) {
      return function(Ne) {
        return fe(Ne);
      };
    }
    function lb(fe, Ne) {
      return Sr(Ne, function(Ce) {
        return fe[Ce];
      });
    }
    function af(fe, Ne) {
      return fe.has(Ne);
    }
    function KR(fe, Ne) {
      for (var Ce = -1, bt = fe.length; ++Ce < bt && pc(Ne, fe[Ce], 0) > -1; )
        ;
      return Ce;
    }
    function jR(fe, Ne) {
      for (var Ce = fe.length; Ce-- && pc(Ne, fe[Ce], 0) > -1; )
        ;
      return Ce;
    }
    function L9(fe, Ne) {
      for (var Ce = fe.length, bt = 0; Ce--; )
        fe[Ce] === Ne && ++bt;
      return bt;
    }
    var k9 = ab(ol), M9 = ab(Zv);
    function P9(fe) {
      return "\\" + ao[fe];
    }
    function F9(fe, Ne) {
      return fe == null ? n : fe[Ne];
    }
    function mc(fe) {
      return Le.test(fe);
    }
    function B9(fe) {
      return it.test(fe);
    }
    function $9(fe) {
      for (var Ne, Ce = []; !(Ne = fe.next()).done; )
        Ce.push(Ne.value);
      return Ce;
    }
    function ub(fe) {
      var Ne = -1, Ce = Array(fe.size);
      return fe.forEach(function(bt, tn) {
        Ce[++Ne] = [tn, bt];
      }), Ce;
    }
    function QR(fe, Ne) {
      return function(Ce) {
        return fe(Ne(Ce));
      };
    }
    function ul(fe, Ne) {
      for (var Ce = -1, bt = fe.length, tn = 0, Fn = []; ++Ce < bt; ) {
        var ni = fe[Ce];
        (ni === Ne || ni === c) && (fe[Ce] = c, Fn[tn++] = Ce);
      }
      return Fn;
    }
    function Xm(fe) {
      var Ne = -1, Ce = Array(fe.size);
      return fe.forEach(function(bt) {
        Ce[++Ne] = bt;
      }), Ce;
    }
    function U9(fe) {
      var Ne = -1, Ce = Array(fe.size);
      return fe.forEach(function(bt) {
        Ce[++Ne] = [bt, bt];
      }), Ce;
    }
    function q9(fe, Ne, Ce) {
      for (var bt = Ce - 1, tn = fe.length; ++bt < tn; )
        if (fe[bt] === Ne)
          return bt;
      return -1;
    }
    function G9(fe, Ne, Ce) {
      for (var bt = Ce + 1; bt--; )
        if (fe[bt] === Ne)
          return bt;
      return bt;
    }
    function hc(fe) {
      return mc(fe) ? H9(fe) : R9(fe);
    }
    function oo(fe) {
      return mc(fe) ? z9(fe) : w9(fe);
    }
    function XR(fe) {
      for (var Ne = fe.length; Ne-- && xe.test(fe.charAt(Ne)); )
        ;
      return Ne;
    }
    var Y9 = ab(Km);
    function H9(fe) {
      for (var Ne = rf.lastIndex = 0; rf.test(fe); )
        ++Ne;
      return Ne;
    }
    function z9(fe) {
      return fe.match(rf) || [];
    }
    function V9(fe) {
      return fe.match(Wm) || [];
    }
    var W9 = function fe(Ne) {
      Ne = Ne == null ? hi : gc.defaults(hi.Object(), Ne, gc.pick(hi, qt));
      var Ce = Ne.Array, bt = Ne.Date, tn = Ne.Error, Fn = Ne.Function, ni = Ne.Math, Kn = Ne.Object, cb = Ne.RegExp, K9 = Ne.String, Ba = Ne.TypeError, Zm = Ce.prototype, j9 = Fn.prototype, _c = Kn.prototype, Jm = Ne["__core-js_shared__"], eh = j9.toString, Yn = _c.hasOwnProperty, Q9 = 0, ZR = function() {
        var p = /[^.]+$/.exec(Jm && Jm.keys && Jm.keys.IE_PROTO || "");
        return p ? "Symbol(src)_1." + p : "";
      }(), th = _c.toString, X9 = eh.call(Kn), Z9 = hi._, J9 = cb(
        "^" + eh.call(Yn).replace(Ve, "\\$&").replace(/hasOwnProperty|(function).*?(?=\\\()| for .+?(?=\\\])/g, "$1.*?") + "$"
      ), nh = MR ? Ne.Buffer : n, cl = Ne.Symbol, rh = Ne.Uint8Array, JR = nh ? nh.allocUnsafe : n, ih = QR(Kn.getPrototypeOf, Kn), ew = Kn.create, tw = _c.propertyIsEnumerable, ah = Zm.splice, nw = cl ? cl.isConcatSpreadable : n, of = cl ? cl.iterator : n, su = cl ? cl.toStringTag : n, oh = function() {
        try {
          var p = fu(Kn, "defineProperty");
          return p({}, "", {}), p;
        } catch {
        }
      }(), eG = Ne.clearTimeout !== hi.clearTimeout && Ne.clearTimeout, tG = bt && bt.now !== hi.Date.now && bt.now, nG = Ne.setTimeout !== hi.setTimeout && Ne.setTimeout, sh = ni.ceil, lh = ni.floor, db = Kn.getOwnPropertySymbols, rG = nh ? nh.isBuffer : n, rw = Ne.isFinite, iG = Zm.join, aG = QR(Kn.keys, Kn), ri = ni.max, Ti = ni.min, oG = bt.now, sG = Ne.parseInt, iw = ni.random, lG = Zm.reverse, fb = fu(Ne, "DataView"), sf = fu(Ne, "Map"), pb = fu(Ne, "Promise"), vc = fu(Ne, "Set"), lf = fu(Ne, "WeakMap"), uf = fu(Kn, "create"), uh = lf && new lf(), bc = {}, uG = pu(fb), cG = pu(sf), dG = pu(pb), fG = pu(vc), pG = pu(lf), ch = cl ? cl.prototype : n, cf = ch ? ch.valueOf : n, aw = ch ? ch.toString : n;
      function H(p) {
        if (Dr(p) && !an(p) && !(p instanceof Sn)) {
          if (p instanceof $a)
            return p;
          if (Yn.call(p, "__wrapped__"))
            return ox(p);
        }
        return new $a(p);
      }
      var Ec = /* @__PURE__ */ function() {
        function p() {
        }
        return function(_) {
          if (!Ar(_))
            return {};
          if (ew)
            return ew(_);
          p.prototype = _;
          var A = new p();
          return p.prototype = n, A;
        };
      }();
      function dh() {
      }
      function $a(p, _) {
        this.__wrapped__ = p, this.__actions__ = [], this.__chain__ = !!_, this.__index__ = 0, this.__values__ = n;
      }
      H.templateSettings = {
        /**
         * Used to detect `data` property values to be HTML-escaped.
         *
         * @memberOf _.templateSettings
         * @type {RegExp}
         */
        escape: G,
        /**
         * Used to detect code to be evaluated.
         *
         * @memberOf _.templateSettings
         * @type {RegExp}
         */
        evaluate: j,
        /**
         * Used to detect `data` property values to inject.
         *
         * @memberOf _.templateSettings
         * @type {RegExp}
         */
        interpolate: ce,
        /**
         * Used to reference the data object in the template text.
         *
         * @memberOf _.templateSettings
         * @type {string}
         */
        variable: "",
        /**
         * Used to import variables into the compiled template.
         *
         * @memberOf _.templateSettings
         * @type {Object}
         */
        imports: {
          /**
           * A reference to the `lodash` function.
           *
           * @memberOf _.templateSettings.imports
           * @type {Function}
           */
          _: H
        }
      }, H.prototype = dh.prototype, H.prototype.constructor = H, $a.prototype = Ec(dh.prototype), $a.prototype.constructor = $a;
      function Sn(p) {
        this.__wrapped__ = p, this.__actions__ = [], this.__dir__ = 1, this.__filtered__ = !1, this.__iteratees__ = [], this.__takeCount__ = V, this.__views__ = [];
      }
      function mG() {
        var p = new Sn(this.__wrapped__);
        return p.__actions__ = Xi(this.__actions__), p.__dir__ = this.__dir__, p.__filtered__ = this.__filtered__, p.__iteratees__ = Xi(this.__iteratees__), p.__takeCount__ = this.__takeCount__, p.__views__ = Xi(this.__views__), p;
      }
      function hG() {
        if (this.__filtered__) {
          var p = new Sn(this);
          p.__dir__ = -1, p.__filtered__ = !0;
        } else
          p = this.clone(), p.__dir__ *= -1;
        return p;
      }
      function gG() {
        var p = this.__wrapped__.value(), _ = this.__dir__, A = an(p), w = _ < 0, F = A ? p.length : 0, z = wY(0, F, this.__views__), J = z.start, ie = z.end, ge = ie - J, ke = w ? ie : J - 1, Fe = this.__iteratees__, qe = Fe.length, lt = 0, Ct = Ti(ge, this.__takeCount__);
        if (!A || !w && F == ge && Ct == ge)
          return xw(p, this.__actions__);
        var Yt = [];
        e:
          for (; ge-- && lt < Ct; ) {
            ke += _;
            for (var fn = -1, Ht = p[ke]; ++fn < qe; ) {
              var vn = Fe[fn], Tn = vn.iteratee, Ea = vn.type, $i = Tn(Ht);
              if (Ea == x)
                Ht = $i;
              else if (!$i) {
                if (Ea == L)
                  continue e;
                break e;
              }
            }
            Yt[lt++] = Ht;
          }
        return Yt;
      }
      Sn.prototype = Ec(dh.prototype), Sn.prototype.constructor = Sn;
      function lu(p) {
        var _ = -1, A = p == null ? 0 : p.length;
        for (this.clear(); ++_ < A; ) {
          var w = p[_];
          this.set(w[0], w[1]);
        }
      }
      function _G() {
        this.__data__ = uf ? uf(null) : {}, this.size = 0;
      }
      function vG(p) {
        var _ = this.has(p) && delete this.__data__[p];
        return this.size -= _ ? 1 : 0, _;
      }
      function bG(p) {
        var _ = this.__data__;
        if (uf) {
          var A = _[p];
          return A === l ? n : A;
        }
        return Yn.call(_, p) ? _[p] : n;
      }
      function EG(p) {
        var _ = this.__data__;
        return uf ? _[p] !== n : Yn.call(_, p);
      }
      function SG(p, _) {
        var A = this.__data__;
        return this.size += this.has(p) ? 0 : 1, A[p] = uf && _ === n ? l : _, this;
      }
      lu.prototype.clear = _G, lu.prototype.delete = vG, lu.prototype.get = bG, lu.prototype.has = EG, lu.prototype.set = SG;
      function fs(p) {
        var _ = -1, A = p == null ? 0 : p.length;
        for (this.clear(); ++_ < A; ) {
          var w = p[_];
          this.set(w[0], w[1]);
        }
      }
      function yG() {
        this.__data__ = [], this.size = 0;
      }
      function TG(p) {
        var _ = this.__data__, A = fh(_, p);
        if (A < 0)
          return !1;
        var w = _.length - 1;
        return A == w ? _.pop() : ah.call(_, A, 1), --this.size, !0;
      }
      function CG(p) {
        var _ = this.__data__, A = fh(_, p);
        return A < 0 ? n : _[A][1];
      }
      function AG(p) {
        return fh(this.__data__, p) > -1;
      }
      function OG(p, _) {
        var A = this.__data__, w = fh(A, p);
        return w < 0 ? (++this.size, A.push([p, _])) : A[w][1] = _, this;
      }
      fs.prototype.clear = yG, fs.prototype.delete = TG, fs.prototype.get = CG, fs.prototype.has = AG, fs.prototype.set = OG;
      function ps(p) {
        var _ = -1, A = p == null ? 0 : p.length;
        for (this.clear(); ++_ < A; ) {
          var w = p[_];
          this.set(w[0], w[1]);
        }
      }
      function RG() {
        this.size = 0, this.__data__ = {
          hash: new lu(),
          map: new (sf || fs)(),
          string: new lu()
        };
      }
      function wG(p) {
        var _ = Ch(this, p).delete(p);
        return this.size -= _ ? 1 : 0, _;
      }
      function xG(p) {
        return Ch(this, p).get(p);
      }
      function NG(p) {
        return Ch(this, p).has(p);
      }
      function DG(p, _) {
        var A = Ch(this, p), w = A.size;
        return A.set(p, _), this.size += A.size == w ? 0 : 1, this;
      }
      ps.prototype.clear = RG, ps.prototype.delete = wG, ps.prototype.get = xG, ps.prototype.has = NG, ps.prototype.set = DG;
      function uu(p) {
        var _ = -1, A = p == null ? 0 : p.length;
        for (this.__data__ = new ps(); ++_ < A; )
          this.add(p[_]);
      }
      function IG(p) {
        return this.__data__.set(p, l), this;
      }
      function LG(p) {
        return this.__data__.has(p);
      }
      uu.prototype.add = uu.prototype.push = IG, uu.prototype.has = LG;
      function so(p) {
        var _ = this.__data__ = new fs(p);
        this.size = _.size;
      }
      function kG() {
        this.__data__ = new fs(), this.size = 0;
      }
      function MG(p) {
        var _ = this.__data__, A = _.delete(p);
        return this.size = _.size, A;
      }
      function PG(p) {
        return this.__data__.get(p);
      }
      function FG(p) {
        return this.__data__.has(p);
      }
      function BG(p, _) {
        var A = this.__data__;
        if (A instanceof fs) {
          var w = A.__data__;
          if (!sf || w.length < i - 1)
            return w.push([p, _]), this.size = ++A.size, this;
          A = this.__data__ = new ps(w);
        }
        return A.set(p, _), this.size = A.size, this;
      }
      so.prototype.clear = kG, so.prototype.delete = MG, so.prototype.get = PG, so.prototype.has = FG, so.prototype.set = BG;
      function ow(p, _) {
        var A = an(p), w = !A && mu(p), F = !A && !w && hl(p), z = !A && !w && !F && Cc(p), J = A || w || F || z, ie = J ? sb(p.length, K9) : [], ge = ie.length;
        for (var ke in p)
          (_ || Yn.call(p, ke)) && !(J && // Safari 9 has enumerable `arguments.length` in strict mode.
          (ke == "length" || // Node.js 0.10 has enumerable non-index properties on buffers.
          F && (ke == "offset" || ke == "parent") || // PhantomJS 2 has enumerable non-index properties on typed arrays.
          z && (ke == "buffer" || ke == "byteLength" || ke == "byteOffset") || // Skip index properties.
          _s(ke, ge))) && ie.push(ke);
        return ie;
      }
      function sw(p) {
        var _ = p.length;
        return _ ? p[Cb(0, _ - 1)] : n;
      }
      function $G(p, _) {
        return Ah(Xi(p), cu(_, 0, p.length));
      }
      function UG(p) {
        return Ah(Xi(p));
      }
      function mb(p, _, A) {
        (A !== n && !lo(p[_], A) || A === n && !(_ in p)) && ms(p, _, A);
      }
      function df(p, _, A) {
        var w = p[_];
        (!(Yn.call(p, _) && lo(w, A)) || A === n && !(_ in p)) && ms(p, _, A);
      }
      function fh(p, _) {
        for (var A = p.length; A--; )
          if (lo(p[A][0], _))
            return A;
        return -1;
      }
      function qG(p, _, A, w) {
        return dl(p, function(F, z, J) {
          _(w, F, A(F), J);
        }), w;
      }
      function lw(p, _) {
        return p && Lo(_, ui(_), p);
      }
      function GG(p, _) {
        return p && Lo(_, Ji(_), p);
      }
      function ms(p, _, A) {
        _ == "__proto__" && oh ? oh(p, _, {
          configurable: !0,
          enumerable: !0,
          value: A,
          writable: !0
        }) : p[_] = A;
      }
      function hb(p, _) {
        for (var A = -1, w = _.length, F = Ce(w), z = p == null; ++A < w; )
          F[A] = z ? n : jb(p, _[A]);
        return F;
      }
      function cu(p, _, A) {
        return p === p && (A !== n && (p = p <= A ? p : A), _ !== n && (p = p >= _ ? p : _)), p;
      }
      function Ua(p, _, A, w, F, z) {
        var J, ie = _ & d, ge = _ & f, ke = _ & h;
        if (A && (J = F ? A(p, w, F, z) : A(p)), J !== n)
          return J;
        if (!Ar(p))
          return p;
        var Fe = an(p);
        if (Fe) {
          if (J = NY(p), !ie)
            return Xi(p, J);
        } else {
          var qe = Ci(p), lt = qe == ut || qe == Tt;
          if (hl(p))
            return Iw(p, ie);
          if (qe == st || qe == oe || lt && !F) {
            if (J = ge || lt ? {} : Xw(p), !ie)
              return ge ? bY(p, GG(J, p)) : vY(p, lw(J, p));
          } else {
            if (!jt[qe])
              return F ? p : {};
            J = DY(p, qe, ie);
          }
        }
        z || (z = new so());
        var Ct = z.get(p);
        if (Ct)
          return Ct;
        z.set(p, J), Ox(p) ? p.forEach(function(Ht) {
          J.add(Ua(Ht, _, A, Ht, p, z));
        }) : Cx(p) && p.forEach(function(Ht, vn) {
          J.set(vn, Ua(Ht, _, A, vn, p, z));
        });
        var Yt = ke ? ge ? Mb : kb : ge ? Ji : ui, fn = Fe ? n : Yt(p);
        return Fa(fn || p, function(Ht, vn) {
          fn && (vn = Ht, Ht = p[vn]), df(J, vn, Ua(Ht, _, A, vn, p, z));
        }), J;
      }
      function YG(p) {
        var _ = ui(p);
        return function(A) {
          return uw(A, p, _);
        };
      }
      function uw(p, _, A) {
        var w = A.length;
        if (p == null)
          return !w;
        for (p = Kn(p); w--; ) {
          var F = A[w], z = _[F], J = p[F];
          if (J === n && !(F in p) || !z(J))
            return !1;
        }
        return !0;
      }
      function cw(p, _, A) {
        if (typeof p != "function")
          throw new Ba(o);
        return vf(function() {
          p.apply(n, A);
        }, _);
      }
      function ff(p, _, A, w) {
        var F = -1, z = jm, J = !0, ie = p.length, ge = [], ke = _.length;
        if (!ie)
          return ge;
        A && (_ = Sr(_, _a(A))), w ? (z = tb, J = !1) : _.length >= i && (z = af, J = !1, _ = new uu(_));
        e:
          for (; ++F < ie; ) {
            var Fe = p[F], qe = A == null ? Fe : A(Fe);
            if (Fe = w || Fe !== 0 ? Fe : 0, J && qe === qe) {
              for (var lt = ke; lt--; )
                if (_[lt] === qe)
                  continue e;
              ge.push(Fe);
            } else z(_, qe, w) || ge.push(Fe);
          }
        return ge;
      }
      var dl = Fw(Io), dw = Fw(_b, !0);
      function HG(p, _) {
        var A = !0;
        return dl(p, function(w, F, z) {
          return A = !!_(w, F, z), A;
        }), A;
      }
      function ph(p, _, A) {
        for (var w = -1, F = p.length; ++w < F; ) {
          var z = p[w], J = _(z);
          if (J != null && (ie === n ? J === J && !ba(J) : A(J, ie)))
            var ie = J, ge = z;
        }
        return ge;
      }
      function zG(p, _, A, w) {
        var F = p.length;
        for (A = un(A), A < 0 && (A = -A > F ? 0 : F + A), w = w === n || w > F ? F : un(w), w < 0 && (w += F), w = A > w ? 0 : wx(w); A < w; )
          p[A++] = _;
        return p;
      }
      function fw(p, _) {
        var A = [];
        return dl(p, function(w, F, z) {
          _(w, F, z) && A.push(w);
        }), A;
      }
      function gi(p, _, A, w, F) {
        var z = -1, J = p.length;
        for (A || (A = LY), F || (F = []); ++z < J; ) {
          var ie = p[z];
          _ > 0 && A(ie) ? _ > 1 ? gi(ie, _ - 1, A, w, F) : ll(F, ie) : w || (F[F.length] = ie);
        }
        return F;
      }
      var gb = Bw(), pw = Bw(!0);
      function Io(p, _) {
        return p && gb(p, _, ui);
      }
      function _b(p, _) {
        return p && pw(p, _, ui);
      }
      function mh(p, _) {
        return sl(_, function(A) {
          return vs(p[A]);
        });
      }
      function du(p, _) {
        _ = pl(_, p);
        for (var A = 0, w = _.length; p != null && A < w; )
          p = p[ko(_[A++])];
        return A && A == w ? p : n;
      }
      function mw(p, _, A) {
        var w = _(p);
        return an(p) ? w : ll(w, A(p));
      }
      function Fi(p) {
        return p == null ? p === n ? Ze : We : su && su in Kn(p) ? RY(p) : UY(p);
      }
      function vb(p, _) {
        return p > _;
      }
      function VG(p, _) {
        return p != null && Yn.call(p, _);
      }
      function WG(p, _) {
        return p != null && _ in Kn(p);
      }
      function KG(p, _, A) {
        return p >= Ti(_, A) && p < ri(_, A);
      }
      function bb(p, _, A) {
        for (var w = A ? tb : jm, F = p[0].length, z = p.length, J = z, ie = Ce(z), ge = 1 / 0, ke = []; J--; ) {
          var Fe = p[J];
          J && _ && (Fe = Sr(Fe, _a(_))), ge = Ti(Fe.length, ge), ie[J] = !A && (_ || F >= 120 && Fe.length >= 120) ? new uu(J && Fe) : n;
        }
        Fe = p[0];
        var qe = -1, lt = ie[0];
        e:
          for (; ++qe < F && ke.length < ge; ) {
            var Ct = Fe[qe], Yt = _ ? _(Ct) : Ct;
            if (Ct = A || Ct !== 0 ? Ct : 0, !(lt ? af(lt, Yt) : w(ke, Yt, A))) {
              for (J = z; --J; ) {
                var fn = ie[J];
                if (!(fn ? af(fn, Yt) : w(p[J], Yt, A)))
                  continue e;
              }
              lt && lt.push(Yt), ke.push(Ct);
            }
          }
        return ke;
      }
      function jG(p, _, A, w) {
        return Io(p, function(F, z, J) {
          _(w, A(F), z, J);
        }), w;
      }
      function pf(p, _, A) {
        _ = pl(_, p), p = tx(p, _);
        var w = p == null ? p : p[ko(Ga(_))];
        return w == null ? n : ga(w, p, A);
      }
      function hw(p) {
        return Dr(p) && Fi(p) == oe;
      }
      function QG(p) {
        return Dr(p) && Fi(p) == we;
      }
      function XG(p) {
        return Dr(p) && Fi(p) == Re;
      }
      function mf(p, _, A, w, F) {
        return p === _ ? !0 : p == null || _ == null || !Dr(p) && !Dr(_) ? p !== p && _ !== _ : ZG(p, _, A, w, mf, F);
      }
      function ZG(p, _, A, w, F, z) {
        var J = an(p), ie = an(_), ge = J ? ae : Ci(p), ke = ie ? ae : Ci(_);
        ge = ge == oe ? st : ge, ke = ke == oe ? st : ke;
        var Fe = ge == st, qe = ke == st, lt = ge == ke;
        if (lt && hl(p)) {
          if (!hl(_))
            return !1;
          J = !0, Fe = !1;
        }
        if (lt && !Fe)
          return z || (z = new so()), J || Cc(p) ? Kw(p, _, A, w, F, z) : AY(p, _, ge, A, w, F, z);
        if (!(A & m)) {
          var Ct = Fe && Yn.call(p, "__wrapped__"), Yt = qe && Yn.call(_, "__wrapped__");
          if (Ct || Yt) {
            var fn = Ct ? p.value() : p, Ht = Yt ? _.value() : _;
            return z || (z = new so()), F(fn, Ht, A, w, z);
          }
        }
        return lt ? (z || (z = new so()), OY(p, _, A, w, F, z)) : !1;
      }
      function JG(p) {
        return Dr(p) && Ci(p) == Ot;
      }
      function Eb(p, _, A, w) {
        var F = A.length, z = F, J = !w;
        if (p == null)
          return !z;
        for (p = Kn(p); F--; ) {
          var ie = A[F];
          if (J && ie[2] ? ie[1] !== p[ie[0]] : !(ie[0] in p))
            return !1;
        }
        for (; ++F < z; ) {
          ie = A[F];
          var ge = ie[0], ke = p[ge], Fe = ie[1];
          if (J && ie[2]) {
            if (ke === n && !(ge in p))
              return !1;
          } else {
            var qe = new so();
            if (w)
              var lt = w(ke, Fe, ge, p, _, qe);
            if (!(lt === n ? mf(Fe, ke, m | v, w, qe) : lt))
              return !1;
          }
        }
        return !0;
      }
      function gw(p) {
        if (!Ar(p) || MY(p))
          return !1;
        var _ = vs(p) ? J9 : vt;
        return _.test(pu(p));
      }
      function eY(p) {
        return Dr(p) && Fi(p) == Je;
      }
      function tY(p) {
        return Dr(p) && Ci(p) == Be;
      }
      function nY(p) {
        return Dr(p) && Dh(p.length) && !!_n[Fi(p)];
      }
      function _w(p) {
        return typeof p == "function" ? p : p == null ? ea : typeof p == "object" ? an(p) ? Ew(p[0], p[1]) : bw(p) : $x(p);
      }
      function Sb(p) {
        if (!_f(p))
          return aG(p);
        var _ = [];
        for (var A in Kn(p))
          Yn.call(p, A) && A != "constructor" && _.push(A);
        return _;
      }
      function rY(p) {
        if (!Ar(p))
          return $Y(p);
        var _ = _f(p), A = [];
        for (var w in p)
          w == "constructor" && (_ || !Yn.call(p, w)) || A.push(w);
        return A;
      }
      function yb(p, _) {
        return p < _;
      }
      function vw(p, _) {
        var A = -1, w = Zi(p) ? Ce(p.length) : [];
        return dl(p, function(F, z, J) {
          w[++A] = _(F, z, J);
        }), w;
      }
      function bw(p) {
        var _ = Fb(p);
        return _.length == 1 && _[0][2] ? Jw(_[0][0], _[0][1]) : function(A) {
          return A === p || Eb(A, p, _);
        };
      }
      function Ew(p, _) {
        return $b(p) && Zw(_) ? Jw(ko(p), _) : function(A) {
          var w = jb(A, p);
          return w === n && w === _ ? Qb(A, p) : mf(_, w, m | v);
        };
      }
      function hh(p, _, A, w, F) {
        p !== _ && gb(_, function(z, J) {
          if (F || (F = new so()), Ar(z))
            iY(p, _, J, A, hh, w, F);
          else {
            var ie = w ? w(qb(p, J), z, J + "", p, _, F) : n;
            ie === n && (ie = z), mb(p, J, ie);
          }
        }, Ji);
      }
      function iY(p, _, A, w, F, z, J) {
        var ie = qb(p, A), ge = qb(_, A), ke = J.get(ge);
        if (ke) {
          mb(p, A, ke);
          return;
        }
        var Fe = z ? z(ie, ge, A + "", p, _, J) : n, qe = Fe === n;
        if (qe) {
          var lt = an(ge), Ct = !lt && hl(ge), Yt = !lt && !Ct && Cc(ge);
          Fe = ge, lt || Ct || Yt ? an(ie) ? Fe = ie : Pr(ie) ? Fe = Xi(ie) : Ct ? (qe = !1, Fe = Iw(ge, !0)) : Yt ? (qe = !1, Fe = Lw(ge, !0)) : Fe = [] : bf(ge) || mu(ge) ? (Fe = ie, mu(ie) ? Fe = xx(ie) : (!Ar(ie) || vs(ie)) && (Fe = Xw(ge))) : qe = !1;
        }
        qe && (J.set(ge, Fe), F(Fe, ge, w, z, J), J.delete(ge)), mb(p, A, Fe);
      }
      function Sw(p, _) {
        var A = p.length;
        if (A)
          return _ += _ < 0 ? A : 0, _s(_, A) ? p[_] : n;
      }
      function yw(p, _, A) {
        _.length ? _ = Sr(_, function(z) {
          return an(z) ? function(J) {
            return du(J, z.length === 1 ? z[0] : z);
          } : z;
        }) : _ = [ea];
        var w = -1;
        _ = Sr(_, _a(Gt()));
        var F = vw(p, function(z, J, ie) {
          var ge = Sr(_, function(ke) {
            return ke(z);
          });
          return { criteria: ge, index: ++w, value: z };
        });
        return D9(F, function(z, J) {
          return _Y(z, J, A);
        });
      }
      function aY(p, _) {
        return Tw(p, _, function(A, w) {
          return Qb(p, w);
        });
      }
      function Tw(p, _, A) {
        for (var w = -1, F = _.length, z = {}; ++w < F; ) {
          var J = _[w], ie = du(p, J);
          A(ie, J) && hf(z, pl(J, p), ie);
        }
        return z;
      }
      function oY(p) {
        return function(_) {
          return du(_, p);
        };
      }
      function Tb(p, _, A, w) {
        var F = w ? N9 : pc, z = -1, J = _.length, ie = p;
        for (p === _ && (_ = Xi(_)), A && (ie = Sr(p, _a(A))); ++z < J; )
          for (var ge = 0, ke = _[z], Fe = A ? A(ke) : ke; (ge = F(ie, Fe, ge, w)) > -1; )
            ie !== p && ah.call(ie, ge, 1), ah.call(p, ge, 1);
        return p;
      }
      function Cw(p, _) {
        for (var A = p ? _.length : 0, w = A - 1; A--; ) {
          var F = _[A];
          if (A == w || F !== z) {
            var z = F;
            _s(F) ? ah.call(p, F, 1) : Rb(p, F);
          }
        }
        return p;
      }
      function Cb(p, _) {
        return p + lh(iw() * (_ - p + 1));
      }
      function sY(p, _, A, w) {
        for (var F = -1, z = ri(sh((_ - p) / (A || 1)), 0), J = Ce(z); z--; )
          J[w ? z : ++F] = p, p += A;
        return J;
      }
      function Ab(p, _) {
        var A = "";
        if (!p || _ < 1 || _ > B)
          return A;
        do
          _ % 2 && (A += p), _ = lh(_ / 2), _ && (p += p);
        while (_);
        return A;
      }
      function mn(p, _) {
        return Gb(ex(p, _, ea), p + "");
      }
      function lY(p) {
        return sw(Ac(p));
      }
      function uY(p, _) {
        var A = Ac(p);
        return Ah(A, cu(_, 0, A.length));
      }
      function hf(p, _, A, w) {
        if (!Ar(p))
          return p;
        _ = pl(_, p);
        for (var F = -1, z = _.length, J = z - 1, ie = p; ie != null && ++F < z; ) {
          var ge = ko(_[F]), ke = A;
          if (ge === "__proto__" || ge === "constructor" || ge === "prototype")
            return p;
          if (F != J) {
            var Fe = ie[ge];
            ke = w ? w(Fe, ge, ie) : n, ke === n && (ke = Ar(Fe) ? Fe : _s(_[F + 1]) ? [] : {});
          }
          df(ie, ge, ke), ie = ie[ge];
        }
        return p;
      }
      var Aw = uh ? function(p, _) {
        return uh.set(p, _), p;
      } : ea, cY = oh ? function(p, _) {
        return oh(p, "toString", {
          configurable: !0,
          enumerable: !1,
          value: Zb(_),
          writable: !0
        });
      } : ea;
      function dY(p) {
        return Ah(Ac(p));
      }
      function qa(p, _, A) {
        var w = -1, F = p.length;
        _ < 0 && (_ = -_ > F ? 0 : F + _), A = A > F ? F : A, A < 0 && (A += F), F = _ > A ? 0 : A - _ >>> 0, _ >>>= 0;
        for (var z = Ce(F); ++w < F; )
          z[w] = p[w + _];
        return z;
      }
      function fY(p, _) {
        var A;
        return dl(p, function(w, F, z) {
          return A = _(w, F, z), !A;
        }), !!A;
      }
      function gh(p, _, A) {
        var w = 0, F = p == null ? w : p.length;
        if (typeof _ == "number" && _ === _ && F <= ne) {
          for (; w < F; ) {
            var z = w + F >>> 1, J = p[z];
            J !== null && !ba(J) && (A ? J <= _ : J < _) ? w = z + 1 : F = z;
          }
          return F;
        }
        return Ob(p, _, ea, A);
      }
      function Ob(p, _, A, w) {
        var F = 0, z = p == null ? 0 : p.length;
        if (z === 0)
          return 0;
        _ = A(_);
        for (var J = _ !== _, ie = _ === null, ge = ba(_), ke = _ === n; F < z; ) {
          var Fe = lh((F + z) / 2), qe = A(p[Fe]), lt = qe !== n, Ct = qe === null, Yt = qe === qe, fn = ba(qe);
          if (J)
            var Ht = w || Yt;
          else ke ? Ht = Yt && (w || lt) : ie ? Ht = Yt && lt && (w || !Ct) : ge ? Ht = Yt && lt && !Ct && (w || !fn) : Ct || fn ? Ht = !1 : Ht = w ? qe <= _ : qe < _;
          Ht ? F = Fe + 1 : z = Fe;
        }
        return Ti(z, K);
      }
      function Ow(p, _) {
        for (var A = -1, w = p.length, F = 0, z = []; ++A < w; ) {
          var J = p[A], ie = _ ? _(J) : J;
          if (!A || !lo(ie, ge)) {
            var ge = ie;
            z[F++] = J === 0 ? 0 : J;
          }
        }
        return z;
      }
      function Rw(p) {
        return typeof p == "number" ? p : ba(p) ? Z : +p;
      }
      function va(p) {
        if (typeof p == "string")
          return p;
        if (an(p))
          return Sr(p, va) + "";
        if (ba(p))
          return aw ? aw.call(p) : "";
        var _ = p + "";
        return _ == "0" && 1 / p == -k ? "-0" : _;
      }
      function fl(p, _, A) {
        var w = -1, F = jm, z = p.length, J = !0, ie = [], ge = ie;
        if (A)
          J = !1, F = tb;
        else if (z >= i) {
          var ke = _ ? null : TY(p);
          if (ke)
            return Xm(ke);
          J = !1, F = af, ge = new uu();
        } else
          ge = _ ? [] : ie;
        e:
          for (; ++w < z; ) {
            var Fe = p[w], qe = _ ? _(Fe) : Fe;
            if (Fe = A || Fe !== 0 ? Fe : 0, J && qe === qe) {
              for (var lt = ge.length; lt--; )
                if (ge[lt] === qe)
                  continue e;
              _ && ge.push(qe), ie.push(Fe);
            } else F(ge, qe, A) || (ge !== ie && ge.push(qe), ie.push(Fe));
          }
        return ie;
      }
      function Rb(p, _) {
        return _ = pl(_, p), p = tx(p, _), p == null || delete p[ko(Ga(_))];
      }
      function ww(p, _, A, w) {
        return hf(p, _, A(du(p, _)), w);
      }
      function _h(p, _, A, w) {
        for (var F = p.length, z = w ? F : -1; (w ? z-- : ++z < F) && _(p[z], z, p); )
          ;
        return A ? qa(p, w ? 0 : z, w ? z + 1 : F) : qa(p, w ? z + 1 : 0, w ? F : z);
      }
      function xw(p, _) {
        var A = p;
        return A instanceof Sn && (A = A.value()), nb(_, function(w, F) {
          return F.func.apply(F.thisArg, ll([w], F.args));
        }, A);
      }
      function wb(p, _, A) {
        var w = p.length;
        if (w < 2)
          return w ? fl(p[0]) : [];
        for (var F = -1, z = Ce(w); ++F < w; )
          for (var J = p[F], ie = -1; ++ie < w; )
            ie != F && (z[F] = ff(z[F] || J, p[ie], _, A));
        return fl(gi(z, 1), _, A);
      }
      function Nw(p, _, A) {
        for (var w = -1, F = p.length, z = _.length, J = {}; ++w < F; ) {
          var ie = w < z ? _[w] : n;
          A(J, p[w], ie);
        }
        return J;
      }
      function xb(p) {
        return Pr(p) ? p : [];
      }
      function Nb(p) {
        return typeof p == "function" ? p : ea;
      }
      function pl(p, _) {
        return an(p) ? p : $b(p, _) ? [p] : ax(qn(p));
      }
      var pY = mn;
      function ml(p, _, A) {
        var w = p.length;
        return A = A === n ? w : A, !_ && A >= w ? p : qa(p, _, A);
      }
      var Dw = eG || function(p) {
        return hi.clearTimeout(p);
      };
      function Iw(p, _) {
        if (_)
          return p.slice();
        var A = p.length, w = JR ? JR(A) : new p.constructor(A);
        return p.copy(w), w;
      }
      function Db(p) {
        var _ = new p.constructor(p.byteLength);
        return new rh(_).set(new rh(p)), _;
      }
      function mY(p, _) {
        var A = _ ? Db(p.buffer) : p.buffer;
        return new p.constructor(A, p.byteOffset, p.byteLength);
      }
      function hY(p) {
        var _ = new p.constructor(p.source, ti.exec(p));
        return _.lastIndex = p.lastIndex, _;
      }
      function gY(p) {
        return cf ? Kn(cf.call(p)) : {};
      }
      function Lw(p, _) {
        var A = _ ? Db(p.buffer) : p.buffer;
        return new p.constructor(A, p.byteOffset, p.length);
      }
      function kw(p, _) {
        if (p !== _) {
          var A = p !== n, w = p === null, F = p === p, z = ba(p), J = _ !== n, ie = _ === null, ge = _ === _, ke = ba(_);
          if (!ie && !ke && !z && p > _ || z && J && ge && !ie && !ke || w && J && ge || !A && ge || !F)
            return 1;
          if (!w && !z && !ke && p < _ || ke && A && F && !w && !z || ie && A && F || !J && F || !ge)
            return -1;
        }
        return 0;
      }
      function _Y(p, _, A) {
        for (var w = -1, F = p.criteria, z = _.criteria, J = F.length, ie = A.length; ++w < J; ) {
          var ge = kw(F[w], z[w]);
          if (ge) {
            if (w >= ie)
              return ge;
            var ke = A[w];
            return ge * (ke == "desc" ? -1 : 1);
          }
        }
        return p.index - _.index;
      }
      function Mw(p, _, A, w) {
        for (var F = -1, z = p.length, J = A.length, ie = -1, ge = _.length, ke = ri(z - J, 0), Fe = Ce(ge + ke), qe = !w; ++ie < ge; )
          Fe[ie] = _[ie];
        for (; ++F < J; )
          (qe || F < z) && (Fe[A[F]] = p[F]);
        for (; ke--; )
          Fe[ie++] = p[F++];
        return Fe;
      }
      function Pw(p, _, A, w) {
        for (var F = -1, z = p.length, J = -1, ie = A.length, ge = -1, ke = _.length, Fe = ri(z - ie, 0), qe = Ce(Fe + ke), lt = !w; ++F < Fe; )
          qe[F] = p[F];
        for (var Ct = F; ++ge < ke; )
          qe[Ct + ge] = _[ge];
        for (; ++J < ie; )
          (lt || F < z) && (qe[Ct + A[J]] = p[F++]);
        return qe;
      }
      function Xi(p, _) {
        var A = -1, w = p.length;
        for (_ || (_ = Ce(w)); ++A < w; )
          _[A] = p[A];
        return _;
      }
      function Lo(p, _, A, w) {
        var F = !A;
        A || (A = {});
        for (var z = -1, J = _.length; ++z < J; ) {
          var ie = _[z], ge = w ? w(A[ie], p[ie], ie, A, p) : n;
          ge === n && (ge = p[ie]), F ? ms(A, ie, ge) : df(A, ie, ge);
        }
        return A;
      }
      function vY(p, _) {
        return Lo(p, Bb(p), _);
      }
      function bY(p, _) {
        return Lo(p, jw(p), _);
      }
      function vh(p, _) {
        return function(A, w) {
          var F = an(A) ? C9 : qG, z = _ ? _() : {};
          return F(A, p, Gt(w, 2), z);
        };
      }
      function Sc(p) {
        return mn(function(_, A) {
          var w = -1, F = A.length, z = F > 1 ? A[F - 1] : n, J = F > 2 ? A[2] : n;
          for (z = p.length > 3 && typeof z == "function" ? (F--, z) : n, J && Bi(A[0], A[1], J) && (z = F < 3 ? n : z, F = 1), _ = Kn(_); ++w < F; ) {
            var ie = A[w];
            ie && p(_, ie, w, z);
          }
          return _;
        });
      }
      function Fw(p, _) {
        return function(A, w) {
          if (A == null)
            return A;
          if (!Zi(A))
            return p(A, w);
          for (var F = A.length, z = _ ? F : -1, J = Kn(A); (_ ? z-- : ++z < F) && w(J[z], z, J) !== !1; )
            ;
          return A;
        };
      }
      function Bw(p) {
        return function(_, A, w) {
          for (var F = -1, z = Kn(_), J = w(_), ie = J.length; ie--; ) {
            var ge = J[p ? ie : ++F];
            if (A(z[ge], ge, z) === !1)
              break;
          }
          return _;
        };
      }
      function EY(p, _, A) {
        var w = _ & b, F = gf(p);
        function z() {
          var J = this && this !== hi && this instanceof z ? F : p;
          return J.apply(w ? A : this, arguments);
        }
        return z;
      }
      function $w(p) {
        return function(_) {
          _ = qn(_);
          var A = mc(_) ? oo(_) : n, w = A ? A[0] : _.charAt(0), F = A ? ml(A, 1).join("") : _.slice(1);
          return w[p]() + F;
        };
      }
      function yc(p) {
        return function(_) {
          return nb(Fx(Px(_).replace(Vm, "")), p, "");
        };
      }
      function gf(p) {
        return function() {
          var _ = arguments;
          switch (_.length) {
            case 0:
              return new p();
            case 1:
              return new p(_[0]);
            case 2:
              return new p(_[0], _[1]);
            case 3:
              return new p(_[0], _[1], _[2]);
            case 4:
              return new p(_[0], _[1], _[2], _[3]);
            case 5:
              return new p(_[0], _[1], _[2], _[3], _[4]);
            case 6:
              return new p(_[0], _[1], _[2], _[3], _[4], _[5]);
            case 7:
              return new p(_[0], _[1], _[2], _[3], _[4], _[5], _[6]);
          }
          var A = Ec(p.prototype), w = p.apply(A, _);
          return Ar(w) ? w : A;
        };
      }
      function SY(p, _, A) {
        var w = gf(p);
        function F() {
          for (var z = arguments.length, J = Ce(z), ie = z, ge = Tc(F); ie--; )
            J[ie] = arguments[ie];
          var ke = z < 3 && J[0] !== ge && J[z - 1] !== ge ? [] : ul(J, ge);
          if (z -= ke.length, z < A)
            return Hw(
              p,
              _,
              bh,
              F.placeholder,
              n,
              J,
              ke,
              n,
              n,
              A - z
            );
          var Fe = this && this !== hi && this instanceof F ? w : p;
          return ga(Fe, this, J);
        }
        return F;
      }
      function Uw(p) {
        return function(_, A, w) {
          var F = Kn(_);
          if (!Zi(_)) {
            var z = Gt(A, 3);
            _ = ui(_), A = function(ie) {
              return z(F[ie], ie, F);
            };
          }
          var J = p(_, A, w);
          return J > -1 ? F[z ? _[J] : J] : n;
        };
      }
      function qw(p) {
        return gs(function(_) {
          var A = _.length, w = A, F = $a.prototype.thru;
          for (p && _.reverse(); w--; ) {
            var z = _[w];
            if (typeof z != "function")
              throw new Ba(o);
            if (F && !J && Th(z) == "wrapper")
              var J = new $a([], !0);
          }
          for (w = J ? w : A; ++w < A; ) {
            z = _[w];
            var ie = Th(z), ge = ie == "wrapper" ? Pb(z) : n;
            ge && Ub(ge[0]) && ge[1] == (O | E | C | R) && !ge[4].length && ge[9] == 1 ? J = J[Th(ge[0])].apply(J, ge[3]) : J = z.length == 1 && Ub(z) ? J[ie]() : J.thru(z);
          }
          return function() {
            var ke = arguments, Fe = ke[0];
            if (J && ke.length == 1 && an(Fe))
              return J.plant(Fe).value();
            for (var qe = 0, lt = A ? _[qe].apply(this, ke) : Fe; ++qe < A; )
              lt = _[qe].call(this, lt);
            return lt;
          };
        });
      }
      function bh(p, _, A, w, F, z, J, ie, ge, ke) {
        var Fe = _ & O, qe = _ & b, lt = _ & y, Ct = _ & (E | S), Yt = _ & D, fn = lt ? n : gf(p);
        function Ht() {
          for (var vn = arguments.length, Tn = Ce(vn), Ea = vn; Ea--; )
            Tn[Ea] = arguments[Ea];
          if (Ct)
            var $i = Tc(Ht), Sa = L9(Tn, $i);
          if (w && (Tn = Mw(Tn, w, F, Ct)), z && (Tn = Pw(Tn, z, J, Ct)), vn -= Sa, Ct && vn < ke) {
            var Fr = ul(Tn, $i);
            return Hw(
              p,
              _,
              bh,
              Ht.placeholder,
              A,
              Tn,
              Fr,
              ie,
              ge,
              ke - vn
            );
          }
          var uo = qe ? A : this, Es = lt ? uo[p] : p;
          return vn = Tn.length, ie ? Tn = qY(Tn, ie) : Yt && vn > 1 && Tn.reverse(), Fe && ge < vn && (Tn.length = ge), this && this !== hi && this instanceof Ht && (Es = fn || gf(Es)), Es.apply(uo, Tn);
        }
        return Ht;
      }
      function Gw(p, _) {
        return function(A, w) {
          return jG(A, p, _(w), {});
        };
      }
      function Eh(p, _) {
        return function(A, w) {
          var F;
          if (A === n && w === n)
            return _;
          if (A !== n && (F = A), w !== n) {
            if (F === n)
              return w;
            typeof A == "string" || typeof w == "string" ? (A = va(A), w = va(w)) : (A = Rw(A), w = Rw(w)), F = p(A, w);
          }
          return F;
        };
      }
      function Ib(p) {
        return gs(function(_) {
          return _ = Sr(_, _a(Gt())), mn(function(A) {
            var w = this;
            return p(_, function(F) {
              return ga(F, w, A);
            });
          });
        });
      }
      function Sh(p, _) {
        _ = _ === n ? " " : va(_);
        var A = _.length;
        if (A < 2)
          return A ? Ab(_, p) : _;
        var w = Ab(_, sh(p / hc(_)));
        return mc(_) ? ml(oo(w), 0, p).join("") : w.slice(0, p);
      }
      function yY(p, _, A, w) {
        var F = _ & b, z = gf(p);
        function J() {
          for (var ie = -1, ge = arguments.length, ke = -1, Fe = w.length, qe = Ce(Fe + ge), lt = this && this !== hi && this instanceof J ? z : p; ++ke < Fe; )
            qe[ke] = w[ke];
          for (; ge--; )
            qe[ke++] = arguments[++ie];
          return ga(lt, F ? A : this, qe);
        }
        return J;
      }
      function Yw(p) {
        return function(_, A, w) {
          return w && typeof w != "number" && Bi(_, A, w) && (A = w = n), _ = bs(_), A === n ? (A = _, _ = 0) : A = bs(A), w = w === n ? _ < A ? 1 : -1 : bs(w), sY(_, A, w, p);
        };
      }
      function yh(p) {
        return function(_, A) {
          return typeof _ == "string" && typeof A == "string" || (_ = Ya(_), A = Ya(A)), p(_, A);
        };
      }
      function Hw(p, _, A, w, F, z, J, ie, ge, ke) {
        var Fe = _ & E, qe = Fe ? J : n, lt = Fe ? n : J, Ct = Fe ? z : n, Yt = Fe ? n : z;
        _ |= Fe ? C : T, _ &= ~(Fe ? T : C), _ & g || (_ &= ~(b | y));
        var fn = [
          p,
          _,
          F,
          Ct,
          qe,
          Yt,
          lt,
          ie,
          ge,
          ke
        ], Ht = A.apply(n, fn);
        return Ub(p) && nx(Ht, fn), Ht.placeholder = w, rx(Ht, p, _);
      }
      function Lb(p) {
        var _ = ni[p];
        return function(A, w) {
          if (A = Ya(A), w = w == null ? 0 : Ti(un(w), 292), w && rw(A)) {
            var F = (qn(A) + "e").split("e"), z = _(F[0] + "e" + (+F[1] + w));
            return F = (qn(z) + "e").split("e"), +(F[0] + "e" + (+F[1] - w));
          }
          return _(A);
        };
      }
      var TY = vc && 1 / Xm(new vc([, -0]))[1] == k ? function(p) {
        return new vc(p);
      } : t0;
      function zw(p) {
        return function(_) {
          var A = Ci(_);
          return A == Ot ? ub(_) : A == Be ? U9(_) : I9(_, p(_));
        };
      }
      function hs(p, _, A, w, F, z, J, ie) {
        var ge = _ & y;
        if (!ge && typeof p != "function")
          throw new Ba(o);
        var ke = w ? w.length : 0;
        if (ke || (_ &= ~(C | T), w = F = n), J = J === n ? J : ri(un(J), 0), ie = ie === n ? ie : un(ie), ke -= F ? F.length : 0, _ & T) {
          var Fe = w, qe = F;
          w = F = n;
        }
        var lt = ge ? n : Pb(p), Ct = [
          p,
          _,
          A,
          w,
          F,
          Fe,
          qe,
          z,
          J,
          ie
        ];
        if (lt && BY(Ct, lt), p = Ct[0], _ = Ct[1], A = Ct[2], w = Ct[3], F = Ct[4], ie = Ct[9] = Ct[9] === n ? ge ? 0 : p.length : ri(Ct[9] - ke, 0), !ie && _ & (E | S) && (_ &= ~(E | S)), !_ || _ == b)
          var Yt = EY(p, _, A);
        else _ == E || _ == S ? Yt = SY(p, _, ie) : (_ == C || _ == (b | C)) && !F.length ? Yt = yY(p, _, A, w) : Yt = bh.apply(n, Ct);
        var fn = lt ? Aw : nx;
        return rx(fn(Yt, Ct), p, _);
      }
      function Vw(p, _, A, w) {
        return p === n || lo(p, _c[A]) && !Yn.call(w, A) ? _ : p;
      }
      function Ww(p, _, A, w, F, z) {
        return Ar(p) && Ar(_) && (z.set(_, p), hh(p, _, n, Ww, z), z.delete(_)), p;
      }
      function CY(p) {
        return bf(p) ? n : p;
      }
      function Kw(p, _, A, w, F, z) {
        var J = A & m, ie = p.length, ge = _.length;
        if (ie != ge && !(J && ge > ie))
          return !1;
        var ke = z.get(p), Fe = z.get(_);
        if (ke && Fe)
          return ke == _ && Fe == p;
        var qe = -1, lt = !0, Ct = A & v ? new uu() : n;
        for (z.set(p, _), z.set(_, p); ++qe < ie; ) {
          var Yt = p[qe], fn = _[qe];
          if (w)
            var Ht = J ? w(fn, Yt, qe, _, p, z) : w(Yt, fn, qe, p, _, z);
          if (Ht !== n) {
            if (Ht)
              continue;
            lt = !1;
            break;
          }
          if (Ct) {
            if (!rb(_, function(vn, Tn) {
              if (!af(Ct, Tn) && (Yt === vn || F(Yt, vn, A, w, z)))
                return Ct.push(Tn);
            })) {
              lt = !1;
              break;
            }
          } else if (!(Yt === fn || F(Yt, fn, A, w, z))) {
            lt = !1;
            break;
          }
        }
        return z.delete(p), z.delete(_), lt;
      }
      function AY(p, _, A, w, F, z, J) {
        switch (A) {
          case je:
            if (p.byteLength != _.byteLength || p.byteOffset != _.byteOffset)
              return !1;
            p = p.buffer, _ = _.buffer;
          case we:
            return !(p.byteLength != _.byteLength || !z(new rh(p), new rh(_)));
          case Se:
          case Re:
          case Xt:
            return lo(+p, +_);
          case nt:
            return p.name == _.name && p.message == _.message;
          case Je:
          case pt:
            return p == _ + "";
          case Ot:
            var ie = ub;
          case Be:
            var ge = w & m;
            if (ie || (ie = Xm), p.size != _.size && !ge)
              return !1;
            var ke = J.get(p);
            if (ke)
              return ke == _;
            w |= v, J.set(p, _);
            var Fe = Kw(ie(p), ie(_), w, F, z, J);
            return J.delete(p), Fe;
          case ft:
            if (cf)
              return cf.call(p) == cf.call(_);
        }
        return !1;
      }
      function OY(p, _, A, w, F, z) {
        var J = A & m, ie = kb(p), ge = ie.length, ke = kb(_), Fe = ke.length;
        if (ge != Fe && !J)
          return !1;
        for (var qe = ge; qe--; ) {
          var lt = ie[qe];
          if (!(J ? lt in _ : Yn.call(_, lt)))
            return !1;
        }
        var Ct = z.get(p), Yt = z.get(_);
        if (Ct && Yt)
          return Ct == _ && Yt == p;
        var fn = !0;
        z.set(p, _), z.set(_, p);
        for (var Ht = J; ++qe < ge; ) {
          lt = ie[qe];
          var vn = p[lt], Tn = _[lt];
          if (w)
            var Ea = J ? w(Tn, vn, lt, _, p, z) : w(vn, Tn, lt, p, _, z);
          if (!(Ea === n ? vn === Tn || F(vn, Tn, A, w, z) : Ea)) {
            fn = !1;
            break;
          }
          Ht || (Ht = lt == "constructor");
        }
        if (fn && !Ht) {
          var $i = p.constructor, Sa = _.constructor;
          $i != Sa && "constructor" in p && "constructor" in _ && !(typeof $i == "function" && $i instanceof $i && typeof Sa == "function" && Sa instanceof Sa) && (fn = !1);
        }
        return z.delete(p), z.delete(_), fn;
      }
      function gs(p) {
        return Gb(ex(p, n, ux), p + "");
      }
      function kb(p) {
        return mw(p, ui, Bb);
      }
      function Mb(p) {
        return mw(p, Ji, jw);
      }
      var Pb = uh ? function(p) {
        return uh.get(p);
      } : t0;
      function Th(p) {
        for (var _ = p.name + "", A = bc[_], w = Yn.call(bc, _) ? A.length : 0; w--; ) {
          var F = A[w], z = F.func;
          if (z == null || z == p)
            return F.name;
        }
        return _;
      }
      function Tc(p) {
        var _ = Yn.call(H, "placeholder") ? H : p;
        return _.placeholder;
      }
      function Gt() {
        var p = H.iteratee || Jb;
        return p = p === Jb ? _w : p, arguments.length ? p(arguments[0], arguments[1]) : p;
      }
      function Ch(p, _) {
        var A = p.__data__;
        return kY(_) ? A[typeof _ == "string" ? "string" : "hash"] : A.map;
      }
      function Fb(p) {
        for (var _ = ui(p), A = _.length; A--; ) {
          var w = _[A], F = p[w];
          _[A] = [w, F, Zw(F)];
        }
        return _;
      }
      function fu(p, _) {
        var A = F9(p, _);
        return gw(A) ? A : n;
      }
      function RY(p) {
        var _ = Yn.call(p, su), A = p[su];
        try {
          p[su] = n;
          var w = !0;
        } catch {
        }
        var F = th.call(p);
        return w && (_ ? p[su] = A : delete p[su]), F;
      }
      var Bb = db ? function(p) {
        return p == null ? [] : (p = Kn(p), sl(db(p), function(_) {
          return tw.call(p, _);
        }));
      } : n0, jw = db ? function(p) {
        for (var _ = []; p; )
          ll(_, Bb(p)), p = ih(p);
        return _;
      } : n0, Ci = Fi;
      (fb && Ci(new fb(new ArrayBuffer(1))) != je || sf && Ci(new sf()) != Ot || pb && Ci(pb.resolve()) != Pt || vc && Ci(new vc()) != Be || lf && Ci(new lf()) != _t) && (Ci = function(p) {
        var _ = Fi(p), A = _ == st ? p.constructor : n, w = A ? pu(A) : "";
        if (w)
          switch (w) {
            case uG:
              return je;
            case cG:
              return Ot;
            case dG:
              return Pt;
            case fG:
              return Be;
            case pG:
              return _t;
          }
        return _;
      });
      function wY(p, _, A) {
        for (var w = -1, F = A.length; ++w < F; ) {
          var z = A[w], J = z.size;
          switch (z.type) {
            case "drop":
              p += J;
              break;
            case "dropRight":
              _ -= J;
              break;
            case "take":
              _ = Ti(_, p + J);
              break;
            case "takeRight":
              p = ri(p, _ - J);
              break;
          }
        }
        return { start: p, end: _ };
      }
      function xY(p) {
        var _ = p.match(Zt);
        return _ ? _[1].split(Jt) : [];
      }
      function Qw(p, _, A) {
        _ = pl(_, p);
        for (var w = -1, F = _.length, z = !1; ++w < F; ) {
          var J = ko(_[w]);
          if (!(z = p != null && A(p, J)))
            break;
          p = p[J];
        }
        return z || ++w != F ? z : (F = p == null ? 0 : p.length, !!F && Dh(F) && _s(J, F) && (an(p) || mu(p)));
      }
      function NY(p) {
        var _ = p.length, A = new p.constructor(_);
        return _ && typeof p[0] == "string" && Yn.call(p, "index") && (A.index = p.index, A.input = p.input), A;
      }
      function Xw(p) {
        return typeof p.constructor == "function" && !_f(p) ? Ec(ih(p)) : {};
      }
      function DY(p, _, A) {
        var w = p.constructor;
        switch (_) {
          case we:
            return Db(p);
          case Se:
          case Re:
            return new w(+p);
          case je:
            return mY(p, A);
          case yt:
          case Rt:
          case sn:
          case me:
          case He:
          case tt:
          case ot:
          case xn:
          case kt:
            return Lw(p, A);
          case Ot:
            return new w();
          case Xt:
          case pt:
            return new w(p);
          case Je:
            return hY(p);
          case Be:
            return new w();
          case ft:
            return gY(p);
        }
      }
      function IY(p, _) {
        var A = _.length;
        if (!A)
          return p;
        var w = A - 1;
        return _[w] = (A > 1 ? "& " : "") + _[w], _ = _.join(A > 2 ? ", " : " "), p.replace(Mt, `{
/* [wrapped with ` + _ + `] */
`);
      }
      function LY(p) {
        return an(p) || mu(p) || !!(nw && p && p[nw]);
      }
      function _s(p, _) {
        var A = typeof p;
        return _ = _ ?? B, !!_ && (A == "number" || A != "symbol" && Q.test(p)) && p > -1 && p % 1 == 0 && p < _;
      }
      function Bi(p, _, A) {
        if (!Ar(A))
          return !1;
        var w = typeof _;
        return (w == "number" ? Zi(A) && _s(_, A.length) : w == "string" && _ in A) ? lo(A[_], p) : !1;
      }
      function $b(p, _) {
        if (an(p))
          return !1;
        var A = typeof p;
        return A == "number" || A == "symbol" || A == "boolean" || p == null || ba(p) ? !0 : Ie.test(p) || !be.test(p) || _ != null && p in Kn(_);
      }
      function kY(p) {
        var _ = typeof p;
        return _ == "string" || _ == "number" || _ == "symbol" || _ == "boolean" ? p !== "__proto__" : p === null;
      }
      function Ub(p) {
        var _ = Th(p), A = H[_];
        if (typeof A != "function" || !(_ in Sn.prototype))
          return !1;
        if (p === A)
          return !0;
        var w = Pb(A);
        return !!w && p === w[0];
      }
      function MY(p) {
        return !!ZR && ZR in p;
      }
      var PY = Jm ? vs : r0;
      function _f(p) {
        var _ = p && p.constructor, A = typeof _ == "function" && _.prototype || _c;
        return p === A;
      }
      function Zw(p) {
        return p === p && !Ar(p);
      }
      function Jw(p, _) {
        return function(A) {
          return A == null ? !1 : A[p] === _ && (_ !== n || p in Kn(A));
        };
      }
      function FY(p) {
        var _ = xh(p, function(w) {
          return A.size === u && A.clear(), w;
        }), A = _.cache;
        return _;
      }
      function BY(p, _) {
        var A = p[1], w = _[1], F = A | w, z = F < (b | y | O), J = w == O && A == E || w == O && A == R && p[7].length <= _[8] || w == (O | R) && _[7].length <= _[8] && A == E;
        if (!(z || J))
          return p;
        w & b && (p[2] = _[2], F |= A & b ? 0 : g);
        var ie = _[3];
        if (ie) {
          var ge = p[3];
          p[3] = ge ? Mw(ge, ie, _[4]) : ie, p[4] = ge ? ul(p[3], c) : _[4];
        }
        return ie = _[5], ie && (ge = p[5], p[5] = ge ? Pw(ge, ie, _[6]) : ie, p[6] = ge ? ul(p[5], c) : _[6]), ie = _[7], ie && (p[7] = ie), w & O && (p[8] = p[8] == null ? _[8] : Ti(p[8], _[8])), p[9] == null && (p[9] = _[9]), p[0] = _[0], p[1] = F, p;
      }
      function $Y(p) {
        var _ = [];
        if (p != null)
          for (var A in Kn(p))
            _.push(A);
        return _;
      }
      function UY(p) {
        return th.call(p);
      }
      function ex(p, _, A) {
        return _ = ri(_ === n ? p.length - 1 : _, 0), function() {
          for (var w = arguments, F = -1, z = ri(w.length - _, 0), J = Ce(z); ++F < z; )
            J[F] = w[_ + F];
          F = -1;
          for (var ie = Ce(_ + 1); ++F < _; )
            ie[F] = w[F];
          return ie[_] = A(J), ga(p, this, ie);
        };
      }
      function tx(p, _) {
        return _.length < 2 ? p : du(p, qa(_, 0, -1));
      }
      function qY(p, _) {
        for (var A = p.length, w = Ti(_.length, A), F = Xi(p); w--; ) {
          var z = _[w];
          p[w] = _s(z, A) ? F[z] : n;
        }
        return p;
      }
      function qb(p, _) {
        if (!(_ === "constructor" && typeof p[_] == "function") && _ != "__proto__")
          return p[_];
      }
      var nx = ix(Aw), vf = nG || function(p, _) {
        return hi.setTimeout(p, _);
      }, Gb = ix(cY);
      function rx(p, _, A) {
        var w = _ + "";
        return Gb(p, IY(w, GY(xY(w), A)));
      }
      function ix(p) {
        var _ = 0, A = 0;
        return function() {
          var w = oG(), F = Y - (w - A);
          if (A = w, F > 0) {
            if (++_ >= P)
              return arguments[0];
          } else
            _ = 0;
          return p.apply(n, arguments);
        };
      }
      function Ah(p, _) {
        var A = -1, w = p.length, F = w - 1;
        for (_ = _ === n ? w : _; ++A < _; ) {
          var z = Cb(A, F), J = p[z];
          p[z] = p[A], p[A] = J;
        }
        return p.length = _, p;
      }
      var ax = FY(function(p) {
        var _ = [];
        return p.charCodeAt(0) === 46 && _.push(""), p.replace(Ue, function(A, w, F, z) {
          _.push(F ? z.replace(pi, "$1") : w || A);
        }), _;
      });
      function ko(p) {
        if (typeof p == "string" || ba(p))
          return p;
        var _ = p + "";
        return _ == "0" && 1 / p == -k ? "-0" : _;
      }
      function pu(p) {
        if (p != null) {
          try {
            return eh.call(p);
          } catch {
          }
          try {
            return p + "";
          } catch {
          }
        }
        return "";
      }
      function GY(p, _) {
        return Fa(Ee, function(A) {
          var w = "_." + A[0];
          _ & A[1] && !jm(p, w) && p.push(w);
        }), p.sort();
      }
      function ox(p) {
        if (p instanceof Sn)
          return p.clone();
        var _ = new $a(p.__wrapped__, p.__chain__);
        return _.__actions__ = Xi(p.__actions__), _.__index__ = p.__index__, _.__values__ = p.__values__, _;
      }
      function YY(p, _, A) {
        (A ? Bi(p, _, A) : _ === n) ? _ = 1 : _ = ri(un(_), 0);
        var w = p == null ? 0 : p.length;
        if (!w || _ < 1)
          return [];
        for (var F = 0, z = 0, J = Ce(sh(w / _)); F < w; )
          J[z++] = qa(p, F, F += _);
        return J;
      }
      function HY(p) {
        for (var _ = -1, A = p == null ? 0 : p.length, w = 0, F = []; ++_ < A; ) {
          var z = p[_];
          z && (F[w++] = z);
        }
        return F;
      }
      function zY() {
        var p = arguments.length;
        if (!p)
          return [];
        for (var _ = Ce(p - 1), A = arguments[0], w = p; w--; )
          _[w - 1] = arguments[w];
        return ll(an(A) ? Xi(A) : [A], gi(_, 1));
      }
      var VY = mn(function(p, _) {
        return Pr(p) ? ff(p, gi(_, 1, Pr, !0)) : [];
      }), WY = mn(function(p, _) {
        var A = Ga(_);
        return Pr(A) && (A = n), Pr(p) ? ff(p, gi(_, 1, Pr, !0), Gt(A, 2)) : [];
      }), KY = mn(function(p, _) {
        var A = Ga(_);
        return Pr(A) && (A = n), Pr(p) ? ff(p, gi(_, 1, Pr, !0), n, A) : [];
      });
      function jY(p, _, A) {
        var w = p == null ? 0 : p.length;
        return w ? (_ = A || _ === n ? 1 : un(_), qa(p, _ < 0 ? 0 : _, w)) : [];
      }
      function QY(p, _, A) {
        var w = p == null ? 0 : p.length;
        return w ? (_ = A || _ === n ? 1 : un(_), _ = w - _, qa(p, 0, _ < 0 ? 0 : _)) : [];
      }
      function XY(p, _) {
        return p && p.length ? _h(p, Gt(_, 3), !0, !0) : [];
      }
      function ZY(p, _) {
        return p && p.length ? _h(p, Gt(_, 3), !0) : [];
      }
      function JY(p, _, A, w) {
        var F = p == null ? 0 : p.length;
        return F ? (A && typeof A != "number" && Bi(p, _, A) && (A = 0, w = F), zG(p, _, A, w)) : [];
      }
      function sx(p, _, A) {
        var w = p == null ? 0 : p.length;
        if (!w)
          return -1;
        var F = A == null ? 0 : un(A);
        return F < 0 && (F = ri(w + F, 0)), Qm(p, Gt(_, 3), F);
      }
      function lx(p, _, A) {
        var w = p == null ? 0 : p.length;
        if (!w)
          return -1;
        var F = w - 1;
        return A !== n && (F = un(A), F = A < 0 ? ri(w + F, 0) : Ti(F, w - 1)), Qm(p, Gt(_, 3), F, !0);
      }
      function ux(p) {
        var _ = p == null ? 0 : p.length;
        return _ ? gi(p, 1) : [];
      }
      function eH(p) {
        var _ = p == null ? 0 : p.length;
        return _ ? gi(p, k) : [];
      }
      function tH(p, _) {
        var A = p == null ? 0 : p.length;
        return A ? (_ = _ === n ? 1 : un(_), gi(p, _)) : [];
      }
      function nH(p) {
        for (var _ = -1, A = p == null ? 0 : p.length, w = {}; ++_ < A; ) {
          var F = p[_];
          w[F[0]] = F[1];
        }
        return w;
      }
      function cx(p) {
        return p && p.length ? p[0] : n;
      }
      function rH(p, _, A) {
        var w = p == null ? 0 : p.length;
        if (!w)
          return -1;
        var F = A == null ? 0 : un(A);
        return F < 0 && (F = ri(w + F, 0)), pc(p, _, F);
      }
      function iH(p) {
        var _ = p == null ? 0 : p.length;
        return _ ? qa(p, 0, -1) : [];
      }
      var aH = mn(function(p) {
        var _ = Sr(p, xb);
        return _.length && _[0] === p[0] ? bb(_) : [];
      }), oH = mn(function(p) {
        var _ = Ga(p), A = Sr(p, xb);
        return _ === Ga(A) ? _ = n : A.pop(), A.length && A[0] === p[0] ? bb(A, Gt(_, 2)) : [];
      }), sH = mn(function(p) {
        var _ = Ga(p), A = Sr(p, xb);
        return _ = typeof _ == "function" ? _ : n, _ && A.pop(), A.length && A[0] === p[0] ? bb(A, n, _) : [];
      });
      function lH(p, _) {
        return p == null ? "" : iG.call(p, _);
      }
      function Ga(p) {
        var _ = p == null ? 0 : p.length;
        return _ ? p[_ - 1] : n;
      }
      function uH(p, _, A) {
        var w = p == null ? 0 : p.length;
        if (!w)
          return -1;
        var F = w;
        return A !== n && (F = un(A), F = F < 0 ? ri(w + F, 0) : Ti(F, w - 1)), _ === _ ? G9(p, _, F) : Qm(p, HR, F, !0);
      }
      function cH(p, _) {
        return p && p.length ? Sw(p, un(_)) : n;
      }
      var dH = mn(dx);
      function dx(p, _) {
        return p && p.length && _ && _.length ? Tb(p, _) : p;
      }
      function fH(p, _, A) {
        return p && p.length && _ && _.length ? Tb(p, _, Gt(A, 2)) : p;
      }
      function pH(p, _, A) {
        return p && p.length && _ && _.length ? Tb(p, _, n, A) : p;
      }
      var mH = gs(function(p, _) {
        var A = p == null ? 0 : p.length, w = hb(p, _);
        return Cw(p, Sr(_, function(F) {
          return _s(F, A) ? +F : F;
        }).sort(kw)), w;
      });
      function hH(p, _) {
        var A = [];
        if (!(p && p.length))
          return A;
        var w = -1, F = [], z = p.length;
        for (_ = Gt(_, 3); ++w < z; ) {
          var J = p[w];
          _(J, w, p) && (A.push(J), F.push(w));
        }
        return Cw(p, F), A;
      }
      function Yb(p) {
        return p == null ? p : lG.call(p);
      }
      function gH(p, _, A) {
        var w = p == null ? 0 : p.length;
        return w ? (A && typeof A != "number" && Bi(p, _, A) ? (_ = 0, A = w) : (_ = _ == null ? 0 : un(_), A = A === n ? w : un(A)), qa(p, _, A)) : [];
      }
      function _H(p, _) {
        return gh(p, _);
      }
      function vH(p, _, A) {
        return Ob(p, _, Gt(A, 2));
      }
      function bH(p, _) {
        var A = p == null ? 0 : p.length;
        if (A) {
          var w = gh(p, _);
          if (w < A && lo(p[w], _))
            return w;
        }
        return -1;
      }
      function EH(p, _) {
        return gh(p, _, !0);
      }
      function SH(p, _, A) {
        return Ob(p, _, Gt(A, 2), !0);
      }
      function yH(p, _) {
        var A = p == null ? 0 : p.length;
        if (A) {
          var w = gh(p, _, !0) - 1;
          if (lo(p[w], _))
            return w;
        }
        return -1;
      }
      function TH(p) {
        return p && p.length ? Ow(p) : [];
      }
      function CH(p, _) {
        return p && p.length ? Ow(p, Gt(_, 2)) : [];
      }
      function AH(p) {
        var _ = p == null ? 0 : p.length;
        return _ ? qa(p, 1, _) : [];
      }
      function OH(p, _, A) {
        return p && p.length ? (_ = A || _ === n ? 1 : un(_), qa(p, 0, _ < 0 ? 0 : _)) : [];
      }
      function RH(p, _, A) {
        var w = p == null ? 0 : p.length;
        return w ? (_ = A || _ === n ? 1 : un(_), _ = w - _, qa(p, _ < 0 ? 0 : _, w)) : [];
      }
      function wH(p, _) {
        return p && p.length ? _h(p, Gt(_, 3), !1, !0) : [];
      }
      function xH(p, _) {
        return p && p.length ? _h(p, Gt(_, 3)) : [];
      }
      var NH = mn(function(p) {
        return fl(gi(p, 1, Pr, !0));
      }), DH = mn(function(p) {
        var _ = Ga(p);
        return Pr(_) && (_ = n), fl(gi(p, 1, Pr, !0), Gt(_, 2));
      }), IH = mn(function(p) {
        var _ = Ga(p);
        return _ = typeof _ == "function" ? _ : n, fl(gi(p, 1, Pr, !0), n, _);
      });
      function LH(p) {
        return p && p.length ? fl(p) : [];
      }
      function kH(p, _) {
        return p && p.length ? fl(p, Gt(_, 2)) : [];
      }
      function MH(p, _) {
        return _ = typeof _ == "function" ? _ : n, p && p.length ? fl(p, n, _) : [];
      }
      function Hb(p) {
        if (!(p && p.length))
          return [];
        var _ = 0;
        return p = sl(p, function(A) {
          if (Pr(A))
            return _ = ri(A.length, _), !0;
        }), sb(_, function(A) {
          return Sr(p, ib(A));
        });
      }
      function fx(p, _) {
        if (!(p && p.length))
          return [];
        var A = Hb(p);
        return _ == null ? A : Sr(A, function(w) {
          return ga(_, n, w);
        });
      }
      var PH = mn(function(p, _) {
        return Pr(p) ? ff(p, _) : [];
      }), FH = mn(function(p) {
        return wb(sl(p, Pr));
      }), BH = mn(function(p) {
        var _ = Ga(p);
        return Pr(_) && (_ = n), wb(sl(p, Pr), Gt(_, 2));
      }), $H = mn(function(p) {
        var _ = Ga(p);
        return _ = typeof _ == "function" ? _ : n, wb(sl(p, Pr), n, _);
      }), UH = mn(Hb);
      function qH(p, _) {
        return Nw(p || [], _ || [], df);
      }
      function GH(p, _) {
        return Nw(p || [], _ || [], hf);
      }
      var YH = mn(function(p) {
        var _ = p.length, A = _ > 1 ? p[_ - 1] : n;
        return A = typeof A == "function" ? (p.pop(), A) : n, fx(p, A);
      });
      function px(p) {
        var _ = H(p);
        return _.__chain__ = !0, _;
      }
      function HH(p, _) {
        return _(p), p;
      }
      function Oh(p, _) {
        return _(p);
      }
      var zH = gs(function(p) {
        var _ = p.length, A = _ ? p[0] : 0, w = this.__wrapped__, F = function(z) {
          return hb(z, p);
        };
        return _ > 1 || this.__actions__.length || !(w instanceof Sn) || !_s(A) ? this.thru(F) : (w = w.slice(A, +A + (_ ? 1 : 0)), w.__actions__.push({
          func: Oh,
          args: [F],
          thisArg: n
        }), new $a(w, this.__chain__).thru(function(z) {
          return _ && !z.length && z.push(n), z;
        }));
      });
      function VH() {
        return px(this);
      }
      function WH() {
        return new $a(this.value(), this.__chain__);
      }
      function KH() {
        this.__values__ === n && (this.__values__ = Rx(this.value()));
        var p = this.__index__ >= this.__values__.length, _ = p ? n : this.__values__[this.__index__++];
        return { done: p, value: _ };
      }
      function jH() {
        return this;
      }
      function QH(p) {
        for (var _, A = this; A instanceof dh; ) {
          var w = ox(A);
          w.__index__ = 0, w.__values__ = n, _ ? F.__wrapped__ = w : _ = w;
          var F = w;
          A = A.__wrapped__;
        }
        return F.__wrapped__ = p, _;
      }
      function XH() {
        var p = this.__wrapped__;
        if (p instanceof Sn) {
          var _ = p;
          return this.__actions__.length && (_ = new Sn(this)), _ = _.reverse(), _.__actions__.push({
            func: Oh,
            args: [Yb],
            thisArg: n
          }), new $a(_, this.__chain__);
        }
        return this.thru(Yb);
      }
      function ZH() {
        return xw(this.__wrapped__, this.__actions__);
      }
      var JH = vh(function(p, _, A) {
        Yn.call(p, A) ? ++p[A] : ms(p, A, 1);
      });
      function e7(p, _, A) {
        var w = an(p) ? GR : HG;
        return A && Bi(p, _, A) && (_ = n), w(p, Gt(_, 3));
      }
      function t7(p, _) {
        var A = an(p) ? sl : fw;
        return A(p, Gt(_, 3));
      }
      var n7 = Uw(sx), r7 = Uw(lx);
      function i7(p, _) {
        return gi(Rh(p, _), 1);
      }
      function a7(p, _) {
        return gi(Rh(p, _), k);
      }
      function o7(p, _, A) {
        return A = A === n ? 1 : un(A), gi(Rh(p, _), A);
      }
      function mx(p, _) {
        var A = an(p) ? Fa : dl;
        return A(p, Gt(_, 3));
      }
      function hx(p, _) {
        var A = an(p) ? A9 : dw;
        return A(p, Gt(_, 3));
      }
      var s7 = vh(function(p, _, A) {
        Yn.call(p, A) ? p[A].push(_) : ms(p, A, [_]);
      });
      function l7(p, _, A, w) {
        p = Zi(p) ? p : Ac(p), A = A && !w ? un(A) : 0;
        var F = p.length;
        return A < 0 && (A = ri(F + A, 0)), Ih(p) ? A <= F && p.indexOf(_, A) > -1 : !!F && pc(p, _, A) > -1;
      }
      var u7 = mn(function(p, _, A) {
        var w = -1, F = typeof _ == "function", z = Zi(p) ? Ce(p.length) : [];
        return dl(p, function(J) {
          z[++w] = F ? ga(_, J, A) : pf(J, _, A);
        }), z;
      }), c7 = vh(function(p, _, A) {
        ms(p, A, _);
      });
      function Rh(p, _) {
        var A = an(p) ? Sr : vw;
        return A(p, Gt(_, 3));
      }
      function d7(p, _, A, w) {
        return p == null ? [] : (an(_) || (_ = _ == null ? [] : [_]), A = w ? n : A, an(A) || (A = A == null ? [] : [A]), yw(p, _, A));
      }
      var f7 = vh(function(p, _, A) {
        p[A ? 0 : 1].push(_);
      }, function() {
        return [[], []];
      });
      function p7(p, _, A) {
        var w = an(p) ? nb : VR, F = arguments.length < 3;
        return w(p, Gt(_, 4), A, F, dl);
      }
      function m7(p, _, A) {
        var w = an(p) ? O9 : VR, F = arguments.length < 3;
        return w(p, Gt(_, 4), A, F, dw);
      }
      function h7(p, _) {
        var A = an(p) ? sl : fw;
        return A(p, Nh(Gt(_, 3)));
      }
      function g7(p) {
        var _ = an(p) ? sw : lY;
        return _(p);
      }
      function _7(p, _, A) {
        (A ? Bi(p, _, A) : _ === n) ? _ = 1 : _ = un(_);
        var w = an(p) ? $G : uY;
        return w(p, _);
      }
      function v7(p) {
        var _ = an(p) ? UG : dY;
        return _(p);
      }
      function b7(p) {
        if (p == null)
          return 0;
        if (Zi(p))
          return Ih(p) ? hc(p) : p.length;
        var _ = Ci(p);
        return _ == Ot || _ == Be ? p.size : Sb(p).length;
      }
      function E7(p, _, A) {
        var w = an(p) ? rb : fY;
        return A && Bi(p, _, A) && (_ = n), w(p, Gt(_, 3));
      }
      var S7 = mn(function(p, _) {
        if (p == null)
          return [];
        var A = _.length;
        return A > 1 && Bi(p, _[0], _[1]) ? _ = [] : A > 2 && Bi(_[0], _[1], _[2]) && (_ = [_[0]]), yw(p, gi(_, 1), []);
      }), wh = tG || function() {
        return hi.Date.now();
      };
      function y7(p, _) {
        if (typeof _ != "function")
          throw new Ba(o);
        return p = un(p), function() {
          if (--p < 1)
            return _.apply(this, arguments);
        };
      }
      function gx(p, _, A) {
        return _ = A ? n : _, _ = p && _ == null ? p.length : _, hs(p, O, n, n, n, n, _);
      }
      function _x(p, _) {
        var A;
        if (typeof _ != "function")
          throw new Ba(o);
        return p = un(p), function() {
          return --p > 0 && (A = _.apply(this, arguments)), p <= 1 && (_ = n), A;
        };
      }
      var zb = mn(function(p, _, A) {
        var w = b;
        if (A.length) {
          var F = ul(A, Tc(zb));
          w |= C;
        }
        return hs(p, w, _, A, F);
      }), vx = mn(function(p, _, A) {
        var w = b | y;
        if (A.length) {
          var F = ul(A, Tc(vx));
          w |= C;
        }
        return hs(_, w, p, A, F);
      });
      function bx(p, _, A) {
        _ = A ? n : _;
        var w = hs(p, E, n, n, n, n, n, _);
        return w.placeholder = bx.placeholder, w;
      }
      function Ex(p, _, A) {
        _ = A ? n : _;
        var w = hs(p, S, n, n, n, n, n, _);
        return w.placeholder = Ex.placeholder, w;
      }
      function Sx(p, _, A) {
        var w, F, z, J, ie, ge, ke = 0, Fe = !1, qe = !1, lt = !0;
        if (typeof p != "function")
          throw new Ba(o);
        _ = Ya(_) || 0, Ar(A) && (Fe = !!A.leading, qe = "maxWait" in A, z = qe ? ri(Ya(A.maxWait) || 0, _) : z, lt = "trailing" in A ? !!A.trailing : lt);
        function Ct(Fr) {
          var uo = w, Es = F;
          return w = F = n, ke = Fr, J = p.apply(Es, uo), J;
        }
        function Yt(Fr) {
          return ke = Fr, ie = vf(vn, _), Fe ? Ct(Fr) : J;
        }
        function fn(Fr) {
          var uo = Fr - ge, Es = Fr - ke, Ux = _ - uo;
          return qe ? Ti(Ux, z - Es) : Ux;
        }
        function Ht(Fr) {
          var uo = Fr - ge, Es = Fr - ke;
          return ge === n || uo >= _ || uo < 0 || qe && Es >= z;
        }
        function vn() {
          var Fr = wh();
          if (Ht(Fr))
            return Tn(Fr);
          ie = vf(vn, fn(Fr));
        }
        function Tn(Fr) {
          return ie = n, lt && w ? Ct(Fr) : (w = F = n, J);
        }
        function Ea() {
          ie !== n && Dw(ie), ke = 0, w = ge = F = ie = n;
        }
        function $i() {
          return ie === n ? J : Tn(wh());
        }
        function Sa() {
          var Fr = wh(), uo = Ht(Fr);
          if (w = arguments, F = this, ge = Fr, uo) {
            if (ie === n)
              return Yt(ge);
            if (qe)
              return Dw(ie), ie = vf(vn, _), Ct(ge);
          }
          return ie === n && (ie = vf(vn, _)), J;
        }
        return Sa.cancel = Ea, Sa.flush = $i, Sa;
      }
      var T7 = mn(function(p, _) {
        return cw(p, 1, _);
      }), C7 = mn(function(p, _, A) {
        return cw(p, Ya(_) || 0, A);
      });
      function A7(p) {
        return hs(p, D);
      }
      function xh(p, _) {
        if (typeof p != "function" || _ != null && typeof _ != "function")
          throw new Ba(o);
        var A = function() {
          var w = arguments, F = _ ? _.apply(this, w) : w[0], z = A.cache;
          if (z.has(F))
            return z.get(F);
          var J = p.apply(this, w);
          return A.cache = z.set(F, J) || z, J;
        };
        return A.cache = new (xh.Cache || ps)(), A;
      }
      xh.Cache = ps;
      function Nh(p) {
        if (typeof p != "function")
          throw new Ba(o);
        return function() {
          var _ = arguments;
          switch (_.length) {
            case 0:
              return !p.call(this);
            case 1:
              return !p.call(this, _[0]);
            case 2:
              return !p.call(this, _[0], _[1]);
            case 3:
              return !p.call(this, _[0], _[1], _[2]);
          }
          return !p.apply(this, _);
        };
      }
      function O7(p) {
        return _x(2, p);
      }
      var R7 = pY(function(p, _) {
        _ = _.length == 1 && an(_[0]) ? Sr(_[0], _a(Gt())) : Sr(gi(_, 1), _a(Gt()));
        var A = _.length;
        return mn(function(w) {
          for (var F = -1, z = Ti(w.length, A); ++F < z; )
            w[F] = _[F].call(this, w[F]);
          return ga(p, this, w);
        });
      }), Vb = mn(function(p, _) {
        var A = ul(_, Tc(Vb));
        return hs(p, C, n, _, A);
      }), yx = mn(function(p, _) {
        var A = ul(_, Tc(yx));
        return hs(p, T, n, _, A);
      }), w7 = gs(function(p, _) {
        return hs(p, R, n, n, n, _);
      });
      function x7(p, _) {
        if (typeof p != "function")
          throw new Ba(o);
        return _ = _ === n ? _ : un(_), mn(p, _);
      }
      function N7(p, _) {
        if (typeof p != "function")
          throw new Ba(o);
        return _ = _ == null ? 0 : ri(un(_), 0), mn(function(A) {
          var w = A[_], F = ml(A, 0, _);
          return w && ll(F, w), ga(p, this, F);
        });
      }
      function D7(p, _, A) {
        var w = !0, F = !0;
        if (typeof p != "function")
          throw new Ba(o);
        return Ar(A) && (w = "leading" in A ? !!A.leading : w, F = "trailing" in A ? !!A.trailing : F), Sx(p, _, {
          leading: w,
          maxWait: _,
          trailing: F
        });
      }
      function I7(p) {
        return gx(p, 1);
      }
      function L7(p, _) {
        return Vb(Nb(_), p);
      }
      function k7() {
        if (!arguments.length)
          return [];
        var p = arguments[0];
        return an(p) ? p : [p];
      }
      function M7(p) {
        return Ua(p, h);
      }
      function P7(p, _) {
        return _ = typeof _ == "function" ? _ : n, Ua(p, h, _);
      }
      function F7(p) {
        return Ua(p, d | h);
      }
      function B7(p, _) {
        return _ = typeof _ == "function" ? _ : n, Ua(p, d | h, _);
      }
      function $7(p, _) {
        return _ == null || uw(p, _, ui(_));
      }
      function lo(p, _) {
        return p === _ || p !== p && _ !== _;
      }
      var U7 = yh(vb), q7 = yh(function(p, _) {
        return p >= _;
      }), mu = hw(/* @__PURE__ */ function() {
        return arguments;
      }()) ? hw : function(p) {
        return Dr(p) && Yn.call(p, "callee") && !tw.call(p, "callee");
      }, an = Ce.isArray, G7 = PR ? _a(PR) : QG;
      function Zi(p) {
        return p != null && Dh(p.length) && !vs(p);
      }
      function Pr(p) {
        return Dr(p) && Zi(p);
      }
      function Y7(p) {
        return p === !0 || p === !1 || Dr(p) && Fi(p) == Se;
      }
      var hl = rG || r0, H7 = FR ? _a(FR) : XG;
      function z7(p) {
        return Dr(p) && p.nodeType === 1 && !bf(p);
      }
      function V7(p) {
        if (p == null)
          return !0;
        if (Zi(p) && (an(p) || typeof p == "string" || typeof p.splice == "function" || hl(p) || Cc(p) || mu(p)))
          return !p.length;
        var _ = Ci(p);
        if (_ == Ot || _ == Be)
          return !p.size;
        if (_f(p))
          return !Sb(p).length;
        for (var A in p)
          if (Yn.call(p, A))
            return !1;
        return !0;
      }
      function W7(p, _) {
        return mf(p, _);
      }
      function K7(p, _, A) {
        A = typeof A == "function" ? A : n;
        var w = A ? A(p, _) : n;
        return w === n ? mf(p, _, n, A) : !!w;
      }
      function Wb(p) {
        if (!Dr(p))
          return !1;
        var _ = Fi(p);
        return _ == nt || _ == Ye || typeof p.message == "string" && typeof p.name == "string" && !bf(p);
      }
      function j7(p) {
        return typeof p == "number" && rw(p);
      }
      function vs(p) {
        if (!Ar(p))
          return !1;
        var _ = Fi(p);
        return _ == ut || _ == Tt || _ == pe || _ == Ke;
      }
      function Tx(p) {
        return typeof p == "number" && p == un(p);
      }
      function Dh(p) {
        return typeof p == "number" && p > -1 && p % 1 == 0 && p <= B;
      }
      function Ar(p) {
        var _ = typeof p;
        return p != null && (_ == "object" || _ == "function");
      }
      function Dr(p) {
        return p != null && typeof p == "object";
      }
      var Cx = BR ? _a(BR) : JG;
      function Q7(p, _) {
        return p === _ || Eb(p, _, Fb(_));
      }
      function X7(p, _, A) {
        return A = typeof A == "function" ? A : n, Eb(p, _, Fb(_), A);
      }
      function Z7(p) {
        return Ax(p) && p != +p;
      }
      function J7(p) {
        if (PY(p))
          throw new tn(a);
        return gw(p);
      }
      function ez(p) {
        return p === null;
      }
      function tz(p) {
        return p == null;
      }
      function Ax(p) {
        return typeof p == "number" || Dr(p) && Fi(p) == Xt;
      }
      function bf(p) {
        if (!Dr(p) || Fi(p) != st)
          return !1;
        var _ = ih(p);
        if (_ === null)
          return !0;
        var A = Yn.call(_, "constructor") && _.constructor;
        return typeof A == "function" && A instanceof A && eh.call(A) == X9;
      }
      var Kb = $R ? _a($R) : eY;
      function nz(p) {
        return Tx(p) && p >= -B && p <= B;
      }
      var Ox = UR ? _a(UR) : tY;
      function Ih(p) {
        return typeof p == "string" || !an(p) && Dr(p) && Fi(p) == pt;
      }
      function ba(p) {
        return typeof p == "symbol" || Dr(p) && Fi(p) == ft;
      }
      var Cc = qR ? _a(qR) : nY;
      function rz(p) {
        return p === n;
      }
      function iz(p) {
        return Dr(p) && Ci(p) == _t;
      }
      function az(p) {
        return Dr(p) && Fi(p) == St;
      }
      var oz = yh(yb), sz = yh(function(p, _) {
        return p <= _;
      });
      function Rx(p) {
        if (!p)
          return [];
        if (Zi(p))
          return Ih(p) ? oo(p) : Xi(p);
        if (of && p[of])
          return $9(p[of]());
        var _ = Ci(p), A = _ == Ot ? ub : _ == Be ? Xm : Ac;
        return A(p);
      }
      function bs(p) {
        if (!p)
          return p === 0 ? p : 0;
        if (p = Ya(p), p === k || p === -k) {
          var _ = p < 0 ? -1 : 1;
          return _ * W;
        }
        return p === p ? p : 0;
      }
      function un(p) {
        var _ = bs(p), A = _ % 1;
        return _ === _ ? A ? _ - A : _ : 0;
      }
      function wx(p) {
        return p ? cu(un(p), 0, V) : 0;
      }
      function Ya(p) {
        if (typeof p == "number")
          return p;
        if (ba(p))
          return Z;
        if (Ar(p)) {
          var _ = typeof p.valueOf == "function" ? p.valueOf() : p;
          p = Ar(_) ? _ + "" : _;
        }
        if (typeof p != "string")
          return p === 0 ? p : +p;
        p = WR(p);
        var A = yi.test(p);
        return A || ue.test(p) ? y9(p.slice(2), A ? 2 : 8) : Si.test(p) ? Z : +p;
      }
      function xx(p) {
        return Lo(p, Ji(p));
      }
      function lz(p) {
        return p ? cu(un(p), -B, B) : p === 0 ? p : 0;
      }
      function qn(p) {
        return p == null ? "" : va(p);
      }
      var uz = Sc(function(p, _) {
        if (_f(_) || Zi(_)) {
          Lo(_, ui(_), p);
          return;
        }
        for (var A in _)
          Yn.call(_, A) && df(p, A, _[A]);
      }), Nx = Sc(function(p, _) {
        Lo(_, Ji(_), p);
      }), Lh = Sc(function(p, _, A, w) {
        Lo(_, Ji(_), p, w);
      }), cz = Sc(function(p, _, A, w) {
        Lo(_, ui(_), p, w);
      }), dz = gs(hb);
      function fz(p, _) {
        var A = Ec(p);
        return _ == null ? A : lw(A, _);
      }
      var pz = mn(function(p, _) {
        p = Kn(p);
        var A = -1, w = _.length, F = w > 2 ? _[2] : n;
        for (F && Bi(_[0], _[1], F) && (w = 1); ++A < w; )
          for (var z = _[A], J = Ji(z), ie = -1, ge = J.length; ++ie < ge; ) {
            var ke = J[ie], Fe = p[ke];
            (Fe === n || lo(Fe, _c[ke]) && !Yn.call(p, ke)) && (p[ke] = z[ke]);
          }
        return p;
      }), mz = mn(function(p) {
        return p.push(n, Ww), ga(Dx, n, p);
      });
      function hz(p, _) {
        return YR(p, Gt(_, 3), Io);
      }
      function gz(p, _) {
        return YR(p, Gt(_, 3), _b);
      }
      function _z(p, _) {
        return p == null ? p : gb(p, Gt(_, 3), Ji);
      }
      function vz(p, _) {
        return p == null ? p : pw(p, Gt(_, 3), Ji);
      }
      function bz(p, _) {
        return p && Io(p, Gt(_, 3));
      }
      function Ez(p, _) {
        return p && _b(p, Gt(_, 3));
      }
      function Sz(p) {
        return p == null ? [] : mh(p, ui(p));
      }
      function yz(p) {
        return p == null ? [] : mh(p, Ji(p));
      }
      function jb(p, _, A) {
        var w = p == null ? n : du(p, _);
        return w === n ? A : w;
      }
      function Tz(p, _) {
        return p != null && Qw(p, _, VG);
      }
      function Qb(p, _) {
        return p != null && Qw(p, _, WG);
      }
      var Cz = Gw(function(p, _, A) {
        _ != null && typeof _.toString != "function" && (_ = th.call(_)), p[_] = A;
      }, Zb(ea)), Az = Gw(function(p, _, A) {
        _ != null && typeof _.toString != "function" && (_ = th.call(_)), Yn.call(p, _) ? p[_].push(A) : p[_] = [A];
      }, Gt), Oz = mn(pf);
      function ui(p) {
        return Zi(p) ? ow(p) : Sb(p);
      }
      function Ji(p) {
        return Zi(p) ? ow(p, !0) : rY(p);
      }
      function Rz(p, _) {
        var A = {};
        return _ = Gt(_, 3), Io(p, function(w, F, z) {
          ms(A, _(w, F, z), w);
        }), A;
      }
      function wz(p, _) {
        var A = {};
        return _ = Gt(_, 3), Io(p, function(w, F, z) {
          ms(A, F, _(w, F, z));
        }), A;
      }
      var xz = Sc(function(p, _, A) {
        hh(p, _, A);
      }), Dx = Sc(function(p, _, A, w) {
        hh(p, _, A, w);
      }), Nz = gs(function(p, _) {
        var A = {};
        if (p == null)
          return A;
        var w = !1;
        _ = Sr(_, function(z) {
          return z = pl(z, p), w || (w = z.length > 1), z;
        }), Lo(p, Mb(p), A), w && (A = Ua(A, d | f | h, CY));
        for (var F = _.length; F--; )
          Rb(A, _[F]);
        return A;
      });
      function Dz(p, _) {
        return Ix(p, Nh(Gt(_)));
      }
      var Iz = gs(function(p, _) {
        return p == null ? {} : aY(p, _);
      });
      function Ix(p, _) {
        if (p == null)
          return {};
        var A = Sr(Mb(p), function(w) {
          return [w];
        });
        return _ = Gt(_), Tw(p, A, function(w, F) {
          return _(w, F[0]);
        });
      }
      function Lz(p, _, A) {
        _ = pl(_, p);
        var w = -1, F = _.length;
        for (F || (F = 1, p = n); ++w < F; ) {
          var z = p == null ? n : p[ko(_[w])];
          z === n && (w = F, z = A), p = vs(z) ? z.call(p) : z;
        }
        return p;
      }
      function kz(p, _, A) {
        return p == null ? p : hf(p, _, A);
      }
      function Mz(p, _, A, w) {
        return w = typeof w == "function" ? w : n, p == null ? p : hf(p, _, A, w);
      }
      var Lx = zw(ui), kx = zw(Ji);
      function Pz(p, _, A) {
        var w = an(p), F = w || hl(p) || Cc(p);
        if (_ = Gt(_, 4), A == null) {
          var z = p && p.constructor;
          F ? A = w ? new z() : [] : Ar(p) ? A = vs(z) ? Ec(ih(p)) : {} : A = {};
        }
        return (F ? Fa : Io)(p, function(J, ie, ge) {
          return _(A, J, ie, ge);
        }), A;
      }
      function Fz(p, _) {
        return p == null ? !0 : Rb(p, _);
      }
      function Bz(p, _, A) {
        return p == null ? p : ww(p, _, Nb(A));
      }
      function $z(p, _, A, w) {
        return w = typeof w == "function" ? w : n, p == null ? p : ww(p, _, Nb(A), w);
      }
      function Ac(p) {
        return p == null ? [] : lb(p, ui(p));
      }
      function Uz(p) {
        return p == null ? [] : lb(p, Ji(p));
      }
      function qz(p, _, A) {
        return A === n && (A = _, _ = n), A !== n && (A = Ya(A), A = A === A ? A : 0), _ !== n && (_ = Ya(_), _ = _ === _ ? _ : 0), cu(Ya(p), _, A);
      }
      function Gz(p, _, A) {
        return _ = bs(_), A === n ? (A = _, _ = 0) : A = bs(A), p = Ya(p), KG(p, _, A);
      }
      function Yz(p, _, A) {
        if (A && typeof A != "boolean" && Bi(p, _, A) && (_ = A = n), A === n && (typeof _ == "boolean" ? (A = _, _ = n) : typeof p == "boolean" && (A = p, p = n)), p === n && _ === n ? (p = 0, _ = 1) : (p = bs(p), _ === n ? (_ = p, p = 0) : _ = bs(_)), p > _) {
          var w = p;
          p = _, _ = w;
        }
        if (A || p % 1 || _ % 1) {
          var F = iw();
          return Ti(p + F * (_ - p + fc("1e-" + ((F + "").length - 1))), _);
        }
        return Cb(p, _);
      }
      var Hz = yc(function(p, _, A) {
        return _ = _.toLowerCase(), p + (A ? Mx(_) : _);
      });
      function Mx(p) {
        return Xb(qn(p).toLowerCase());
      }
      function Px(p) {
        return p = qn(p), p && p.replace(ye, k9).replace(au, "");
      }
      function zz(p, _, A) {
        p = qn(p), _ = va(_);
        var w = p.length;
        A = A === n ? w : cu(un(A), 0, w);
        var F = A;
        return A -= _.length, A >= 0 && p.slice(A, F) == _;
      }
      function Vz(p) {
        return p = qn(p), p && M.test(p) ? p.replace(te, M9) : p;
      }
      function Wz(p) {
        return p = qn(p), p && dt.test(p) ? p.replace(Ve, "\\$&") : p;
      }
      var Kz = yc(function(p, _, A) {
        return p + (A ? "-" : "") + _.toLowerCase();
      }), jz = yc(function(p, _, A) {
        return p + (A ? " " : "") + _.toLowerCase();
      }), Qz = $w("toLowerCase");
      function Xz(p, _, A) {
        p = qn(p), _ = un(_);
        var w = _ ? hc(p) : 0;
        if (!_ || w >= _)
          return p;
        var F = (_ - w) / 2;
        return Sh(lh(F), A) + p + Sh(sh(F), A);
      }
      function Zz(p, _, A) {
        p = qn(p), _ = un(_);
        var w = _ ? hc(p) : 0;
        return _ && w < _ ? p + Sh(_ - w, A) : p;
      }
      function Jz(p, _, A) {
        p = qn(p), _ = un(_);
        var w = _ ? hc(p) : 0;
        return _ && w < _ ? Sh(_ - w, A) + p : p;
      }
      function eV(p, _, A) {
        return A || _ == null ? _ = 0 : _ && (_ = +_), sG(qn(p).replace(Pe, ""), _ || 0);
      }
      function tV(p, _, A) {
        return (A ? Bi(p, _, A) : _ === n) ? _ = 1 : _ = un(_), Ab(qn(p), _);
      }
      function nV() {
        var p = arguments, _ = qn(p[0]);
        return p.length < 3 ? _ : _.replace(p[1], p[2]);
      }
      var rV = yc(function(p, _, A) {
        return p + (A ? "_" : "") + _.toLowerCase();
      });
      function iV(p, _, A) {
        return A && typeof A != "number" && Bi(p, _, A) && (_ = A = n), A = A === n ? V : A >>> 0, A ? (p = qn(p), p && (typeof _ == "string" || _ != null && !Kb(_)) && (_ = va(_), !_ && mc(p)) ? ml(oo(p), 0, A) : p.split(_, A)) : [];
      }
      var aV = yc(function(p, _, A) {
        return p + (A ? " " : "") + Xb(_);
      });
      function oV(p, _, A) {
        return p = qn(p), A = A == null ? 0 : cu(un(A), 0, p.length), _ = va(_), p.slice(A, A + _.length) == _;
      }
      function sV(p, _, A) {
        var w = H.templateSettings;
        A && Bi(p, _, A) && (_ = n), p = qn(p), _ = Lh({}, _, w, Vw);
        var F = Lh({}, _.imports, w.imports, Vw), z = ui(F), J = lb(F, z), ie, ge, ke = 0, Fe = _.interpolate || ct, qe = "__p += '", lt = cb(
          (_.escape || ct).source + "|" + Fe.source + "|" + (Fe === ce ? Cr : ct).source + "|" + (_.evaluate || ct).source + "|$",
          "g"
        ), Ct = "//# sourceURL=" + (Yn.call(_, "sourceURL") ? (_.sourceURL + "").replace(/\s/g, " ") : "lodash.templateSources[" + ++Pn + "]") + `
`;
        p.replace(lt, function(Ht, vn, Tn, Ea, $i, Sa) {
          return Tn || (Tn = Ea), qe += p.slice(ke, Sa).replace(en, P9), vn && (ie = !0, qe += `' +
__e(` + vn + `) +
'`), $i && (ge = !0, qe += `';
` + $i + `;
__p += '`), Tn && (qe += `' +
((__t = (` + Tn + `)) == null ? '' : __t) +
'`), ke = Sa + Ht.length, Ht;
        }), qe += `';
`;
        var Yt = Yn.call(_, "variable") && _.variable;
        if (!Yt)
          qe = `with (obj) {
` + qe + `
}
`;
        else if (Un.test(Yt))
          throw new tn(s);
        qe = (ge ? qe.replace(Dn, "") : qe).replace(gn, "$1").replace(Vn, "$1;"), qe = "function(" + (Yt || "obj") + `) {
` + (Yt ? "" : `obj || (obj = {});
`) + "var __t, __p = ''" + (ie ? ", __e = _.escape" : "") + (ge ? `, __j = Array.prototype.join;
function print() { __p += __j.call(arguments, '') }
` : `;
`) + qe + `return __p
}`;
        var fn = Bx(function() {
          return Fn(z, Ct + "return " + qe).apply(n, J);
        });
        if (fn.source = qe, Wb(fn))
          throw fn;
        return fn;
      }
      function lV(p) {
        return qn(p).toLowerCase();
      }
      function uV(p) {
        return qn(p).toUpperCase();
      }
      function cV(p, _, A) {
        if (p = qn(p), p && (A || _ === n))
          return WR(p);
        if (!p || !(_ = va(_)))
          return p;
        var w = oo(p), F = oo(_), z = KR(w, F), J = jR(w, F) + 1;
        return ml(w, z, J).join("");
      }
      function dV(p, _, A) {
        if (p = qn(p), p && (A || _ === n))
          return p.slice(0, XR(p) + 1);
        if (!p || !(_ = va(_)))
          return p;
        var w = oo(p), F = jR(w, oo(_)) + 1;
        return ml(w, 0, F).join("");
      }
      function fV(p, _, A) {
        if (p = qn(p), p && (A || _ === n))
          return p.replace(Pe, "");
        if (!p || !(_ = va(_)))
          return p;
        var w = oo(p), F = KR(w, oo(_));
        return ml(w, F).join("");
      }
      function pV(p, _) {
        var A = q, w = $;
        if (Ar(_)) {
          var F = "separator" in _ ? _.separator : F;
          A = "length" in _ ? un(_.length) : A, w = "omission" in _ ? va(_.omission) : w;
        }
        p = qn(p);
        var z = p.length;
        if (mc(p)) {
          var J = oo(p);
          z = J.length;
        }
        if (A >= z)
          return p;
        var ie = A - hc(w);
        if (ie < 1)
          return w;
        var ge = J ? ml(J, 0, ie).join("") : p.slice(0, ie);
        if (F === n)
          return ge + w;
        if (J && (ie += ge.length - ie), Kb(F)) {
          if (p.slice(ie).search(F)) {
            var ke, Fe = ge;
            for (F.global || (F = cb(F.source, qn(ti.exec(F)) + "g")), F.lastIndex = 0; ke = F.exec(Fe); )
              var qe = ke.index;
            ge = ge.slice(0, qe === n ? ie : qe);
          }
        } else if (p.indexOf(va(F), ie) != ie) {
          var lt = ge.lastIndexOf(F);
          lt > -1 && (ge = ge.slice(0, lt));
        }
        return ge + w;
      }
      function mV(p) {
        return p = qn(p), p && _e.test(p) ? p.replace(X, Y9) : p;
      }
      var hV = yc(function(p, _, A) {
        return p + (A ? " " : "") + _.toUpperCase();
      }), Xb = $w("toUpperCase");
      function Fx(p, _, A) {
        return p = qn(p), _ = A ? n : _, _ === n ? B9(p) ? V9(p) : x9(p) : p.match(_) || [];
      }
      var Bx = mn(function(p, _) {
        try {
          return ga(p, n, _);
        } catch (A) {
          return Wb(A) ? A : new tn(A);
        }
      }), gV = gs(function(p, _) {
        return Fa(_, function(A) {
          A = ko(A), ms(p, A, zb(p[A], p));
        }), p;
      });
      function _V(p) {
        var _ = p == null ? 0 : p.length, A = Gt();
        return p = _ ? Sr(p, function(w) {
          if (typeof w[1] != "function")
            throw new Ba(o);
          return [A(w[0]), w[1]];
        }) : [], mn(function(w) {
          for (var F = -1; ++F < _; ) {
            var z = p[F];
            if (ga(z[0], this, w))
              return ga(z[1], this, w);
          }
        });
      }
      function vV(p) {
        return YG(Ua(p, d));
      }
      function Zb(p) {
        return function() {
          return p;
        };
      }
      function bV(p, _) {
        return p == null || p !== p ? _ : p;
      }
      var EV = qw(), SV = qw(!0);
      function ea(p) {
        return p;
      }
      function Jb(p) {
        return _w(typeof p == "function" ? p : Ua(p, d));
      }
      function yV(p) {
        return bw(Ua(p, d));
      }
      function TV(p, _) {
        return Ew(p, Ua(_, d));
      }
      var CV = mn(function(p, _) {
        return function(A) {
          return pf(A, p, _);
        };
      }), AV = mn(function(p, _) {
        return function(A) {
          return pf(p, A, _);
        };
      });
      function e0(p, _, A) {
        var w = ui(_), F = mh(_, w);
        A == null && !(Ar(_) && (F.length || !w.length)) && (A = _, _ = p, p = this, F = mh(_, ui(_)));
        var z = !(Ar(A) && "chain" in A) || !!A.chain, J = vs(p);
        return Fa(F, function(ie) {
          var ge = _[ie];
          p[ie] = ge, J && (p.prototype[ie] = function() {
            var ke = this.__chain__;
            if (z || ke) {
              var Fe = p(this.__wrapped__), qe = Fe.__actions__ = Xi(this.__actions__);
              return qe.push({ func: ge, args: arguments, thisArg: p }), Fe.__chain__ = ke, Fe;
            }
            return ge.apply(p, ll([this.value()], arguments));
          });
        }), p;
      }
      function OV() {
        return hi._ === this && (hi._ = Z9), this;
      }
      function t0() {
      }
      function RV(p) {
        return p = un(p), mn(function(_) {
          return Sw(_, p);
        });
      }
      var wV = Ib(Sr), xV = Ib(GR), NV = Ib(rb);
      function $x(p) {
        return $b(p) ? ib(ko(p)) : oY(p);
      }
      function DV(p) {
        return function(_) {
          return p == null ? n : du(p, _);
        };
      }
      var IV = Yw(), LV = Yw(!0);
      function n0() {
        return [];
      }
      function r0() {
        return !1;
      }
      function kV() {
        return {};
      }
      function MV() {
        return "";
      }
      function PV() {
        return !0;
      }
      function FV(p, _) {
        if (p = un(p), p < 1 || p > B)
          return [];
        var A = V, w = Ti(p, V);
        _ = Gt(_), p -= V;
        for (var F = sb(w, _); ++A < p; )
          _(A);
        return F;
      }
      function BV(p) {
        return an(p) ? Sr(p, ko) : ba(p) ? [p] : Xi(ax(qn(p)));
      }
      function $V(p) {
        var _ = ++Q9;
        return qn(p) + _;
      }
      var UV = Eh(function(p, _) {
        return p + _;
      }, 0), qV = Lb("ceil"), GV = Eh(function(p, _) {
        return p / _;
      }, 1), YV = Lb("floor");
      function HV(p) {
        return p && p.length ? ph(p, ea, vb) : n;
      }
      function zV(p, _) {
        return p && p.length ? ph(p, Gt(_, 2), vb) : n;
      }
      function VV(p) {
        return zR(p, ea);
      }
      function WV(p, _) {
        return zR(p, Gt(_, 2));
      }
      function KV(p) {
        return p && p.length ? ph(p, ea, yb) : n;
      }
      function jV(p, _) {
        return p && p.length ? ph(p, Gt(_, 2), yb) : n;
      }
      var QV = Eh(function(p, _) {
        return p * _;
      }, 1), XV = Lb("round"), ZV = Eh(function(p, _) {
        return p - _;
      }, 0);
      function JV(p) {
        return p && p.length ? ob(p, ea) : 0;
      }
      function eW(p, _) {
        return p && p.length ? ob(p, Gt(_, 2)) : 0;
      }
      return H.after = y7, H.ary = gx, H.assign = uz, H.assignIn = Nx, H.assignInWith = Lh, H.assignWith = cz, H.at = dz, H.before = _x, H.bind = zb, H.bindAll = gV, H.bindKey = vx, H.castArray = k7, H.chain = px, H.chunk = YY, H.compact = HY, H.concat = zY, H.cond = _V, H.conforms = vV, H.constant = Zb, H.countBy = JH, H.create = fz, H.curry = bx, H.curryRight = Ex, H.debounce = Sx, H.defaults = pz, H.defaultsDeep = mz, H.defer = T7, H.delay = C7, H.difference = VY, H.differenceBy = WY, H.differenceWith = KY, H.drop = jY, H.dropRight = QY, H.dropRightWhile = XY, H.dropWhile = ZY, H.fill = JY, H.filter = t7, H.flatMap = i7, H.flatMapDeep = a7, H.flatMapDepth = o7, H.flatten = ux, H.flattenDeep = eH, H.flattenDepth = tH, H.flip = A7, H.flow = EV, H.flowRight = SV, H.fromPairs = nH, H.functions = Sz, H.functionsIn = yz, H.groupBy = s7, H.initial = iH, H.intersection = aH, H.intersectionBy = oH, H.intersectionWith = sH, H.invert = Cz, H.invertBy = Az, H.invokeMap = u7, H.iteratee = Jb, H.keyBy = c7, H.keys = ui, H.keysIn = Ji, H.map = Rh, H.mapKeys = Rz, H.mapValues = wz, H.matches = yV, H.matchesProperty = TV, H.memoize = xh, H.merge = xz, H.mergeWith = Dx, H.method = CV, H.methodOf = AV, H.mixin = e0, H.negate = Nh, H.nthArg = RV, H.omit = Nz, H.omitBy = Dz, H.once = O7, H.orderBy = d7, H.over = wV, H.overArgs = R7, H.overEvery = xV, H.overSome = NV, H.partial = Vb, H.partialRight = yx, H.partition = f7, H.pick = Iz, H.pickBy = Ix, H.property = $x, H.propertyOf = DV, H.pull = dH, H.pullAll = dx, H.pullAllBy = fH, H.pullAllWith = pH, H.pullAt = mH, H.range = IV, H.rangeRight = LV, H.rearg = w7, H.reject = h7, H.remove = hH, H.rest = x7, H.reverse = Yb, H.sampleSize = _7, H.set = kz, H.setWith = Mz, H.shuffle = v7, H.slice = gH, H.sortBy = S7, H.sortedUniq = TH, H.sortedUniqBy = CH, H.split = iV, H.spread = N7, H.tail = AH, H.take = OH, H.takeRight = RH, H.takeRightWhile = wH, H.takeWhile = xH, H.tap = HH, H.throttle = D7, H.thru = Oh, H.toArray = Rx, H.toPairs = Lx, H.toPairsIn = kx, H.toPath = BV, H.toPlainObject = xx, H.transform = Pz, H.unary = I7, H.union = NH, H.unionBy = DH, H.unionWith = IH, H.uniq = LH, H.uniqBy = kH, H.uniqWith = MH, H.unset = Fz, H.unzip = Hb, H.unzipWith = fx, H.update = Bz, H.updateWith = $z, H.values = Ac, H.valuesIn = Uz, H.without = PH, H.words = Fx, H.wrap = L7, H.xor = FH, H.xorBy = BH, H.xorWith = $H, H.zip = UH, H.zipObject = qH, H.zipObjectDeep = GH, H.zipWith = YH, H.entries = Lx, H.entriesIn = kx, H.extend = Nx, H.extendWith = Lh, e0(H, H), H.add = UV, H.attempt = Bx, H.camelCase = Hz, H.capitalize = Mx, H.ceil = qV, H.clamp = qz, H.clone = M7, H.cloneDeep = F7, H.cloneDeepWith = B7, H.cloneWith = P7, H.conformsTo = $7, H.deburr = Px, H.defaultTo = bV, H.divide = GV, H.endsWith = zz, H.eq = lo, H.escape = Vz, H.escapeRegExp = Wz, H.every = e7, H.find = n7, H.findIndex = sx, H.findKey = hz, H.findLast = r7, H.findLastIndex = lx, H.findLastKey = gz, H.floor = YV, H.forEach = mx, H.forEachRight = hx, H.forIn = _z, H.forInRight = vz, H.forOwn = bz, H.forOwnRight = Ez, H.get = jb, H.gt = U7, H.gte = q7, H.has = Tz, H.hasIn = Qb, H.head = cx, H.identity = ea, H.includes = l7, H.indexOf = rH, H.inRange = Gz, H.invoke = Oz, H.isArguments = mu, H.isArray = an, H.isArrayBuffer = G7, H.isArrayLike = Zi, H.isArrayLikeObject = Pr, H.isBoolean = Y7, H.isBuffer = hl, H.isDate = H7, H.isElement = z7, H.isEmpty = V7, H.isEqual = W7, H.isEqualWith = K7, H.isError = Wb, H.isFinite = j7, H.isFunction = vs, H.isInteger = Tx, H.isLength = Dh, H.isMap = Cx, H.isMatch = Q7, H.isMatchWith = X7, H.isNaN = Z7, H.isNative = J7, H.isNil = tz, H.isNull = ez, H.isNumber = Ax, H.isObject = Ar, H.isObjectLike = Dr, H.isPlainObject = bf, H.isRegExp = Kb, H.isSafeInteger = nz, H.isSet = Ox, H.isString = Ih, H.isSymbol = ba, H.isTypedArray = Cc, H.isUndefined = rz, H.isWeakMap = iz, H.isWeakSet = az, H.join = lH, H.kebabCase = Kz, H.last = Ga, H.lastIndexOf = uH, H.lowerCase = jz, H.lowerFirst = Qz, H.lt = oz, H.lte = sz, H.max = HV, H.maxBy = zV, H.mean = VV, H.meanBy = WV, H.min = KV, H.minBy = jV, H.stubArray = n0, H.stubFalse = r0, H.stubObject = kV, H.stubString = MV, H.stubTrue = PV, H.multiply = QV, H.nth = cH, H.noConflict = OV, H.noop = t0, H.now = wh, H.pad = Xz, H.padEnd = Zz, H.padStart = Jz, H.parseInt = eV, H.random = Yz, H.reduce = p7, H.reduceRight = m7, H.repeat = tV, H.replace = nV, H.result = Lz, H.round = XV, H.runInContext = fe, H.sample = g7, H.size = b7, H.snakeCase = rV, H.some = E7, H.sortedIndex = _H, H.sortedIndexBy = vH, H.sortedIndexOf = bH, H.sortedLastIndex = EH, H.sortedLastIndexBy = SH, H.sortedLastIndexOf = yH, H.startCase = aV, H.startsWith = oV, H.subtract = ZV, H.sum = JV, H.sumBy = eW, H.template = sV, H.times = FV, H.toFinite = bs, H.toInteger = un, H.toLength = wx, H.toLower = lV, H.toNumber = Ya, H.toSafeInteger = lz, H.toString = qn, H.toUpper = uV, H.trim = cV, H.trimEnd = dV, H.trimStart = fV, H.truncate = pV, H.unescape = mV, H.uniqueId = $V, H.upperCase = hV, H.upperFirst = Xb, H.each = mx, H.eachRight = hx, H.first = cx, e0(H, function() {
        var p = {};
        return Io(H, function(_, A) {
          Yn.call(H.prototype, A) || (p[A] = _);
        }), p;
      }(), { chain: !1 }), H.VERSION = r, Fa(["bind", "bindKey", "curry", "curryRight", "partial", "partialRight"], function(p) {
        H[p].placeholder = H;
      }), Fa(["drop", "take"], function(p, _) {
        Sn.prototype[p] = function(A) {
          A = A === n ? 1 : ri(un(A), 0);
          var w = this.__filtered__ && !_ ? new Sn(this) : this.clone();
          return w.__filtered__ ? w.__takeCount__ = Ti(A, w.__takeCount__) : w.__views__.push({
            size: Ti(A, V),
            type: p + (w.__dir__ < 0 ? "Right" : "")
          }), w;
        }, Sn.prototype[p + "Right"] = function(A) {
          return this.reverse()[p](A).reverse();
        };
      }), Fa(["filter", "map", "takeWhile"], function(p, _) {
        var A = _ + 1, w = A == L || A == I;
        Sn.prototype[p] = function(F) {
          var z = this.clone();
          return z.__iteratees__.push({
            iteratee: Gt(F, 3),
            type: A
          }), z.__filtered__ = z.__filtered__ || w, z;
        };
      }), Fa(["head", "last"], function(p, _) {
        var A = "take" + (_ ? "Right" : "");
        Sn.prototype[p] = function() {
          return this[A](1).value()[0];
        };
      }), Fa(["initial", "tail"], function(p, _) {
        var A = "drop" + (_ ? "" : "Right");
        Sn.prototype[p] = function() {
          return this.__filtered__ ? new Sn(this) : this[A](1);
        };
      }), Sn.prototype.compact = function() {
        return this.filter(ea);
      }, Sn.prototype.find = function(p) {
        return this.filter(p).head();
      }, Sn.prototype.findLast = function(p) {
        return this.reverse().find(p);
      }, Sn.prototype.invokeMap = mn(function(p, _) {
        return typeof p == "function" ? new Sn(this) : this.map(function(A) {
          return pf(A, p, _);
        });
      }), Sn.prototype.reject = function(p) {
        return this.filter(Nh(Gt(p)));
      }, Sn.prototype.slice = function(p, _) {
        p = un(p);
        var A = this;
        return A.__filtered__ && (p > 0 || _ < 0) ? new Sn(A) : (p < 0 ? A = A.takeRight(-p) : p && (A = A.drop(p)), _ !== n && (_ = un(_), A = _ < 0 ? A.dropRight(-_) : A.take(_ - p)), A);
      }, Sn.prototype.takeRightWhile = function(p) {
        return this.reverse().takeWhile(p).reverse();
      }, Sn.prototype.toArray = function() {
        return this.take(V);
      }, Io(Sn.prototype, function(p, _) {
        var A = /^(?:filter|find|map|reject)|While$/.test(_), w = /^(?:head|last)$/.test(_), F = H[w ? "take" + (_ == "last" ? "Right" : "") : _], z = w || /^find/.test(_);
        F && (H.prototype[_] = function() {
          var J = this.__wrapped__, ie = w ? [1] : arguments, ge = J instanceof Sn, ke = ie[0], Fe = ge || an(J), qe = function(vn) {
            var Tn = F.apply(H, ll([vn], ie));
            return w && lt ? Tn[0] : Tn;
          };
          Fe && A && typeof ke == "function" && ke.length != 1 && (ge = Fe = !1);
          var lt = this.__chain__, Ct = !!this.__actions__.length, Yt = z && !lt, fn = ge && !Ct;
          if (!z && Fe) {
            J = fn ? J : new Sn(this);
            var Ht = p.apply(J, ie);
            return Ht.__actions__.push({ func: Oh, args: [qe], thisArg: n }), new $a(Ht, lt);
          }
          return Yt && fn ? p.apply(this, ie) : (Ht = this.thru(qe), Yt ? w ? Ht.value()[0] : Ht.value() : Ht);
        });
      }), Fa(["pop", "push", "shift", "sort", "splice", "unshift"], function(p) {
        var _ = Zm[p], A = /^(?:push|sort|unshift)$/.test(p) ? "tap" : "thru", w = /^(?:pop|shift)$/.test(p);
        H.prototype[p] = function() {
          var F = arguments;
          if (w && !this.__chain__) {
            var z = this.value();
            return _.apply(an(z) ? z : [], F);
          }
          return this[A](function(J) {
            return _.apply(an(J) ? J : [], F);
          });
        };
      }), Io(Sn.prototype, function(p, _) {
        var A = H[_];
        if (A) {
          var w = A.name + "";
          Yn.call(bc, w) || (bc[w] = []), bc[w].push({ name: _, func: A });
        }
      }), bc[bh(n, y).name] = [{
        name: "wrapper",
        func: n
      }], Sn.prototype.clone = mG, Sn.prototype.reverse = hG, Sn.prototype.value = gG, H.prototype.at = zH, H.prototype.chain = VH, H.prototype.commit = WH, H.prototype.next = KH, H.prototype.plant = QH, H.prototype.reverse = XH, H.prototype.toJSON = H.prototype.valueOf = H.prototype.value = ZH, H.prototype.first = H.prototype.head, of && (H.prototype[of] = jH), H;
    }, gc = W9();
    ou ? ((ou.exports = gc)._ = gc, Jv._ = gc) : hi._ = gc;
  }).call(Pc);
})(k_, k_.exports);
var kHe = k_.exports;
const Oa = /* @__PURE__ */ E1(kHe), MHe = {
  name: "TextElement",
  data() {
    return {
      merge: !0,
      defaultClasses: {}
    };
  }
}, PHe = ["value", "type", "name", "id", "placeholder", "autocomplete", "disabled", "readonly"], FHe = {
  key: 4,
  class: "vfb-element-selector-plugin"
};
function BHe(e, t, n, r, i, a) {
  const o = Bt("ElementAddon"), s = Bt("ElementLabelFloating"), l = Bt("ElementLoader"), u = Bt("Vueform");
  return U(), Ae(ze(e.elementLayout), { ref: "container" }, nr({
    element: Qe(() => [
      de("div", {
        class: re(e.classes.inputContainer)
      }, [
        e.hasAddonBefore ? (U(), Ae(o, {
          key: 0,
          type: "before"
        }, {
          default: Qe(() => [
            Me(e.$slots, "addon-before")
          ]),
          _: 3
        })) : se("", !0),
        e.hasAddonAfter ? (U(), Ae(o, {
          key: 1,
          type: "after"
        }, {
          default: Qe(() => [
            Me(e.$slots, "addon-after")
          ]),
          _: 3
        })) : se("", !0),
        e.hasFloating && !e.empty ? (U(), Ae(s, {
          key: 2,
          visible: !e.empty
        }, null, 8, ["visible"])) : se("", !0),
        e.isLoading ? (U(), Ae(l, { key: 3 })) : se("", !0),
        de("input", $e({
          value: e.model,
          type: e.inputType,
          name: e.name,
          id: e.fieldId,
          class: e.classes.input,
          placeholder: e.placeholder,
          autocomplete: e.autocomplete,
          disabled: e.isDisabled,
          readonly: e.readonly
        }, {
          ...e.attrs,
          ...e.aria
        }, {
          onKeydown: t[0] || (t[0] = (...c) => e.handleKeydown && e.handleKeydown(...c)),
          onKeyup: t[1] || (t[1] = (...c) => e.handleKeyup && e.handleKeyup(...c)),
          onKeypress: t[2] || (t[2] = (...c) => e.handleKeypress && e.handleKeypress(...c)),
          onInput: t[3] || (t[3] = (...c) => e.handleInput && e.handleInput(...c)),
          onSelect: t[4] || (t[4] = (...c) => e.handleInput && e.handleInput(...c)),
          onBlur: t[5] || (t[5] = (...c) => e.handleBlur && e.handleBlur(...c)),
          ref: "input"
        }), null, 16, PHe),
        e.elementSelector && e.selectingElement ? (U(), ee("div", FHe, [
          rn(u, $e({ ref: "elementSelector$" }, e.elementSelectorForm), null, 16)
        ])) : se("", !0)
      ], 2)
    ]),
    _: 2
  }, [
    It(e.elementSlots, (c, d) => ({
      name: d,
      fn: Qe(() => [
        Me(e.$slots, d, { el$: e.el$ }, () => [
          (U(), Ae(ze(c), { el$: e.el$ }, null, 8, ["el$"]))
        ])
      ])
    }))
  ]), 1536);
}
const $He = /* @__PURE__ */ Zs(MHe, [["render", BHe]]), UHe = {
  name: "TextareaElement",
  data() {
    return {
      merge: !0,
      defaultClasses: {}
    };
  }
}, qHe = ["value", "name", "id", "placeholder", "disabled", "readonly", "rows"], GHe = {
  key: 3,
  class: "vfb-element-selector-plugin"
};
function YHe(e, t, n, r, i, a) {
  const o = Bt("ElementAddon"), s = Bt("ElementLabelFloating"), l = Bt("ElementLoader"), u = Bt("Vueform");
  return U(), Ae(ze(e.elementLayout), { ref: "container" }, nr({
    element: Qe(() => [
      de("div", {
        class: re(e.classes.inputContainer)
      }, [
        e.hasAddonBefore ? (U(), Ae(o, {
          key: 0,
          type: "before"
        }, {
          default: Qe(() => [
            Me(e.$slots, "addon-before")
          ]),
          _: 3
        })) : se("", !0),
        e.hasAddonAfter ? (U(), Ae(o, {
          key: 1,
          type: "after"
        }, {
          default: Qe(() => [
            Me(e.$slots, "addon-after")
          ]),
          _: 3
        })) : se("", !0),
        e.hasFloating && !e.empty ? (U(), Ae(s, {
          key: 2,
          visible: !e.empty
        }, null, 8, ["visible"])) : se("", !0),
        Gn(rn(l, null, null, 512), [
          [Wi, e.pending]
        ]),
        de("textarea", $e({
          value: e.model,
          name: e.name,
          id: e.fieldId,
          class: e.classes.input,
          placeholder: e.placeholder,
          disabled: e.isDisabled,
          readonly: e.readonly,
          rows: e.rows
        }, {
          ...e.attrs,
          ...e.aria
        }, {
          onKeydown: t[0] || (t[0] = (...c) => e.handleKeydown && e.handleKeydown(...c)),
          onKeyup: t[1] || (t[1] = (...c) => e.handleKeyup && e.handleKeyup(...c)),
          onKeypress: t[2] || (t[2] = (...c) => e.handleKeypress && e.handleKeypress(...c)),
          onInput: t[3] || (t[3] = (...c) => e.handleInput && e.handleInput(...c)),
          onBlur: t[4] || (t[4] = (...c) => e.handleBlur && e.handleBlur(...c)),
          ref: "input"
        }), null, 16, qHe),
        e.elementSelector && e.selectingElement ? (U(), ee("div", GHe, [
          rn(u, $e({ ref: "elementSelector$" }, e.elementSelectorForm), null, 16)
        ])) : se("", !0)
      ], 2)
    ]),
    _: 2
  }, [
    It(e.elementSlots, (c, d) => ({
      name: d,
      fn: Qe(() => [
        Me(e.$slots, d, { el$: e.el$ }, () => [
          (U(), Ae(ze(c), { el$: e.el$ }, null, 8, ["el$"]))
        ])
      ])
    }))
  ]), 1536);
}
const HHe = /* @__PURE__ */ Zs(UHe, [["render", YHe]]), zHe = {
  props: {
    option: {
      type: Object,
      required: !0
    },
    isPointed: {
      type: Function,
      required: !1
    },
    isSelected: {
      type: Function,
      required: !1
    }
  }
}, VHe = { class: "vfb-field-spacing" }, WHe = { class: "vfb-field-icon-container" }, KHe = ["src", "title"], jHe = {
  class: "vfb-field-text",
  "aria-hidden": "true"
}, QHe = { class: "vfb-field-text-primary" }, XHe = {
  key: 0,
  class: "vfb-field-text-secondary"
};
function ZHe(e, t, n, r, i, a) {
  const o = Bt("builder-icon");
  return U(), ee("div", {
    class: re([
      "vfb-field-wrapper",
      n.option.root ? "vfb-field-wrapper-root" : null,
      n.option.container ? "vfb-field-wrapper-container" : null,
      n.option.disabled ? "vfb-field-wrapper-disabled" : null
    ])
  }, [
    de("div", VHe, [
      (U(!0), ee(gt, null, It(n.option.level, (s) => (U(), ee(gt, null, [
        qx("        ")
      ], 64))), 256)),
      n.option.level >= 1 ? (U(), ee(gt, { key: 0 }, [
        qx("   ")
      ], 64)) : se("", !0)
    ]),
    n.option.container && n.option.children && n.option.children.length && !n.option.root ? (U(), ee("div", {
      key: 0,
      class: re([
        "vfb-field-chevron-container",
        n.option.level > 0 ? "vfb-field-chevron-container-sub" : null
      ])
    }, [
      rn(o, {
        class: "vfb-field-chevron",
        icon: ["fas", "chevron-down"]
      })
    ], 2)) : se("", !0),
    de("div", WHe, [
      typeof n.option.icon == "string" ? (U(), ee("img", {
        key: 0,
        class: "vfb-field-icon",
        src: n.option.icon,
        title: n.option.typeLabel
      }, null, 8, KHe)) : (U(), Ae(o, {
        key: 1,
        class: "vfb-field-icon",
        icon: n.option.icon || ["fas", "shapes"]
      }, null, 8, ["icon"]))
    ]),
    de("div", jHe, [
      de("div", QHe, zt(n.option.primaryLabel), 1),
      n.option.secondaryLabel ? (U(), ee("div", XHe, zt(n.option.secondaryLabel), 1)) : se("", !0)
    ])
  ], 2);
}
const JHe = /* @__PURE__ */ Zs(zHe, [["render", ZHe]]);
function e7e() {
  return [
    () => ({
      config(e) {
        e.theme.templates.TextElement_elementSelector = Ll($He), e.theme.templates.TextareaElement_elementSelector = Ll(HHe), e.theme.classes.TextElement.inputContainer_elementSelector = "relative", e.theme.classes.TextareaElement.inputContainer_elementSelector = "relative";
        let t = e.theme.classes.TextElement.$inputContainer, n = e.theme.classes.TextareaElement.$inputContainer;
        return e.theme.classes.TextElement.$inputContainer = (r, i) => t(r, i).concat(
          i.elementSelector ? r.inputContainer_elementSelector : null
        ), e.theme.classes.TextareaElement.$inputContainer = (r, i) => n(r, i).concat(
          i.elementSelector ? r.inputContainer_elementSelector : null
        ), e;
      }
    }),
    () => ({
      apply: ["TextElement", "TextareaElement"],
      props: {
        elementSelector: {
          type: Boolean,
          required: !1,
          default: !1
        },
        elementSelectorOptions: {
          type: Object,
          required: !1,
          default: () => ({})
        }
      },
      setup(e, t, n) {
        const { elementSelector: r, elementSelectorOptions: i, builder: a } = De(e);
        if (!(r != null && r.value))
          return n;
        const o = he(!1), s = he(null), l = he(-1), u = N(() => m(n.form$.value.builderPagedTree || [])), c = N(() => i.value.excludeSelf || !1), d = N(() => n.form$.value.selectedElement), f = N(() => ({
          schema: {
            field: {
              type: "select",
              inputType: "search",
              canClear: !1,
              canDeselect: !1,
              search: !0,
              items: u.value,
              autocomplete: "off",
              placeholder: "Search field",
              trackBy: "searchLabel",
              caret: !1,
              object: !0,
              noResultsText: "No elements found",
              addClass: {
                select: {
                  search: "vfb-field-input",
                  dropdown: "vfb-fields-container vfb-fields-dropdown",
                  option: u.value.some((y) => y.container && (y == null ? void 0 : y.children.length)) ? "" : "vfb-field-container-no-nesting",
                  optionPointed: "vfb-field-pointed",
                  optionSelected: "vfb-field-selected",
                  optionSelectedPointed: "vfb-field-pointed vfb-field-selected",
                  groupLabel: "vfb-field-group-label-container"
                }
              },
              slots: {
                option: Ll(JHe)
              },
              onChange(y) {
                o.value = !1;
                let g = l.value + y.path.length, E = n.input.value, S = E.value.slice(0, l.value), C = E.value.slice(l.value), T = S;
                T += y.path, ["}", "|"].indexOf(C.charAt(0)) === -1 && (T += "}");
                let O = T;
                T += C, n.update(T), n.input.value.focus(), Ut(() => {
                  if (h(n.input.value, g + 1), ["text", "search"].indexOf(n.input.value.type) !== -1) {
                    const R = document.createElement("span");
                    R.style.visibility = "hidden", R.style.position = "absolute", R.style.whiteSpace = "nowrap", R.style.font = n.input.value.font, document.body.appendChild(R), R.textContent = O, n.input.value.scrollLeft = R.offsetWidth - n.input.value.clientWidth, document.body.removeChild(R);
                  } else n.autosize && n.autosize();
                });
              },
              onClose(y, g) {
                o.value = !1, Ut(() => {
                  h(n.input.value, l.value);
                });
              }
            }
          }
        })), h = (y, g) => {
          if (y)
            if (y.createTextRange) {
              let E = y.createTextRange();
              E.move("character", g), E.select();
            } else
              y.selectionStart ? (y.focus(), y.setSelectionRange(g, g)) : y.focus();
        }, m = (y = pagedTree.value, g = 0) => {
          let E = [];
          return Oa.forEach(y, (S) => {
            let C = S.root ? "__VUEFORM_ROOT__" : S.path.replace(/\.0\b/g, () => ".*");
            if (c.value && C === d.value.replace(/\.0\b/g, () => ".*"))
              return;
            let T = {
              ...S,
              path: C,
              level: g,
              value: C,
              searchLabel: `${S.primaryLabel || ""} ${S.secondaryLabel || ""}`
            };
            E.push(T), ["group", "object", "tabs", "steps", "root"].indexOf(S.type) !== -1 && (E = E.concat(m(S.children || [], g + 1) || [])), S.type === "list" && S.children[0].type === "object" && d.value.match(new RegExp(`^${S.path.replace(".", "\\.")}\\.`)) && (E = E.concat(m(S.children[0].children || [], g + 1) || []));
          }), E;
        }, v = (y) => {
          y.key === "Backspace" && y.target.value == "" && (y.preventDefault(), o.value = !1, Ut(() => {
            h(n.input.value, l.value);
          }));
        };
        return {
          ...n,
          handleKeydown: (y) => {
            y.key === "{" ? (o.value = !0, l.value = y.target.selectionStart + 1, setTimeout(() => {
              let g = s.value.el$("field");
              g.input.focus(), g.input.open(), g.input.input.addEventListener("keydown", v);
            }, 0)) : t.emit("keydown", y, n.el$);
          },
          elementSelector$: s,
          selectingElement: o,
          elementSelectorForm: f
        };
      }
    })
  ];
}
const rF = async (e, t) => {
  for (let n = 0; n < (Oa.isPlainObject(e) ? Oa.values(e) : e).length; n++) {
    let r = Oa.isPlainObject(e) ? Oa.keys(e)[n] : n;
    await t(e[r], r, e);
  }
}, t7e = (e, t) => {
  if (!t)
    return;
  const n = t.split("."), r = n.length, i = (a, o = 1) => {
    const s = n[o - 1];
    if (r === o)
      return a[s];
    if (r > o) {
      let l = a[n[o - 1]], u = l.type === "list" ? { 0: l.element } : l.schema;
      return i(u, o + 1);
    }
  };
  return i(e);
};
function n7e() {
  return [
    ...e7e(),
    () => ({
      config(e) {
        return e.presets = {
          ...e.presets,
          "preview-form": {},
          "props-form": {
            removeClasses: {
              FormElements: {
                container_sm: ["form-gap-y-gutter-sm"]
              }
            },
            replaceClasses: {
              ToggleElement: {
                wrapper: {
                  "items-start": "vfb-util-props-toggle-wrapper"
                }
              },
              TagsElement: {
                select: {
                  tag: {
                    "whitespace-nowrap": "vfb-util-props-tags"
                  }
                }
              }
            },
            addClasses: {
              ElementLabel: {
                wrapper: "leading-snug"
              },
              SliderElement: {
                container: "vfb-config-slider"
              },
              ToggleElement: {
                container: "vfb-config-toggle"
              },
              ListElement: {
                remove: "vfb-config-list-remove"
              }
            }
          },
          separator: {
            addClasses: {
              ElementLayout: {
                container: "vfb-util-props-separator"
              }
            }
          },
          "separator-top": {
            addClasses: {
              ElementLayout: {
                container: "vfb-util-props-separator-top"
              }
            }
          },
          "prop-multiline": {
            addClasses: {
              ElementAddon: {
                container: "pt-2 mt-px"
              }
            },
            replaceClasses: {
              ElementAddon: {
                container: {
                  "items-center": "items-start"
                }
              }
            }
          },
          "prop-toggle": {
            addClasses: {
              ElementLabel: {
                container: "flex items-center"
              }
            }
          },
          "prop-subtitle": {
            addClasses: {
              StaticElement: {
                container: "vfb-util-props-subtitle"
              }
            }
          },
          "prop-subtitle-no-m": {
            addClasses: {
              StaticElement: {
                container: "vfb-util-props-subtitle-no-m"
              }
            }
          },
          "prop-list-subtitle": {
            addClasses: {
              ElementLabel: {
                container: "vfb-util-props-list-subtitle"
              }
            }
          },
          "prop-list": {
            addClasses: {
              ElementLabel: {
                container: "vfb-util-props-list-label"
              },
              ListElement: {
                add: "vfb-util-props-list-add"
              },
              ElementLayout: {
                container: "vfb-util-props-list-layout"
              }
            },
            removeClasses: {
              ListElement: {
                listItem_sm: ["form-gap-gutter-sm"]
              }
            }
          },
          "prop-list-object": {
            removeClasses: {
              ObjectElement: {
                wrapper_sm: ["form-gap-gutter-sm"]
              }
            }
          },
          "prop-list-el": {
            removeClasses: {
              TextElement: {
                inputContainer: ["form-border-width-input"],
                inputContainer_sm: ["form-radius-input-sm"],
                inputContainer_default: ["form-bg-input", "hover:form-bg-input-hover", "focused:form-bg-input-focus", "focused:form-ring"],
                inputContainer_success: ["form-bg-input-success", "focused:form-ring"]
              },
              TTextElement: {
                inputContainer: ["form-border-width-input"],
                inputContainer_sm: ["form-radius-input-sm"],
                inputContainer_default: ["form-bg-input", "hover:form-bg-input-hover", "focused:form-bg-input-focus", "focused:form-ring"],
                inputContainer_success: ["form-bg-input-success", "focused:form-ring"]
              },
              TextareaElement: {
                inputContainer: ["form-border-width-input"],
                inputContainer_sm: ["form-radius-large-sm"],
                inputContainer_default: ["form-bg-input", "hover:form-bg-input-hover", "focused:form-bg-input-focus", "focused:form-ring"],
                inputContainer_success: ["form-bg-input-success", "focused:form-ring"]
              },
              TTextareaElement: {
                inputContainer: ["form-border-width-input"],
                inputContainer_sm: ["form-radius-large-sm"],
                inputContainer_default: ["form-bg-input", "hover:form-bg-input-hover", "focused:form-bg-input-focus", "focused:form-ring"],
                inputContainer_success: ["form-bg-input-success", "focused:form-ring"]
              },
              DateElement: {
                inputContainer: ["form-border-width-input"],
                inputContainer_sm: ["form-radius-input-sm"],
                inputContainer_default: ["form-bg-input", "hover:form-bg-input-hover", "focused:form-bg-input-focus", "focused:form-ring"],
                inputContainer_success: ["form-bg-input-success", "focused:form-ring"]
              },
              SelectElement: {
                input: ["form-border-width-input"],
                input_sm: ["form-radius-input-sm"],
                input_default: ["form-bg-input", "hover:form-bg-input-hover", "focused:form-bg-input-focus", "focused:form-ring"],
                input_success: ["form-bg-input-success", "focused:form-ring"],
                select: {
                  container: ["form-border-width-input"],
                  container_sm: ["form-radius-input-sm"],
                  container_default: ["form-bg-input", "hover:form-bg-input-hover", "focused:form-bg-input-focus", "focused:form-ring"],
                  container_success: ["form-bg-input-success", "focused:form-ring"]
                }
              },
              TagsElement: {
                select: {
                  container: ["form-border-width-input"],
                  container_sm: ["form-radius-input-sm"],
                  container_default: ["form-bg-input", "hover:form-bg-input-hover", "focused:form-bg-input-focus", "focused:form-ring"],
                  container_success: ["form-bg-input-success", "focused:form-ring"]
                }
              }
            },
            addClasses: {
              TextElement: {
                inputContainer: "vfb-util-props-list-el-input",
                inputContainer_default: "vfb-util-props-list-el-input-default",
                inputContainer_success: "vfb-util-props-list-el-input-success"
              },
              TTextElement: {
                inputContainer: "vfb-util-props-list-el-input",
                inputContainer_default: "vfb-util-props-list-el-input-default",
                inputContainer_success: "vfb-util-props-list-el-input-success"
              },
              TextareaElement: {
                inputContainer: "vfb-util-props-list-el-input",
                inputContainer_default: "vfb-util-props-list-el-input-default",
                inputContainer_success: "vfb-util-props-list-el-input-success"
              },
              TTextareaElement: {
                inputContainer: "vfb-util-props-list-el-input",
                inputContainer_default: "vfb-util-props-list-el-input-default",
                inputContainer_success: "vfb-util-props-list-el-input-success"
              },
              DateElement: {
                inputContainer: "vfb-util-props-list-el-input",
                inputContainer_default: "vfb-util-props-list-el-input-default",
                inputContainer_success: "vfb-util-props-list-el-input-success"
              },
              SelectElement: {
                input: "vfb-util-props-list-el-select",
                input_default: "vfb-util-props-list-el-select-default",
                input_success: "vfb-util-props-list-el-select-success",
                select: {
                  container: "vfb-util-props-list-el-select-container",
                  container_default: "vfb-util-props-list-el-select-container-default",
                  container_success: "vfb-util-props-list-el-select-container-success"
                }
              },
              TagsElement: {
                select: {
                  container: "vfb-util-props-list-el-select-container",
                  container_default: "vfb-util-props-list-el-select-container-default",
                  container_success: "vfb-util-props-list-el-select-container-success"
                }
              }
            }
          },
          "prop-group": {
            addClasses: {
              GroupElement: {
                container: "vfb-util-props-group"
              }
            }
          },
          colorpicker: {
            addClasses: {
              TextElement: {
                inputContainer: "vfb-util-colorpicker-input"
              },
              ElementAddon: {
                container: "vfb-util-colorpicker-addon"
              }
            }
          },
          number: {
            replaceClasses: {
              TextElement: {
                input_sm: {
                  "form-p-input-sm": "vfb-util-number-input"
                }
              },
              ElementAddon: {
                container: {
                  "form-color-addon": "vfb-util-number-addon"
                }
              }
            }
          },
          "tabs-outline": {
            overrideClasses: {
              RadiogroupRadio: {
                wrapper_selected: "vfb-util-tabs-outline-selected",
                wrapper_unselected: "vfb-util-tabs-outline-unselected"
              }
            }
          },
          "tabs-outline-gray": {
            overrideClasses: {
              RadiogroupRadio: {
                wrapper_selected: "vfb-util-tabs-outline-gray-selected",
                wrapper_unselected: "vfb-util-tabs-outline-gray-unselected"
              }
            }
          },
          "tabs-2": {
            addClasses: {
              RadiogroupElement: {
                wrapper: "vfb-util-grid-cols-12"
              },
              RadiogroupRadio: {
                container: "vfb-util-col-span-6"
              }
            }
          },
          "tabs-3": {
            addClasses: {
              RadiogroupElement: {
                wrapper: "vfb-util-grid-cols-12"
              },
              RadiogroupRadio: {
                container: "vfb-util-col-span-4"
              }
            }
          },
          "tabs-4": {
            addClasses: {
              RadiogroupElement: {
                wrapper: "vfb-util-grid-cols-12"
              },
              RadiogroupRadio: {
                container: "vfb-util-col-span-3"
              }
            }
          },
          "tabs-6": {
            addClasses: {
              RadiogroupElement: {
                wrapper: "vfb-util-grid-cols-12"
              },
              RadiogroupRadio: {
                container: "vfb-util-col-span-2"
              }
            }
          },
          "tabs-12": {
            addClasses: {
              RadiogroupElement: {
                wrapper: "vfb-util-grid-cols-12"
              },
              RadiogroupRadio: {
                container: "vfb-util-col-span-1"
              }
            }
          },
          "tabs-tiny": {
            replaceClasses: {
              RadiogroupRadio: {
                wrapper_sm: {
                  "form-text-sm": "vfb-util-tabs-tiny"
                }
              },
              CheckboxgroupCheckbox: {
                wrapper_sm: {
                  "form-text-sm": "vfb-util-tabs-tiny"
                }
              },
              ElementLabel: {
                wrapper: {
                  "leading-snug": "leading-none"
                }
              }
            }
          },
          "tabs-small": {
            replaceClasses: {
              RadiogroupRadio: {
                wrapper_sm: {
                  "form-text-sm": "vfb-util-tabs-small"
                }
              }
            }
          }
        }, e;
      }
    }),
    () => ({
      apply: ["Vueform"],
      emits: [
        "rename-page",
        "add-page",
        "remove-page",
        "move-page",
        "move-to-page",
        "move-element",
        "add-element",
        "remove-pages",
        "select-page",
        "event"
      ],
      props: {
        selectedElement: {
          required: !1,
          type: String
        },
        selectedPage: {
          type: String,
          required: !1
        },
        draggingElement: {
          required: !1,
          type: [null, String, Boolean]
        },
        draggingPage: {
          required: !1,
          type: [null, String, Boolean]
        },
        builder: {
          required: !1,
          type: Boolean,
          default: !1
        },
        nesting: {
          required: !1,
          type: Boolean,
          default: !1
        },
        draggedSchema: {
          required: !1,
          type: Object
        },
        elementTypes: {
          required: !1,
          type: Object,
          default: () => ({})
        },
        builderTree: {
          required: !1,
          type: Array,
          default: () => []
        },
        builderFlatTree: {
          required: !1,
          type: Array,
          default: () => []
        },
        builderPagedTree: {
          required: !1,
          type: Array,
          default: () => []
        },
        device: {
          required: !1,
          type: String
        }
      },
      setup(e, t, n) {
        const { builder: r, schema: i, draggedSchema: a, tabs: o, steps: s } = De(e);
        if (!r.value)
          return n;
        const l = En("subscribeOnce"), u = he(!1), c = N(() => o.value && Object.keys(o.value).length), d = N(() => s.value && Object.keys(s.value).length), f = N(() => {
          var P, Y, L, x, I, k;
          return c.value ? !((L = (Y = (P = n.tabs$.value) == null ? void 0 : P.current$) == null ? void 0 : Y.elements) != null && L.length) : d.value ? !((k = (I = (x = n.steps$.value) == null ? void 0 : x.current$) == null ? void 0 : I.elements) != null && k.length) : !Object.keys(i.value).length;
        }), h = N(() => c.value ? n.tabs$.value.current$ : d.value ? n.steps$.value.current$ : void 0), m = N(() => c.value || d.value), v = N(() => c.value ? "tab" : d.value ? "step" : void 0);
        return {
          ...n,
          isEmpty: f,
          droppingFirst: u,
          hasPages: m,
          pageType: v,
          reset: (P = !0) => {
            Oa.each(n.elements$.value, (Y) => {
              Y.isStatic || Y.reset(P);
            }), n.steps$.value !== null && n.steps$.value.reset(), n.tabs$.value !== null && n.tabs$.value.reset(), n.fire("reset");
          },
          submit: async () => {
            if (!n.isDisabled.value && (await n.validate(), !n.invalid.value)) {
              n.preparing.value = !0;
              try {
                await n.prepareElements(), typeof n.options.value.prepare == "function" && await n.options.value.prepare(n.form$.value);
              } catch (P) {
                n.fire("error", P, { type: "prepare" }, n.form$.value), console.error(P);
                return;
              } finally {
                n.preparing.value = !1;
              }
              n.fire("submit", n.form$.value);
            }
          },
          handleSelectPage: (P) => {
            t.emit("select-page", P);
          },
          handleRenamePage: (P, Y) => {
            t.emit("rename-page", P, Y);
          },
          handleRemovePage: (P) => {
            t.emit("remove-page", P);
          },
          handleAddPage: () => {
            t.emit("add-page");
          },
          handleRemovePages: () => {
            t.emit("remove-pages");
          },
          handleMovePage: (P, Y, L) => {
            t.emit("move-page", P, Y, L);
          },
          handleMoveToPage: (P, Y, L) => {
            t.emit("move-to-page", P, Y, L);
          },
          handleDragOver: (P) => {
            P.preventDefault(), a.value && ["tabs", "steps"].indexOf(a.value.type) === -1 && (u.value = !0);
          },
          handleDragLeave: () => {
            u.value = !1;
          },
          handleDrop: (P) => {
            var x;
            let Y = P.dataTransfer.getData("schema"), L = P.dataTransfer.getData("path");
            if (L && h.value) {
              let I = h.value.name;
              if (L && L.match(/\./)) {
                l("moved-element", (B) => {
                  Ut(() => {
                    t.emit("move-to-page", I, B);
                  });
                });
                let k = (x = h.value.elements) == null ? void 0 : x.pop();
                n.el$(L).$emit("move-element", L, "after", k);
              } else L ? t.emit("move-to-page", I, L) : (l("added-element", (k, B) => {
                Ut(() => {
                  t.emit("move-to-page", I, B);
                });
              }), t.emit("add-element", JSON.parse(Y), "after"));
            } else Y && t.emit("add-element", JSON.parse(Y), "after");
            u.value = !1;
          }
        };
      }
    }),
    () => ({
      apply: ["Vueform"],
      emits: [
        "update-builder",
        "download",
        "closed-changed",
        "announce"
      ],
      props: {
        pluginSettings: {
          required: !1,
          type: Boolean,
          default: !1
        },
        name: {
          type: String,
          required: !1
        },
        sections: {
          required: !1,
          type: Object
        },
        fieldOptions: {
          required: !1,
          type: Object,
          default: () => ({})
        },
        closed: {
          required: !1,
          type: Array,
          default: () => []
        },
        k: {
          required: !1,
          type: String,
          default: "key"
        },
        lazy: {
          required: !1,
          type: Boolean,
          default: !1
        },
        excludeFields: {
          required: !1,
          type: Array,
          default: () => []
        }
      },
      setup(e, t, n) {
        const { pluginSettings: r } = De(e);
        if (!r.value)
          return n;
        const i = n, {
          sections: a,
          fieldOptions: o,
          closed: s,
          name: l,
          lazy: u,
          excludeFields: c
        } = De(e), d = Bt("BuilderIcon"), f = Bt("BuilderTooltip"), h = En("config$"), m = En("storage$"), v = he({
          size: "sm",
          displayErrors: !1,
          forceLabels: !1,
          presets: ["props-form"]
        }), b = he([...s.value]), y = he([
          ...Object.keys(a.value).filter((B) => a.value[B].collapsible === !1 || s.value.indexOf(B) === -1)
        ]), g = he(!1), E = he([]), S = he([]), C = he({}), T = he([]), O = N(() => {
          let B = [];
          return Object.keys(a.value).forEach((W) => {
            const Z = a.value[W];
            Object.keys(Z.fields).forEach((V) => {
              const K = Z.fields[V];
              c.value.indexOf(`${W}.${V}`) === -1 && B.push(new K.type({
                ...o.value,
                loading: g,
                emit: t.emit,
                icon: d,
                tooltip: f,
                section: Z.name,
                field: K,
                closedSections: b,
                closeAll: x,
                openAll: I,
                config$: h.value
              }));
            });
          }), B;
        }), R = N(() => {
          let B = {};
          return Object.keys(a.value).forEach((W) => {
            const Z = a.value[W];
            let V = {};
            Object.keys(Z.fields).forEach((K) => {
              const ne = Z.fields[K];
              let Ee = new ne.type({
                ...o.value,
                loading: g,
                emit: t.emit,
                icon: d,
                tooltip: f,
                section: W,
                field: ne,
                closedSections: b,
                closeAll: x,
                openAll: I,
                config$: h.value
              });
              c.value.indexOf(`${W}.${K}`) === -1 && (V = {
                ...V,
                ...Ee.finalSchema
              });
            }), B[W] = {
              ...Z,
              schema: V
            };
          }), B;
        }), D = async (B, W) => {
          W || (C.value = Oa.cloneDeep(B)), await Ut();
          let Z = {};
          g.value = !0;
          let V = O.value;
          W && (V = V.filter((Ee) => Ee.section === W)), await rF(V, async (Ee) => {
            Z = {
              ...Z,
              ...await Ee.load(B, i) || {}
            }, Ee.watchers && Object.keys(Ee.watchers).forEach((oe) => {
              Ee.watchers[oe].forEach((ae) => {
                let pe = Array.isArray(ae[0]) ? ae[0] : [ae[0]];
                pe = pe.map((Ye) => N(() => Oa.get(i.data.value, Ye)));
                let Se = (Ye, nt) => {
                  ae[1](
                    i.el$(oe),
                    Array.isArray(ae[0]) ? Ye : Ye[0],
                    Array.isArray(ae[0]) ? nt : nt[0]
                  );
                }, Re = et(pe, Se);
                E.value.push(Re), S.value.push({
                  target: pe,
                  elementPath: oe,
                  watcherFunction: Se
                });
              });
            });
          });
          let K = W ? i.el$(W) : i, ne = W ? K.children$ : K.elements$.value;
          K.load(Z), Object.keys(ne).forEach((Ee) => {
            let oe = ne[Ee];
            oe.isStatic || oe.messageBag.clear();
          }), setTimeout(() => {
            g.value = !1;
          }, 0);
        }, q = () => {
          g.value = !0, $(), i.clear(), setTimeout(() => {
            g.value = !1;
          }, 0);
        }, $ = () => {
          E.value.forEach((B) => B()), E.value = [], S.value = [];
        }, P = (B) => {
          b.value.push(B), t.emit("announce", "COLLAPSED");
        }, Y = async (B) => {
          y.value.indexOf(B) === -1 ? (T.value.push(B), setTimeout(() => {
            y.value = y.value.concat([B]), b.value = b.value.filter((W) => W !== B), Ut(() => {
              document.querySelectorAll(".vfb-panels-container textarea[data-autogrow]").forEach((W) => {
                n.form$.value.$vueform.services.autosize.update(W);
              });
            }), t.emit("announce", "EXPANDED");
          }, 0)) : (b.value = b.value.filter((W) => W !== B), t.emit("announce", "EXPANDED"));
        }, L = (B) => {
          b.value.indexOf(B) !== -1 ? Y(B) : P(B);
        }, x = () => {
          b.value = [
            ...Object.keys(a.value).filter((B) => a.value[B].collapsible !== !1)
          ];
        }, I = () => {
          b.value = [], Object.keys(a.value).filter((W) => y.value.indexOf(W) === -1).forEach((W) => {
            T.value.push(W);
          }), setTimeout(() => {
            y.value = [
              ...Object.keys(a.value).filter((W) => a.value[W].collapsible !== !1)
            ];
          }, 0);
        }, k = () => {
          "activeElement" in document && document.activeElement.blur();
        };
        return et(b, (B) => {
          u.value || (m.value.set(`${l.value}-closed`, JSON.stringify(B)), t.emit("closed-changed", B));
        }, { deep: !0 }), et(l, (B) => {
          B && m.value.get(`${B}-closed`) && (b.value = JSON.parse(m.value.get(`${B}-closed`)));
        }, { immediate: !1 }), et(y, async (B, W) => {
          if (!u.value) {
            Oa.difference(B, W).forEach((Z) => {
              T.value = T.value.filter((V) => V !== Z);
            });
            return;
          }
          await Ut(), await rF(Oa.difference(B, W), async (Z) => {
            T.value.push(Z), await D(C.value, Z), T.value = T.value.filter((V) => V !== Z);
          });
        }, { immediate: !1 }), On(() => {
          u.value || m.value.get(`${l.value}-closed`) && (b.value = JSON.parse(m.value.get(`${l.value}-closed`)));
        }), {
          ...i,
          vueform: v,
          onceOpened: y,
          closedSections: b,
          resolvedSections: R,
          loadSettings: D,
          clearSettings: q,
          clearWatchers: $,
          toggle: L,
          closeAll: x,
          openAll: I,
          handleFormSubmit: k,
          watchers: E,
          watchersLog: S,
          loadingSections: T
        };
      }
    }),
    () => ({
      apply: ["FormElements"],
      props: {
        draggingElement: {
          required: !1,
          type: [null, String, Boolean]
        },
        draggingPage: {
          required: !1,
          type: [null, String, Boolean]
        },
        draggedSchema: {
          required: !1,
          type: Object
        }
      }
    }),
    () => ({
      apply: ["FormTabs", "FormSteps"],
      emits: [
        "rename-page",
        "add-page",
        "remove-pages",
        "remove-page",
        "move-page",
        "move-to-page",
        "add-element",
        "select-page",
        "start-moving"
      ],
      props: {
        draggingElement: {
          required: !1,
          type: [null, String, Boolean]
        },
        draggingPage: {
          required: !1,
          type: [null, String, Boolean]
        },
        draggedSchema: {
          required: !1,
          type: Object
        },
        moving: {
          required: !1,
          type: [Boolean, Object],
          default: !1
        },
        pointer: {
          required: !1,
          type: Object,
          default: () => ({})
        }
      },
      setup(e, t, n) {
        if (!n.form$.value.builder)
          return n;
        const r = En("announce"), i = he(null);
        return {
          ...n,
          wrapper: i,
          handleRenamePage: (m, v) => {
            t.emit("rename-page", m, v);
          },
          handleAddClick: () => {
            t.emit("add-page"), Ut(() => {
              n.last$.value.edit();
            });
          },
          handleRemoveClick: () => {
            t.emit("remove-pages"), t.emit("select-page", null), r("REMOVED");
          },
          handleRemovePage: (m) => {
            t.emit("remove-page", m);
          },
          handleMovePage: (m, v, b) => {
            t.emit("move-page", m, v, b);
          },
          handleMoveToPage: (m, v, b) => {
            t.emit("move-to-page", m, v, b);
          },
          handleAddElement: (m, v, b) => {
            t.emit("add-element", m, v, b);
          },
          handleSelectPage: (m) => {
            t.emit("select-page", m);
          },
          handleStartMoving: (m, v) => {
            t.emit("start-moving", m, v);
          }
        };
      }
    }),
    () => ({
      apply: ["FormTab"],
      setup(e, t, n) {
        if (!n.form$.value.builder)
          return n;
        const r = he("This will also remove all elements within the tab. Are you sure?"), i = N(() => n.tabLabel.value), a = N(() => {
          var s;
          return (s = n.tabs$.value) == null ? void 0 : s.tabs$;
        });
        return {
          ...n,
          removeConfirm: r,
          pageLabel: i,
          pages$: a,
          goTo: (s) => {
            n.form$.value.tabs$.goTo(s);
          }
        };
      }
    }),
    () => ({
      apply: ["FormStep"],
      setup(e, t, n) {
        if (!n.form$.value.builder)
          return n;
        const r = he("This will also remove all elements within the step. Are you sure?"), i = N(() => n.stepLabel.value), a = N(() => {
          var s;
          return (s = n.steps$.value) == null ? void 0 : s.steps$;
        });
        return {
          ...n,
          removeConfirm: r,
          pageLabel: i,
          pages$: a,
          goTo: (s) => {
            n.form$.value.steps$.goTo(s);
          }
        };
      }
    }),
    () => ({
      apply: ["FormTab", "FormStep"],
      props: {
        builder: {
          type: Object,
          required: !1
        },
        draggingElement: {
          required: !1,
          type: [null, String, Boolean]
        },
        draggingPage: {
          required: !1,
          type: [null, String, Boolean]
        },
        draggedSchema: {
          required: !1,
          type: Object
        },
        moving: {
          required: !1,
          type: [Boolean, Object],
          default: !1
        },
        pointer: {
          required: !1,
          type: Object,
          default: () => ({})
        }
      },
      emits: [
        "rename-page",
        "remove-page",
        "move-page",
        "move-to-page",
        "add-element",
        "select-page",
        "start-moving"
      ],
      setup(e, t, n) {
        if (!n.form$.value.builder)
          return n;
        const { name: r, draggingPage: i, moving: a, pointer: o } = De(e), s = En("subscribeOnce"), l = En("announce"), u = he(!1), c = he(null), d = he(null), f = he(null), h = N(() => i.value === r.value), m = N(() => n.form$.value.selectedPage), v = N(() => r.value === m.value), b = N(() => a.value ? a.value.source === "preview" && a.value.type === "page" && a.value.path === r.value : !1), y = N(() => a.value.source === "preview" && o.value.path === r.value && (a.value.type === "page" || o.value.type === "page")), g = N(() => parseInt(r.value.replace("page", ""))), E = N(() => Object.keys(n.form$.value[`${S.value}s`]).length), S = N(() => n.form$.value.pageType), C = () => {
          u.value = !0, c.value = n.pageLabel.value, Ut(() => {
            d.value.select();
          });
        }, T = () => {
          u.value = !1, t.emit("rename-page", r.value, c.value);
        }, O = () => {
          u.value = !1;
        }, R = (ne) => {
          n.form$.value.$el.querySelector(`[data-page="${ne}"]`).focus();
        }, D = (ne) => {
          ne.stopPropagation(), n.form$.value.editorMode && !ne.ctrlKey && !ne.metaKey && (t.emit("select-page", r.value), n.form$.value.$emit("select-element", null)), n.select();
        }, q = (ne) => {
          n.form$.value.editorMode && (["Enter"].indexOf(ne.key) !== -1 ? (ne.preventDefault(), ne.stopPropagation(), t.emit("select-page", r.value), n.form$.value.$emit("select-element", null), setTimeout(() => {
            ne.target.closest(".vfb-builder").querySelector(".vfb-config-panel-container-page").focus();
          }, 1e3), l("CONFIG_PANEL_OPENED")) : [" "].indexOf(ne.key) !== -1 ? (ne.preventDefault(), ne.stopPropagation(), l("PAGE_GRABBED", {
            page: n.pageLabel.value
          }), t.emit("start-moving", {
            path: r.value,
            source: "preview",
            type: "page"
          })) : ["ArrowRight"].indexOf(ne.key) !== -1 ? (ne.preventDefault(), E.value > g.value + 1 && R(`page${g.value + 1}`)) : ["ArrowLeft"].indexOf(ne.key) !== -1 ? (ne.preventDefault(), g.value > 0 && R(`page${g.value - 1}`)) : ["Delete"].indexOf(ne.key) !== -1 && (ne.preventDefault(), L())), ["Enter", " "].indexOf(ne.key) !== -1 && n.select();
        }, $ = () => {
          n.form$.value.editorMode && C();
        }, P = () => {
          t.emit("select-page", r.value);
        }, Y = () => {
        }, L = () => {
          Object.keys(n.children$.value).length && Object.keys(n.pages$.value).length > 1 && !confirm(n.removeConfirm.value) || t.emit("remove-page", r.value);
        };
        return {
          ...n,
          handleKeyDown: q,
          handleDoubleClick: $,
          handleEditClick: P,
          handleConditionsClick: Y,
          handleRemoveClick: L,
          handleClearClick: () => {
          },
          handleInputBlur: () => {
            u.value && T();
          },
          handleInputKeyDown: (ne) => {
            ne.key === "Enter" && T(), ne.key === "Escape" && (ne.preventDefault(), O());
          },
          handleDragStart: (ne) => {
            ne.dataTransfer.setData("page", r.value), ne.dataTransfer.effectAllowed = "move", ne.dataTransfer.dropEffect = "move";
          },
          handleDragEnd: () => {
          },
          handleDragOver: (ne, Ee) => {
            ne.preventDefault(), f.value = Ee, Ee === "middle" && (n.goTo(r.value), m.value !== r.value && t.emit("select-page", r.value));
          },
          handleDragLeave: () => {
            f.value = null;
          },
          handleDrop: (ne, Ee) => {
            var pe;
            f.value = null;
            let oe = ne.dataTransfer.getData("page") || void 0;
            if (oe) {
              t.emit("move-page", oe, Ee, r.value);
              return;
            }
            let ae = ne.dataTransfer.getData("path") || void 0;
            if (ae && ae.match(/\./)) {
              s("moved-element", (Re) => {
                Ut(() => {
                  t.emit("move-to-page", r.value, Re);
                });
              });
              let Se = (pe = n.form$.value.tabs$.current$.elements) == null ? void 0 : pe.pop();
              n.form$.value.el$(ae).$emit("move-element", ae, "after", Se);
            } else if (ae)
              t.emit("move-to-page", r.value, ae);
            else {
              let Se = JSON.parse(ne.dataTransfer.getData("schema"));
              s("added-element", (Re, Ye) => {
                Ut(() => {
                  t.emit("move-to-page", r.value, Ye);
                });
              }), t.emit("add-element", Se, "after");
            }
          },
          handleClick: D,
          edit: C,
          pointed: y,
          beingMoved: b,
          isSelected: v,
          selectedPage: m,
          beingDragged: h,
          highlighted: f,
          editing: u,
          editLabel: c,
          input: d
        };
      }
    }),
    () => ({
      apply: ["FormStepsControls"],
      emits: [
        "select-page"
      ],
      setup(e, t, n) {
        if (!n.form$.value.builder)
          return n;
        const r = N(() => !!n.form$.value.selectedPage);
        return {
          ...n,
          isSelected: r,
          handleClick: () => {
            n.form$.value.editorMode && Ut(() => {
              t.emit("select-page", n.form$.value.steps$.current$.name);
            });
          }
        };
      }
    }),
    () => ({
      apply: ["HiddenElement"],
      props: {
        classes: {
          required: !1,
          type: Object,
          default: () => ({})
        },
        columnsClasses: {
          required: !1,
          type: Object,
          default: () => ({
            container: "col-span-12",
            innerContainer: "col-span-12",
            wrapper: "col-span-12"
          })
        },
        visible: {
          required: !1,
          type: Boolean,
          default: !0
        }
      }
    }),
    () => ({
      apply: ["StaticElement"],
      props: {
        sourcePath: {
          type: String,
          required: !1
        },
        emptyText: {
          type: String,
          required: !1
        },
        handleEvent: {
          type: Function,
          required: !1
        },
        conditionType: {
          type: String,
          required: !1
        }
      }
    }),
    () => ({
      apply: ["FileElement"],
      setup(e, t, n) {
        if (!n.form$.value.builder)
          return n;
        const r = {
          request: (i) => new Promise((a) => {
            let { data: o } = i;
            return a(i.url == "/vueform/file/remove" ? !0 : {
              data: o.get([...o.keys()][0]).name
            });
          }),
          CancelToken: { source: () => ({ token: "token" }) },
          token: null,
          isCancel: () => !1,
          __CUSTOM__: !0
        };
        return et(n.axios, (i) => {
          i.__CUSTOM__ || (n.axios.value = r);
        }), {
          ...n,
          axios: r
        };
      }
    }),
    () => ({
      apply: ["ListElement"],
      setup(e, t, n) {
        if (!n.form$.value.builder)
          return n;
        const { element: r, initial: i } = De(e), a = N(() => {
          var l;
          return n.isObject.value && n.prototype.value.schema || !n.isObject.value && r && ((l = r.value) == null ? void 0 : l.type);
        }), o = N(() => {
          var l, u, c;
          if (!(!r || !((l = r.value) != null && l.type) || !((c = (u = r.value) == null ? void 0 : u.builder) != null && c.type)))
            return "(repeat)";
        });
        return {
          ...n,
          hasPrototype: a,
          childName: o,
          reset: (l = !0) => {
            n.value.value = l ? Oa.cloneDeep(n.defaultValue.value) : Oa.cloneDeep(n.nullValue.value), n.resetValidators();
            let u = n.form$.value.editorMode ? 1 : i.value;
            if (!n.value.value.length && u > 0) {
              for (let c = 0; c < u; c++)
                n.add();
              Ut(() => {
                n.children$Array.value.forEach((c) => {
                  c.reset();
                });
              });
            }
            Ut(() => {
              n.refreshOrderStore(n.value.value);
            });
          }
        };
      }
    }),
    () => ({
      apply: ["ObjectElement", "GroupElement"],
      setup(e, t, n) {
        return n.form$.value.builder ? {
          ...n,
          reset: (i = !0) => {
            Oa.each(n.children$.value, (a) => {
              a.isStatic || a.reset(i);
            });
          }
        } : n;
      }
    }),
    () => ({
      apply: ["ObjectElement", "GroupElement", "ListElement"],
      setup(e, t, n) {
        if (!n.form$.value.builder)
          return n;
        const r = N(() => n.el$.value.path.split(".").length - 1);
        return {
          ...n,
          nestingLevel: r
        };
      }
    }),
    () => ({
      apply: ["FormElements", "Vueform", "GroupElement", "ObjectElement", "ListElement"],
      emits: [
        "add-element",
        "move-element",
        "select-element",
        "clone-element",
        "remove-element",
        "resize-element",
        "set-dragged-schema",
        "announce",
        "start-moving"
      ],
      props: {
        editorMode: {
          required: !1,
          type: Boolean,
          default: !1
        },
        moving: {
          required: !1,
          type: [Boolean, Object],
          default: !1
        },
        pointer: {
          required: !1,
          type: Object,
          default: () => ({})
        }
      },
      setup(e, t, n) {
        return n.form$.value.builder ? {
          ...n,
          handleAddElement: (f, h, m) => {
            t.emit("add-element", f, h, m);
          },
          handleMoveElement: (f, h, m) => {
            t.emit("move-element", f, h, m);
          },
          handleSelectElement: (f) => {
            t.emit("select-element", f);
          },
          handleCloneElement: (f) => {
            t.emit("clone-element", f);
          },
          handleRemoveElement: (f) => {
            t.emit("remove-element", f);
          },
          handleResizeElement: (f, h) => {
            t.emit("resize-element", f, h);
          },
          handleSetDraggedSchema: (f) => {
            t.emit("set-dragged-schema", f);
          },
          handleAnnounce: (f, h) => {
            t.emit("announce", f, h);
          },
          handleStartMoving: (f, h) => {
            t.emit("start-moving", f, h);
          }
        } : n;
      }
    }),
    () => ({
      apply: /^[a-zA-Z]*Element$/,
      emits: [
        "add-element",
        "move-element",
        "select-element",
        "clone-element",
        "remove-element",
        "resize-element",
        "set-dragged-schema",
        "announce",
        "start-moving"
      ],
      props: {
        builder: {
          required: !1,
          type: Object
        },
        droppable: {
          required: !1,
          type: Boolean,
          default: !0
        },
        cloneable: {
          required: !1,
          type: Boolean,
          default: !0
        },
        displayName: {
          required: !1,
          type: String
        },
        allowSiblings: {
          required: !1,
          type: Boolean,
          default: !0
        },
        draggingElement: {
          required: !1,
          type: [null, String, Boolean]
        },
        draggingPage: {
          required: !1,
          type: [null, String, Boolean]
        },
        draggedSchema: {
          required: !1,
          type: Object
        },
        moving: {
          required: !1,
          type: [Boolean, Object],
          default: !1
        },
        pointer: {
          required: !1,
          type: Object,
          default: () => ({})
        }
      },
      setup(e, t, n) {
        if (!n.form$.value.builder)
          return n;
        const { droppable: r, draggingElement: i, moving: a, pointer: o } = De(e), s = he(!1), l = N(() => i.value === n.path.value), u = N(() => !l.value && r.value), c = N(() => {
          var f;
          return a.value && a.value.source === "preview" && ((f = o.value) == null ? void 0 : f.path) === n.path.value;
        });
        return {
          ...n,
          announce: (f, h) => {
            t.emit("announce", f, h);
          },
          highlighted: s,
          beingDragged: l,
          Droppable: u,
          pointed: c
        };
      }
    }),
    () => ({
      apply: "ElementLayout",
      emits: [
        "add-element",
        "select-element",
        "clone-element",
        "remove-element",
        "resize-element",
        "announce"
      ],
      props: {
        draggingElement: {
          required: !1,
          type: [null, String, Boolean]
        },
        draggingPage: {
          required: !1,
          type: [null, String, Boolean]
        },
        draggedSchema: {
          required: !1,
          type: Object
        }
      },
      setup(e, t, n) {
        var Rt, sn;
        if (!n.form$.value.builder)
          return n;
        const r = En("config$"), i = he(!1), a = he(!1), o = he(0), s = he(null), l = he(0), u = he(!1), c = he(!1);
        let d = he({
          default: "default",
          tablet: (Rt = r.value.breakpoints) == null ? void 0 : Rt.tablet.breakpoint,
          desktop: (sn = r.value.breakpoints) == null ? void 0 : sn.desktop.breakpoint
        });
        const f = N(() => n.el$.value.form$.device || "default"), h = N(() => d.value[f.value]), m = N(() => Object.values(d.value)), v = N(() => {
          if (!n.el$.value.moving)
            return !1;
          let me = n.el$.value.moving;
          return me.source === "preview" && me.type === "element" && me.path === b.value;
        }), b = N(() => n.el$.value.path), y = N(() => n.el$.value.form$.flatTree || []), g = N(() => n.form$.value.selectedElement), E = N(() => y.value.indexOf(b.value)), S = N(() => g.value === b.value), C = N({
          get() {
            return n.el$.value.highlighted;
          },
          set(me) {
            n.el$.value.highlighted = me;
          }
        }), T = N(() => k(n.el$.value)), O = N(() => {
          var me;
          return !T.value.remove && ((me = n.el$.value.builder) == null ? void 0 : me.remove) !== !1;
        }), R = N(() => {
          var me;
          return !T.value.clone && ((me = n.el$.value.builder) == null ? void 0 : me.clone) !== !1 && n.el$.value.cloneable;
        }), D = N(() => {
          var me;
          return ((me = n.el$.value.builder) == null ? void 0 : me.edit) !== !1;
        }), q = N(() => {
          var me;
          return !T.value.move && ((me = n.el$.value.builder) == null ? void 0 : me.move) !== !1;
        }), $ = N(() => {
          var me;
          return !T.value.resize && ((me = n.el$.value.builder) == null ? void 0 : me.resize) !== !1;
        }), P = N(() => ["object", "group"].indexOf(n.el$.value.type) !== -1 ? !Object.keys(n.el$.value.children).length && (!n.el$.value.draggedSchema || ["tabs", "steps"].indexOf(n.el$.value.draggedSchema.type) === -1) : ["list"].indexOf(n.el$.value.type) !== -1 ? !n.el$.value.hasPrototype && (!n.el$.value.draggedSchema || ["list", "tabs", "steps"].indexOf(n.el$.value.draggedSchema.type) === -1) : !1), Y = N(() => !n.el$.value.draggedSchema || ["tabs", "steps"].indexOf(n.el$.value.draggedSchema.type) === -1), L = N(() => !1), x = N(() => b.value.replace(/\./g, " / ")), I = N(() => n.form$.value.pageType), k = (me) => {
          let He = {
            remove: !1,
            clone: !1,
            move: !1,
            edit: !1,
            resize: !1
          };
          if (!me || ["object", "group", "list"].indexOf(me.type) === -1)
            return He;
          let tt = ["object", "group"].indexOf(me.type) !== -1 ? me.schema || {} : me.element ? { 0: me.element } : {};
          return Object.values(tt).forEach((ot) => {
            var xn, kt, Dn, gn, Vn;
            if (Object.values(He).some((X) => !X)) {
              let X = ["object", "group", "list"].indexOf(ot.type) !== -1 ? k(ot) : {
                remove: ((xn = ot.builder) == null ? void 0 : xn.remove) === !1,
                clone: ((kt = ot.builder) == null ? void 0 : kt.clone) === !1,
                move: ((Dn = ot.builder) == null ? void 0 : Dn.move) === !1,
                edit: ((gn = ot.builder) == null ? void 0 : gn.edit) === !1,
                resize: ((Vn = ot.builder) == null ? void 0 : Vn.resize) === !1
              };
              Object.keys(He).forEach((te) => {
                X[te] && (He[te] = !0);
              });
            }
          }), He;
        }, B = () => {
          Tt("ELEMENT_GRABBED", {
            element: x.value
          }), u.value = !0;
        }, W = () => {
          u.value = !1;
        }, Z = () => {
          n.el$.value.$emit("start-moving", {
            path: b.value,
            source: "preview",
            type: "element"
          });
        }, V = () => {
          W();
        }, K = () => {
          let me = n.el$.value.columnsClassesService.cols, He;
          if (me[h.value])
            He = me[h.value].container;
          else {
            let tt = [...m.value].reverse(), ot = tt.indexOf(h.value);
            tt.forEach((xn, kt) => {
              kt > ot && !He && me[xn] && (He = me[xn].container);
            }), He || (He = me.default.container);
          }
          l.value = He, o.value = l.value, c.value = !0, Re(b.value).focus();
        }, ne = (me) => {
          W(), c.value = !1;
          let He, tt = {};
          o.value !== l.value && me ? (He = "SAVED_WIDTH", tt = {
            width: l.value
          }, pe()) : (He = "CANCEL_WIDTH", tt = {
            width: o.value
          }, !me && l.value !== o.value && ae(o.value, !1)), Tt(He, tt);
        }, Ee = () => {
          ne(!0);
        }, oe = () => {
          ne(!1);
        }, ae = (me, He = !0) => {
          if (me !== l.value) {
            l.value = me;
            let tt = n.el$.value.columns;
            h.value === "default" ? tt && typeof tt == "object" ? tt.container || tt.label || tt.wrapper ? tt.container = me : (tt.default || (tt.default = {}), tt.default.container = me) : tt = { container: me } : tt && typeof tt == "object" ? tt[h.value] ? tt[h.value].container = me : tt.container || tt.label || tt.wrapper ? tt = {
              default: tt,
              [h.value]: {
                container: me
              }
            } : tt[h.value] = {
              container: me
            } : tt = {
              [h.value]: {
                container: me
              }
            }, n.el$.value.updateColumns(tt), He && Tt("WIDTH_CHANGED", { width: me });
          }
        }, pe = () => {
          n.el$.value.$emit("resize-element", b.value, l.value);
        }, Se = (me) => {
          let He = y.value.indexOf(b.value), tt = y.value[He + me] || (me > 0 ? y.value[y.value.length - 1] : y.value[0]);
          if (tt)
            return tt;
        }, Re = (me) => n.el$.value.form$.$el.querySelector(`[data-path="${me}"]`), Ye = (me) => {
          let He = Re(me);
          He == null || He.focus(), nt(me) && (ut(me), Ut(() => {
            var tt;
            (tt = Re(me)) == null || tt.focus();
          }));
        }, nt = (me) => window.getComputedStyle(Re(me)).getPropertyValue("display") === "none" && n.form$.value.hasPages, ut = (me) => {
          let He = Object.keys(n.form$.value[`${I.value}s`]).find((tt) => {
            let ot = n.form$.value[`${I.value}s`][tt], xn = me.split(".")[0];
            return ot.elements.indexOf(xn) !== -1;
          });
          n.form$.value[`${I.value}s$`].goTo(He);
        }, Tt = (me, He) => {
          n.el$.value.announce(me, He);
        }, Ot = () => {
          D.value && (n.el$.value.$emit("select-element", b.value), n.form$.value.$emit("select-page", null));
        }, Xt = () => {
          n.el$.value.$emit("clone-element", b.value);
        }, We = () => {
          n.el$.value.$emit("remove-element", b.value);
        }, st = function(me) {
          me.dataTransfer.effectAllowed = "move";
          let He = t7e(n.form$.value.options.schema, b.value);
          me.dataTransfer.setData("schema", JSON.stringify(He)), me.dataTransfer.setData("path", b.value), n.el$.value.$emit("set-dragged-schema", He);
        }, Pt = (me) => {
          n.el$.value.$emit("set-dragged-schema", null);
        }, Ke = (me, He) => {
          me.preventDefault(), !(!n.el$.value.Droppable || n.el$.value.beingDragged) && (C.value = He);
        }, Je = (me) => {
          setTimeout(() => {
            C.value = null;
          }, 0);
        }, Be = (me, He) => {
          if (me.preventDefault(), !n.el$.value.Droppable)
            return;
          C.value = null;
          const tt = me.dataTransfer.getData("path") || void 0;
          if (tt)
            n.el$.value.$emit("move-element", tt, He, b.value);
          else {
            const ot = JSON.parse(me.dataTransfer.getData("schema"));
            n.el$.value.$emit("add-element", ot, He, b.value);
          }
        }, pt = (me) => {
          me.dataTransfer.effectAllowed = "move", l.value = 0;
          let He = me.path || (me == null ? void 0 : me.composedPath());
          s.value = {
            from: He[1].getBoundingClientRect().x,
            to: He[1].getBoundingClientRect().x + He[2].getBoundingClientRect().width
          }, c.value = !0;
        }, ft = (me) => {
          let He = s.value.to - s.value.from, tt = me.x - s.value.from, ot = Math.round(tt / He * 12);
          ot < 1 && (ot = 1), ot > 12 && (ot = 12), me.x === 0 && me.y === 0 || ae(ot, !1);
        }, Ze = (me) => {
          c.value = !1, pe();
        }, _t = () => {
          a.value = !0;
        }, St = () => {
          a.value = !1;
        }, we = (me) => {
          let He = l.value - 1;
          me && (He = l.value > 6 ? 6 : 1), ae(He);
        }, je = (me) => {
          let He = l.value + 1;
          me && (He = l.value < 6 ? 6 : 12), ae(He);
        }, yt = (me) => {
          if (!(!a.value && !c.value))
            if (c.value)
              me.key === "ArrowLeft" && l.value > 1 ? (me.preventDefault(), me.stopPropagation(), we(me.shiftKey)) : me.key === "ArrowRight" && l.value < 12 ? (me.preventDefault(), me.stopPropagation(), je(me.shiftKey)) : [" ", "Enter"].indexOf(me.key) !== -1 ? (me.preventDefault(), me.stopPropagation(), Ee()) : ["Escape"].indexOf(me.key) !== -1 ? (me.preventDefault(), me.stopPropagation(), oe()) : ["Tab"].indexOf(me.key) !== -1 && oe();
            else if (u.value)
              if (["ArrowLeft", "ArrowRight"].indexOf(me.key) !== -1) {
                if (me.preventDefault(), me.stopPropagation(), !$.value)
                  return;
                K(), me.key === "ArrowLeft" && l.value > 1 ? we(me.shiftKey) : me.key === "ArrowRight" && l.value < 12 && je(me.shiftKey);
              } else if (["ArrowUp", "ArrowDown"].indexOf(me.key) !== -1) {
                if (me.preventDefault(), me.stopPropagation(), !q.value)
                  return;
                Z();
              } else [" ", "Escape"].indexOf(me.key) !== -1 ? (me.preventDefault(), me.stopPropagation(), W()) : ["Tab"].indexOf(me.key) !== -1 && W();
            else if (me.key === "Enter") {
              if (me.preventDefault(), me.stopPropagation(), !D.value)
                return;
              Ot(), Tt("CONFIG_PANEL_OPENED"), setTimeout(() => {
                me.target.closest(".vfb-builder").querySelector(".vfb-config-panel-container-element").focus();
              }, 1e3);
            } else if (me.key === " ") {
              if (me.preventDefault(), me.stopPropagation(), !q.value && !$.value)
                return;
              B();
            } else if (me.key === "Delete") {
              if (me.preventDefault(), me.stopPropagation(), !O.value)
                return;
              We(), y.value[E.value + 1] ? Ye(Se(1)) : y.value[E.value - 1] ? Ye(Se(-1)) : me.target.closest(".vfb-builder").querySelector(".vfb-preview-wrapper").focus();
            } else if (me.key === "ArrowDown" && me.shiftKey) {
              me.preventDefault(), me.stopPropagation();
              let He = n.el$.value.form$.$el.querySelector(".vfb-preview-form > div > .vfb-preview-element-container:last-of-type");
              He && He.focus();
            } else if (me.key === "ArrowUp" && me.shiftKey) {
              me.preventDefault(), me.stopPropagation();
              let He = n.el$.value.form$.$el.querySelector(".vfb-preview-form > div > .vfb-preview-element-container:first-of-type");
              He && He.focus();
            } else me.key === "ArrowDown" ? (me.preventDefault(), me.stopPropagation(), Ye(Se(1))) : me.key === "ArrowUp" && (me.preventDefault(), me.stopPropagation(), Ye(Se(-1)));
        };
        return et(v, (me, He) => {
          me || V();
        }), {
          ...n,
          ariaLabel: x,
          editing: u,
          resizing: c,
          moving: v,
          highlighted: C,
          hovered: i,
          focused: a,
          isSelected: S,
          canRemove: O,
          canClone: R,
          canEdit: D,
          canMove: q,
          canResize: $,
          canDragInside: P,
          canDragSibling: Y,
          hideDragLine: L,
          lastWidth: l,
          childRestrictions: T,
          handleOverlayClick: Ot,
          handleCloneClick: Xt,
          handleRemoveClick: We,
          handleFocus: _t,
          handleBlur: St,
          handleKeydown: yt,
          handleDragOver: Ke,
          handleDragLeave: Je,
          handleDrop: Be,
          handleDragStart: st,
          handleDragEnd: Pt,
          handleResizeDragStart: pt,
          handleResizeDrag: ft,
          handleResizeDragEnd: Ze
        };
      }
    })
  ];
}
const r7e = {
  theme: LHe,
  locales: { en: B8e },
  locale: "en",
  apiKey: "u5uk-fzq2-u141-vxww-9zzs",
  plugins: [
    n7e
  ]
}, Qi = WT(d8e);
Qi.use(_8e);
Qi.use(b8e);
Qi.use(D$e);
Qi.use(qq);
Qi.use(F8e);
Qi.use(y_, r7e);
Qi.component("DocTabs", xO);
Qi.component("MarkdownView", jq);
Qi.component("Chat", wO);
Qi.component("MDForm", Kp);
Qi.component("GameIO", Qq);
Qi.component("TwoPaneLayout", Xq);
Qi.component("ResizableLayout", C8e);
Qi.component("Vueform", y_.Form);
Qi.mount("#app");
const x7e = {
  install(e, t) {
    e.use(qq), e.use(websocketPlugin), e.use(userDataPlugin);
  }
};
export {
  yl as $,
  Qf as A,
  Zce as B,
  Jce as C,
  Wce as D,
  Nie as E,
  v7e as F,
  ide as G,
  fue as H,
  R1 as I,
  d3 as J,
  cm as K,
  rre as L,
  m3 as M,
  o7e as N,
  Pc as O,
  E1 as P,
  fte as Q,
  la as R,
  Na as S,
  sde as T,
  m7e as U,
  Vle as V,
  SB as W,
  W1 as X,
  Ule as Y,
  jo as Z,
  w1 as _,
  Xce as a,
  j3 as a$,
  Rp as a0,
  ck as a1,
  cre as a2,
  Qle as a3,
  cue as a4,
  Xu as a5,
  Gse as a6,
  Mse as a7,
  Yse as a8,
  Hse as a9,
  l7e as aA,
  g7e as aB,
  h7e as aC,
  c7e as aD,
  Qt as aE,
  Ko as aF,
  pm as aG,
  Od as aH,
  zg as aI,
  Rse as aJ,
  fle as aK,
  fm as aL,
  Wg as aM,
  Sse as aN,
  W3 as aO,
  Aoe as aP,
  Ooe as aQ,
  Cu as aR,
  Uk as aS,
  Roe as aT,
  $1 as aU,
  Coe as aV,
  Noe as aW,
  Rd as aX,
  Hl as aY,
  Mk as aZ,
  U1 as a_,
  eB as aa,
  K_ as ab,
  Z_ as ac,
  Kg as ad,
  yoe as ae,
  B1 as af,
  nB as ag,
  J3 as ah,
  Ese as ai,
  gse as aj,
  Pse as ak,
  Vse as al,
  tv as am,
  C7e as an,
  ede as ao,
  dm as ap,
  xt as aq,
  $t as ar,
  I1 as as,
  u7e as at,
  f7e as au,
  _k as av,
  gk as aw,
  p7e as ax,
  d7e as ay,
  s7e as az,
  Qce as b,
  vC as b0,
  Moe as b1,
  iT as b2,
  yue as b3,
  cte as b4,
  x7e as b5,
  wO as b6,
  xO as b7,
  Kp as b8,
  Qq as b9,
  C8e as ba,
  jq as bb,
  Xq as bc,
  qq as bd,
  b8e as be,
  D$e as bf,
  Qc as bg,
  Bm as bh,
  $m as bi,
  Z1 as c,
  Lp as d,
  Di as e,
  Qg as f,
  jce as g,
  ja as h,
  HB as i,
  H1 as j,
  _ue as k,
  Ft as l,
  XF as m,
  Rie as n,
  uue as o,
  dB as p,
  nue as q,
  Yce as r,
  Kce as s,
  T7e as t,
  c3 as u,
  Ete as v,
  hue as w,
  Hoe as x,
  F1 as y,
  Jf as z
};
//# sourceMappingURL=main-8k4vh9Gc.js.map
